-- +-------------------------------------------------+
-- © 2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
-- +-------------------------------------------------+
-- $Id: bibliportail.sql,v 1.4.2.1 2016-03-30 08:50:46 mbertin Exp $

-- MySQL dump 10.14  Distrib 5.5.36-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: bibli
-- ------------------------------------------------------
-- Server version	5.5.36-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `abo_liste_lecture`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abo_liste_lecture (
  num_empr int(8) unsigned NOT NULL DEFAULT '0',
  num_liste int(8) unsigned NOT NULL DEFAULT '0',
  etat int(1) unsigned NOT NULL DEFAULT '0',
  commentaire mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_empr,num_liste)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abo_liste_lecture`
--

LOCK TABLES abo_liste_lecture WRITE;
/*!40000 ALTER TABLE abo_liste_lecture DISABLE KEYS */;
/*!40000 ALTER TABLE abo_liste_lecture ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_abts`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_abts (
  abt_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  abt_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  base_modele_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  base_modele_id int(11) NOT NULL DEFAULT '0',
  num_notice int(11) NOT NULL DEFAULT '0',
  date_debut date NOT NULL DEFAULT '0000-00-00',
  date_fin date NOT NULL DEFAULT '0000-00-00',
  fournisseur int(11) NOT NULL DEFAULT '0',
  destinataire varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cote varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  typdoc_id int(11) NOT NULL DEFAULT '0',
  exemp_auto int(11) NOT NULL DEFAULT '0',
  location_id int(11) NOT NULL DEFAULT '0',
  section_id int(11) NOT NULL DEFAULT '0',
  lender_id int(11) NOT NULL DEFAULT '0',
  statut_id int(11) NOT NULL DEFAULT '0',
  codestat_id int(11) NOT NULL DEFAULT '0',
  type_antivol int(11) NOT NULL DEFAULT '0',
  duree_abonnement int(11) NOT NULL DEFAULT '0',
  abt_numeric int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (abt_id),
  KEY index_num_notice (num_notice),
  KEY i_date_fin (date_fin)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_abts`
--

LOCK TABLES abts_abts WRITE;
/*!40000 ALTER TABLE abts_abts DISABLE KEYS */;
/*!40000 ALTER TABLE abts_abts ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_abts_modeles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_abts_modeles (
  modele_id int(11) NOT NULL DEFAULT '0',
  abt_id int(11) NOT NULL DEFAULT '0',
  num int(11) NOT NULL DEFAULT '0',
  vol int(11) NOT NULL DEFAULT '0',
  tome int(11) NOT NULL DEFAULT '0',
  delais int(11) NOT NULL DEFAULT '0',
  critique int(11) NOT NULL DEFAULT '0',
  num_statut_general smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (modele_id,abt_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_abts_modeles`
--

LOCK TABLES abts_abts_modeles WRITE;
/*!40000 ALTER TABLE abts_abts_modeles DISABLE KEYS */;
/*!40000 ALTER TABLE abts_abts_modeles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_grille_abt`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_grille_abt (
  id_bull int(11) NOT NULL AUTO_INCREMENT,
  num_abt int(10) unsigned NOT NULL DEFAULT '0',
  date_parution date NOT NULL DEFAULT '0000-00-00',
  modele_id int(11) NOT NULL DEFAULT '0',
  `type` int(11) NOT NULL DEFAULT '0',
  nombre int(11) NOT NULL DEFAULT '0',
  numero int(11) NOT NULL DEFAULT '0',
  ordre int(11) NOT NULL DEFAULT '0',
  state int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_bull),
  KEY num_abt (num_abt)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_grille_abt`
--

LOCK TABLES abts_grille_abt WRITE;
/*!40000 ALTER TABLE abts_grille_abt DISABLE KEYS */;
/*!40000 ALTER TABLE abts_grille_abt ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_grille_modele`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_grille_modele (
  num_modele int(10) unsigned NOT NULL DEFAULT '0',
  date_parution date NOT NULL DEFAULT '0000-00-00',
  type_serie int(11) NOT NULL DEFAULT '0',
  numero varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  nombre_recu int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (num_modele,date_parution,type_serie),
  KEY num_modele (num_modele)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_grille_modele`
--

LOCK TABLES abts_grille_modele WRITE;
/*!40000 ALTER TABLE abts_grille_modele DISABLE KEYS */;
/*!40000 ALTER TABLE abts_grille_modele ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_modeles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_modeles (
  modele_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  modele_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_notice int(10) unsigned NOT NULL DEFAULT '0',
  num_periodicite int(10) unsigned NOT NULL DEFAULT '0',
  duree_abonnement int(11) NOT NULL DEFAULT '0',
  date_debut date DEFAULT NULL,
  date_fin date DEFAULT NULL,
  days varchar(7) COLLATE utf8_unicode_ci NOT NULL DEFAULT '1111111',
  day_month varchar(31) COLLATE utf8_unicode_ci NOT NULL DEFAULT '1111111111111111111111111111111',
  week_month varchar(6) COLLATE utf8_unicode_ci NOT NULL DEFAULT '111111',
  week_year varchar(54) COLLATE utf8_unicode_ci NOT NULL DEFAULT '111111111111111111111111111111111111111111111111111111',
  month_year varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '111111111111',
  num_cycle int(11) NOT NULL DEFAULT '0',
  num_combien int(11) NOT NULL DEFAULT '0',
  num_increment int(11) NOT NULL DEFAULT '0',
  num_date_unite int(11) NOT NULL DEFAULT '0',
  num_increment_date int(11) NOT NULL DEFAULT '0',
  num_depart int(11) NOT NULL DEFAULT '0',
  vol_actif int(11) NOT NULL DEFAULT '0',
  vol_increment int(11) NOT NULL DEFAULT '0',
  vol_date_unite int(11) NOT NULL DEFAULT '0',
  vol_increment_numero int(11) NOT NULL DEFAULT '0',
  vol_increment_date int(11) NOT NULL DEFAULT '0',
  vol_cycle int(11) NOT NULL DEFAULT '0',
  vol_combien int(11) NOT NULL DEFAULT '0',
  vol_depart int(11) NOT NULL DEFAULT '0',
  tom_actif int(11) NOT NULL DEFAULT '0',
  tom_increment int(11) NOT NULL DEFAULT '0',
  tom_date_unite int(11) NOT NULL DEFAULT '0',
  tom_increment_numero int(11) NOT NULL DEFAULT '0',
  tom_increment_date int(11) NOT NULL DEFAULT '0',
  tom_cycle int(11) NOT NULL DEFAULT '0',
  tom_combien int(11) NOT NULL DEFAULT '0',
  tom_depart int(11) NOT NULL DEFAULT '0',
  format_aff varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  format_periode varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (modele_id),
  KEY num_notice (num_notice),
  KEY num_periodicite (num_periodicite)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_modeles`
--

LOCK TABLES abts_modeles WRITE;
/*!40000 ALTER TABLE abts_modeles DISABLE KEYS */;
/*!40000 ALTER TABLE abts_modeles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `abts_periodicites`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE abts_periodicites (
  periodicite_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  duree int(11) NOT NULL DEFAULT '0',
  unite int(11) NOT NULL DEFAULT '0',
  retard_periodicite int(4) DEFAULT '0',
  seuil_periodicite int(4) DEFAULT '0',
  consultation_duration int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (periodicite_id)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `abts_periodicites`
--

LOCK TABLES abts_periodicites WRITE;
/*!40000 ALTER TABLE abts_periodicites DISABLE KEYS */;
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (1,'Mensuel',1,1,7,4,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (2,'Hebdomadaire',7,0,4,2,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (3,'Quotidien',1,0,3,1,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (4,'Trimestriel',3,1,30,15,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (5,'Bimestriel',2,1,30,15,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (6,'Annuel',1,2,365,180,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (7,'Quinzomadaire',14,0,14,7,0);
INSERT INTO abts_periodicites (periodicite_id, libelle, duree, unite, retard_periodicite, seuil_periodicite, consultation_duration) VALUES (8,'Semestriel',6,1,180,60,0);
/*!40000 ALTER TABLE abts_periodicites ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `acces_profiles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE acces_profiles (
  prf_id int(2) unsigned NOT NULL AUTO_INCREMENT,
  prf_type int(1) unsigned NOT NULL DEFAULT '1',
  prf_name varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  prf_rule blob NOT NULL,
  prf_hrule mediumtext COLLATE utf8_unicode_ci NOT NULL,
  prf_used int(2) unsigned NOT NULL DEFAULT '0',
  dom_num int(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (prf_id),
  KEY prf_type (prf_type),
  KEY prf_name (prf_name),
  KEY dom_num (dom_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `acces_profiles`
--

LOCK TABLES acces_profiles WRITE;
/*!40000 ALTER TABLE acces_profiles DISABLE KEYS */;
/*!40000 ALTER TABLE acces_profiles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `acces_rights`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE acces_rights (
  dom_num int(2) unsigned NOT NULL DEFAULT '0',
  usr_prf_num int(2) unsigned NOT NULL DEFAULT '0',
  res_prf_num int(2) unsigned NOT NULL DEFAULT '0',
  dom_rights int(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (dom_num,usr_prf_num,res_prf_num),
  KEY dom_num (dom_num),
  KEY usr_prf_num (usr_prf_num),
  KEY res_prf_num (res_prf_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `acces_rights`
--

LOCK TABLES acces_rights WRITE;
/*!40000 ALTER TABLE acces_rights DISABLE KEYS */;
/*!40000 ALTER TABLE acces_rights ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `actes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE actes (
  id_acte int(8) unsigned NOT NULL AUTO_INCREMENT,
  date_acte date NOT NULL DEFAULT '0000-00-00',
  numero varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  type_acte int(3) unsigned NOT NULL DEFAULT '0',
  statut int(3) unsigned NOT NULL DEFAULT '0',
  date_paiement date NOT NULL DEFAULT '0000-00-00',
  num_paiement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_entite int(5) unsigned NOT NULL DEFAULT '0',
  num_fournisseur int(5) unsigned NOT NULL DEFAULT '0',
  num_contact_livr int(8) unsigned NOT NULL DEFAULT '0',
  num_contact_fact int(8) unsigned NOT NULL DEFAULT '0',
  num_exercice int(8) unsigned NOT NULL DEFAULT '0',
  commentaires mediumtext COLLATE utf8_unicode_ci NOT NULL,
  reference varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_acte mediumtext COLLATE utf8_unicode_ci NOT NULL,
  devise varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaires_i mediumtext COLLATE utf8_unicode_ci NOT NULL,
  date_valid date NOT NULL DEFAULT '0000-00-00',
  date_ech date NOT NULL DEFAULT '0000-00-00',
  nom_acte varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_acte),
  KEY num_fournisseur (num_fournisseur),
  KEY `date` (date_acte),
  KEY num_entite (num_entite),
  KEY numero (numero)
) ENGINE=MyISAM AUTO_INCREMENT=23 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `actes`
--

LOCK TABLES actes WRITE;
/*!40000 ALTER TABLE actes DISABLE KEYS */;
/*!40000 ALTER TABLE actes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_session`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE admin_session (
  userid int(10) unsigned NOT NULL DEFAULT '0',
  `session` mediumblob,
  PRIMARY KEY (userid)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_session`
--

LOCK TABLES admin_session WRITE;
/*!40000 ALTER TABLE admin_session DISABLE KEYS */;
/*!40000 ALTER TABLE admin_session ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `analysis`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE analysis (
  analysis_bulletin int(8) unsigned NOT NULL DEFAULT '0',
  analysis_notice int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (analysis_bulletin,analysis_notice),
  KEY analysis_notice (analysis_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `analysis`
--

LOCK TABLES analysis WRITE;
/*!40000 ALTER TABLE analysis DISABLE KEYS */;
INSERT INTO analysis (analysis_bulletin, analysis_notice) VALUES (7,125);
INSERT INTO analysis (analysis_bulletin, analysis_notice) VALUES (7,126);
INSERT INTO analysis (analysis_bulletin, analysis_notice) VALUES (8,127);
INSERT INTO analysis (analysis_bulletin, analysis_notice) VALUES (11,133);
/*!40000 ALTER TABLE analysis ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `arch_emplacement`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE arch_emplacement (
  archempla_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  archempla_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (archempla_id)
) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `arch_emplacement`
--

LOCK TABLES arch_emplacement WRITE;
/*!40000 ALTER TABLE arch_emplacement DISABLE KEYS */;
INSERT INTO arch_emplacement (archempla_id, archempla_libelle) VALUES (1,'Présentoir');
INSERT INTO arch_emplacement (archempla_id, archempla_libelle) VALUES (2,'Rayonnages');
INSERT INTO arch_emplacement (archempla_id, archempla_libelle) VALUES (3,'Réserve');
INSERT INTO arch_emplacement (archempla_id, archempla_libelle) VALUES (4,'En ligne');
/*!40000 ALTER TABLE arch_emplacement ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `arch_statut`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE arch_statut (
  archstatut_id int(8) NOT NULL AUTO_INCREMENT,
  archstatut_gestion_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  archstatut_opac_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  archstatut_visible_opac tinyint(1) unsigned NOT NULL DEFAULT '1',
  archstatut_visible_opac_abon tinyint(1) unsigned NOT NULL DEFAULT '1',
  archstatut_visible_gestion tinyint(1) unsigned NOT NULL DEFAULT '1',
  archstatut_class_html varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (archstatut_id)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `arch_statut`
--

LOCK TABLES arch_statut WRITE;
/*!40000 ALTER TABLE arch_statut DISABLE KEYS */;
INSERT INTO arch_statut (archstatut_id, archstatut_gestion_libelle, archstatut_opac_libelle, archstatut_visible_opac, archstatut_visible_opac_abon, archstatut_visible_gestion, archstatut_class_html) VALUES (1,'Empruntable','Empruntable',1,0,1,'statutnot1');
INSERT INTO arch_statut (archstatut_id, archstatut_gestion_libelle, archstatut_opac_libelle, archstatut_visible_opac, archstatut_visible_opac_abon, archstatut_visible_gestion, archstatut_class_html) VALUES (2,'Consultation sur place','Consultation sur place',1,0,0,'statutnot1');
INSERT INTO arch_statut (archstatut_id, archstatut_gestion_libelle, archstatut_opac_libelle, archstatut_visible_opac, archstatut_visible_opac_abon, archstatut_visible_gestion, archstatut_class_html) VALUES (3,'Texte intégral','Texte intégral',1,0,0,'');
/*!40000 ALTER TABLE arch_statut ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `arch_type`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE arch_type (
  archtype_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  archtype_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (archtype_id)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `arch_type`
--

LOCK TABLES arch_type WRITE;
/*!40000 ALTER TABLE arch_type DISABLE KEYS */;
INSERT INTO arch_type (archtype_id, archtype_libelle) VALUES (1,'Imprimé');
INSERT INTO arch_type (archtype_id, archtype_libelle) VALUES (2,'Electronique');
/*!40000 ALTER TABLE arch_type ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `audit`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE audit (
  type_obj int(1) NOT NULL DEFAULT '0',
  object_id int(10) unsigned NOT NULL DEFAULT '0',
  user_id int(8) unsigned NOT NULL DEFAULT '0',
  user_name varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  type_modif int(1) NOT NULL DEFAULT '1',
  quand timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  type_user int(1) unsigned NOT NULL DEFAULT '0',
  info text COLLATE utf8_unicode_ci NOT NULL,
  KEY type_obj (type_obj),
  KEY object_id (object_id),
  KEY user_id (user_id),
  KEY type_modif (type_modif)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `audit`
--

LOCK TABLES audit WRITE;
/*!40000 ALTER TABLE audit DISABLE KEYS */;
/*!40000 ALTER TABLE audit ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `aut_link`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE aut_link (
  aut_link_from int(2) NOT NULL DEFAULT '0',
  aut_link_from_num int(11) NOT NULL DEFAULT '0',
  aut_link_to int(2) NOT NULL DEFAULT '0',
  aut_link_to_num int(11) NOT NULL DEFAULT '0',
  aut_link_type varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  aut_link_reciproc int(1) NOT NULL DEFAULT '0',
  aut_link_comment varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (aut_link_from,aut_link_from_num,aut_link_to,aut_link_to_num,aut_link_type)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `aut_link`
--

LOCK TABLES aut_link WRITE;
/*!40000 ALTER TABLE aut_link DISABLE KEYS */;
/*!40000 ALTER TABLE aut_link ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `author_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE author_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `author_custom`
--

LOCK TABLES author_custom WRITE;
/*!40000 ALTER TABLE author_custom DISABLE KEYS */;
/*!40000 ALTER TABLE author_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `author_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE author_custom_lists (
  author_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  author_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  author_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (author_custom_champ),
  KEY editorial_champ_list_value (author_custom_champ,author_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `author_custom_lists`
--

LOCK TABLES author_custom_lists WRITE;
/*!40000 ALTER TABLE author_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE author_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `author_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE author_custom_values (
  author_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  author_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  author_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  author_custom_text text COLLATE utf8_unicode_ci,
  author_custom_integer int(11) DEFAULT NULL,
  author_custom_date date DEFAULT NULL,
  author_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (author_custom_champ),
  KEY editorial_custom_origine (author_custom_origine),
  KEY i_acv_st (author_custom_small_text),
  KEY i_acv_t (author_custom_text(255)),
  KEY i_acv_i (author_custom_integer),
  KEY i_acv_d (author_custom_date),
  KEY i_acv_f (author_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `author_custom_values`
--

LOCK TABLES author_custom_values WRITE;
/*!40000 ALTER TABLE author_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE author_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authorities_sources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authorities_sources (
  id_authority_source int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_authority int(10) unsigned NOT NULL DEFAULT '0',
  authority_number varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  authority_type varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_origin_authority int(10) unsigned NOT NULL DEFAULT '0',
  authority_favorite int(10) unsigned NOT NULL DEFAULT '0',
  import_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  update_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (id_authority_source)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authorities_sources`
--

LOCK TABLES authorities_sources WRITE;
/*!40000 ALTER TABLE authorities_sources DISABLE KEYS */;
/*!40000 ALTER TABLE authorities_sources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `authors` (
  author_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  author_type enum('70','71','72') COLLATE utf8_unicode_ci NOT NULL DEFAULT '70',
  author_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_rejete varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_date varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_see mediumint(8) unsigned NOT NULL DEFAULT '0',
  author_web varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_author mediumtext COLLATE utf8_unicode_ci,
  author_comment mediumtext COLLATE utf8_unicode_ci,
  author_lieu varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_ville varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_pays varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_subdivision varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_numero varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  author_import_denied int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (author_id),
  KEY author_see (author_see),
  KEY author_name (author_name),
  KEY author_rejete (author_rejete)
) ENGINE=MyISAM AUTO_INCREMENT=94 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authors`
--

LOCK TABLES authors WRITE;
/*!40000 ALTER TABLE authors DISABLE KEYS */;
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (11,'70','Blixen','Karen','1885-1962',0,'',' blixen karen ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (12,'70','Metzger','Marthe','',0,'',' metzger marthe ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (13,'70','Bâ','Amadou Hampâté','1901-1991',0,'',' ba amadou hampate ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (14,'70','Zaïd','Nassera','',0,'',' zaid nassera ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (15,'70','Depardon','Raymond','1942-....',0,'',' depardon raymond ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (16,'70','Grosléziat','Chantal','',0,'',' grosleziat chantal ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (17,'70','Nouhen','Elodie','1970-...',0,'',' nouhen elodie ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (18,'70','Mindy','Paul','1952-...',0,'',' mindy paul ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (19,'70','Dedieu','Thierry','',0,'',' dedieu thierry ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (20,'70','De Boel','Anne-Catherine','1975-....',0,'',' de boel anne catherine ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (21,'70','Abouet','Marguerite','1971-....',0,'',' abouet marguerite ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (22,'70','Oubrerie','Clément','1966-....',0,'',' oubrerie clement ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (23,'70','Mabanckou','Alain','1966-....',0,'',' mabanckou alain ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (24,'70','Marechera','Dambudzo','1952-1987',0,'',' marechera dambudzo ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (25,'70','Garnier','Xavier','',0,'',' garnier xavier ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (26,'70','Evette','Jean-Baptiste','1964-....',0,'',' evette jean baptiste ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (27,'70','Gravett','Emily','',0,'',' gravett emily ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (28,'70','Gudule','','',0,'',' gudule ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (29,'70','Durual','Christophe','',0,'',' durual christophe ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (30,'70','Heitz','Bruno','1957-....',0,'',' heitz bruno ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (31,'70','Melot','Michel','1943-....',0,'',' melot michel ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (32,'71','Association des bibliothécaires français','','',0,'',' association des bibliothecaires francais ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (33,'70','Alix','Yves','1953-....',0,'',' alix yves ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (34,'70','Pallier','Denis','1944-....',0,'',' pallier denis ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (35,'70','Brisou-pellen','Evelyn','',0,'',' brisou pellen evelyn ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (36,'70','Beinhart','Larry','1947-....',0,'',' beinhart larry ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (37,'70','Carrer','Patrice','1953-....',0,'',' carrer patrice ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (38,'70','Mahy','Margaret','1936-....',0,'',' mahy margaret ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (39,'70','Blake','Quentin','1932-....',0,'',' blake quentin ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (40,'70','Saint-Dizier','Marie','1944-....',0,'',' saint dizier marie ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (41,'70','Farré','Raymond','1941-....',0,'',' farre raymond ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (42,'70','Bonnet','Jacques','1949-....',0,'',' bonnet jacques ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (43,'70','Bella Ola','Alexandre','',0,'',' bella ola alexandre ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (44,'70','Cuvilliez','Joëlle','',0,'',' cuvilliez joelle ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (45,'70','Tabuteau','Jean-Luc','',0,'',' tabuteau jean luc ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (46,'70','Nantet','Bernard','1938-....',0,'',' nantet bernard ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (47,'70','Gourounas','Jean','1965-....',0,'',' gourounas jean ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (48,'70','Guettier','Bénédicte','1962-....',0,'',' guettier benedicte ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (49,'70','Gay-Para','Praline','1956-....',0,'',' gay para praline ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (50,'70','Prigent','Andrée','1963-....',0,'',' prigent andree ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (51,'70','Guidoux','Valerie','',0,'',' guidoux valerie ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (52,'70','Corentin','Philippe','1936-....',0,'',' corentin philippe ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (53,'70','Loubier','Virginie','',0,'',' loubier virginie ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (54,'70','Serres','Alain','1956-....',0,'',' serres alain ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (55,'70','Jarrie','Martin','1953-....',0,'',' jarrie martin ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (56,'70','Teyras','Emmanuelle','',0,'',' teyras emmanuelle ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (57,'70','Clément','Marie-Christine','',0,'',' clement marie christine ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (58,'70','Freymann','Saxton','',0,'',' freymann saxton ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (59,'70','Elffers','Joost','',0,'',' elffers joost ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (60,'70','Bravi','Soledad','1965-....',0,'',' bravi soledad ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (61,'70','Bradbury','Ray','1920-....',0,'',' bradbury ray ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (62,'70','Chambon','Jacques','1942-2003',0,'',' chambon jacques ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (63,'70','Robillot','Henri','',0,'',' robillot henri ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (64,'70','Pratchett','Terry','1948-....',0,'',' pratchett terry ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (65,'70','Couton','Patrick','',0,'',' couton patrick ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (66,'70','Burton','Tim','',0,'',' burton tim ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (68,'70','De baecque','Anto','',0,'',' de baecque anto ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (69,'70','Silloray','Florent','1971-...',0,'',' silloray florent ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (70,'70','Depp','Johnny','',0,'',' depp johnny ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (71,'70','Ryder','Winona','',0,'',' ryder winona ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (72,'70','Keaton','Mickael','',0,'',' keaton mickael ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (73,'70','McGregor','Ewan','',0,'',' mcgregor ewan ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (74,'70','Makeba','Miriam','1932-2008',0,'',' makeba miriam ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (75,'70','Lo','Ismaël','1956-....',0,'',' lo ismael ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (76,'70','Traoré','Rokia','1974-....',0,'',' traore rokia ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (77,'70','Keita','Salif','',0,'',' keita salif ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (78,'71','Amadou & Mariam','','',0,'',' amadou mariam ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (79,'71','ENSSIB','','',0,'',' enssib ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (80,'70','Bonnet','Jacques','',0,'',' bonnet jacques ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (81,'70','Akkouche','Mouloud','',0,'',' akkouche mouloud ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (82,'70','Aïoutz','Renaud','',0,'',' aioutz renaud ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (83,'71','Interactica','','',0,'',' interactica ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (84,'70','Boulnois','Philippe','',0,'',' boulnois philippe ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (85,'70','Cervantès Saavedra','Miguel de','1547-1616',0,'',' cervantes saavedra miguel de ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (86,'70','Florian','Jean-Pierre Claris de','1755-1794',0,'',' florian jean pierre claris de ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (87,'70','Staal','Gustave','1817-1882',0,'',' staal gustave ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (88,'70','David','Jules','1808-1892',0,'',' david jules ','','','','','','',0);
INSERT INTO authors (author_id, author_type, author_name, author_rejete, author_date, author_see, author_web, index_author, author_comment, author_lieu, author_ville, author_pays, author_subdivision, author_numero, author_import_denied) VALUES (89,'70','Baudelaire','Charles','1821-1867',0,'',' baudelaire charles ','','','','','','',0);
/*!40000 ALTER TABLE authors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authperso`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authperso (
  id_authperso int(10) unsigned NOT NULL AUTO_INCREMENT,
  authperso_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  authperso_notice_onglet_num int(10) unsigned NOT NULL DEFAULT '0',
  authperso_isbd_script text COLLATE utf8_unicode_ci NOT NULL,
  authperso_view_script text COLLATE utf8_unicode_ci NOT NULL,
  authperso_opac_search int(10) unsigned NOT NULL DEFAULT '0',
  authperso_opac_multi_search int(10) unsigned NOT NULL DEFAULT '0',
  authperso_gestion_search int(10) unsigned NOT NULL DEFAULT '0',
  authperso_gestion_multi_search int(10) unsigned NOT NULL DEFAULT '0',
  authperso_comment text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_authperso)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authperso`
--

LOCK TABLES authperso WRITE;
/*!40000 ALTER TABLE authperso DISABLE KEYS */;
/*!40000 ALTER TABLE authperso ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authperso_authorities`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authperso_authorities (
  id_authperso_authority int(10) unsigned NOT NULL AUTO_INCREMENT,
  authperso_authority_authperso_num int(10) unsigned NOT NULL DEFAULT '0',
  authperso_infos_global text COLLATE utf8_unicode_ci NOT NULL,
  authperso_index_infos_global text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_authperso_authority)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authperso_authorities`
--

LOCK TABLES authperso_authorities WRITE;
/*!40000 ALTER TABLE authperso_authorities DISABLE KEYS */;
/*!40000 ALTER TABLE authperso_authorities ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authperso_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authperso_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  custom_prefixe varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authperso_custom`
--

LOCK TABLES authperso_custom WRITE;
/*!40000 ALTER TABLE authperso_custom DISABLE KEYS */;
/*!40000 ALTER TABLE authperso_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authperso_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authperso_custom_lists (
  authperso_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  authperso_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  authperso_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (authperso_custom_champ),
  KEY editorial_champ_list_value (authperso_custom_champ,authperso_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authperso_custom_lists`
--

LOCK TABLES authperso_custom_lists WRITE;
/*!40000 ALTER TABLE authperso_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE authperso_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `authperso_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE authperso_custom_values (
  authperso_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  authperso_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  authperso_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  authperso_custom_text text COLLATE utf8_unicode_ci,
  authperso_custom_integer int(11) DEFAULT NULL,
  authperso_custom_date date DEFAULT NULL,
  authperso_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (authperso_custom_champ),
  KEY editorial_custom_origine (authperso_custom_origine),
  KEY i_acv_st (authperso_custom_small_text),
  KEY i_acv_t (authperso_custom_text(255)),
  KEY i_acv_i (authperso_custom_integer),
  KEY i_acv_d (authperso_custom_date),
  KEY i_acv_f (authperso_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `authperso_custom_values`
--

LOCK TABLES authperso_custom_values WRITE;
/*!40000 ALTER TABLE authperso_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE authperso_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `avis`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE avis (
  id_avis mediumint(8) NOT NULL AUTO_INCREMENT,
  num_empr mediumint(8) NOT NULL DEFAULT '0',
  num_notice mediumint(8) NOT NULL DEFAULT '0',
  note int(3) DEFAULT NULL,
  sujet mediumtext COLLATE utf8_unicode_ci,
  commentaire mediumtext COLLATE utf8_unicode_ci,
  dateajout timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  valide int(1) unsigned NOT NULL DEFAULT '0',
  avis_rank int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_avis),
  KEY avis_num_notice (num_notice),
  KEY avis_num_empr (num_empr),
  KEY avis_note (note)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `avis`
--

LOCK TABLES avis WRITE;
/*!40000 ALTER TABLE avis DISABLE KEYS */;
/*!40000 ALTER TABLE avis ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_abon`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_abon (
  num_bannette int(9) unsigned NOT NULL DEFAULT '0',
  num_empr int(9) unsigned NOT NULL DEFAULT '0',
  actif int(1) unsigned NOT NULL DEFAULT '0',
  bannette_mail varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (num_bannette,num_empr),
  KEY i_num_empr (num_empr)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_abon`
--

LOCK TABLES bannette_abon WRITE;
/*!40000 ALTER TABLE bannette_abon DISABLE KEYS */;
/*!40000 ALTER TABLE bannette_abon ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_contenu`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_contenu (
  num_bannette int(9) unsigned NOT NULL DEFAULT '0',
  num_notice int(9) unsigned NOT NULL DEFAULT '0',
  date_ajout timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (num_bannette,num_notice),
  KEY date_ajout (date_ajout),
  KEY i_num_notice (num_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_contenu`
--

LOCK TABLES bannette_contenu WRITE;
/*!40000 ALTER TABLE bannette_contenu DISABLE KEYS */;
/*!40000 ALTER TABLE bannette_contenu ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_equation`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_equation (
  num_bannette int(9) unsigned NOT NULL DEFAULT '0',
  num_equation int(9) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_bannette,num_equation)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_equation`
--

LOCK TABLES bannette_equation WRITE;
/*!40000 ALTER TABLE bannette_equation DISABLE KEYS */;
/*!40000 ALTER TABLE bannette_equation ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_exports`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_exports (
  num_bannette int(11) unsigned NOT NULL DEFAULT '0',
  export_format int(3) NOT NULL DEFAULT '0',
  export_data longblob NOT NULL,
  export_nomfichier varchar(255) COLLATE utf8_unicode_ci DEFAULT '',
  PRIMARY KEY (num_bannette,export_format)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_exports`
--

LOCK TABLES bannette_exports WRITE;
/*!40000 ALTER TABLE bannette_exports DISABLE KEYS */;
/*!40000 ALTER TABLE bannette_exports ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_facettes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_facettes (
  num_ban_facette int(10) unsigned NOT NULL DEFAULT '0',
  ban_facette_critere int(5) NOT NULL DEFAULT '0',
  ban_facette_ss_critere int(5) NOT NULL DEFAULT '0',
  ban_facette_order int(1) NOT NULL DEFAULT '0',
  KEY bannette_facettes_key (num_ban_facette,ban_facette_critere,ban_facette_ss_critere)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_facettes`
--

LOCK TABLES bannette_facettes WRITE;
/*!40000 ALTER TABLE bannette_facettes DISABLE KEYS */;
/*!40000 ALTER TABLE bannette_facettes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannette_tpl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannette_tpl (
  bannettetpl_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  bannettetpl_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  bannettetpl_comment varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  bannettetpl_tpl text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (bannettetpl_id)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannette_tpl`
--

LOCK TABLES bannette_tpl WRITE;
/*!40000 ALTER TABLE bannette_tpl DISABLE KEYS */;
INSERT INTO bannette_tpl (bannettetpl_id, bannettetpl_name, bannettetpl_comment, bannettetpl_tpl) VALUES (1,'Template PMB','','{{info.header}}\r\n<br /><br />\r\n<div class=\"summary\">\r\n{% for sommaire in sommaires %}\r\n<a href=\"#[{{sommaire.level}}]\">\r\n{{sommaire.level}} - {{sommaire.title}}\r\n</a>\r\n<br />\r\n{% endfor %}\r\n</div>\r\n<hr>\r\n{% for sommaire in sommaires %}\r\n<a name=\"[{{sommaire.level}}]\" />\r\n<h1>{{sommaire.level}} - {{sommaire.title}}</h1>\r\n{% for record in sommaire.records %}\r\n{{record.render}}\r\n<hr>\r\n{% endfor %}\r\n<br />\r\n{% endfor %}\r\n{{info.footer}}');
/*!40000 ALTER TABLE bannette_tpl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannettes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannettes (
  id_bannette int(9) unsigned NOT NULL AUTO_INCREMENT,
  num_classement int(8) unsigned NOT NULL DEFAULT '1',
  nom_bannette varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  comment_gestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  comment_public mediumtext COLLATE utf8_unicode_ci NOT NULL,
  entete_mail mediumtext COLLATE utf8_unicode_ci NOT NULL,
  date_last_remplissage datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_last_envoi datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  proprio_bannette int(9) unsigned NOT NULL DEFAULT '0',
  bannette_auto int(1) unsigned NOT NULL DEFAULT '0',
  periodicite int(3) unsigned NOT NULL DEFAULT '7',
  diffusion_email int(1) unsigned NOT NULL DEFAULT '0',
  categorie_lecteurs int(8) unsigned NOT NULL DEFAULT '0',
  nb_notices_diff int(4) unsigned NOT NULL DEFAULT '0',
  num_panier int(8) unsigned NOT NULL DEFAULT '0',
  limite_type char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  limite_nombre int(6) NOT NULL DEFAULT '0',
  update_type char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'C',
  typeexport varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  prefixe_fichier varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  param_export blob NOT NULL,
  piedpage_mail mediumtext COLLATE utf8_unicode_ci NOT NULL,
  notice_tpl int(10) unsigned NOT NULL DEFAULT '0',
  group_type int(10) unsigned NOT NULL DEFAULT '0',
  group_pperso int(10) unsigned NOT NULL DEFAULT '0',
  display_notice_in_every_group int(10) unsigned NOT NULL DEFAULT '0',
  statut_not_account int(1) unsigned NOT NULL DEFAULT '0',
  archive_number int(10) unsigned NOT NULL DEFAULT '0',
  document_generate int(10) unsigned NOT NULL DEFAULT '0',
  document_notice_tpl int(10) unsigned NOT NULL DEFAULT '0',
  document_insert_docnum int(10) unsigned NOT NULL DEFAULT '0',
  document_group int(10) unsigned NOT NULL DEFAULT '0',
  document_add_summary int(10) unsigned NOT NULL DEFAULT '0',
  groupe_lecteurs int(8) unsigned NOT NULL DEFAULT '0',
  bannette_opac_accueil int(10) unsigned NOT NULL DEFAULT '0',
  bannette_tpl_num int(6) unsigned NOT NULL DEFAULT '0',
  bannette_aff_notice_number int(10) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_bannette)
) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannettes`
--

LOCK TABLES bannettes WRITE;
/*!40000 ALTER TABLE bannettes DISABLE KEYS */;
/*!40000 ALTER TABLE bannettes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bannettes_descriptors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bannettes_descriptors (
  num_bannette int(11) NOT NULL DEFAULT '0',
  num_noeud int(11) NOT NULL DEFAULT '0',
  bannette_descriptor_order int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_bannette,num_noeud)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bannettes_descriptors`
--

LOCK TABLES bannettes_descriptors WRITE;
/*!40000 ALTER TABLE bannettes_descriptors DISABLE KEYS */;
/*!40000 ALTER TABLE bannettes_descriptors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `budgets`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE budgets (
  id_budget int(8) unsigned NOT NULL AUTO_INCREMENT,
  num_entite int(5) unsigned NOT NULL DEFAULT '0',
  num_exercice int(8) unsigned NOT NULL DEFAULT '0',
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaires mediumtext COLLATE utf8_unicode_ci,
  montant_global double(12,2) unsigned NOT NULL DEFAULT '0.00',
  seuil_alerte int(3) unsigned NOT NULL DEFAULT '100',
  statut int(3) unsigned NOT NULL DEFAULT '0',
  type_budget int(3) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_budget)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `budgets`
--

LOCK TABLES budgets WRITE;
/*!40000 ALTER TABLE budgets DISABLE KEYS */;
/*!40000 ALTER TABLE budgets ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `bulletins`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE bulletins (
  bulletin_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  bulletin_numero varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  bulletin_notice int(8) NOT NULL DEFAULT '0',
  mention_date varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_date date NOT NULL DEFAULT '0000-00-00',
  bulletin_titre mediumtext COLLATE utf8_unicode_ci,
  index_titre mediumtext COLLATE utf8_unicode_ci,
  bulletin_cb varchar(30) COLLATE utf8_unicode_ci DEFAULT NULL,
  num_notice int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (bulletin_id),
  KEY bulletin_numero (bulletin_numero),
  KEY bulletin_notice (bulletin_notice),
  KEY date_date (date_date),
  KEY i_num_notice (num_notice)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `bulletins`
--

LOCK TABLES bulletins WRITE;
/*!40000 ALTER TABLE bulletins DISABLE KEYS */;
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (4,'N° 403',120,'septembre 2012','2012-09-01','Numéro spécial Afrique',' numero special afrique ','',121);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (5,'N° 393',120,'novembre 2011','2011-11-01','L\'Île de Pâques',' ile paques ','',122);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (6,'N° 402',120,'août 2012','2012-08-01','Compostelle, Shikoku, Lalibela... Les chemins de la sagesse',' compostelle shikoku lalibela chemins sagesse ','',123);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (7,'Tome 55, n° 6',124,'','2010-11-01','La bibliothèque vue par ses usagers, même',' bibliotheque vue par ses usagers meme ','',0);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (8,'Tome 57, n° 5',124,'','2012-09-01','Bibliothèques et techniques',' bibliotheques techniques ','',0);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (9,'Numéro Moustache',129,'','2012-10-24','','  ','',130);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (10,'Numéro Cupcake',129,'','2012-10-24','','  ','',131);
INSERT INTO bulletins (bulletin_id, bulletin_numero, bulletin_notice, mention_date, date_date, bulletin_titre, index_titre, bulletin_cb, num_notice) VALUES (11,'N° 37',132,'avril 2012','2012-04-01','','  ','',0);
/*!40000 ALTER TABLE bulletins ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_amendes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cache_amendes (
  id_empr int(10) unsigned NOT NULL DEFAULT '0',
  cache_date date NOT NULL DEFAULT '0000-00-00',
  data_amendes blob NOT NULL,
  KEY id_empr (id_empr)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_amendes`
--

LOCK TABLES cache_amendes WRITE;
/*!40000 ALTER TABLE cache_amendes DISABLE KEYS */;
INSERT INTO cache_amendes (id_empr, cache_date, data_amendes) VALUES (1,'2012-11-20',0x613A303A7B7D);
INSERT INTO cache_amendes (id_empr, cache_date, data_amendes) VALUES (10,'2012-12-12',0x613A303A7B7D);
INSERT INTO cache_amendes (id_empr, cache_date, data_amendes) VALUES (6,'2012-12-12',0x613A303A7B7D);
INSERT INTO cache_amendes (id_empr, cache_date, data_amendes) VALUES (2,'2012-12-12',0x613A303A7B7D);
INSERT INTO cache_amendes (id_empr, cache_date, data_amendes) VALUES (7,'2012-12-12',0x613A313A7B693A303B613A333A7B733A373A2269645F6578706C223B733A323A223930223B733A373A227072696E746564223B733A313A2230223B733A363A22616D656E6465223B613A383A7B733A363A2276616C657572223B693A303B733A31323A227265636F757672656D656E74223B623A303B733A363A226E6A6F757273223B733A313A2231223B733A363A226E6976656175223B693A303B733A393A22646174655F70726574223B733A31393A22323031322D31312D32302030393A33343A3137223B733A31313A22646174655F7265746F7572223B733A31303A22323031322D31322D3131223B733A31343A226E69766561755F72656C616E6365223B733A313A2230223B733A31323A22646174655F72656C616E6365223B733A31303A22303030302D30302D3030223B7D7D7D);
/*!40000 ALTER TABLE cache_amendes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `caddie`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE caddie (
  idcaddie int(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'NOTI',
  `comment` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  autorisations longtext COLLATE utf8_unicode_ci,
  caddie_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  acces_rapide int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idcaddie),
  KEY caddie_type (`type`)
) ENGINE=MyISAM AUTO_INCREMENT=19 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `caddie`
--

LOCK TABLES caddie WRITE;
/*!40000 ALTER TABLE caddie DISABLE KEYS */;
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (15,'Nouveautés documentaires','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (16,'Nouveautés CD','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (17,'Nouveautés DVD','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (18,'Nouveautés périodiques','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (14,'Nouveautés fiction jeunesse','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (13,'Nouveautés fiction adultes','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (6,'Exemple de panier de bulletins','BULL','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (12,'Nouveautés en page d\'accueil','NOTI','','1','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (8,'Exemple de panier d\'exemplaires','EXPL','','1 4 3 2','',0);
INSERT INTO caddie (idcaddie, name, type, comment, autorisations, caddie_classement, acces_rapide) VALUES (11,'Exemple de panier de notices','NOTI','','1','',0);
/*!40000 ALTER TABLE caddie ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `caddie_content`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE caddie_content (
  caddie_id int(8) unsigned NOT NULL DEFAULT '0',
  object_id int(10) unsigned NOT NULL DEFAULT '0',
  content varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  blob_type varchar(100) COLLATE utf8_unicode_ci DEFAULT '',
  flag varchar(10) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (caddie_id,object_id,content),
  KEY object_id (object_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `caddie_content`
--

LOCK TABLES caddie_content WRITE;
/*!40000 ALTER TABLE caddie_content DISABLE KEYS */;
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,71,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,119,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,101,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,84,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,102,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,88,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,117,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,100,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,79,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,112,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,128,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,123,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (12,127,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,68,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,75,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,76,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,77,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,78,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,86,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,103,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,104,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (13,105,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,73,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,74,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,79,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,80,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,81,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,85,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,87,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,91,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,92,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,93,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,95,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,101,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (14,102,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,69,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,70,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,71,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,72,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,82,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,83,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,84,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,88,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,89,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,90,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,94,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,96,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,97,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,98,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,99,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,100,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,106,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,107,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,108,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (15,109,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (16,115,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (16,116,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (16,117,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (16,118,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (16,119,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (17,110,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (17,111,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (17,112,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (17,113,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (17,114,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,120,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,121,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,122,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,123,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,124,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,125,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,126,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,127,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,129,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,130,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,131,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,132,'','',NULL);
INSERT INTO caddie_content (caddie_id, object_id, content, blob_type, flag) VALUES (18,133,'','',NULL);
/*!40000 ALTER TABLE caddie_content ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `caddie_procs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE caddie_procs (
  idproc smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  `type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'SELECT',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  requete blob NOT NULL,
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  autorisations longtext COLLATE utf8_unicode_ci,
  parameters mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (idproc)
) ENGINE=MyISAM AUTO_INCREMENT=33 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `caddie_procs`
--

LOCK TABLES caddie_procs WRITE;
/*!40000 ALTER TABLE caddie_procs DISABLE KEYS */;
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (2,'SELECT','Notices en doublons',0x6372656174652054454D504F52415259205441424C4520746D702053454C45435420746974312046524F4D206E6F7469636573205748455245206E69766561755F6269626C696F3D276D2720414E4420747970646F6320213D276C272047524F5550204259207469743120484156494E4720636F756E74282A293E313B0D0A53454C454354206E6F746963655F6964206173206F626A6563745F69642C20274E4F544927206173206F626A6563745F747970652046524F4D206E6F74696365732C20746D70205748455245206E6F74696365732E746974313D746D702E7469743120414E44206E69766561755F6269626C696F3D276D2720414E4420747970646F6320213D276C27,'Sélection des notices en doublons sur le premier titre','1 2 3','');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (3,'SELECT','EXPL par section / propriétaire',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F73656374696F6E20696E2028212173656374696F6E21212920616E64206578706C5F6F776E65723D212170726F7072696F2121,'Sélection d\'exemplaires par section par propriétaire','1 2','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"section\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Section]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idsection, section_libelle from docs_section order by section_libelle]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n <FIELD NAME=\"proprio\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Propriétaire]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY>select idlender, lender_libelle from lenders order by lender_libelle</QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (4,'SELECT','EXPL où cote commence par',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F636F7465206C696B6520272121636F6D6D655F636F746521212527,'Sélection d\'exemplaire à partir du début de cote','1 2','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"comme_cote\" MANDATORY=\"no\">\n  <ALIAS><![CDATA[Début de la cote]]></ALIAS>\n  <TYPE>text</TYPE>\n<OPTIONS FOR=\"text\">\r\n <SIZE>20</SIZE>\r\n <MAXSIZE>20</MAXSIZE>\r\n</OPTIONS> \n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (5,'ACTION','Changement de statut des exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F7374617475743D21216E6F75766561755F7374617475742121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"nouveau_statut\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[nouveau_statut]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY>SELECT idstatut, statut_libelle FROM docs_statut</QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (17,'ACTION','Changement de localisation des exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F6C6F636174696F6E3D21216E6F7576656C6C655F6C6F63616C69736174696F6E2121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"nouvelle_localisation\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[nouvelle localisation]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idlocation, location_libelle from docs_location order by location_libelle]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[sélectionnez une localisation]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (6,'SELECT','Jamais prêtés',0x53454C454354206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652C20636F6E63617428224C4956524520222C74697431292061732054697472652046524F4D206E6F7469636573206A6F696E206578656D706C6169726573206F6E206578706C5F6E6F746963653D6E6F746963655F6964204C454654204A4F494E20707265745F61726368697665204F4E206172635F6578706C5F6E6F74696365203D206E6F746963655F6964207768657265206172635F6578706C5F6964204953204E554C4C20414E44206578706C5F6964204953204E4F54204E554C4C20554E494F4E2053454C454354206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652C20636F6E6361742822504552494F20222C746974312C2022204E756DC3A9726F203A20222C62756C6C6574696E5F6E756D65726F292061732054697472652046524F4D202862756C6C6574696E7320494E4E4552204A4F494E206E6F7469636573204F4E2062756C6C6574696E732E62756C6C6574696E5F6E6F74696365203D206E6F74696365732E6E6F746963655F69642920494E4E4552204A4F494E206578656D706C6169726573206F6E206578706C5F62756C6C6574696E3D62756C6C6574696E5F6964204C454654204A4F494E20707265745F61726368697665204F4E206578706C5F6964203D206172635F6578706C5F696420574845524520707265745F617263686976652E6172635F6964204973204E756C6C,'Ajoute dans un panier les exemplaires jamais prêtés','1 2','');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (7,'SELECT','Sélection d\'exemplaires par statut',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F73746174757420696E20282121737461747574212129,'','1 2','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"statut\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[statut]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idstatut, statut_libelle from docs_statut]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (8,'SELECT','Sélection d\'exemplaires par localisation, section, statut, propriétaire',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F73656374696F6E20696E2028212173656374696F6E21212920616E64206578706C5F6C6F636174696F6E20696E202821216C6F636174696F6E21212920616E64206578706C5F73746174757420696E2028212173746174757421212920616E64206578706C5F6F776E65723D212170726F7072696F21212020,'','1 2','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"section\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Section]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idsection, section_libelle from docs_section order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n <FIELD NAME=\"location\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Localisation]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idlocation, location_libelle from docs_location order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n <FIELD NAME=\"statut\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Statut]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idstatut, statut_libelle from docs_statut order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n <FIELD NAME=\"proprio\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Propriétaire]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idlender, lender_libelle from lenders order by 2]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (9,'ACTION','Changement de section des exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F73656374696F6E3D21216E6F7576656C6C655F73656374696F6E2121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1 4 3 2','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"nouvelle_section\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[nouvelle section]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select * from docs_section order by section_libelle]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[Choisissez une section]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (18,'ACTION','Ajout d\'une catégories aux notices d\'un panier',0x7265706C61636520696E746F206E6F74696365735F63617465676F7269657320286E6F7463617465675F6E6F746963652C6E756D5F6E6F657564292053454C454354206E6F746963655F69642C202221216E6F7576656C6C655F63617465676F7269652121222066726F6D206E6F7469636573207768657265206E6F746963655F696420696E2028434144444945284E4F54492929,'Via un sélecteur','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"thesaurus\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[thesaurus]]></ALIAS>\n  <TYPE>text</TYPE>\n<OPTIONS></OPTIONS>\n </FIELD>\n <FIELD NAME=\"langue\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[langue]]></ALIAS>\n  <TYPE>text</TYPE>\n<OPTIONS></OPTIONS>\n </FIELD>\n <FIELD NAME=\"nouvelle_categorie\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[nouvelle_categorie]]></ALIAS>\n  <TYPE>selector</TYPE>\n<OPTIONS FOR=\"selector\">\r\n <METHOD>1</METHOD>\r\n <DATA_TYPE>2</DATA_TYPE>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (19,'ACTION','Suppression d\'une catégorie aux notices d\'un panier',0x64656C6574652066726F6D206E6F74696365735F63617465676F72696573207768657265206E756D5F6E6F6575643D22212173757070725F63617465676F72696521212220616E64206E6F7463617465675F6E6F7469636520696E2028434144444945284E4F54492929,'Via un sélecteur d\'autorité','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"suppr_categorie\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Catégorie à supprimer :]]></ALIAS>\n  <TYPE>selector</TYPE>\n<OPTIONS FOR=\"selector\">\r\n <METHOD>1</METHOD>\r\n <DATA_TYPE>2</DATA_TYPE>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (20,'ACTION','Changement du code statistique d\'exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F636F6465737461743D21216E6F75766561755F636F6465737461742121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"nouveau_codestat\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Nouveau code statistique]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idcode, codestat_libelle from docs_codestat order by codestat_libelle]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (21,'ACTION','Changement de type de document des notices d\'un panier',0x757064617465206E6F74696365732073657420747970646F633D21216E65775F747970646F632121207768657265206E6F746963655F696420696E2028434144444945284E4F54492929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"new_typdoc\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[Nouveau type de document]]></ALIAS>\n<TYPE>list</TYPE>\n<OPTIONS FOR=\"list\">\n<ITEMS>\n<ITEM VALUE=\"b\">texte manuscrit</ITEM>\n<ITEM VALUE=\"c\">partition musicale imprimée</ITEM>\n<ITEM VALUE=\"d\">partition musicale manuscrite</ITEM>\n<ITEM VALUE=\"e\">document cartographique imprimé</ITEM>\n<ITEM VALUE=\"f\">document cartographique manuscrit</ITEM>\n<ITEM VALUE=\"g\">document projeté ou vidéo</ITEM>\n<ITEM VALUE=\"i\">enregistrement sonore non musical</ITEM>\n<ITEM VALUE=\"j\">enregistrement sonore musical</ITEM>\n<ITEM VALUE=\"k\">document graphique à deux dimensions</ITEM>\n<ITEM VALUE=\"l\">document électronique</ITEM>\n<ITEM VALUE=\"m\">document multimédia</ITEM>\n<ITEM VALUE=\"r\">objet à 3 dimensions, artefacts, ...</ITEM>\n</ITEMS>\n<MULTIPLE>no</MULTIPLE>\n<UNSELECT_ITEM VALUE=\"a\">texte imprimé</UNSELECT_ITEM>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (22,'ACTION','Changement de message des exemplaires d\'un panier',0x757064617465206578656D706C616972657320736574206578706C5F6E6F74653D2721216E65775F6E6F7465212127207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"new_note\" MANDATORY=\"no\">\n<ALIAS><![CDATA[Nouveau message]]></ALIAS>\n<TYPE>text</TYPE>\n<OPTIONS FOR=\"text\">\n<SIZE>25</SIZE>\n<MAXSIZE>25</MAXSIZE>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (23,'ACTION','Changement d\'une partie de la cote des exemplaires d\'un panier',0x757064617465206578656D706C616972657320736574206578706C5F636F74653D7265706C616365286578706C5F636F74652C202721216D6F7469665F312121272C202721216D6F7469665F3221212729207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"motif_1\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[Remplacer]]></ALIAS>\n<TYPE>text</TYPE>\n<OPTIONS FOR=\"text\">\n<SIZE>50</SIZE>\n<MAXSIZE>50</MAXSIZE>\n</OPTIONS>\n</FIELD>\n<FIELD NAME=\"motif_2\" MANDATORY=\"no\">\n<ALIAS><![CDATA[Par]]></ALIAS>\n<TYPE>text</TYPE>\n<OPTIONS FOR=\"text\">\n<SIZE>50</SIZE>\n<MAXSIZE>50</MAXSIZE>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (24,'ACTION','Changement de propriétaire des exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F6F776E65723D21216F776E65722121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"owner\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[propriétaire]]></ALIAS>\n<TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\n<QUERY>select idlender, lender_libelle from lenders order by lender_libelle</QUERY>\n<MULTIPLE>no</MULTIPLE>\n<UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (25,'ACTION','Changement de support des exemplaires',0x757064617465206578656D706C616972657320736574206578706C5F747970646F633D21216E6F75766561755F747970646F632121207768657265206578706C5F696420696E2028434144444945284558504C2929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"nouveau_typdoc\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[nouveau support]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idtyp_doc, tdoc_libelle from docs_type order by 2]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (26,'ACTION','Changement de statut des notices d\'un panier',0x757064617465206E6F746963657320736574207374617475743D2721216E65775F737461747574212127207768657265206E6F746963655F696420696E2028434144444945284E4F54492929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"new_statut\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[Nouveau statut]]></ALIAS>\n<TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\n<QUERY>select id_notice_statut, gestion_libelle from notice_statut order by 2</QUERY>\n<MULTIPLE>no</MULTIPLE>\n<UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (27,'SELECT','Collecte des 20 titres les plus empruntés par sections et localisations',0x73656C656374206E6F746963655F6964206173206F626A6563745F69642C274E4F544927206173206F626A6563745F747970652066726F6D206E6F7469636573207768657265206E6F746963655F696420696E202873656C656374202A2066726F6D202873656C656374206172635F6578706C5F6E6F746963652066726F6D20707265745F61726368697665206C656674206A6F696E20646F63735F73656374696F6E206F6E206172635F6578706C5F73656374696F6E3D696473656374696F6E206C656674206A6F696E20646F63735F6C6F636174696F6E206F6E206172635F6578706C5F6C6F636174696F6E3D69646C6F636174696F6E207768657265206172635F6578706C5F6C6F636174696F6E20696E2028212163686F69786C6F636121212920616E64206172635F6578706C5F73656374696F6E20696E2028212163686F697873656374696F6E21212920616E64206172635F6578706C5F6E6F74696365213D302067726F7570206279206172635F6578706C5F6E6F74696365206F7264657220627920636F756E742864697374696E6374206172635F6964292044455343206C696D697420302C32302920616C69617329,'Idéal pour constituer en un clic des étagères en OPAC sur les titres les plus empruntés par section','1','<?xml version=\"1.0\" encoding=\"utf-8\"?><FIELDS><FIELD NAME=\"choixloca\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[Choisissez une ou plusieurs localisations :]]></ALIAS>\n<TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\n<QUERY>select idlocation, location_libelle from docs_location order by 2</QUERY>\n<MULTIPLE>yes</MULTIPLE>\n<UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\n</OPTIONS>\n</FIELD>\n<FIELD NAME=\"choixsection\" MANDATORY=\"yes\">\n<ALIAS><![CDATA[Choisissez une ou plusieurs sections :]]></ALIAS>\n<TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\n<QUERY>select idsection, section_libelle from docs_section order by 2</QUERY>\n<MULTIPLE>yes</MULTIPLE>\n<UNSELECT_ITEM VALUE=\"\"></UNSELECT_ITEM>\n</OPTIONS>\n</FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (28,'SELECT','Sélection / Pointage des exemplaires en cours de prêt',0x53454C45435420707265745F69646578706C206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D2070726574,'','1','');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (29,'SELECT','Sélection d\'exemplaires à partir d\'un fichier de code barres',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F636220696E2028212166696368696572212129,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"fichier\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[fichier]]></ALIAS>\n  <TYPE>file_box</TYPE>\n<OPTIONS FOR=\"file_box\">\r\n <METHOD>1</METHOD>\r\n <TEMP_TABLE_NAME></TEMP_TABLE_NAME>\r\n <DATA_TYPE>1</DATA_TYPE>\r\n</OPTIONS> \n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (30,'SELECT','Sélection / pointage à partir d\'un panier de bulletins',0x73656C6563742062756C6C6574696E5F6964206173206F626A6563745F69642C202742554C4C27206173206F626A6563745F747970652066726F6D2062756C6C6574696E732077686572652062756C6C6574696E5F696420696E202873656C656374206361646469655F636F6E74656E742E6F626A6563745F69642066726F6D206361646469655F636F6E74656E74206A6F696E20636164646965206F6E20286361646469655F69643D69646361646469652920776865726520696463616464696520696E2028212163686F697863616464696521212929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"choixcaddie\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Choisir un ou plusieurs paniers :]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idcaddie, name from caddie where type=\'BULL\' order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (31,'SELECT','Sélection / pointage à partir d\'un panier d\'exemplaires',0x73656C656374206578706C5F6964206173206F626A6563745F69642C20274558504C27206173206F626A6563745F747970652066726F6D206578656D706C6169726573207768657265206578706C5F696420696E202873656C656374206361646469655F636F6E74656E742E6F626A6563745F69642066726F6D206361646469655F636F6E74656E74206A6F696E20636164646965206F6E20286361646469655F69643D69646361646469652920776865726520696463616464696520696E2028212163686F697863616464696521212929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"choixcaddie\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Choisir un ou plusieurs paniers :]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idcaddie, name from caddie where type=\'EXPL\' order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
INSERT INTO caddie_procs (idproc, type, name, requete, comment, autorisations, parameters) VALUES (32,'SELECT','Sélection / pointage à partir d\'un panier de notices',0x73656C656374206E6F746963655F6964206173206F626A6563745F69642C20274E4F544927206173206F626A6563745F747970652066726F6D206E6F7469636573207768657265206E6F746963655F696420696E202873656C656374206361646469655F636F6E74656E742E6F626A6563745F69642066726F6D206361646469655F636F6E74656E74206A6F696E20636164646965206F6E20286361646469655F69643D69646361646469652920776865726520696463616464696520696E2028212163686F697863616464696521212929,'','1','<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<FIELDS>\n <FIELD NAME=\"choixcaddie\" MANDATORY=\"yes\">\n  <ALIAS><![CDATA[Choisir un ou plusieurs paniers :]]></ALIAS>\n  <TYPE>query_list</TYPE>\n<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idcaddie, name from caddie where type=\'NOTI\' order by 2]]></QUERY>\r\n <MULTIPLE>yes</MULTIPLE>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[]]></UNSELECT_ITEM>\r\n</OPTIONS>\n </FIELD>\n</FIELDS>');
/*!40000 ALTER TABLE caddie_procs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cashdesk`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cashdesk (
  cashdesk_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  cashdesk_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cashdesk_autorisations varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cashdesk_transactypes varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cashdesk_cashbox int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (cashdesk_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cashdesk`
--

LOCK TABLES cashdesk WRITE;
/*!40000 ALTER TABLE cashdesk DISABLE KEYS */;
/*!40000 ALTER TABLE cashdesk ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cashdesk_locations`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cashdesk_locations (
  cashdesk_loc_cashdesk_num int(10) unsigned NOT NULL DEFAULT '0',
  cashdesk_loc_num int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (cashdesk_loc_cashdesk_num,cashdesk_loc_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cashdesk_locations`
--

LOCK TABLES cashdesk_locations WRITE;
/*!40000 ALTER TABLE cashdesk_locations DISABLE KEYS */;
/*!40000 ALTER TABLE cashdesk_locations ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cashdesk_sections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cashdesk_sections (
  cashdesk_section_cashdesk_num int(10) unsigned NOT NULL DEFAULT '0',
  cashdesk_section_num int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (cashdesk_section_cashdesk_num,cashdesk_section_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cashdesk_sections`
--

LOCK TABLES cashdesk_sections WRITE;
/*!40000 ALTER TABLE cashdesk_sections DISABLE KEYS */;
/*!40000 ALTER TABLE cashdesk_sections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categ_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE categ_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categ_custom`
--

LOCK TABLES categ_custom WRITE;
/*!40000 ALTER TABLE categ_custom DISABLE KEYS */;
/*!40000 ALTER TABLE categ_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categ_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE categ_custom_lists (
  categ_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  categ_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  categ_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (categ_custom_champ),
  KEY editorial_champ_list_value (categ_custom_champ,categ_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categ_custom_lists`
--

LOCK TABLES categ_custom_lists WRITE;
/*!40000 ALTER TABLE categ_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE categ_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categ_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE categ_custom_values (
  categ_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  categ_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  categ_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  categ_custom_text text COLLATE utf8_unicode_ci,
  categ_custom_integer int(11) DEFAULT NULL,
  categ_custom_date date DEFAULT NULL,
  categ_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (categ_custom_champ),
  KEY editorial_custom_origine (categ_custom_origine),
  KEY i_ccv_st (categ_custom_small_text),
  KEY i_ccv_t (categ_custom_text(255)),
  KEY i_ccv_i (categ_custom_integer),
  KEY i_ccv_d (categ_custom_date),
  KEY i_ccv_f (categ_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categ_custom_values`
--

LOCK TABLES categ_custom_values WRITE;
/*!40000 ALTER TABLE categ_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE categ_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE categories (
  num_thesaurus int(3) unsigned NOT NULL DEFAULT '1',
  num_noeud int(9) unsigned NOT NULL DEFAULT '0',
  langue varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'fr_FR',
  libelle_categorie mediumtext COLLATE utf8_unicode_ci NOT NULL,
  note_application mediumtext COLLATE utf8_unicode_ci NOT NULL,
  comment_public mediumtext COLLATE utf8_unicode_ci NOT NULL,
  comment_voir mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_categorie mediumtext COLLATE utf8_unicode_ci NOT NULL,
  path_word_categ mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_path_word_categ mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_noeud,langue),
  KEY categ_langue (langue),
  KEY libelle_categorie (libelle_categorie(5))
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories`
--

LOCK TABLES categories WRITE;
/*!40000 ALTER TABLE categories DISABLE KEYS */;
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2512,'fr_FR','~termes non classés','','','',' termes non classes ',' ~termes non classés ',' termes non classes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1378,'fr_FR','Art et culture','','','',' art culture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1379,'fr_FR','Institutions et politique','','','',' institutions politique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1380,'fr_FR','Jeunesse','','','',' jeunesse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1381,'fr_FR','Sciences','','','',' sciences ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1382,'fr_FR','Sciences humaines','','','',' sciences humaines ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1383,'fr_FR','Société','','','',' societe ',' Société ',' societe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1384,'fr_FR','Sports et loisirs','','','',' sports loisirs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1385,'fr_FR','Techniques','','','',' techniques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1386,'fr_FR','Vie pratique','','','',' vie pratique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1387,'fr_FR','Zones géographiques','','','',' zones geographiques ',' Zones géographiques ',' zones geographiques ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1388,'fr_FR','Essais','','','',' essais ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1389,'fr_FR','Illustration','','','',' illustration ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1390,'fr_FR','Architecture','','','',' architecture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1391,'fr_FR','Bande dessinée','','','',' bande dessinee ',' Bande dessinée ',' bande dessinee ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1392,'fr_FR','Cinéma','','','',' cinema ',' Cinéma ',' cinema ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1393,'fr_FR','Design','','','',' design ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1394,'fr_FR','Littérature','','','',' litterature ',' Littérature ',' litterature ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1395,'fr_FR','Livre','','','',' livre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1396,'fr_FR','Mobilier et objets d\'art','','','',' mobilier objets art ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1397,'fr_FR','Musées','','','',' musees ',' Musées ',' musees ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1398,'fr_FR','Musique','','','',' musique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1399,'fr_FR','Peinture','','','',' peinture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1400,'fr_FR','Photographie','','','',' photographie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1401,'fr_FR','Sculpture','','','',' sculpture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1402,'fr_FR','Architectes','','','',' architectes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1403,'fr_FR','Moyen-Age','','','',' moyen age ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1404,'fr_FR','Ecoles et styles','','','',' ecoles styles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1405,'fr_FR','Edifices','','','',' edifices ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1406,'fr_FR','Géographie','','','',' geographie ',' Géographie ',' geographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1407,'fr_FR','XIXème siècle','','','',' xixeme siecle ',' XIXème siècle ',' xixeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1408,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1409,'fr_FR','XXème siècle','','','',' xxeme siecle ',' XXème siècle ',' xxeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1410,'fr_FR','Afrique','','','',' afrique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1411,'fr_FR','Récit historique','','','',' recit historique ',' Récit historique ',' recit historique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1412,'fr_FR','Heroic fantasy','','','',' heroic fantasy ',' Heroic fantasy ',' heroic fantasy ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1413,'fr_FR','Fantastique','','','',' fantastique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1414,'fr_FR','Science-fiction','','','',' science fiction ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1415,'fr_FR','Policier','','','',' policier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1416,'fr_FR','Humour','','','',' humour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1417,'fr_FR','Aventure','','','',' aventure ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1418,'fr_FR','Manga','','','',' manga ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1419,'fr_FR','Réalité','','','',' realite ',' Réalité ',' realite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1420,'fr_FR','Par genre (sélection)','','','',' par genre selection ',' Par genre (sélection) ',' par genre selection ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1421,'fr_FR','Antiquité grecque et romaine','','','',' antiquite grecque romaine ',' Antiquité grecque et romaine ',' antiquite grecque romaine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1422,'fr_FR','Moyen-Age','','','',' moyen age ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1423,'fr_FR','Renaissance','','','',' renaissance ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1424,'fr_FR','XVIIème siècle','','','',' xviieme siecle ',' XVIIème siècle ',' xviieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1425,'fr_FR','XVIIIème siècle','','','',' xviiieme siecle ',' XVIIIème siècle ',' xviiieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1426,'fr_FR','De 1800 à 1849','','','',' 1800 1849 ',' De 1800 à 1849 ',' 1800 1849 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1427,'fr_FR','De 1850 à 1899','','','',' 1850 1899 ',' De 1850 à 1899 ',' 1850 1899 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1428,'fr_FR','De 1900 à 1949','','','',' 1900 1949 ',' De 1900 à 1949 ',' 1900 1949 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1429,'fr_FR','De 1950 à 1999 (sélection)','','','',' 1950 1999 selection ',' De 1950 à 1999 (sélection) ',' 1950 1999 selection ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1430,'fr_FR','De 2000 à aujourd\'hui (sélection)','','','',' 2000 aujourd hui selection ',' De 2000 à aujourd\'hui (sélection) ',' 2000 aujourd hui selection ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1431,'fr_FR','Roman historique','','','',' roman historique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1432,'fr_FR','Récits de voyage et d\'exploration','','','',' recits voyage exploration ',' Récits de voyage et d\'exploration ',' recits voyage exploration ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1433,'fr_FR','Fantastique et merveilleux','','','',' fantastique merveilleux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1434,'fr_FR','Roman policier','','','',' roman policier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1435,'fr_FR','Science-fiction','','','',' science fiction ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1436,'fr_FR','Nouvelles','','','',' nouvelles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1437,'fr_FR','Littérature en miettes','','','',' litterature miettes ',' Littérature en miettes ',' litterature miettes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1438,'fr_FR','Distorsions','','','',' distorsions ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1439,'fr_FR','Mémoires et autobiographies','','','',' memoires autobiographies ',' Mémoires et autobiographies ',' memoires autobiographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1440,'fr_FR','Journaux et carnets','','','',' journaux carnets ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1441,'fr_FR','Correspondance','','','',' correspondance ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1442,'fr_FR','Littérature asiatique','','','',' litterature asiatique ',' Littérature asiatique ',' litterature asiatique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1443,'fr_FR','L\'écrivain et son oeuvre','','','',' ecrivain son oeuvre ',' L\'écrivain et son oeuvre ',' ecrivain son oeuvre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1444,'fr_FR','Le livre comme miroir','','','',' livre comme miroir ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1445,'fr_FR','Littérature américaine','','','',' litterature americaine ',' Littérature américaine ',' litterature americaine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1446,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1447,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1448,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1449,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1450,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1451,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1452,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1453,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1454,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1455,'fr_FR','Littérature hispano-américaine','','','',' litterature hispano americaine ',' Littérature hispano-américaine ',' litterature hispano americaine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1456,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1457,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1458,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1459,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1460,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1461,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1462,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1463,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1464,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1465,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1466,'fr_FR','Littérature allemande','','','',' litterature allemande ',' Littérature allemande ',' litterature allemande ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1467,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1468,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1469,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1470,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1471,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1472,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1473,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1474,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1475,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1476,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1477,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1478,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1479,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1480,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1481,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1482,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1483,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1484,'fr_FR','Antiquité','','','',' antiquite ',' Antiquité ',' antiquite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1485,'fr_FR','Moyen-Age','','','',' moyen age ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1486,'fr_FR','Renaissance','','','',' renaissance ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1487,'fr_FR','XVIIème siècle','','','',' xviieme siecle ',' XVIIème siècle ',' xviieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1488,'fr_FR','XVIIIème siècle','','','',' xviiieme siecle ',' XVIIIème siècle ',' xviiieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1489,'fr_FR','XIXème siècle','','','',' xixeme siecle ',' XIXème siècle ',' xixeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1490,'fr_FR','XXème siècle','','','',' xxeme siecle ',' XXème siècle ',' xxeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1492,'fr_FR','Par sujet','','','',' par sujet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1493,'fr_FR','Biographies','','','',' biographies ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1494,'fr_FR','Essais politiques','','','',' essais politiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1495,'fr_FR','France','','','',' france ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1496,'fr_FR','Europe','','','',' europe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1497,'fr_FR','Monde','','','',' monde ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1498,'fr_FR','Science politique','','','',' science politique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1499,'fr_FR','Administration','','','',' administration ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1500,'fr_FR','Citoyenneté','','','',' citoyennete ',' Citoyenneté ',' citoyennete ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1501,'fr_FR','Président et gouvernement','','','',' president gouvernement ',' Président et gouvernement ',' president gouvernement ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1502,'fr_FR','Parlement','','','',' parlement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1503,'fr_FR','Justice','','','',' justice ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1504,'fr_FR','Collectivités territoriales','','','',' collectivites territoriales ',' Collectivités territoriales ',' collectivites territoriales ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1505,'fr_FR','Défense nationale - Sécurité publique','','','',' defense nationale securite publique ',' Défense nationale - Sécurité publique ',' defense nationale securite publique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1506,'fr_FR','Droit','','','',' droit ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1507,'fr_FR','Elections','','','',' elections ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1508,'fr_FR','Fiscalité','','','',' fiscalite ',' Fiscalité ',' fiscalite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1509,'fr_FR','Partis politiques','','','',' partis politiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1510,'fr_FR','Protection sociale','','','',' protection sociale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1511,'fr_FR','Syndicats','','','',' syndicats ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1512,'fr_FR','Mondialisation','','','',' mondialisation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1513,'fr_FR','Organisations internationales','','','',' organisations internationales ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1514,'fr_FR','Relations internationales','','','',' relations internationales ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1515,'fr_FR','Animaux','','','',' animaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1516,'fr_FR','Corps et santé','','','',' corps sante ',' Corps et santé ',' corps sante ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1517,'fr_FR','Découvrir le monde','','','',' decouvrir monde ',' Découvrir le monde ',' decouvrir monde ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1518,'fr_FR','Eveil et apprentissage','','','',' eveil apprentissage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1519,'fr_FR','Sports et loisirs','','','',' sports loisirs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1520,'fr_FR','Nature et environnement','','','',' nature environnement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1521,'fr_FR','Personnages extraordinaires et mondes imaginaires','','','',' personnages extraordinaires mondes imaginaires ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1522,'fr_FR','Art et culture','','','',' art culture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1523,'fr_FR','Vivre ensemble','','','',' vivre ensemble ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1524,'fr_FR','Chat','','','',' chat ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1525,'fr_FR','Mammifères','','','',' mammiferes ',' Mammifères ',' mammiferes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1526,'fr_FR','Par environnement','','','',' par environnement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1527,'fr_FR','Champs','','','',' champs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1528,'fr_FR','Forêt','','','',' foret ',' Forêt ',' foret ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1529,'fr_FR','Montagne','','','',' montagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1530,'fr_FR','Jungle','','','',' jungle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1531,'fr_FR','Poissons','','','',' poissons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1532,'fr_FR','Insectes','','','',' insectes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1533,'fr_FR','Oiseaux','','','',' oiseaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1534,'fr_FR','Animaux menacés','','','',' animaux menaces ',' Animaux menacés ',' animaux menaces ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1535,'fr_FR','Dinosaures','','','',' dinosaures ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1536,'fr_FR','Corps','','','',' corps ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1537,'fr_FR','Hygiène et santé','','','',' hygiene sante ',' Hygiène et santé ',' hygiene sante ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1538,'fr_FR','Nourriture','','','',' nourriture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1539,'fr_FR','Vêtement et coiffure','','','',' vetement coiffure ',' Vêtement et coiffure ',' vetement coiffure ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1540,'fr_FR','Avoir un bébé','','','',' avoir bebe ',' Avoir un bébé ',' avoir bebe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1541,'fr_FR','Maladie','','','',' maladie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1542,'fr_FR','Handicap','','','',' handicap ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1543,'fr_FR','Médecin et hôpital','','','',' medecin hopital ',' Médecin et hôpital ',' medecin hopital ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1544,'fr_FR','Sexualité','','','',' sexualite ',' Sexualité ',' sexualite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1545,'fr_FR','Voyage','','','',' voyage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1546,'fr_FR','Transports','','','',' transports ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1547,'fr_FR','Communiquer - S\'informer','','','',' communiquer s informer ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1548,'fr_FR','Géographie','','','',' geographie ',' Géographie ',' geographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1549,'fr_FR','Préhistoire','','','',' prehistoire ',' Préhistoire ',' prehistoire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1550,'fr_FR','Amérique','','','',' amerique ',' Amérique ',' amerique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1551,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1552,'fr_FR','Science et expériences','','','',' science experiences ',' Science et expériences ',' science experiences ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1553,'fr_FR','Espace - Planètes','','','',' espace planetes ',' Espace - Planètes ',' espace planetes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1554,'fr_FR','Premiers acquis','','','',' premiers acquis ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1555,'fr_FR','Autour du langage','','','',' autour langage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1556,'fr_FR','Vers l\'autonomie','','','',' vers autonomie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1557,'fr_FR','Langues étrangères','','','',' langues etrangeres ',' Langues étrangères ',' langues etrangeres ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1558,'fr_FR','Informatique','','','',' informatique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1559,'fr_FR','Activités manuelles','','','',' activites manuelles ',' Activités manuelles ',' activites manuelles ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1560,'fr_FR','Cuisine','','','',' cuisine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1561,'fr_FR','Jardinage','','','',' jardinage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1562,'fr_FR','Sport','','','',' sport ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1563,'fr_FR','Jeux et jouets','','','',' jeux jouets ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1564,'fr_FR','Déguisements','','','',' deguisements ',' Déguisements ',' deguisements ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1565,'fr_FR','Dessin et peinture','','','',' dessin peinture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1566,'fr_FR','Enigmes et devinettes','','','',' enigmes devinettes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1567,'fr_FR','Adjectif','','','',' adjectif ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1568,'fr_FR','Campagne','','','',' campagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1569,'fr_FR','Montagne','','','',' montagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1570,'fr_FR','Forêt','','','',' foret ',' Forêt ',' foret ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1571,'fr_FR','Mer et océan','','','',' mer ocean ',' Mer et océan ',' mer ocean ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1572,'fr_FR','Désert','','','',' desert ',' Désert ',' desert ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1573,'fr_FR','Ville','','','',' ville ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1574,'fr_FR','Air','','','',' air ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1575,'fr_FR','Eau','','','',' eau ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1576,'fr_FR','Feu','','','',' feu ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1577,'fr_FR','Saisons','','','',' saisons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1578,'fr_FR','Arbres','','','',' arbres ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1579,'fr_FR','Fleurs','','','',' fleurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1580,'fr_FR','Météo','','','',' meteo ',' Météo ',' meteo ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1581,'fr_FR','Protéger l\'environnement','','','',' proteger environnement ',' Protéger l\'environnement ',' proteger environnement ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1583,'fr_FR','Sorcière','','','',' sorciere ',' Sorcière ',' sorciere ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1584,'fr_FR','Monstre et dragon','','','',' monstre dragon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1585,'fr_FR','Prince, princesse, roi et reine','','','',' prince princesse roi reine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1586,'fr_FR','Ogre','','','',' ogre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1587,'fr_FR','Nain et géant','','','',' nain geant ',' Nain et géant ',' nain geant ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1588,'fr_FR','Fantôme','','','',' fantome ',' Fantôme ',' fantome ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1589,'fr_FR','Pirate et corsaire','','','',' pirate corsaire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1590,'fr_FR','Extra-terrestre','','','',' extra terrestre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1591,'fr_FR','Monde imaginaire','','','',' monde imaginaire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1592,'fr_FR','Peinture et sculpture','','','',' peinture sculpture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1593,'fr_FR','Roman','','','',' roman ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1594,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1595,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1596,'fr_FR','Livre','','','',' livre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1597,'fr_FR','Musique','','','',' musique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1598,'fr_FR','Danse','','','',' danse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1599,'fr_FR','Bande dessinée','','','',' bande dessinee ',' Bande dessinée ',' bande dessinee ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1600,'fr_FR','Cinéma - Télévision','','','',' cinema television ',' Cinéma - Télévision ',' cinema television ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1601,'fr_FR','Photographie','','','',' photographie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1602,'fr_FR','Architecture','','','',' architecture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1603,'fr_FR','En famille','','','',' famille ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1604,'fr_FR','A l\'école et au collège','','','',' ecole college ',' A l\'école et au collège ',' ecole college ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1605,'fr_FR','En société','','','',' societe ',' En société ',' societe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1606,'fr_FR','Amour et sentiments','','','',' amour sentiments ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1607,'fr_FR','Enfants','','','',' enfants ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1608,'fr_FR','Fêtes','','','',' fetes ',' Fêtes ',' fetes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1609,'fr_FR','Métiers','','','',' metiers ',' Métiers ',' metiers ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1610,'fr_FR','Religion','','','',' religion ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1611,'fr_FR','C\'est compliqué','','','',' c est complique ',' C\'est compliqué ',' c est complique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1612,'fr_FR','Astronomie','','','',' astronomie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1613,'fr_FR','Plantes','','','',' plantes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1614,'fr_FR','Chimie','','','',' chimie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1615,'fr_FR','Ecologie','','','',' ecologie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1616,'fr_FR','Génétique et évolution','','','',' genetique evolution ',' Génétique et évolution ',' genetique evolution ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1617,'fr_FR','Mathématiques','','','',' mathematiques ',' Mathématiques ',' mathematiques ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1618,'fr_FR','Physique','','','',' physique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1619,'fr_FR','Préhistoire','','','',' prehistoire ',' Préhistoire ',' prehistoire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1620,'fr_FR','Terre','','','',' terre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1621,'fr_FR','Animaux','','','',' animaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1622,'fr_FR','Structure','','','',' structure ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1623,'fr_FR','Climatologie','','','',' climatologie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1624,'fr_FR','Météorologie','','','',' meteorologie ',' Météorologie ',' meteorologie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1625,'fr_FR','Océanographie - Hydrologie','','','',' oceanographie hydrologie ',' Océanographie - Hydrologie ',' oceanographie hydrologie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1626,'fr_FR','Continents et relief','','','',' continents relief ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1627,'fr_FR','Roches et minéraux','','','',' roches mineraux ',' Roches et minéraux ',' roches mineraux ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1628,'fr_FR','Volcans','','','',' volcans ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1629,'fr_FR','Micro-organismes','','','',' micro organismes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1630,'fr_FR','Invertébrés','','','',' invertebres ',' Invertébrés ',' invertebres ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1631,'fr_FR','Mollusques','','','',' mollusques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1632,'fr_FR','Crustacés','','','',' crustaces ',' Crustacés ',' crustaces ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1633,'fr_FR','Insectes','','','',' insectes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1634,'fr_FR','Arachnides','','','',' arachnides ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1635,'fr_FR','Poissons','','','',' poissons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1636,'fr_FR','Batraciens','','','',' batraciens ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1637,'fr_FR','Reptiles','','','',' reptiles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1638,'fr_FR','Oiseaux','','','',' oiseaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1639,'fr_FR','Mammifères','','','',' mammiferes ',' Mammifères ',' mammiferes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1640,'fr_FR','Marsupiaux','','','',' marsupiaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1641,'fr_FR','Chat','','','',' chat ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1642,'fr_FR','Primates','','','',' primates ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1643,'fr_FR','Chien','','','',' chien ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1644,'fr_FR','Félins','','','',' felins ',' Félins ',' felins ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1645,'fr_FR','Rongeurs','','','',' rongeurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1646,'fr_FR','Archéologie','','','',' archeologie ',' Archéologie ',' archeologie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1647,'fr_FR','Communication et Information','','','',' communication information ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1648,'fr_FR','Economie','','','',' economie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1649,'fr_FR','Démographie','','','',' demographie ',' Démographie ',' demographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1650,'fr_FR','Géographie','','','',' geographie ',' Géographie ',' geographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1651,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1652,'fr_FR','Langues - Linguistique','','','',' langues linguistique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1653,'fr_FR','Médecine','','','',' medecine ',' Médecine ',' medecine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1654,'fr_FR','Philosophie','','','',' philosophie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1655,'fr_FR','Psychologie - Psychanalyse','','','',' psychologie psychanalyse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1656,'fr_FR','Sociologie','','','',' sociologie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1657,'fr_FR','Ethnologie','','','',' ethnologie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1658,'fr_FR','Bibliothéconomie','','','',' bibliotheconomie ',' Bibliothéconomie ',' bibliotheconomie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1659,'fr_FR','Société de l\'information','','','',' societe information ',' Société de l\'information ',' societe information ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1660,'fr_FR','Journalisme','','','',' journalisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1661,'fr_FR','Edition','','','',' edition ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1662,'fr_FR','Communication','','','',' communication ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1663,'fr_FR','Antiquité et mondes anciens','','','',' antiquite mondes anciens ',' Antiquité et mondes anciens ',' antiquite mondes anciens ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1664,'fr_FR','Moyen-Age','','','',' moyen age ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1665,'fr_FR','Renaissance','','','',' renaissance ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1666,'fr_FR','XVIIème siècle (De 1600 à 1699)','','','',' xviieme siecle 1600 1699 ',' XVIIème siècle (De 1600 à 1699) ',' xviieme siecle 1600 1699 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1667,'fr_FR','XVIIIème siècle (De 1700 à 1799)','','','',' xviiieme siecle 1700 1799 ',' XVIIIème siècle (De 1700 à 1799) ',' xviiieme siecle 1700 1799 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1668,'fr_FR','XIXème siècle (De 1800 à 1899)','','','',' xixeme siecle 1800 1899 ',' XIXème siècle (De 1800 à 1899) ',' xixeme siecle 1800 1899 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1669,'fr_FR','De 1900 à 1914','','','',' 1900 1914 ',' De 1900 à 1914 ',' 1900 1914 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1670,'fr_FR','Première Guerre Mondiale (1914-1918)','','','',' premiere guerre mondiale 1914 1918 ',' Première Guerre Mondiale (1914-1918) ',' premiere guerre mondiale 1914 1918 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1671,'fr_FR','Entre-deux guerres (1919-1938)','','','',' entre deux guerres 1919 1938 ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1672,'fr_FR','Deuxième Guerre Mondiale (1939-1945)','','','',' deuxieme guerre mondiale 1939 1945 ',' Deuxième Guerre Mondiale (1939-1945) ',' deuxieme guerre mondiale 1939 1945 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1673,'fr_FR','De 1946 à 1999','','','',' 1946 1999 ',' De 1946 à 1999 ',' 1946 1999 ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1674,'fr_FR','Depuis 2000','','','',' depuis 2000 ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1675,'fr_FR','Métaphysique','','','',' metaphysique ',' Métaphysique ',' metaphysique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1676,'fr_FR','Epistémologie','','','',' epistemologie ',' Epistémologie ',' epistemologie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1677,'fr_FR','Philosophie antique','','','',' philosophie antique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1678,'fr_FR','Philosophie médiévale','','','',' philosophie medievale ',' Philosophie médiévale ',' philosophie medievale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1679,'fr_FR','Philosophie orientale','','','',' philosophie orientale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1680,'fr_FR','Philosophie occidentale moderne','','','',' philosophie occidentale moderne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1681,'fr_FR','Amour','','','',' amour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1682,'fr_FR','De l\'enfant à l\'âge adulte','','','',' enfant age adulte ',' De l\'enfant à l\'âge adulte ',' enfant age adulte ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1683,'fr_FR','Problèmes et débats de société','','','',' problemes debats societe ',' Problèmes et débats de société ',' problemes debats societe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1684,'fr_FR','Vivre ensemble','','','',' vivre ensemble ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1685,'fr_FR','Criminalité','','','',' criminalite ',' Criminalité ',' criminalite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1686,'fr_FR','Emploi','','','',' emploi ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1687,'fr_FR','Enseignement et Formation','','','',' enseignement formation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1688,'fr_FR','Couple','','','',' couple ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1689,'fr_FR','Famille','','','',' famille ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1690,'fr_FR','Environnement','','','',' environnement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1691,'fr_FR','Handicap','','','',' handicap ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1692,'fr_FR','Illettrisme','','','',' illettrisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1693,'fr_FR','Migrations','','','',' migrations ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1694,'fr_FR','Mode et Costume','','','',' mode costume ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1695,'fr_FR','Urbanisme','','','',' urbanisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1696,'fr_FR','Religion','','','',' religion ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1697,'fr_FR','Esotérisme','','','',' esoterisme ',' Esotérisme ',' esoterisme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1698,'fr_FR','Sexualité','','','',' sexualite ',' Sexualité ',' sexualite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1699,'fr_FR','Solidarité et Action sociale','','','',' solidarite action sociale ',' Solidarité et Action sociale ',' solidarite action sociale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1700,'fr_FR','Logement','','','',' logement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1701,'fr_FR','Vie associative','','','',' vie associative ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1702,'fr_FR','Enfants','','','',' enfants ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1703,'fr_FR','Jeunes','','','',' jeunes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1704,'fr_FR','Femmes','','','',' femmes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1705,'fr_FR','Hommes','','','',' hommes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1706,'fr_FR','Troisième âge','','','',' troisieme age ',' Troisième âge ',' troisieme age ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1707,'fr_FR','Conseil et Orientation','','','',' conseil orientation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1708,'fr_FR','Enseignement primaire','','','',' enseignement primaire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1709,'fr_FR','Enseignement secondaire','','','',' enseignement secondaire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1710,'fr_FR','Enseignement supérieur','','','',' enseignement superieur ',' Enseignement supérieur ',' enseignement superieur ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1711,'fr_FR','Examens et Concours','','','',' examens concours ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1712,'fr_FR','Pédagogie','','','',' pedagogie ',' Pédagogie ',' pedagogie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1713,'fr_FR','Problèmes et Débats','','','',' problemes debats ',' Problèmes et Débats ',' problemes debats ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1714,'fr_FR','Drogue','','','',' drogue ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1715,'fr_FR','Bible','','','',' bible ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1716,'fr_FR','Christianisme','','','',' christianisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1717,'fr_FR','Sectes','','','',' sectes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1718,'fr_FR','Bouddhisme','','','',' bouddhisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1719,'fr_FR','Hindouisme','','','',' hindouisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1720,'fr_FR','Judaîsme','','','',' judaisme ',' Judaîsme ',' judaisme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1721,'fr_FR','Islam','','','',' islam ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1722,'fr_FR','Autres mouvements religieux','','','',' autres mouvements religieux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1723,'fr_FR','Artisanat','','','',' artisanat ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1724,'fr_FR','Arts plastiques','','','',' arts plastiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1725,'fr_FR','Chasse et pêche','','','',' chasse peche ',' Chasse et pêche ',' chasse peche ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1726,'fr_FR','Collections','','','',' collections ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1727,'fr_FR','Jardin','','','',' jardin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1728,'fr_FR','Généalogie','','','',' genealogie ',' Généalogie ',' genealogie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1729,'fr_FR','Jeux et Jouets','','','',' jeux jouets ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1730,'fr_FR','Photographie','','','',' photographie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1731,'fr_FR','Sports','','','',' sports ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1733,'fr_FR','Véhicules','','','',' vehicules ',' Véhicules ',' vehicules ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1734,'fr_FR','Régions','','','',' regions ',' Régions ',' regions ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1735,'fr_FR','Alsace','','','',' alsace ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1736,'fr_FR','Aquitaine','','','',' aquitaine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1737,'fr_FR','Auvergne','','','',' auvergne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1738,'fr_FR','Bourgogne','','','',' bourgogne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1739,'fr_FR','Bretagne','','','',' bretagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1740,'fr_FR','Centre','','','',' centre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1741,'fr_FR','Champagne-Ardenne','','','',' champagne ardenne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1742,'fr_FR','Corse','','','',' corse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1743,'fr_FR','Franche-Comté','','','',' franche comte ',' Franche-Comté ',' franche comte ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1744,'fr_FR','Ile-de-France','','','',' ile france ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1746,'fr_FR','Languedoc-Roussillon','','','',' languedoc roussillon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1747,'fr_FR','Limousin','','','',' limousin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1748,'fr_FR','Pays de la Loire','','','',' pays loire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1749,'fr_FR','Lorraine','','','',' lorraine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1750,'fr_FR','Midi-Pyrénées','','','',' midi pyrenees ',' Midi-Pyrénées ',' midi pyrenees ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1751,'fr_FR','Nord-Pas-de-Calais','','','',' nord pas calais ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1752,'fr_FR','Normandie (Haute-)','','','',' normandie haute ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1753,'fr_FR','Normandie (Basse-)','','','',' normandie basse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1754,'fr_FR','Picardie','','','',' picardie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1755,'fr_FR','Poitou-Charentes','','','',' poitou charentes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1756,'fr_FR','Provence-Alpes-Côte d\'Azur','','','',' provence alpes cote azur ',' Provence-Alpes-Côte d\'Azur ',' provence alpes cote azur ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1757,'fr_FR','Rhône-Alpes','','','',' rhone alpes ',' Rhône-Alpes ',' rhone alpes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1758,'fr_FR','Agriculture - Elevage','','','',' agriculture elevage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1759,'fr_FR','Agroalimentaire','','','',' agroalimentaire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1760,'fr_FR','Aviation - Aéronautique','','','',' aviation aeronautique ',' Aviation - Aéronautique ',' aviation aeronautique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1761,'fr_FR','Bâtiment et Travaux publics','','','',' batiment travaux publics ',' Bâtiment et Travaux publics ',' batiment travaux publics ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1762,'fr_FR','Energie','','','',' energie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1763,'fr_FR','Espace - Astronautique','','','',' espace astronautique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1764,'fr_FR','Industries diverses','','','',' industries diverses ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1765,'fr_FR','Informatique','','','',' informatique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1766,'fr_FR','Navigation','','','',' navigation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1767,'fr_FR','Inventions','','','',' inventions ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1768,'fr_FR','Robots - Vie artificielle','','','',' robots vie artificielle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1769,'fr_FR','Télécommunications','','','',' telecommunications ',' Télécommunications ',' telecommunications ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1770,'fr_FR','Transports','','','',' transports ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1771,'fr_FR','Commerce','','','',' commerce ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1772,'fr_FR','Gestion de l\'entreprise','','','',' gestion entreprise ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1773,'fr_FR','Programmation','','','',' programmation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1774,'fr_FR','Bases de données','','','',' bases donnees ',' Bases de données ',' bases donnees ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1775,'fr_FR','Logiciels','','','',' logiciels ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1776,'fr_FR','Réseaux','','','',' reseaux ',' Réseaux ',' reseaux ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1777,'fr_FR','Internet','','','',' internet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1778,'fr_FR','Animaux domestiques','','','',' animaux domestiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1779,'fr_FR','Bricolage','','','',' bricolage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1780,'fr_FR','Cuisine','','','',' cuisine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1781,'fr_FR','Développement personnel','','','',' developpement personnel ',' Développement personnel ',' developpement personnel ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1782,'fr_FR','Droit pratique','','','',' droit pratique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1783,'fr_FR','Ecologie pratique','','','',' ecologie pratique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1784,'fr_FR','Maison et Décoration','','','',' maison decoration ',' Maison et Décoration ',' maison decoration ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1785,'fr_FR','Puériculture','','','',' puericulture ',' Puériculture ',' puericulture ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1786,'fr_FR','Parents et Enfants','','','',' parents enfants ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1787,'fr_FR','Santé','','','',' sante ',' Santé ',' sante ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1788,'fr_FR','Afrique','','','',' afrique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1789,'fr_FR','Amérique du Nord','','','',' amerique nord ',' Amérique du Nord ',' amerique nord ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1790,'fr_FR','Amérique centrale','','','',' amerique centrale ',' Amérique centrale ',' amerique centrale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1791,'fr_FR','Amérique du Sud','','','',' amerique sud ',' Amérique du Sud ',' amerique sud ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1792,'fr_FR','Europe','','','',' europe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1793,'fr_FR','Asie','','','',' asie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1794,'fr_FR','Océanie','','','',' oceanie ',' Océanie ',' oceanie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1795,'fr_FR','Antarctique','','','',' antarctique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1796,'fr_FR','Arctique','','','',' arctique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1797,'fr_FR','Afrique du Nord','','','',' afrique nord ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1798,'fr_FR','Afrique de l\'Ouest','','','',' afrique ouest ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1799,'fr_FR','Afrique centrale','','','',' afrique centrale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1800,'fr_FR','Afrique de l\'Est','','','',' afrique est ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1801,'fr_FR','Afrique équatoriale','','','',' afrique equatoriale ',' Afrique équatoriale ',' afrique equatoriale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1802,'fr_FR','Afrique du Sud','','','',' afrique sud ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1803,'fr_FR','Iles de l\'océan indien','','','',' iles ocean indien ',' Iles de l\'océan indien ',' iles ocean indien ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1804,'fr_FR','Alaska','','','',' alaska ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1805,'fr_FR','Canada','','','',' canada ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1806,'fr_FR','Saint-Pierre-et-Miquelon','','','',' saint pierre miquelon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1807,'fr_FR','Groenland','','','',' groenland ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1808,'fr_FR','Etats-Unis','','','',' etats unis ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1809,'fr_FR','Bermudes','','','',' bermudes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1810,'fr_FR','Mexique','','','',' mexique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1811,'fr_FR','Belize','','','',' belize ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1812,'fr_FR','Guatemala','','','',' guatemala ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1813,'fr_FR','Salvador','','','',' salvador ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1814,'fr_FR','Honduras','','','',' honduras ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1815,'fr_FR','Nicaragua','','','',' nicaragua ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1816,'fr_FR','Costa Rica','','','',' costa rica ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1817,'fr_FR','Panama','','','',' panama ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1818,'fr_FR','Antilles','','','',' antilles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1819,'fr_FR','Colombie','','','',' colombie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1820,'fr_FR','Vénézuela','','','',' venezuela ',' Vénézuela ',' venezuela ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1821,'fr_FR','Guyana','','','',' guyana ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1822,'fr_FR','Surinam','','','',' surinam ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1823,'fr_FR','Guyane française','','','',' guyane francaise ',' Guyane française ',' guyane francaise ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1824,'fr_FR','Equateur','','','',' equateur ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1825,'fr_FR','Pérou','','','',' perou ',' Pérou ',' perou ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1826,'fr_FR','Brésil','','','',' bresil ',' Brésil ',' bresil ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1827,'fr_FR','Bolivie','','','',' bolivie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1828,'fr_FR','Chili','','','',' chili ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1829,'fr_FR','Paraguay','','','',' paraguay ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1830,'fr_FR','Argentine','','','',' argentine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1831,'fr_FR','Uruguay','','','',' uruguay ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1832,'fr_FR','Europe du Nord','','','',' europe nord ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1833,'fr_FR','Europe de l\'Ouest','','','',' europe ouest ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1834,'fr_FR','Europe centrale','','','',' europe centrale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1835,'fr_FR','Europe de l\'Est','','','',' europe est ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1836,'fr_FR','Europe du Sud','','','',' europe sud ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1837,'fr_FR','Balkans','','','',' balkans ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1838,'fr_FR','Moyen-Orient','','','',' moyen orient ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1839,'fr_FR','Transcaucasie','','','',' transcaucasie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1840,'fr_FR','Asie centrale','','','',' asie centrale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1841,'fr_FR','Asie de l\'Est','','','',' asie est ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1842,'fr_FR','Asie du Sud','','','',' asie sud ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1843,'fr_FR','Asie du Sud-Est','','','',' asie sud est ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1844,'fr_FR','Australie','','','',' australie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1845,'fr_FR','Mélanésie','','','',' melanesie ',' Mélanésie ',' melanesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1846,'fr_FR','Micronésie','','','',' micronesie ',' Micronésie ',' micronesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1847,'fr_FR','Polynésie','','','',' polynesie ',' Polynésie ',' polynesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1848,'fr_FR','Maroc','','','',' maroc ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1849,'fr_FR','Tunisie','','','',' tunisie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1850,'fr_FR','Algérie','','','',' algerie ',' Algérie ',' algerie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1851,'fr_FR','Libye','','','',' libye ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1852,'fr_FR','Sierra Leone','','','',' sierra leone ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1853,'fr_FR','Mauritanie','','','',' mauritanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1854,'fr_FR','Mali','','','',' mali ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1855,'fr_FR','Sénégal','','','',' senegal ',' Sénégal ',' senegal ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1856,'fr_FR','Guin','','','',' guin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1857,'fr_FR','Côte d\'Ivoire','','','',' cote ivoire ',' Côte d\'Ivoire ',' cote ivoire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1858,'fr_FR','Gambie','','','',' gambie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1859,'fr_FR','Guinée-Bissau','','','',' guinee bissau ',' Guinée-Bissau ',' guinee bissau ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1860,'fr_FR','Liberia','','','',' liberia ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1861,'fr_FR','Burkina Faso','','','',' burkina faso ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1862,'fr_FR','Ghana','','','',' ghana ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1863,'fr_FR','Togo','','','',' togo ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1864,'fr_FR','Bénin','','','',' benin ',' Bénin ',' benin ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1865,'fr_FR','Iles du Cap-Vert','','','',' iles cap vert ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1866,'fr_FR','Tchad','','','',' tchad ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1867,'fr_FR','Niger','','','',' niger ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1868,'fr_FR','Nigeria','','','',' nigeria ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1869,'fr_FR','Cameroun','','','',' cameroun ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1870,'fr_FR','Centrafricaine (République)','','','',' centrafricaine republique ',' Centrafricaine (République) ',' centrafricaine republique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1871,'fr_FR','Soudan','','','',' soudan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1872,'fr_FR','Erythrée','','','',' erythree ',' Erythrée ',' erythree ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1873,'fr_FR','Ethiopie','','','',' ethiopie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1874,'fr_FR','Somalie','','','',' somalie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1875,'fr_FR','Kenya','','','',' kenya ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1876,'fr_FR','Tanzanie','','','',' tanzanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1877,'fr_FR','Djibouti','','','',' djibouti ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1878,'fr_FR','Ouganda','','','',' ouganda ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1879,'fr_FR','Congo','','','',' congo ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1880,'fr_FR','Congo (République démocratique du)','','','',' congo republique democratique ',' Congo (République démocratique du) ',' congo republique democratique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1881,'fr_FR','Gabon','','','',' gabon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1882,'fr_FR','Guinée équatoriale','','','',' guinee equatoriale ',' Guinée équatoriale ',' guinee equatoriale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1883,'fr_FR','Sao Tomé et Principe','','','',' sao tome principe ',' Sao Tomé et Principe ',' sao tome principe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1884,'fr_FR','Rwanda','','','',' rwanda ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1885,'fr_FR','Burundi','','','',' burundi ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1886,'fr_FR','Angola','','','',' angola ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1887,'fr_FR','Zambie','','','',' zambie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1888,'fr_FR','Zimbabwe','','','',' zimbabwe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1889,'fr_FR','Botswana','','','',' botswana ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1890,'fr_FR','Afrique du Sud','','','',' afrique sud ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1891,'fr_FR','Swaziland','','','',' swaziland ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1892,'fr_FR','Lesotho','','','',' lesotho ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1893,'fr_FR','Namibie','','','',' namibie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1894,'fr_FR','Mozambique','','','',' mozambique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1895,'fr_FR','Malawi','','','',' malawi ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1896,'fr_FR','Seychelles','','','',' seychelles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1897,'fr_FR','Ile Maurice','','','',' ile maurice ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1898,'fr_FR','Réunion','','','',' reunion ',' Réunion ',' reunion ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1899,'fr_FR','Madagascar','','','',' madagascar ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1900,'fr_FR','Comores','','','',' comores ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1901,'fr_FR','Mayotte','','','',' mayotte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1902,'fr_FR','Bahamas','','','',' bahamas ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1903,'fr_FR','Cuba','','','',' cuba ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1904,'fr_FR','Jamaïque','','','',' jamaique ',' Jamaïque ',' jamaique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1905,'fr_FR','Haïti','','','',' haiti ',' Haïti ',' haiti ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1906,'fr_FR','Dominicaine (République)','','','',' dominicaine republique ',' Dominicaine (République) ',' dominicaine republique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1907,'fr_FR','Porto Rico','','','',' porto rico ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1908,'fr_FR','Guadeloupe','','','',' guadeloupe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1909,'fr_FR','Martinique','','','',' martinique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1910,'fr_FR','Islande','','','',' islande ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1911,'fr_FR','Norvège','','','',' norvege ',' Norvège ',' norvege ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1912,'fr_FR','Suède','','','',' suede ',' Suède ',' suede ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1913,'fr_FR','Finlande','','','',' finlande ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1914,'fr_FR','Danemark','','','',' danemark ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1915,'fr_FR','Irlande','','','',' irlande ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1916,'fr_FR','Grande-Bretagne','','','',' grande bretagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1917,'fr_FR','France','','','',' france ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1918,'fr_FR','Pays-Bas','','','',' pays bas ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1919,'fr_FR','Belgique','','','',' belgique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1920,'fr_FR','Luxembourg','','','',' luxembourg ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1921,'fr_FR','Suisse','','','',' suisse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1922,'fr_FR','Allemagne','','','',' allemagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1923,'fr_FR','Tchèque (République)','','','',' tcheque republique ',' Tchèque (République) ',' tcheque republique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1924,'fr_FR','Slovaquie','','','',' slovaquie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1925,'fr_FR','Autriche','','','',' autriche ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1926,'fr_FR','Hongrie','','','',' hongrie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1927,'fr_FR','Pologne','','','',' pologne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1928,'fr_FR','Estonie','','','',' estonie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1929,'fr_FR','Lettonie','','','',' lettonie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1930,'fr_FR','Lituanie','','','',' lituanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1931,'fr_FR','Biélorussie','','','',' bielorussie ',' Biélorussie ',' bielorussie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1932,'fr_FR','Ukraine','','','',' ukraine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1933,'fr_FR','Moldavie','','','',' moldavie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1934,'fr_FR','Roumanie','','','',' roumanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1935,'fr_FR','Portugal','','','',' portugal ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1936,'fr_FR','Espagne','','','',' espagne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1937,'fr_FR','Italie','','','',' italie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1938,'fr_FR','Malte','','','',' malte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1939,'fr_FR','Slovénie','','','',' slovenie ',' Slovénie ',' slovenie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1940,'fr_FR','Croatie','','','',' croatie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1941,'fr_FR','Bosnie-Herzégovine','','','',' bosnie herzegovine ',' Bosnie-Herzégovine ',' bosnie herzegovine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1942,'fr_FR','Macédoine','','','',' macedoine ',' Macédoine ',' macedoine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1943,'fr_FR','Albanie','','','',' albanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1944,'fr_FR','Grèce','','','',' grece ',' Grèce ',' grece ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1945,'fr_FR','Bulgarie','','','',' bulgarie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1946,'fr_FR','Serbie','','','',' serbie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1947,'fr_FR','Monténégro','','','',' montenegro ',' Monténégro ',' montenegro ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1948,'fr_FR','Proche-Orient','','','',' proche orient ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1949,'fr_FR','Jordanie','','','',' jordanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1950,'fr_FR','Irak','','','',' irak ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1951,'fr_FR','Arabie','','','',' arabie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1952,'fr_FR','Chypre','','','',' chypre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1953,'fr_FR','Egypte','','','',' egypte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1954,'fr_FR','Israël','','','',' israel ',' Israël ',' israel ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1955,'fr_FR','Liban','','','',' liban ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1956,'fr_FR','Syrie','','','',' syrie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1957,'fr_FR','Palestine (Territoires autonomes de)','','','',' palestine territoires autonomes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1958,'fr_FR','Turquie','','','',' turquie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1959,'fr_FR','Arabie saoudite','','','',' arabie saoudite ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1960,'fr_FR','Bahrein','','','',' bahrein ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1961,'fr_FR','Emirats arabes unis','','','',' emirats arabes unis ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1962,'fr_FR','Koweït','','','',' koweit ',' Koweït ',' koweit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1963,'fr_FR','Oman','','','',' oman ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1964,'fr_FR','Qatar','','','',' qatar ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1965,'fr_FR','Yémen','','','',' yemen ',' Yémen ',' yemen ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1966,'fr_FR','Géorgie','','','',' georgie ',' Géorgie ',' georgie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1967,'fr_FR','Arménie','','','',' armenie ',' Arménie ',' armenie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1968,'fr_FR','Azerbaïdjan','','','',' azerbaidjan ',' Azerbaïdjan ',' azerbaidjan ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1969,'fr_FR','Russie (Fédération de)','','','',' russie federation ',' Russie (Fédération de) ',' russie federation ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1970,'fr_FR','Kazakhstan','','','',' kazakhstan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1971,'fr_FR','Ouzbékistan','','','',' ouzbekistan ',' Ouzbékistan ',' ouzbekistan ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1972,'fr_FR','Kirghizistan','','','',' kirghizistan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1973,'fr_FR','Turkménistan','','','',' turkmenistan ',' Turkménistan ',' turkmenistan ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1974,'fr_FR','Tadjikistan','','','',' tadjikistan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1975,'fr_FR','Iran','','','',' iran ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1976,'fr_FR','Afghanistan','','','',' afghanistan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1977,'fr_FR','Pakistan','','','',' pakistan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1978,'fr_FR','Mongolie','','','',' mongolie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1979,'fr_FR','Corée du Nord','','','',' coree nord ',' Corée du Nord ',' coree nord ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1980,'fr_FR','Corée du Sud','','','',' coree sud ',' Corée du Sud ',' coree sud ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1981,'fr_FR','Japon','','','',' japon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1982,'fr_FR','Chine','','','',' chine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1983,'fr_FR','TaÏwan','','','',' taiwan ',' TaÏwan ',' taiwan ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1984,'fr_FR','Inde','','','',' inde ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1985,'fr_FR','Népal','','','',' nepal ',' Népal ',' nepal ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1986,'fr_FR','Bhoutan','','','',' bhoutan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1987,'fr_FR','Bangladesh','','','',' bangladesh ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1988,'fr_FR','Sri Lanka','','','',' sri lanka ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1989,'fr_FR','Maldives','','','',' maldives ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1990,'fr_FR','Birmanie','','','',' birmanie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1991,'fr_FR','Brunei','','','',' brunei ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1992,'fr_FR','Cambodge','','','',' cambodge ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1993,'fr_FR','Indonésie','','','',' indonesie ',' Indonésie ',' indonesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1994,'fr_FR','Laos','','','',' laos ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1995,'fr_FR','Malaisie','','','',' malaisie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1996,'fr_FR','Philippines','','','',' philippines ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1997,'fr_FR','Singapour','','','',' singapour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1998,'fr_FR','Thaïlande','','','',' thailande ',' Thaïlande ',' thailande ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,1999,'fr_FR','Viêt-Nam','','','',' viet nam ',' Viêt-Nam ',' viet nam ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2000,'fr_FR','Papouasie-Nouvelle-Guinée','','','',' papouasie nouvelle guinee ',' Papouasie-Nouvelle-Guinée ',' papouasie nouvelle guinee ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2001,'fr_FR','Nouvelle-Calédonie','','','',' nouvelle caledonie ',' Nouvelle-Calédonie ',' nouvelle caledonie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2002,'fr_FR','Vanuatu','','','',' vanuatu ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2003,'fr_FR','Iles Fidji','','','',' iles fidji ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2004,'fr_FR','Iles Salomon','','','',' iles salomon ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2005,'fr_FR','Bismarck (archipel)','','','',' bismarck archipel ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2006,'fr_FR','Carolines','','','',' carolines ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2007,'fr_FR','Kiribati','','','',' kiribati ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2008,'fr_FR','Mariannes','','','',' mariannes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2009,'fr_FR','Marshall','','','',' marshall ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2010,'fr_FR','Palau','','','',' palau ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2011,'fr_FR','Nouvelle-Zélande','','','',' nouvelle zelande ',' Nouvelle-Zélande ',' nouvelle zelande ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2012,'fr_FR','Tonga','','','',' tonga ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2013,'fr_FR','Wallis-et-Futuna','','','',' wallis futuna ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2014,'fr_FR','Nauru','','','',' nauru ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2015,'fr_FR','Tuvalu','','','',' tuvalu ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2016,'fr_FR','Samoa occidentales','','','',' samoa occidentales ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2017,'fr_FR','Hawaii','','','',' hawaii ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2018,'fr_FR','Samoa orientales','','','',' samoa orientales ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2019,'fr_FR','Iles Cook','','','',' iles cook ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2020,'fr_FR','Polynésie française','','','',' polynesie francaise ',' Polynésie française ',' polynesie francaise ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2021,'fr_FR','Ile de Pâques','','','',' ile paques ',' Ile de Pâques ',' ile paques ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2022,'fr_FR','Sciences de la vie','','','',' sciences vie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2023,'fr_FR','Hommes','','','',' hommes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2024,'fr_FR','Hommes','','','',' hommes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2025,'fr_FR','Femmes','','','',' femmes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2026,'fr_FR','Femmes','','','',' femmes ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2027,'fr_FR','Homosexualité','','','',' homosexualite ',' Homosexualité ',' homosexualite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2028,'fr_FR','Sommeil','','','',' sommeil ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2029,'fr_FR','Avocat','','','',' avocat ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2030,'fr_FR','Maladie mentale','','','',' maladie mentale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2031,'fr_FR','Autisme','','','',' autisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2032,'fr_FR','Psychiatrie','','','',' psychiatrie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2034,'fr_FR','Formes et tailles','','','',' formes tailles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2035,'fr_FR','Littérature de Méditerranée orientale et Maghreb','','','',' litterature mediterranee orientale maghreb ',' Littérature de Méditerranée orientale et Maghreb ',' litterature mediterranee orientale maghreb ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2036,'fr_FR','Littérature anglaise','','','',' litterature anglaise ',' Littérature anglaise ',' litterature anglaise ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2037,'fr_FR','Angoisse','','','',' angoisse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2040,'fr_FR','Roller','','','',' roller ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2043,'fr_FR','Fauteuil roulant','','','',' fauteuil roulant ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2044,'fr_FR','Essai et récit','','','',' essai recit ',' Essai et récit ',' essai recit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2045,'fr_FR','Littérature française','','','',' litterature francaise ',' Littérature française ',' litterature francaise ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2046,'fr_FR','Littérature étrangère (sélection)','','','',' litterature etrangere selection ',' Littérature étrangère (sélection) ',' litterature etrangere selection ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2047,'fr_FR','Littérature espagnole','','','',' litterature espagnole ',' Littérature espagnole ',' litterature espagnole ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2048,'fr_FR','Littérature d\'Europe centrale','','','',' litterature europe centrale ',' Littérature d\'Europe centrale ',' litterature europe centrale ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2049,'fr_FR','Littérature italienne','','','',' litterature italienne ',' Littérature italienne ',' litterature italienne ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2050,'fr_FR','Littérature lusitanienne (Portugal, Brésil)','','','',' litterature lusitanienne portugal bresil ',' Littérature lusitanienne (Portugal, Brésil) ',' litterature lusitanienne portugal bresil ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2051,'fr_FR','Littérature nordique','','','',' litterature nordique ',' Littérature nordique ',' litterature nordique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2052,'fr_FR','Littérature russe','','','',' litterature russe ',' Littérature russe ',' litterature russe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2053,'fr_FR','Littérature d\'Afrique noire','','','',' litterature afrique noire ',' Littérature d\'Afrique noire ',' litterature afrique noire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2054,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2057,'fr_FR','Aventure','','','',' aventure ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2058,'fr_FR','Roman historique','','','',' roman historique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2059,'fr_FR','Amour','','','',' amour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2060,'fr_FR','Science-fiction','','','',' science fiction ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2061,'fr_FR','Humour','','','',' humour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2062,'fr_FR','Policier','','','',' policier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2063,'fr_FR','Horreur','','','',' horreur ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2064,'fr_FR','Fantastique','','','',' fantastique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2065,'fr_FR','Vie quotidienne','','','',' vie quotidienne ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2068,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2071,'fr_FR','Chiffres','','','',' chiffres ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2072,'fr_FR','Alphabet','','','',' alphabet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2074,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2075,'fr_FR','Anglais','','','',' anglais ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2076,'fr_FR','Café','','','',' cafe ',' Café ',' cafe ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2078,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2079,'fr_FR','Mayas','','','',' mayas ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2080,'fr_FR','Incas','','','',' incas ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2081,'fr_FR','Aztèques','','','',' azteques ',' Aztèques ',' azteques ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2082,'fr_FR','Civilisations précolombiennes','','','',' civilisations precolombiennes ',' Civilisations précolombiennes ',' civilisations precolombiennes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2084,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2085,'fr_FR','Elèves','','','',' eleves ',' Elèves ',' eleves ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2086,'fr_FR','Prison','','','',' prison ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2087,'fr_FR','Prisonniers','','','',' prisonniers ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2089,'fr_FR','Critique littéraire - Biographies','','','',' critique litteraire biographies ',' Critique littéraire - Biographies ',' critique litteraire biographies ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2090,'fr_FR','Byron, George Gordon Noel','','','',' byron george gordon noel ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2093,'fr_FR','Athènes','','','',' athenes ',' Athènes ',' athenes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2094,'fr_FR','Epices','','','',' epices ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2095,'fr_FR','Essai et récit','','','',' essai recit ',' Essai et récit ',' essai recit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2096,'fr_FR','Essai et récit','','','',' essai recit ',' Essai et récit ',' essai recit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2097,'fr_FR','Essai et récit','','','',' essai recit ',' Essai et récit ',' essai recit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2098,'fr_FR','Venise','','','',' venise ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2099,'fr_FR','Essai et récit','','','',' essai recit ',' Essai et récit ',' essai recit ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2101,'fr_FR','Aventure','','','',' aventure ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2102,'fr_FR','Humour','','','',' humour ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2103,'fr_FR','Policier','','','',' policier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2104,'fr_FR','Science-fiction','','','',' science fiction ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2105,'fr_FR','Récit historique','','','',' recit historique ',' Récit historique ',' recit historique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2106,'fr_FR','Fantastique','','','',' fantastique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2107,'fr_FR','Western','','','',' western ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2108,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2109,'fr_FR','Amitié','','','',' amitie ',' Amitié ',' amitie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2110,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2111,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2112,'fr_FR','Roman d\'aventure','','','',' roman aventure ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2113,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2116,'fr_FR','Site web','','','',' site web ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2120,'fr_FR','Cultures et communauté','','','',' cultures communaute ',' Cultures et communauté ',' cultures communaute ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2121,'fr_FR','Gitans','','','',' gitans ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2124,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2125,'fr_FR','Aliments','','','',' aliments ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2126,'fr_FR','Huître','','','',' huitre ',' Huître ',' huitre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2127,'fr_FR','Moule','','','',' moule ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2128,'fr_FR','Coquillages','','','',' coquillages ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2129,'fr_FR','Conchyliculture','','','',' conchyliculture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2130,'fr_FR','Ostréiculture','','','',' ostreiculture ',' Ostréiculture ',' ostreiculture ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2131,'fr_FR','Mytiliculture','','','',' mytiliculture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2132,'fr_FR','Lingerie','','','',' lingerie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2135,'fr_FR','Par sujet','','','',' par sujet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2136,'fr_FR','Atlantide','','','',' atlantide ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2137,'fr_FR','Fête foraine','','','',' fete foraine ',' Fête foraine ',' fete foraine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2139,'fr_FR','Cheval','','','',' cheval ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2140,'fr_FR','Equidés','','','',' equides ',' Equidés ',' equides ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2141,'fr_FR','Canidés','','','',' canides ',' Canidés ',' canides ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2142,'fr_FR','Musée de l\'Homme','','','',' musee homme ',' Musée de l\'Homme ',' musee homme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2144,'fr_FR','Paris','','','',' paris ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2146,'fr_FR','Surréalisme','','','',' surrealisme ',' Surréalisme ',' surrealisme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2147,'fr_FR','Histoire littéraire (ouvrages généraux)','','','',' histoire litteraire ouvrages generaux ',' Histoire littéraire (ouvrages généraux) ',' histoire litteraire ouvrages generaux ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2148,'fr_FR','Dadaïsme','','','',' dadaisme ',' Dadaïsme ',' dadaisme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2150,'fr_FR','Romantisme','','','',' romantisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2152,'fr_FR','Antiquité','','','',' antiquite ',' Antiquité ',' antiquite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2153,'fr_FR','Renaissance','','','',' renaissance ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2154,'fr_FR','Moyen-Age','','','',' moyen age ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2155,'fr_FR','XVIIème siècle','','','',' xviieme siecle ',' XVIIème siècle ',' xviieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2156,'fr_FR','XVIIIème siècle','','','',' xviiieme siecle ',' XVIIIème siècle ',' xviiieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2157,'fr_FR','XIXème siècle','','','',' xixeme siecle ',' XIXème siècle ',' xixeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2158,'fr_FR','XXème siècle','','','',' xxeme siecle ',' XXème siècle ',' xxeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2159,'fr_FR','Géographie','','','',' geographie ',' Géographie ',' geographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2160,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2161,'fr_FR','Aquarelle','','','',' aquarelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2162,'fr_FR','Mer','','','',' mer ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2163,'fr_FR','Rivière','','','',' riviere ',' Rivière ',' riviere ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2164,'fr_FR','Araignées','','','',' araignees ',' Araignées ',' araignees ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2165,'fr_FR','Reptiles','','','',' reptiles ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2166,'fr_FR','Littérature','','','',' litterature ',' Littérature ',' litterature ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2167,'fr_FR','Paysage','','','',' paysage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2168,'fr_FR','Eléments','','','',' elements ',' Eléments ',' elements ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2169,'fr_FR','Ciel','','','',' ciel ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2170,'fr_FR','Art du paysage','','','',' art paysage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2171,'fr_FR','Mythes et légendes','','','',' mythes legendes ',' Mythes et légendes ',' mythes legendes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2172,'fr_FR','Jardin','','','',' jardin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2174,'fr_FR','Bali','','','',' bali ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2175,'fr_FR','Claudel, Camille','','','',' claudel camille ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2177,'fr_FR','Effel, Jean','','','',' effel jean ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2179,'fr_FR','Cubisme','','','',' cubisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2180,'fr_FR','Couleur','','','',' couleur ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2181,'fr_FR','Couleur','','','',' couleur ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2182,'fr_FR','Porte','','','',' porte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2183,'fr_FR','Animaux menacés','','','',' animaux menaces ',' Animaux menacés ',' animaux menaces ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2184,'fr_FR','Edifices industriels','','','',' edifices industriels ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2185,'fr_FR','Par sujet','','','',' par sujet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2186,'fr_FR','Stern, Bert','','','',' stern bert ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2191,'fr_FR','Lune','','','',' lune ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2192,'fr_FR','Lune','','','',' lune ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2193,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2194,'fr_FR','Essais','','','',' essais ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2196,'fr_FR','Automobile','','','',' automobile ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2197,'fr_FR','Renault','','','',' renault ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2198,'fr_FR','4 Chevaux','','','',' 4 chevaux ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2200,'fr_FR','Danse','','','',' danse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2201,'fr_FR','Cunningham, Merce','','','',' cunningham merce ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2203,'fr_FR','Jardinage','','','',' jardinage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2205,'fr_FR','Géographie','','','',' geographie ',' Géographie ',' geographie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2206,'fr_FR','Asie','','','',' asie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2207,'fr_FR','Moyen-Orient','','','',' moyen orient ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2212,'fr_FR','Océanie','','','',' oceanie ',' Océanie ',' oceanie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2214,'fr_FR','Fleurs','','','',' fleurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2215,'fr_FR','Tropiques','','','',' tropiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2216,'fr_FR','Orchidés','','','',' orchides ',' Orchidés ',' orchides ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2217,'fr_FR','Tropiques','','','',' tropiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2218,'fr_FR','Tropiques','','','',' tropiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2219,'fr_FR','Par environnement','','','',' par environnement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2220,'fr_FR','Tropiques','','','',' tropiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2221,'fr_FR','Mer','','','',' mer ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2222,'fr_FR','Mer tropicale','','','',' mer tropicale ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2223,'fr_FR','Coquillage','','','',' coquillage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2224,'fr_FR','Fruits','','','',' fruits ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2225,'fr_FR','Légumes','','','',' legumes ',' Légumes ',' legumes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2226,'fr_FR','XXIème siècle','','','',' xxieme siecle ',' XXIème siècle ',' xxieme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2227,'fr_FR','Papier','','','',' papier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2228,'fr_FR','Art nouveau','','','',' art nouveau ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2229,'fr_FR','Mucha, Alfons','','','',' mucha alfons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2231,'fr_FR','Michel-Ange','','','',' michel ange ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2232,'fr_FR','Michel-Ange','','','',' michel ange ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2233,'fr_FR','Klee, Paul','','','',' klee paul ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2235,'fr_FR','Afrique','','','',' afrique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2236,'fr_FR','Champignons','','','',' champignons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2237,'fr_FR','Maison','','','',' maison ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2239,'fr_FR','Hôtels particuliers','','','',' hotels particuliers ',' Hôtels particuliers ',' hotels particuliers ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2240,'fr_FR','Nouvel, Jean','','','',' nouvel jean ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2242,'fr_FR','Modigliani, Amedeo','','','',' modigliani amedeo ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2245,'fr_FR','Art brut','','','',' art brut ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2246,'fr_FR','Rodin, Auguste','','','',' rodin auguste ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2248,'fr_FR','Duchamp, Marcel','','','',' duchamp marcel ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2250,'fr_FR','Picasso, Pablo','','','',' picasso pablo ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2252,'fr_FR','Cochon d\'Inde','','','',' cochon inde ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2253,'fr_FR','Elevage','','','',' elevage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2254,'fr_FR','Explorateurs','','','',' explorateurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2255,'fr_FR','Conquérants','','','',' conquerants ',' Conquérants ',' conquerants ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2256,'fr_FR','Sociétés secrètes','','','',' societes secretes ',' Sociétés secrètes ',' societes secretes ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2257,'fr_FR','Gangs','','','',' gangs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2258,'fr_FR','Mafia','','','',' mafia ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2259,'fr_FR','Fonds marins','','','',' fonds marins ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2260,'fr_FR','Monuments','','','',' monuments ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2261,'fr_FR','Esclavage','','','',' esclavage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2262,'fr_FR','Voile','','','',' voile ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2264,'fr_FR','Equitation et sports équestres','','','',' equitation sports equestres ',' Equitation et sports équestres ',' equitation sports equestres ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2265,'fr_FR','France','','','',' france ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2266,'fr_FR','Rois','','','',' rois ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2267,'fr_FR','Mythologie','','','',' mythologie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2268,'fr_FR','Chien','','','',' chien ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2269,'fr_FR','Cheval','','','',' cheval ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2270,'fr_FR','Poney','','','',' poney ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2271,'fr_FR','XXème siècle','','','',' xxeme siecle ',' XXème siècle ',' xxeme siecle ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2272,'fr_FR','Personnages célèbres','','','',' personnages celebres ',' Personnages célèbres ',' personnages celebres ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2273,'fr_FR','Civilisation','','','',' civilisation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2274,'fr_FR','Pharaons','','','',' pharaons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2275,'fr_FR','Egypte','','','',' egypte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2276,'fr_FR','Chien','','','',' chien ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2277,'fr_FR','Antiquité','','','',' antiquite ',' Antiquité ',' antiquite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2278,'fr_FR','Age de pierre','','','',' age pierre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2279,'fr_FR','Football','','','',' football ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2280,'fr_FR','Avion','','','',' avion ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2281,'fr_FR','Bateau','','','',' bateau ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2282,'fr_FR','Train','','','',' train ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2283,'fr_FR','Océan','','','',' ocean ',' Océan ',' ocean ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2284,'fr_FR','Verbe','','','',' verbe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2285,'fr_FR','Nom','','','',' nom ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2286,'fr_FR','Adverbe','','','',' adverbe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2287,'fr_FR','Monastère','','','',' monastere ',' Monastère ',' monastere ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2288,'fr_FR','Tibet','','','',' tibet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2289,'fr_FR','Mare','','','',' mare ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2290,'fr_FR','Nain de jardin','','','',' nain jardin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2291,'fr_FR','Pêche','','','',' peche ',' Pêche ',' peche ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2294,'fr_FR','Distillation','','','',' distillation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2295,'fr_FR','Cadou, René Guy','','','',' cadou rene guy ',' Cadou, René Guy ',' cadou rene guy ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2297,'fr_FR','Mondialisation','','','',' mondialisation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2298,'fr_FR','Lecture','','','',' lecture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2299,'fr_FR','Jeux olympiques','','','',' jeux olympiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2300,'fr_FR','Balzac, Honoré de','','','',' balzac honore ',' Balzac, Honoré de ',' balzac honore ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2302,'fr_FR','Musset, Alfred de','','','',' musset alfred ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2303,'fr_FR','Electroménager','','','',' electromenager ',' Electroménager ',' electromenager ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2304,'fr_FR','Londres','','','',' londres ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2306,'fr_FR','Artisanat','','','',' artisanat ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2308,'fr_FR','Boissons','','','',' boissons ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2309,'fr_FR','Vin','','','',' vin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2310,'fr_FR','Explorateurs','','','',' explorateurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2311,'fr_FR','SQL','','','',' sql ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2312,'fr_FR','Québec','','','',' quebec ',' Québec ',' quebec ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2313,'fr_FR','Méditerranée','','','',' mediterranee ',' Méditerranée ',' mediterranee ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2314,'fr_FR','Rapport de stage','','','',' rapport stage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2315,'fr_FR','Mémoire','','','',' memoire ',' Mémoire ',' memoire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2316,'fr_FR','Analyse de texte','','','',' analyse texte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2317,'fr_FR','Commentaire de texte','','','',' commentaire texte ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2318,'fr_FR','Traces','','','',' traces ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2320,'fr_FR','Classification','','','',' classification ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2321,'fr_FR','Dewey','','','',' dewey ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2322,'fr_FR','Dewey, Melvil','','','',' dewey melvil ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2326,'fr_FR','Paternité','','','',' paternite ',' Paternité ',' paternite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2327,'fr_FR','Imprimerie','','','',' imprimerie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2328,'fr_FR','Union européenne','','','',' union europeenne ',' Union européenne ',' union europeenne ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2329,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2330,'fr_FR','Trouble obsessionnel compulsif','','','',' trouble obsessionnel compulsif ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2332,'fr_FR','ONU','','','',' onu ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2335,'fr_FR','Couple','','','',' couple ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2336,'fr_FR','Automobile','','','',' automobile ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2337,'fr_FR','Renault','','','',' renault ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2338,'fr_FR','Guerre','','','',' guerre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2339,'fr_FR','Désert','','','',' desert ',' Désert ',' desert ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2340,'fr_FR','Star','','','',' star ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2341,'fr_FR','Civilisations menacées','','','',' civilisations menacees ',' Civilisations menacées ',' civilisations menacees ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2342,'fr_FR','Objet','','','',' objet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2343,'fr_FR','OMC','','','',' omc ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2345,'fr_FR','Politique économique','','','',' politique economique ',' Politique économique ',' politique economique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2346,'fr_FR','Mondialisation culturelle','','','',' mondialisation culturelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2347,'fr_FR','Culture','','','',' culture ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2348,'fr_FR','Chômage','','','',' chomage ',' Chômage ',' chomage ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2349,'fr_FR','Système monétaire international','','','',' systeme monetaire international ',' Système monétaire international ',' systeme monetaire international ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2350,'fr_FR','Bière','','','',' biere ',' Bière ',' biere ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2352,'fr_FR','Adolescents','','','',' adolescents ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2353,'fr_FR','Dubuffet, Jean','','','',' dubuffet jean ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2354,'fr_FR','Sauces','','','',' sauces ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2356,'fr_FR','Surréalisme','','','',' surrealisme ',' Surréalisme ',' surrealisme ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2358,'fr_FR','Dali, Salvador','','','',' dali salvador ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2359,'fr_FR','Mouvements','','','',' mouvements ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2361,'fr_FR','Miel','','','',' miel ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2362,'fr_FR','Ernst, Max','','','',' ernst max ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2364,'fr_FR','Miro, Joan','','','',' miro joan ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2366,'fr_FR','Magritte, Ren','','','',' magritte ren ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2368,'fr_FR','Mouvements','','','',' mouvements ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2369,'fr_FR','Infusions','','','',' infusions ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2371,'fr_FR','Commerce international','','','',' commerce international ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2372,'fr_FR','Argumentation','','','',' argumentation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2373,'fr_FR','Théories','','','',' theories ',' Théories ',' theories ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2374,'fr_FR','Journalisme','','','',' journalisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2375,'fr_FR','Mariage','','','',' mariage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2376,'fr_FR','Europe','','','',' europe ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2377,'fr_FR','Fromage','','','',' fromage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2378,'fr_FR','Agriculteurs','','','',' agriculteurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2380,'fr_FR','Mouche','','','',' mouche ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2381,'fr_FR','Portrait','','','',' portrait ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2382,'fr_FR','Enfant','','','',' enfant ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2383,'fr_FR','Herbier','','','',' herbier ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2384,'fr_FR','France','','','',' france ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2385,'fr_FR','Paris','','','',' paris ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2386,'fr_FR','Amérique','','','',' amerique ',' Amérique ',' amerique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2387,'fr_FR','Tex mex','','','',' tex mex ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2388,'fr_FR','Jamaïque','','','',' jamaique ',' Jamaïque ',' jamaique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2391,'fr_FR','Italie','','','',' italie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2394,'fr_FR','Japonais','','','',' japonais ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2395,'fr_FR','Chinois','','','',' chinois ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2396,'fr_FR','Plantes aromatiques','','','',' plantes aromatiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2397,'fr_FR','Plat unique','','','',' plat unique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2399,'fr_FR','Immigration','','','',' immigration ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2400,'fr_FR','Immigration clandestine','','','',' immigration clandestine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2402,'fr_FR','Soufisme','','','',' soufisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2403,'fr_FR','Relaxation','','','',' relaxation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2404,'fr_FR','Banlieue','','','',' banlieue ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2405,'fr_FR','Taï chi chuan','','','',' tai chi chuan ',' Taï chi chuan ',' tai chi chuan ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2406,'fr_FR','Jouet','','','',' jouet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2407,'fr_FR','Jouet','','','',' jouet ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2408,'fr_FR','Portugal','','','',' portugal ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2410,'fr_FR','Acteurs','','','',' acteurs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2411,'fr_FR','Afrique','','','',' afrique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2412,'fr_FR','Maroc','','','',' maroc ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2413,'fr_FR','Economique','','','',' economique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2414,'fr_FR','Herbes aromatiques','','','',' herbes aromatiques ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2416,'fr_FR','Keynes, John Maynard','','','',' keynes john maynard ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2418,'fr_FR','Capitalisme','','','',' capitalisme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2420,'fr_FR','OGM','','','',' ogm ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2422,'fr_FR','Rapide','','','',' rapide ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2423,'fr_FR','Pomme de terre','','','',' pomme terre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2424,'fr_FR','Pomme','','','',' pomme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2425,'fr_FR','Fête foraine','','','',' fete foraine ',' Fête foraine ',' fete foraine ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2426,'fr_FR','Paris','','','',' paris ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2427,'fr_FR','Vin','','','',' vin ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2428,'fr_FR','Amérique','','','',' amerique ',' Amérique ',' amerique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2429,'fr_FR','Indiens','','','',' indiens ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2430,'fr_FR','Navajos','','','',' navajos ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2431,'fr_FR','Roman et nouvelle','','','',' roman nouvelle ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2432,'fr_FR','Publication Assistée par Ordinateur','','','',' publication assistee par ordinateur ',' Publication Assistée par Ordinateur ',' publication assistee par ordinateur ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2442,'fr_FR','Théâtre','','','',' theatre ',' Théâtre ',' theatre ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2444,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2446,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2447,'fr_FR','Homme','','','',' homme ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2448,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2449,'fr_FR','ADN','','','',' adn ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2451,'fr_FR','Biographies','','','',' biographies ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2452,'fr_FR','Crick, Francis Harry Compton','','','',' crick francis harry compton ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2454,'fr_FR','Watson, James Dewey','','','',' watson james dewey ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2456,'fr_FR','Bibliographie','','','',' bibliographie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2457,'fr_FR','Biographies','','','',' biographies ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2458,'fr_FR','Einstein, Albert','','','',' einstein albert ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2460,'fr_FR','Relativité','','','',' relativite ',' Relativité ',' relativite ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2461,'fr_FR','Trou noir','','','',' trou noir ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2462,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2463,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2465,'fr_FR','Histoire','','','',' histoire ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2466,'fr_FR','Ordinateur','','','',' ordinateur ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2467,'fr_FR','Turing, Alan Mathison','','','',' turing alan mathison ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2469,'fr_FR','Oppenheimer, Julius Robert','','','',' oppenheimer julius robert ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2471,'fr_FR','Bombe atomique','','','',' bombe atomique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2472,'fr_FR','Physique nucléaire','','','',' physique nucleaire ',' Physique nucléaire ',' physique nucleaire ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2473,'fr_FR','Newton, Isaac','','','',' newton isaac ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2475,'fr_FR','Gravitation','','','',' gravitation ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2476,'fr_FR','Images pieuses','','','',' images pieuses ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2477,'fr_FR','Images','','','',' images ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2478,'fr_FR','Soins médicaux','','','',' soins medicaux ',' Soins médicaux ',' soins medicaux ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2479,'fr_FR','Poésie','','','',' poesie ',' Poésie ',' poesie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2480,'fr_FR','Philatélie','','','',' philatelie ',' Philatélie ',' philatelie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2481,'fr_FR','Timbres','','','',' timbres ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2482,'fr_FR','Numismatie','','','',' numismatie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2483,'fr_FR','Pièces','','','',' pieces ',' Pièces ',' pieces ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2484,'fr_FR','~termes orphelins','','','',' termes orphelins ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2485,'fr_FR','usine','','','',' usine ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2486,'fr_FR','usines','','','',' usines ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2487,'fr_FR','Armement','','','',' armement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2488,'fr_FR','Histoire politique','','','',' histoire politique ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2489,'fr_FR','Guerre','','','',' guerre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2490,'fr_FR','Stratégie','','','',' strategie ',' Stratégie ',' strategie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2491,'fr_FR','Retraite','','','',' retraite ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2492,'fr_FR','Vieillesse','','','',' vieillesse ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2493,'fr_FR','Echecs','','','',' echecs ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2494,'fr_FR','Guerres mondiales','','','',' guerres mondiales ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2495,'fr_FR','Jeux de stratégie','','','',' jeux strategie ',' Jeux de stratégie ',' jeux strategie ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2496,'fr_FR','Temps libre','','','',' temps libre ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2497,'fr_FR','Récupération du Temps de Travail (RTT)','','','',' recuperation temps travail rtt ',' Récupération du Temps de Travail (RTT) ',' recuperation temps travail rtt ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2498,'fr_FR','Ages de la vie','','','',' ages vie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2499,'fr_FR','Troisième âge','','','',' troisieme age ',' Troisième âge ',' troisieme age ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2500,'fr_FR','Quatrième âge','','','',' quatrieme age ',' Quatrième âge ',' quatrieme age ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2501,'fr_FR','Signes du vieillissement','','','',' signes vieillissement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2502,'fr_FR','Signes du vieillissement','','','',' signes vieillissement ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2503,'fr_FR','Esthétique','','','',' esthetique ',' Esthétique ',' esthetique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2504,'fr_FR','Calvitie','','','',' calvitie ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2505,'fr_FR','Chirurgie esthétique','','','',' chirurgie esthetique ',' Chirurgie esthétique ',' chirurgie esthetique ');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2506,'fr_FR','Chirurgie reconstructrice','','','',' chirurgie reconstructrice ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2507,'fr_FR','Implants','','','',' implants ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2508,'fr_FR','Fabrication','','','',' fabrication ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2509,'fr_FR','Silicone','','','',' silicone ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2510,'fr_FR','Cryptage','','','',' cryptage ','','');
INSERT INTO categories (num_thesaurus, num_noeud, langue, libelle_categorie, note_application, comment_public, comment_voir, index_categorie, path_word_categ, index_path_word_categ) VALUES (1,2511,'fr_FR','poilus','','','',' poilus ','','');
/*!40000 ALTER TABLE categories ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `classements`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE classements (
  id_classement int(8) unsigned NOT NULL AUTO_INCREMENT,
  type_classement char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'BAN',
  nom_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_classement)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `classements`
--

LOCK TABLES classements WRITE;
/*!40000 ALTER TABLE classements DISABLE KEYS */;
INSERT INTO classements (id_classement, type_classement, nom_classement) VALUES (1,'','_NON CLASSE_');
/*!40000 ALTER TABLE classements ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms (
  id_cms int(10) unsigned NOT NULL AUTO_INCREMENT,
  cms_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cms_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  cms_opac_default int(10) unsigned NOT NULL DEFAULT '0',
  cms_opac_view_num int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_cms)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms`
--

LOCK TABLES cms WRITE;
/*!40000 ALTER TABLE cms DISABLE KEYS */;
INSERT INTO cms (id_cms, cms_name, cms_comment, cms_opac_default, cms_opac_view_num) VALUES (1,'cms','',1,0);
/*!40000 ALTER TABLE cms ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_articles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_articles (
  id_article int(10) unsigned NOT NULL AUTO_INCREMENT,
  article_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  article_resume mediumtext COLLATE utf8_unicode_ci NOT NULL,
  article_contenu mediumtext COLLATE utf8_unicode_ci NOT NULL,
  article_logo mediumblob NOT NULL,
  article_publication_state varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  article_start_date datetime DEFAULT NULL,
  article_end_date datetime DEFAULT NULL,
  num_section int(11) NOT NULL DEFAULT '0',
  article_num_type int(10) unsigned NOT NULL DEFAULT '0',
  article_creation_date date DEFAULT NULL,
  article_order int(10) unsigned DEFAULT '0',
  article_update_timestamp timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (id_article),
  KEY i_cms_article_title (article_title),
  KEY i_cms_article_publication_state (article_publication_state),
  KEY i_cms_article_num_parent (num_section)
) ENGINE=MyISAM AUTO_INCREMENT=25 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_articles`
--

LOCK TABLES cms_articles WRITE;
/*!40000 ALTER TABLE cms_articles DISABLE KEYS */;
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (1,'Cultures d\'Afrique noire contemporaine','Venez découvrir la richesse culturelle de l\'Afrique noire auourd\'hui !<br />','<p>\nFusce egestas vestibulum neque et faucibus. Integer commodo pretium \nporttitor. Phasellus varius dui at neque dignissim a fermentum magna \nluctus. Nulla facilisi. Cras erat nulla, ullamcorper in tincidunt eget, \ndignissim nec nisl. Nam ut dui nunc. Etiam in enim a sapien fermentum \naccumsan. Donec semper magna non tellus porttitor ultricies nec et \nlorem. Fusce ac felis odio. Cras eu urna nulla. Sed quis dignissim \nmagna. Praesent ultricies, dui et viverra facilisis, elit dui volutpat \narcu, venenatis malesuada justo velit a mi.\n</p>\n<p>\nUt quis volutpat est. Vestibulum ante ipsum primis in faucibus orci \nluctus et ultrices posuere cubilia Curae; Cras congue, dolor eget \ngravida congue, diam ante cursus nisi, nec dictum odio mauris et leo. \nPellentesque nisl massa, facilisis a varius facilisis, laoreet eget \nfelis. Fusce non orci laoreet sem congue vulputate at vel justo. Integer\n at mi lorem, in accumsan ipsum. Pellentesque ullamcorper semper \nlaoreet. Integer et dui felis, ut faucibus diam. Suspendisse blandit \nmollis elit sed posuere. Sed vitae erat et dui tempus egestas.\n</p>', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',4,3,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (2,'Lisez 5 fruits et légumes par jour !','Dans l\'assiette,<br />La courgette<br />C\'est ennuyant !<br />Mais dans les livres,<br />C\'est bien plus amusant !<br />','La bibliothèque vous propose :<br /><br /><blockquote>Une heure du conte potagère !<br /><br />Et des ateliers de création avec fruits et légumes du marché...<br /></blockquote>', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',5,6,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (3,'Fiction adultes','Découvrez les nouveautés du rayon adultes en romans, livres audio, BD<br />','<br />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (4,'Poisson rouge','Le meilleur site de jeux en ligne pour les tout-petits !<br />','Fusce egestas vestibulum neque et faucibus. Integer commodo pretium \nporttitor. Phasellus varius dui at neque dignissim a fermentum magna \nluctus. Nulla facilisi. Cras erat nulla, ullamcorper in tincidunt eget, \ndignissim nec nisl. Nam ut dui nunc. Etiam in enim a sapien fermentum \naccumsan. <br /><br />Donec semper magna non tellus porttitor ultricies nec et \nlorem. Fusce ac felis odio. Cras eu urna nulla. Sed quis dignissim \nmagna. Praesent ultricies, dui et viverra facilisis, elit dui volutpat \narcu, venenatis malesuada justo velit a mi.\n', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',8,5,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (12,'Georges : petit-petit-petit magazine','Le concept de Georges :<br />\nBienvenue dans l\'univers de Georges, petit petit petit magazine, \nrevue alternative trimestrielle créée par les Éditions Grains de Sel, \npour les enfants ni trop petits ni trop grands.<br />','Mais qui est Georges ?<br />\n\nUn magazine décalé et exigeant qui stimule la curiosité et revisite les traitements traditionnels des magazines pour enfants.<br />\n\n<br />\n\nQuels sont ses atouts ?<br />\n\nUn graphisme épuré  et un thème original pour chaque numéro, sur un beau\n papier offset et recyclé, avec des illustrateurs aux univers sensibles \net un second degré qui séduit les enfants (et même leurs parents).<br />\n\n<br />\n\nComment se présente-t-il ?<br />\n\nPartie 1 : des HISTOIRES vraies, courtes, longues ou à l\'envers.<br />\n\nPartie 2 : des JEUX à colorier, calculer ou déchiffrer autour du thème du numéro.<br />\n\nPartie 3 : des RUBRIQUES-À-BRAC pour découvrir des métiers, langues \nétrangères, scènes de films ou expériences scientifiques, mais de façon \ntoujours farfelue !', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',8,5,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (17,'Des bibliothèques pleines de fantômes','Avez-vous peur de mourir dans votre sommeil, enseveli sous l\'écroulement\n de votre bibliothèque ? Classez-vous les volumes par \nthème, langue, auteur, date de parution, format ou selon un autre \ncritère de vous seul connu ?','Autant de graves questions se posant à cette espèce en voie de \ndisparition : les bibliomanes, qui, outre la passion de posséder les \nlivres, ont celle de les lire. Les bibliothèques sont des êtres vivants à\n l\'image de notre complexité intérieure. Elles finissent par composer un\n labyrinthe dont pour notre plus grand, et dangereux, plaisir nous \npouvons très bien ne plus sortir. Dans ce petit traité sur l\'art de \nvivre avec trop de livres apparaissent, parmi nombre d\'autres, Pessoa \ntentant de devenir bibliothécaire, Matisse postulant au poste de \n«contrôleur du droit des pauvres» ou encore le capitaine Achab et le \nmystère de sa jambe abandonnée à Moby Dick. En fait, ces milliers de \npages qui occupent nos étagères sont peuplées de fantômes bien vivants \nqui, une fois rencontrés, ne nous quittent plus.', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',8,5,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (18,'Les annales du disque-monde','\n      Le disque-monde est plat, porté par quatre éléphants debout sur le dos\n d\'une tortue naviguant dans le cosmos. Tout le monde le sait et \nquoiqu\'en disent certaines sectes, c\'est la vérité. <br />','<p>Les héros de ce monde sont à son image : atypiques.<br /> Rincevent, \nmagicien malchanceux froussard et raté, ne connaît qu\'un seul sort mais \nil n\'ose pas le lancer car il pourrait tout détruire.<br /> Mémé \nCiredutemps, sorcière d\'un certain âge, ne peut que diriger tous ceux \nqui l\'entourent, elle ne fait d\'ailleurs que très rarement usage de sa \nmagie car tout le monde la connaît et lui obéit.<br /> La Mort, la faucheuse avec son grand suaire et sa faux bien aiguisée, grande humaniste incomprise.  </p>Pratchett\n consacre chacun de ses romans à un de ces personnages même s\'il arrive \nqu\'ils se rencontrent de temps en temps, car tout est possible dans cet \nunivers totalement fou et plein d\'humour !<br />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',8,5,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (19,'Fermeture exceptionnelle','Le jour de Noël, et aussi le jour de l\'an<br />','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',13,4,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (20,'Vous avez le droit d\'emprunter des documents !','10 prêts en tout dont maximum 5 livres, 5 CD pour une durée de 3 semaines<br />','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',13,4,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (21,'Encore un exemple de brève','Ceci est une brève !<br />','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',13,4,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (22,'Flash info','Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer mattis eleifend lorem, ut tristique leo...','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',13,4,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (23,'Et une dernière pour la route','Ceci est aussi une brève<br />','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',13,4,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (11,'Projections : journée Tim Burton','L\'après-midi pour les enfants,<br />Le soir pour les grands !<br />','Au programme :<br /><br />Les noces funèbres<br /><br />Beetlejuice<br /><br />Big Fish<br />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',4,6,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (10,'Comment s\'inscrire ?','Comment s\'inscrire ?<br /><br />Pour quels services ?<br />','Contenu du règlement de la bibliothèque<br />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',10,4,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (7,'Mais que font les bibliothécaires ?','Non non les bibliothécaires ne passent pas leur temps à lire et à jouer à Star Wars avec leurs douchettes laser !<br />','<br />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',9,4,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (9,'Horaires','La bibliothèque est ouverte tous les jours...<br />','Tableau des horaires<br />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',9,4,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (13,'Fiction jeunesse','Découvrez les nouveautés du rayon jeunesse en albums, BD, romans','<br _moz_editor_bogus_node=\"TRUE\" />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (24,'Périodiques','Découvrez nos nouveautés du rayon périodiques<br />','<br _moz_editor_bogus_node=\"TRUE\" />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-27',0,'2012-10-26 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (16,'Cinéma','Découvrez nos nouveautés du rayon cinéma<br />','<br _moz_editor_bogus_node=\"TRUE\" />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (14,'Documentaires','Découvrez nos nouveaux documentaires, pour grands et petits<br />','<br _moz_editor_bogus_node=\"TRUE\" />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_articles (id_article, article_title, article_resume, article_contenu, article_logo, article_publication_state, article_start_date, article_end_date, num_section, article_num_type, article_creation_date, article_order, article_update_timestamp) VALUES (15,'Musique','Découvrez nos nouveautés du rayon musique<br />','<br _moz_editor_bogus_node=\"TRUE\" />', ,'2','0000-00-00 00:00:00','0000-00-00 00:00:00',7,2,'2012-10-26',0,'2012-10-25 22:00:00');
/*!40000 ALTER TABLE cms_articles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_articles_descriptors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_articles_descriptors (
  num_article int(11) NOT NULL DEFAULT '0',
  num_noeud int(11) NOT NULL DEFAULT '0',
  article_descriptor_order int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_article,num_noeud)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_articles_descriptors`
--

LOCK TABLES cms_articles_descriptors WRITE;
/*!40000 ALTER TABLE cms_articles_descriptors DISABLE KEYS */;
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (2,2225,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (1,1788,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (7,1658,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (11,1392,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (4,1563,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (12,1563,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (17,1658,0);
INSERT INTO cms_articles_descriptors (num_article, num_noeud, article_descriptor_order) VALUES (18,1433,0);
/*!40000 ALTER TABLE cms_articles_descriptors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_build`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_build (
  id_build int(10) unsigned NOT NULL AUTO_INCREMENT,
  build_version_num int(11) NOT NULL DEFAULT '0',
  build_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'cadre',
  build_fixed int(11) NOT NULL DEFAULT '0',
  build_obj varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  build_page int(11) NOT NULL DEFAULT '0',
  build_parent varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  build_child_before varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  build_child_after varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  build_css mediumtext COLLATE utf8_unicode_ci NOT NULL,
  build_div int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_build),
  KEY cms_build_index (build_version_num,build_obj),
  KEY i_build_parent_build_version_num (build_parent,build_version_num),
  KEY i_build_obj_build_version_num (build_obj,build_version_num)
) ENGINE=MyISAM AUTO_INCREMENT=7152 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_build`
--

LOCK TABLES cms_build WRITE;
/*!40000 ALTER TABLE cms_build DISABLE KEYS */;
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1,1,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2,1,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3,1,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4,1,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5,1,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6,1,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7,1,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (8,1,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (9,1,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (10,1,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (11,1,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (12,1,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (13,2,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (14,2,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (15,2,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (16,2,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (17,2,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (18,2,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (19,2,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (20,2,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (21,2,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (22,2,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (23,2,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (24,2,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (25,2,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (26,2,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (27,2,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (28,2,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_1','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (124,7,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (125,7,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (30,2,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (31,2,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (32,3,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (33,3,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (34,3,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (35,3,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (36,3,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (37,3,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (38,3,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (39,3,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (40,3,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (41,3,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (42,3,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (43,3,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (44,3,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (45,3,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (46,3,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (873,35,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (48,3,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_2','cms_module_recordslist_1','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (122,7,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (123,7,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (50,3,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (51,3,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (52,4,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (53,4,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (54,4,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (55,4,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (56,4,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (57,4,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (58,4,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (59,4,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (60,4,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (61,4,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (62,4,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (63,4,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (64,4,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (65,4,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (66,4,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (139,8,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (140,8,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (68,4,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_articleslist_3','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (129,7,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (130,7,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (120,7,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (121,7,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (71,4,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (72,4,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (73,5,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (74,5,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (75,5,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (76,5,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (77,5,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (78,5,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (79,5,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (80,5,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (81,5,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (82,5,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (83,5,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (84,5,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (85,5,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (86,5,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (87,5,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (136,8,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (137,8,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (138,8,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (89,5,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_articleslist_3','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (127,7,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (128,7,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (118,7,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (119,7,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (92,5,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (93,5,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (94,6,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (95,6,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (96,6,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (97,6,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (98,6,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (99,6,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (100,6,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (101,6,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (102,6,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (103,6,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (104,6,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (105,6,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (106,6,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (107,6,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (108,6,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (132,7,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_section_6','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (133,7,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (134,7,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (135,8,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (111,6,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_articleslist_3','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (126,7,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (116,7,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (117,7,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (114,6,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (115,6,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (141,8,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (142,8,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (143,8,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (144,8,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (145,8,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (146,8,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (147,8,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (148,8,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (149,8,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (797,32,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (798,32,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (151,8,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_7','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (153,8,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (154,8,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (155,9,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (156,9,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (157,9,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (158,9,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (159,9,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (160,9,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (161,9,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (162,9,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (163,9,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (164,9,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (165,9,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (166,9,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (167,9,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (168,9,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (169,9,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (872,35,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 588px; top: -103px; height: 42.45px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (171,9,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_7','cms_module_recordslist_8','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (854,35,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (855,35,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (174,9,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (175,9,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (176,10,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (177,10,'cadre',1,'accueil',0,'bandeau','','adresse','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (178,10,'cadre',1,'adresse',0,'bandeau','accueil','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (179,10,'cadre',1,'connexion',0,'bandeau','adresse','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (180,10,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (890,36,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (182,10,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (183,10,'cadre',1,'intro_bibli',0,'intro','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (184,10,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (185,10,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (186,10,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (187,10,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (188,10,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (189,10,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (190,10,'cadre',1,'navigator',0,'main_hors_footer','','resume_panier','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (191,10,'cadre',1,'resume_panier',0,'main_hors_footer','navigator','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (871,35,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (193,10,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_7','cms_module_recordslist_8','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (851,34,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (853,35,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (196,10,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (197,10,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (198,11,'zone',1,'bandeau',0,'container','intro','bandeau_2','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (199,11,'cadre',1,'adresse',0,'bandeau','','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (200,11,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 757px; top: -395px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (201,11,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (202,11,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (203,11,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (204,11,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (205,11,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (206,11,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (207,11,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (208,11,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (209,11,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (210,11,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (211,11,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (212,11,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (213,11,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (888,36,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (889,36,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (793,32,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (794,32,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (847,34,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (848,34,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (849,34,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (850,34,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (218,11,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (219,11,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (220,12,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 790px; top: 175px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (221,12,'cadre',1,'adresse',0,'bandeau','','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (222,12,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -43px; top: -330px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (223,12,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (224,12,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (225,12,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (226,12,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (227,12,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (228,12,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (229,12,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (230,12,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (231,12,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (232,12,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (233,12,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (234,12,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (235,12,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (791,32,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (792,32,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (845,34,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (846,34,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (240,12,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (241,12,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (242,13,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (243,13,'cadre',1,'adresse',0,'bandeau','','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (244,13,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (245,13,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (246,13,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (247,13,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (248,13,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (249,13,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (250,13,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (251,13,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (252,13,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (253,13,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (254,13,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (255,13,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (256,13,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (257,13,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (258,13,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (259,13,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (260,13,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (261,13,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (887,36,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (844,34,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (842,34,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (843,34,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (266,13,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (267,13,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (268,14,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (269,14,'cadre',0,'post_adress',0,'bandeau','','adresse','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (270,14,'cadre',1,'adresse',0,'bandeau','','connexion','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (271,14,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (272,14,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (273,14,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (274,14,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (275,14,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 115px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (276,14,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (277,14,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (278,14,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (279,14,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (280,14,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (281,14,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (282,14,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (283,14,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (284,14,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (285,14,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (286,14,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (287,14,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (288,14,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (840,34,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (841,34,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (293,14,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (294,14,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (295,15,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (296,15,'cadre',1,'adresse',0,'bandeau','','connexion','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (297,15,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (298,15,'cadre',0,'post_adress',0,'bandeau','connexion','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (299,15,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (300,15,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (301,15,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (302,15,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (303,15,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (304,15,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (305,15,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (306,15,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (307,15,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (308,15,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (309,15,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (310,15,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (311,15,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (312,15,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (313,15,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (314,15,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (315,15,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (885,36,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (886,36,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (789,32,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_8','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (837,34,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (838,34,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (839,34,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (320,15,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (321,15,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (322,16,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (323,16,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -5px; top: 37px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (324,16,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (325,16,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: -8px; top: -268px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (326,16,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (327,16,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (328,16,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (329,16,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (330,16,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (331,16,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (332,16,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (333,16,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (334,16,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (335,16,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (336,16,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (337,16,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (338,16,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (339,16,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (340,16,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (341,16,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (342,16,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (883,36,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (884,36,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (787,32,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (788,32,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (834,34,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (835,34,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (836,34,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (347,16,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (348,16,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (349,17,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px; visibility: visible; display: block; height: 311.967px; width: 178px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (350,17,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -5px; top: 37px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (351,17,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px; visibility: visible; display: block; height: 98.1333px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (352,17,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: -8px; top: -268px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (353,17,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (354,17,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (355,17,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (356,17,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (357,17,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (358,17,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (359,17,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (360,17,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (361,17,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (362,17,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (363,17,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (364,17,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (365,17,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (366,17,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (367,17,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (368,17,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (369,17,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (882,36,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (833,34,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (374,17,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (375,17,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (376,18,'zone',1,'bandeau',0,'container','intro','bandeau_2','left: 833px; top: 166px; visibility: visible; display: block; height: 311.967px; width: 178px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (377,18,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -5px; top: 37px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (378,18,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: -80px; top: -321px; visibility: visible; display: block; height: 98.1333px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (379,18,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: -8px; top: -268px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (380,18,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (381,18,'zone',1,'intro',0,'container','main','bandeau','left: -2px; top: -3px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (382,18,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (383,18,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (384,18,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (385,18,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (386,18,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (387,18,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (388,18,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (389,18,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (390,18,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (391,18,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (392,18,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (393,18,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (394,18,'cadre',0,'location',0,'main_hors_footer','search','etageres','position: relative; left: -232px; top: -196px; height: 488.917px; width: 210px; margin: 0px 0px 20px; padding: 0px 0px 4px; float: none; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (395,18,'cadre',0,'etageres',0,'main_hors_footer','location','last_entries','position: relative; left: 0px; top: 0px; height: 249.883px; width: 550px; margin: 0px 0px 20px; padding: 0px 0px 20px; float: none; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (396,18,'cadre',0,'last_entries',0,'main_hors_footer','etageres','','position: relative; left: -2px; top: -801px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (786,32,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (829,34,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (852,35,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (831,34,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (832,34,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (401,18,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (402,18,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (403,19,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (404,19,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 37px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (405,19,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 757px; top: -395px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (406,19,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 1px; top: -299px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (407,19,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (408,19,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (409,19,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (410,19,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (411,19,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (412,19,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (413,19,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (414,19,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (415,19,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (416,19,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (417,19,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (418,19,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (419,19,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (420,19,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (421,19,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (422,19,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (423,19,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (784,32,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (785,32,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (828,34,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (428,19,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (429,19,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (430,20,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (431,20,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (432,20,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 757px; top: -395px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (433,20,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (434,20,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (435,20,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (436,20,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (437,20,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (438,20,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (439,20,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (440,20,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (441,20,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (442,20,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (443,20,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (444,20,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (445,20,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (446,20,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (447,20,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (448,20,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (449,20,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (450,20,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (881,36,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (783,32,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (826,34,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (827,34,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (455,20,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (456,20,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (457,21,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (458,21,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (459,21,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 757px; top: -395px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (460,21,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (461,21,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (462,21,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (463,21,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (464,21,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (465,21,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (466,21,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (467,21,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (468,21,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (469,21,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (470,21,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (471,21,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (472,21,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (473,21,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (474,21,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (475,21,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (476,21,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (477,21,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (880,36,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (781,32,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (782,32,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (823,33,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (824,33,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (825,34,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (482,21,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (483,21,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (484,22,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (485,22,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (486,22,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (487,22,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (488,22,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (489,22,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (490,22,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (491,22,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (492,22,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (493,22,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (494,22,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (495,22,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (496,22,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (497,22,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (498,22,'zone',1,'main_hors_footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (499,22,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (500,22,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (501,22,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (502,22,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (503,22,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (504,22,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (780,32,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (819,33,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (820,33,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (821,33,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (822,33,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (509,22,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (510,22,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (511,23,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (512,23,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (513,23,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (514,23,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (515,23,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (516,23,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (517,23,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (518,23,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (519,23,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (520,23,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (521,23,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (522,23,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (523,23,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (524,23,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (525,23,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (526,23,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (527,23,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (528,23,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (529,23,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (530,23,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (531,23,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (879,36,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (779,32,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (818,33,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (536,23,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (537,23,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (538,24,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (539,24,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (540,24,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (541,24,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (542,24,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (543,24,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (544,24,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (545,24,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (546,24,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (547,24,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (548,24,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (549,24,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (550,24,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (551,24,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (552,24,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (553,24,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (554,24,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_10','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (870,35,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (556,24,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (557,24,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (558,24,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (559,24,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (877,35,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (878,35,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (778,32,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (815,33,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (816,33,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (817,33,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (564,24,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (565,24,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (566,25,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (567,25,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (568,25,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (569,25,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (570,25,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (571,25,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (572,25,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (573,25,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (574,25,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (575,25,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (576,25,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (577,25,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (578,25,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (579,25,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (580,25,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (595,26,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (582,25,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (583,25,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_10','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (585,25,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (586,25,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (587,25,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (588,25,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (876,35,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (776,32,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (777,32,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (814,33,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (593,25,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (594,25,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (596,26,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (597,26,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (598,26,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (599,26,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (600,26,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (601,26,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (602,26,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (603,26,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (604,26,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (605,26,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (606,26,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (607,26,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (608,26,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (609,26,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (744,31,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (611,26,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (612,26,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (613,26,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (614,26,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (615,26,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (616,26,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (868,35,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (869,35,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (874,35,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (875,35,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (811,33,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (812,33,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (813,33,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (622,26,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (623,26,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (624,27,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (625,27,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (626,27,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (627,27,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (628,27,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (629,27,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (630,27,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (631,27,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (632,27,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (633,27,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (634,27,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (635,27,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (636,27,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (637,27,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (638,27,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (640,27,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (641,27,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (642,27,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (643,27,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (644,27,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (645,27,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (866,35,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (867,35,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (773,32,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (774,32,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (808,33,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (809,33,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (810,33,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (651,27,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (652,27,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (653,28,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (654,28,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (655,28,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (656,28,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (657,28,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (658,28,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (659,28,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (660,28,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (661,28,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (662,28,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (663,28,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (664,28,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (665,28,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (666,28,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (667,28,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (743,31,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (669,28,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (670,28,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (671,28,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (672,28,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (673,28,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (674,28,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (863,35,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (864,35,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (865,35,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (806,33,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (807,33,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (680,28,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (681,28,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (682,29,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (683,29,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (684,29,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (685,29,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (686,29,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (687,29,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (688,29,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (689,29,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (690,29,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (691,29,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (692,29,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (693,29,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (694,29,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (695,29,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (696,29,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (742,31,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (698,29,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (699,29,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (700,29,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (701,29,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (702,29,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (703,29,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (861,35,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (862,35,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (772,32,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (802,33,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (803,33,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (804,33,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (805,33,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (709,29,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (710,29,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (711,30,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (712,30,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (713,30,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (714,30,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (715,30,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (716,30,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (717,30,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (718,30,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (719,30,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 228px; top: 45px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (720,30,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (721,30,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (722,30,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (723,30,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (724,30,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (725,30,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (726,30,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (727,30,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (728,30,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (729,30,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (730,30,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (731,30,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (732,30,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (741,31,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (859,35,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (860,35,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (771,32,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (801,33,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (739,30,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (740,30,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (745,31,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (746,31,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (747,31,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (748,31,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (749,31,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (750,31,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (751,31,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (752,31,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (753,31,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (754,31,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (755,31,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (756,31,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (757,31,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (758,31,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','search','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (759,31,'cadre',0,'search',0,'main_hors_footer','intro_message','location','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (760,31,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (761,31,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (762,31,'cadre',0,'etageres',0,'main_hors_footer','last_entries','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (856,35,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (857,35,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (858,35,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (770,32,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (799,33,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (800,33,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (768,31,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (769,31,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (891,36,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (892,36,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (893,36,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (894,36,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (895,36,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (896,36,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (897,36,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (898,36,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (899,36,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (900,36,'cadre',0,'intro_message',0,'main_hors_footer','etageres','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (901,36,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 588px; top: -103px; height: 42.45px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (902,36,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (903,36,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (904,36,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (905,36,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (906,37,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (907,37,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (908,37,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (909,37,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (910,37,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (911,37,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (912,37,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (913,37,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (914,37,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (915,37,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (916,37,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (917,37,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (918,37,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (919,37,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (920,37,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (921,37,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (922,37,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (923,37,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_section_18','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (924,37,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (925,37,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (926,37,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (927,37,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (928,37,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (929,37,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 588px; top: -103px; height: 42.45px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (930,37,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (931,37,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (932,37,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (933,37,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (934,38,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (935,38,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (936,38,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (937,38,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (938,38,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (939,38,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (940,38,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (941,38,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (942,38,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (943,38,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (944,38,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (945,38,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (946,38,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (947,38,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (948,38,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (949,38,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (950,38,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (951,38,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (952,38,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (953,38,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (954,38,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 588px; top: -103px; height: 42.45px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (955,38,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (956,38,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (957,38,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (958,38,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (959,38,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (960,38,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (961,38,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (962,39,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (963,39,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (964,39,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (965,39,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (966,39,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (967,39,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (968,39,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (969,39,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (970,39,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (971,39,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (972,39,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (973,39,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (974,39,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (975,39,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (976,39,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (977,39,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (978,39,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (979,39,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (980,39,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (981,39,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (982,39,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 588px; top: -103px; height: 42.45px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (983,39,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (984,39,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (985,39,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (986,39,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (987,39,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (988,39,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (989,39,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (990,40,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (991,40,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (992,40,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (993,40,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (994,40,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (995,40,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (996,40,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (997,40,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (998,40,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (999,40,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1000,40,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1001,40,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1002,40,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1003,40,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1004,40,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1005,40,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1006,40,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1007,40,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1008,40,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1009,40,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1010,40,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 585px; top: -475px; height: 400px; width: 150px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1011,40,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1012,40,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1013,40,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1014,40,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1015,40,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1016,40,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1017,40,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1018,41,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1019,41,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1020,41,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1021,41,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1022,41,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1023,41,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1024,41,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1025,41,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1026,41,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1027,41,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1028,41,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1029,41,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1030,41,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1031,41,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1032,41,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1033,41,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1034,41,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1035,41,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1036,41,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1037,41,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1038,41,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 568px; top: -470px; height: 400px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1039,41,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1040,41,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1041,41,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1042,41,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1043,41,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1044,41,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1045,41,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1046,42,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1047,42,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1048,42,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1049,42,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1050,42,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1051,42,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1052,42,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1053,42,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1054,42,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1055,42,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1056,42,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1057,42,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1058,42,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1059,42,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1060,42,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1061,42,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1062,42,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1063,42,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1064,42,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1065,42,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1066,42,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: relative; left: 568px; top: -470px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1067,42,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1068,42,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1069,42,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1070,42,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1071,42,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1072,42,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1073,42,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1074,43,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1075,43,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1076,43,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1077,43,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1078,43,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1079,43,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1080,43,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1081,43,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1082,43,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1083,43,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1084,43,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1085,43,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1086,43,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1087,43,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1088,43,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1089,43,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1090,43,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1091,43,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1092,43,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1093,43,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1094,43,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1095,43,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1096,43,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1097,43,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1098,43,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1099,43,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1100,43,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1101,43,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1102,44,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1103,44,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1104,44,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1105,44,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1106,44,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1107,44,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1108,44,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1109,44,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1110,44,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1111,44,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1112,44,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1113,44,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1114,44,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1115,44,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1116,44,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1117,44,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1118,44,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1119,44,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_record_19','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3263,99,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1122,44,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1123,44,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1124,44,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1125,44,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1126,44,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1127,44,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1128,44,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1129,44,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1130,44,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1131,44,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1132,45,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1133,45,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1134,45,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1135,45,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1136,45,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1137,45,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1138,45,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1139,45,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1140,45,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1141,45,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1142,45,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1143,45,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1144,45,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1145,45,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1146,45,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1147,45,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1148,45,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1149,45,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1150,45,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3262,99,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7034,181,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1153,45,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1154,45,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1155,45,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1156,45,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1157,45,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1158,45,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1159,45,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1160,45,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1161,45,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1162,45,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1163,46,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1164,46,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1165,46,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1166,46,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1167,46,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1168,46,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1169,46,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1170,46,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1171,46,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1172,46,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1173,46,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1174,46,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1175,46,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1176,46,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1177,46,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1178,46,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1179,46,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1180,46,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1181,46,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1182,46,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3260,99,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3261,99,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7033,181,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1185,46,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1186,46,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1187,46,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1188,46,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1189,46,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1190,46,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1191,46,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1192,46,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1193,46,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1194,46,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1195,47,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1196,47,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1197,47,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1198,47,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1199,47,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1200,47,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1201,47,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1202,47,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1203,47,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1204,47,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1205,47,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1206,47,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1207,47,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1208,47,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1209,47,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1210,47,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1211,47,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1212,47,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1213,47,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1214,47,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1215,47,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3258,99,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3259,99,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1218,47,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1219,47,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1220,47,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1221,47,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1222,47,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1223,47,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1224,47,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1225,47,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1226,47,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1227,47,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1228,48,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1229,48,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1230,48,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1231,48,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1232,48,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1233,48,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1234,48,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1235,48,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1236,48,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1237,48,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1238,48,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1239,48,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1240,48,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1241,48,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1242,48,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1243,48,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1244,48,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1245,48,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1246,48,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1247,48,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1248,48,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3257,99,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7032,181,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1251,48,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1252,48,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1253,48,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1254,48,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1255,48,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1256,48,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1257,48,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1258,48,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1259,48,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1260,48,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1261,49,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1262,49,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1263,49,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1264,49,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1265,49,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1266,49,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1267,49,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1268,49,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1269,49,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1270,49,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1271,49,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1272,49,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1273,49,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1274,49,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1275,49,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1276,49,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1277,49,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1278,49,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1279,49,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1280,49,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1281,49,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1282,49,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1283,49,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1284,49,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1287,49,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1288,49,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1289,49,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1290,49,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1291,49,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1292,49,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1293,49,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1294,50,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1295,50,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1296,50,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1297,50,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1298,50,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1299,50,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1300,50,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1301,50,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1302,50,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1303,50,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1304,50,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1305,50,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1306,50,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1307,50,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1308,50,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1309,50,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1310,50,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1311,50,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1312,50,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1313,50,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1314,50,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1315,50,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1316,50,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1317,50,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3256,99,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7031,181,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1320,50,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1321,50,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1322,50,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1323,50,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1324,50,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1325,50,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1326,50,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1327,51,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1328,51,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1329,51,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1330,51,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1331,51,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1332,51,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1333,51,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1334,51,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1335,51,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1336,51,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1337,51,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1338,51,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1339,51,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1340,51,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1341,51,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1342,51,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1343,51,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1344,51,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1345,51,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1346,51,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1347,51,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1348,51,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1349,51,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1350,51,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3255,99,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1353,51,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1354,51,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1355,51,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1356,51,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1357,51,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1358,51,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1359,51,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1360,52,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1361,52,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1362,52,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1363,52,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1364,52,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1365,52,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1366,52,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1367,52,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1368,52,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1369,52,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1370,52,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1371,52,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1372,52,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1373,52,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1374,52,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1375,52,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1376,52,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1377,52,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1378,52,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1379,52,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1380,52,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1381,52,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1382,52,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1383,52,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 564px; top: -2px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3254,99,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1386,52,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1387,52,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1388,52,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1389,52,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1390,52,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1391,52,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1392,52,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1393,53,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1394,53,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1395,53,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1396,53,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1397,53,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1398,53,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1399,53,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1400,53,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1401,53,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1402,53,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1403,53,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1404,53,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1405,53,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1406,53,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1407,53,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1408,53,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1409,53,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1410,53,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1411,53,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1412,53,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1413,53,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1414,53,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1415,53,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1416,53,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3252,99,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3253,99,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7030,181,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1419,53,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1420,53,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1421,53,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1422,53,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1423,53,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1424,53,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1425,53,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1426,54,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1427,54,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1428,54,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1429,54,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1430,54,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1431,54,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1432,54,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1433,54,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1434,54,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1435,54,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1436,54,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1437,54,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1438,54,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1439,54,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1440,54,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1441,54,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1442,54,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1443,54,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_record_19','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3251,99,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1446,54,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1447,54,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1448,54,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1449,54,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1450,54,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1451,54,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1452,54,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1453,54,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1454,54,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1455,54,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1456,54,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1457,54,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1458,54,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1459,55,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1460,55,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1461,55,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1462,55,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1463,55,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1464,55,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1465,55,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1466,55,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1467,55,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1468,55,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1469,55,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1470,55,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1471,55,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1472,55,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1473,55,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1474,55,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1475,55,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1476,55,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','notice','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1477,55,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6916,178,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3250,99,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7029,181,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1481,55,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1482,55,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1483,55,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1484,55,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1485,55,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1486,55,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1487,55,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1488,55,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1489,55,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1490,55,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1491,55,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1492,55,'cadre',1,'lvl1',0,'bandeau_2','','facettes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1493,55,'cadre',1,'facette',0,'bandeau_2','lvl1','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1494,56,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1495,56,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1496,56,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1497,56,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1498,56,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1499,56,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1500,56,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1501,56,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1502,56,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1503,56,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1504,56,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1505,56,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1506,56,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1507,56,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1508,56,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1509,56,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1510,56,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1511,56,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1512,56,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1513,56,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1514,56,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1515,56,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1516,56,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1517,56,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1518,56,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1519,56,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1520,56,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3249,99,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7028,181,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1524,56,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1525,56,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1526,56,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1527,56,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1528,56,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1529,56,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1530,56,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1531,56,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1532,56,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1533,56,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1534,56,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1535,57,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1536,57,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1537,57,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1538,57,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1539,57,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1540,57,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1541,57,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1542,57,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1543,57,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1544,57,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1545,57,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1546,57,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1547,57,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1548,57,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1549,57,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1550,57,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1551,57,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1552,57,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1553,57,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1554,57,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1555,57,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1556,57,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1557,57,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1558,57,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1559,57,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1560,57,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1561,57,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1562,57,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7027,181,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1566,57,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1567,57,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1568,57,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1569,57,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1570,57,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1571,57,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1572,57,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1573,57,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1574,58,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1575,58,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1576,58,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1577,58,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1578,58,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1579,58,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1580,58,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1581,58,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1582,58,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1583,58,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1584,58,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1585,58,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1586,58,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1587,58,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1588,58,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1589,58,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1590,58,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1591,58,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1592,58,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 150px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1593,58,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1594,58,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1595,58,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1596,58,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1597,58,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1598,58,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1599,58,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1600,58,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1601,58,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6915,178,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3248,99,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1605,58,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1606,58,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1607,58,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1608,58,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1609,58,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1610,58,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1611,58,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1612,58,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1613,59,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1614,59,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1615,59,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1616,59,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1617,59,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1618,59,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1619,59,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1620,59,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1621,59,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1622,59,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1623,59,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1624,59,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1625,59,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1626,59,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1627,59,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1628,59,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1629,59,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1630,59,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1631,59,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1632,59,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1633,59,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1634,59,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1635,59,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1636,59,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1637,59,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1638,59,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1639,59,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1640,59,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6914,178,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6912,178,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7025,181,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7026,181,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1644,59,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1645,59,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1646,59,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1647,59,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1648,59,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1649,59,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1650,59,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1651,59,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1652,60,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1653,60,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1654,60,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1655,60,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1656,60,'zone',1,'bandeau_2',0,'container','bandeau','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1773,63,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1658,60,'zone',1,'intro',0,'container','main','bandeau','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1659,60,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1660,60,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1661,60,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1662,60,'zone',1,'footer',0,'main','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1663,60,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1664,60,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1665,60,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1666,60,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1667,60,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1668,60,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1669,60,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1670,60,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1671,60,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1672,60,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1673,60,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1674,60,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1675,60,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1676,60,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1677,60,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1678,60,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1679,60,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1680,60,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3245,98,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6913,178,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1684,60,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1685,60,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1686,60,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1687,60,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1688,60,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1689,60,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1690,60,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1691,60,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1692,61,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1693,61,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1694,61,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1695,61,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1696,61,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1697,61,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1698,61,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1699,61,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1700,61,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1701,61,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1702,61,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1703,61,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1704,61,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1705,61,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1706,61,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1707,61,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1708,61,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1709,61,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1710,61,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1711,61,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1712,61,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1714,61,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1715,61,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1716,61,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1717,61,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1718,61,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1719,61,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1720,61,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1721,61,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1722,61,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1723,61,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3243,98,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3244,98,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7024,181,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1727,61,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1728,61,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1729,61,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1730,61,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1731,61,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1732,62,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1733,62,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1734,62,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1735,62,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1736,62,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1737,62,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1738,62,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1739,62,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1740,62,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1741,62,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1742,62,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1743,62,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1744,62,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1745,62,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1746,62,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1747,62,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1748,62,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1749,62,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1750,62,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1751,62,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1752,62,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1772,63,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1754,62,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1755,62,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1756,62,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1757,62,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1758,62,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1759,62,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1760,62,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1761,62,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1762,62,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1763,62,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6911,178,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3241,98,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3242,98,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7023,181,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1767,62,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1768,62,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1769,62,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1770,62,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1771,62,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1774,63,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1775,63,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1776,63,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1777,63,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1778,63,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1779,63,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1780,63,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1781,63,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1782,63,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1783,63,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1784,63,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1785,63,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1786,63,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1787,63,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1788,63,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1789,63,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1790,63,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1791,63,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1792,63,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1793,63,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1794,63,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1795,63,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1796,63,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1797,63,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1798,63,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1799,63,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1800,63,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1801,63,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1802,63,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3240,98,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7022,181,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1806,63,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1807,63,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1808,63,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1809,63,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1810,63,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1811,64,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1812,64,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1813,64,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1814,64,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1815,64,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1816,64,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1817,64,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1818,64,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1819,64,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1820,64,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1821,64,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1822,64,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1823,64,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1824,64,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1825,64,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1826,64,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1827,64,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1828,64,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1829,64,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1830,64,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1831,64,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1832,64,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1833,64,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1834,64,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1835,64,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1836,64,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1837,64,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1838,64,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1839,64,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1840,64,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1841,64,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3238,98,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3239,98,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7021,181,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1845,64,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1846,64,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1847,64,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1848,64,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1849,64,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1850,65,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1851,65,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1852,65,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1853,65,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1854,65,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1855,65,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1856,65,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1857,65,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1858,65,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1859,65,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1860,65,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1861,65,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1862,65,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1863,65,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1864,65,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1865,65,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1866,65,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1867,65,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1868,65,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 156px; width: 565px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1869,65,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1870,65,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1871,65,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1872,65,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1873,65,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1874,65,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1875,65,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1876,65,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1877,65,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1878,65,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1879,65,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1880,65,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6910,178,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3237,98,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7020,181,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 24px; display: block; height: 25.35px; width: 133px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1884,65,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1885,65,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1886,65,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1887,65,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1888,65,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1889,66,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1890,66,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1891,66,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1892,66,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1893,66,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1894,66,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1895,66,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1896,66,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1897,66,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1898,66,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1899,66,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1900,66,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1901,66,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1902,66,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1903,66,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1904,66,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1905,66,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1906,66,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1907,66,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1908,66,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1909,66,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1910,66,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1911,66,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1912,66,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1913,66,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1914,66,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1915,66,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1916,66,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1917,66,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1918,66,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1919,66,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6909,178,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3235,98,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3236,98,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1923,66,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1924,66,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1925,66,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1926,66,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1927,66,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1928,67,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1929,67,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1930,67,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1931,67,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1932,67,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1933,67,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1934,67,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1935,67,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1936,67,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1937,67,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1938,67,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1939,67,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1940,67,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1941,67,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1942,67,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1943,67,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1944,67,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1945,67,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1946,67,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1947,67,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1948,67,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1949,67,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1950,67,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1951,67,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1952,67,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1953,67,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1954,67,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1955,67,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1956,67,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1957,67,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1958,67,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3234,98,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7019,181,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 57px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1962,67,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1963,67,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1964,67,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1965,67,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1966,67,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1967,68,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1968,68,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1969,68,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1970,68,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1971,68,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1972,68,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1973,68,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1974,68,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1975,68,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1976,68,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1977,68,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1978,68,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1979,68,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1980,68,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1981,68,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1982,68,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1983,68,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1984,68,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1985,68,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1986,68,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1987,68,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1988,68,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1989,68,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1990,68,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1991,68,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1992,68,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1993,68,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1994,68,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1995,68,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1996,68,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (1997,68,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6908,178,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5878,157,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3233,98,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7018,181,'cadre',0,'cms_module_menu_13',0,'intro','intro_bibli','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2001,68,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2002,68,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2003,68,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2004,68,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2005,68,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2006,69,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2007,69,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2008,69,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2010,69,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2011,69,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2012,69,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2013,69,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2014,69,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2015,69,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2016,69,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2017,69,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2018,69,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2019,69,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2020,69,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2021,69,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2022,69,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2023,69,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2024,69,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2025,69,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2026,69,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2027,69,'cadre',0,'intro_message',0,'main_hors_footer','etageres','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2028,69,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2029,69,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2030,69,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2031,69,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2032,69,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2033,69,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2034,69,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2035,69,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2036,69,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2037,69,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2038,69,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2039,69,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2040,69,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2041,69,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7016,181,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7017,181,'cadre',1,'intro_bibli',0,'intro','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2045,69,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2046,70,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2047,70,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2048,70,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2086,71,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2050,70,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2051,70,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2052,70,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2053,70,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2054,70,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2055,70,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2056,70,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2057,70,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2058,70,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2059,70,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2060,70,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2061,70,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2062,70,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2063,70,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2064,70,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2065,70,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2066,70,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2067,70,'cadre',0,'intro_message',0,'main_hors_footer','etageres','','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2068,70,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2069,70,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2070,70,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2071,70,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2072,70,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2073,70,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2074,70,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2075,70,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2076,70,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2077,70,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2078,70,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2079,70,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2080,70,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2081,70,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6907,178,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3231,98,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7015,181,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2085,70,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2087,71,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2088,71,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2089,71,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2090,71,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2091,71,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2092,71,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2093,71,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2094,71,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2095,71,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2096,71,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2097,71,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2098,71,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2099,71,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2100,71,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2101,71,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2102,71,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2103,71,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2104,71,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2105,71,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2106,71,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2107,71,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2108,71,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2109,71,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2110,71,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2111,71,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2112,71,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2113,71,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2114,71,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2115,71,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2116,71,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2117,71,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2118,71,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2119,71,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2120,71,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6906,178,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3230,98,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7014,181,'cadre',1,'accueil',0,'bandeau','adresse','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2124,71,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2125,72,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2165,73,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2127,72,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2128,72,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2129,72,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2130,72,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2131,72,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2132,72,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2133,72,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2134,72,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2135,72,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2136,72,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2137,72,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2138,72,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2139,72,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2140,72,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2141,72,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2142,72,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2143,72,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2144,72,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2145,72,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2146,72,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2147,72,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2148,72,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2149,72,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2150,72,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2151,72,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2152,72,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2153,72,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2154,72,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2155,72,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2156,72,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2157,72,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2158,72,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2159,72,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2160,72,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7013,181,'cadre',1,'adresse',0,'bandeau','connexion','accueil','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2164,72,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2166,73,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2167,73,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2168,73,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2169,73,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2170,73,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2171,73,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2172,73,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2173,73,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2174,73,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2175,73,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2176,73,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2177,73,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2178,73,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2179,73,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2180,73,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2181,73,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2182,73,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2183,73,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2184,73,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2185,73,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2186,73,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2187,73,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2188,73,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2189,73,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2190,73,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2191,73,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2192,73,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2193,73,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2194,73,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2195,73,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2196,73,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2197,73,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2198,73,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2199,73,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2200,73,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6905,178,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3229,98,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2204,73,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2205,74,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2206,74,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2207,74,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2246,75,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2209,74,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2210,74,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2211,74,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2212,74,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2213,74,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2214,74,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2215,74,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2216,74,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2217,74,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2218,74,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2219,74,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2220,74,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2221,74,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2222,74,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2223,74,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2224,74,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2225,74,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2226,74,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2227,74,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2228,74,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2229,74,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2230,74,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2231,74,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2232,74,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2233,74,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2234,74,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2235,74,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2236,74,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2237,74,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2238,74,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2239,74,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2240,74,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2241,74,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6903,178,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6904,178,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7012,181,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2245,74,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2247,75,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2248,75,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2249,75,'cadre',0,'cms_module_agenda_27',0,'bandeau','adresse','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2250,75,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2251,75,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2252,75,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2253,75,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2254,75,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2255,75,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2256,75,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2257,75,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2258,75,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2259,75,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2260,75,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2261,75,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2262,75,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2263,75,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2264,75,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2265,75,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2266,75,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2267,75,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2268,75,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2269,75,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2270,75,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2271,75,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2272,75,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2273,75,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2274,75,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2275,75,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2276,75,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2277,75,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2278,75,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2279,75,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2280,75,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2281,75,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2282,75,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6902,178,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3228,98,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7011,181,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2286,75,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2287,76,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2288,76,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2289,76,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2290,76,'cadre',0,'cms_module_agenda_27',0,'bandeau','adresse','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2291,76,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2292,76,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2293,76,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2294,76,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2295,76,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2296,76,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2297,76,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2298,76,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2299,76,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2300,76,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2301,76,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2302,76,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2303,76,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2304,76,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2305,76,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2306,76,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2307,76,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2308,76,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2309,76,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2310,76,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2311,76,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2312,76,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2313,76,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2314,76,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2315,76,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2316,76,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2317,76,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2318,76,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2319,76,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2320,76,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2321,76,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2322,76,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2323,76,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6901,178,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3227,98,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2327,76,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2328,77,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2329,77,'cadre',1,'adresse',0,'bandeau','','connexion','position: relative; left: -1px; top: 44px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2330,77,'cadre',1,'connexion',0,'bandeau','adresse','','position: relative; left: 766px; top: -385px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2331,77,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2332,77,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2333,77,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2334,77,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2335,77,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2336,77,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2337,77,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2338,77,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2339,77,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2340,77,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2341,77,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2342,77,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2343,77,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2344,77,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2345,77,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_section_18','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2346,77,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2347,77,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2348,77,'cadre',0,'cms_module_agenda_27',0,'bandeau','adresse','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2349,77,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2350,77,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2351,77,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2352,77,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2353,77,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2354,77,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2355,77,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2356,77,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2357,77,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2358,77,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 570px; top: 14px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2359,77,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2360,77,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2361,77,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2362,77,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2363,77,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2364,77,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2365,77,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6899,178,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6900,178,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7010,180,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2369,78,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: 311.967px; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2370,78,'cadre',0,'cms_module_menu_30',0,'bandeau','','adresse','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2371,78,'cadre',1,'adresse',0,'bandeau','','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2372,78,'cadre',0,'cms_module_agenda_27',0,'bandeau','adresse','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2373,78,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2374,78,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2375,78,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2376,78,'cadre',1,'accueil',0,'intro','intro_bibli','connexion','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2377,78,'cadre',0,'cms_module_menu_13',0,'intro','accueil','connexion','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2378,78,'cadre',1,'connexion',0,'intro','accueil','','position: relative; left: 757px; top: -40px; visibility: visible; display: block; height: 121.133px; width: 200px; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2379,78,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2380,78,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2381,78,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2382,78,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2383,78,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2384,78,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2385,78,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2386,78,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2387,78,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2388,78,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_article_14','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2389,78,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2390,78,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2391,78,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2392,78,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2393,78,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2394,78,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2395,78,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2396,78,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2397,78,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2398,78,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2399,78,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2400,78,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2401,78,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2402,78,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2403,78,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2404,78,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2405,78,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2406,78,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3226,98,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2410,79,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2411,79,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2412,79,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2413,79,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2414,79,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2415,79,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2416,79,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2417,79,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2418,79,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2419,79,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2420,79,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2421,79,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2422,79,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2423,79,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2424,79,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2425,79,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2426,79,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2427,79,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2428,79,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_search_22','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2429,79,'cadre',0,'cms_module_search_22',0,'main_hors_footer','cms_module_articleslist_21','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2430,79,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_search_22','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2431,79,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2432,79,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2433,79,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2434,79,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2435,79,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2436,79,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2437,79,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2438,79,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2439,79,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2440,79,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2441,79,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2442,79,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2443,79,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2444,79,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2445,79,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2446,79,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2447,79,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6898,178,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7009,180,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2451,80,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2452,80,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2453,80,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2454,80,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2455,80,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2456,80,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2457,80,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2458,80,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2459,80,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2460,80,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','','visibility: visible; position: relative; left: 715px; top: 12px; display: block; height: 51px; width: 200px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2461,80,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2462,80,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2463,80,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2464,80,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2465,80,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2466,80,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2467,80,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2468,80,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2469,80,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2470,80,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2471,80,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2472,80,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2473,80,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2474,80,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2475,80,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2476,80,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2477,80,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2478,80,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2479,80,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2480,80,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2481,80,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2482,80,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2483,80,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2484,80,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2485,80,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2486,80,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2487,80,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2488,80,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6897,178,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3225,98,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7008,180,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2492,81,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2493,81,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2494,81,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2495,81,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2496,81,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2497,81,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2498,81,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2499,81,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2500,81,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2501,81,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','','visibility: visible; position: relative; left: 715px; top: 12px; display: block; height: 51px; width: 200px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2502,81,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2503,81,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2504,81,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2505,81,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2506,81,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2507,81,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2508,81,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2509,81,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2510,81,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2511,81,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2512,81,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2513,81,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2514,81,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2515,81,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2516,81,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2517,81,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2518,81,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2519,81,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2520,81,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2521,81,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2522,81,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2523,81,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2524,81,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2525,81,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2526,81,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2527,81,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2528,81,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2529,81,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6896,178,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3223,98,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3224,98,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7007,180,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2533,82,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2534,82,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2535,82,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2536,82,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2537,82,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2538,82,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2539,82,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2540,82,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2541,82,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2542,82,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','','visibility: visible; position: relative; left: 715px; top: 12px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 213px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2543,82,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2544,82,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2545,82,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2546,82,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2547,82,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2548,82,'cadre',1,'navigator',0,'footer','footer_link_pmb','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2549,82,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2550,82,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2551,82,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2552,82,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2553,82,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2554,82,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2555,82,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2556,82,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2557,82,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2558,82,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2559,82,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2560,82,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2561,82,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2562,82,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2563,82,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2564,82,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2565,82,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2566,82,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2567,82,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2568,82,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2569,82,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2570,82,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6895,178,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2574,83,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2575,83,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2576,83,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2577,83,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2578,83,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2579,83,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2580,83,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2581,83,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2582,83,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2583,83,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','','visibility: visible; position: relative; left: 715px; top: 12px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 213px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2584,83,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2585,83,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2586,83,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2587,83,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2588,83,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2589,83,'cadre',1,'navigator',0,'footer','footer_link_pmb','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2590,83,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2591,83,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2592,83,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2593,83,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2594,83,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2595,83,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2596,83,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2597,83,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2598,83,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2599,83,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2600,83,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2601,83,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2602,83,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2603,83,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2604,83,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2605,83,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2606,83,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2607,83,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2608,83,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2609,83,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2610,83,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2611,83,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6894,178,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3221,98,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3222,98,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7006,180,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2615,84,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2616,84,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2617,84,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2618,84,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2619,84,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2620,84,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2621,84,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2622,84,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2623,84,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2624,84,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2625,84,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2626,84,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2627,84,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2628,84,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2629,84,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2630,84,'cadre',1,'navigator',0,'footer','footer_link_pmb','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2631,84,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2632,84,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2633,84,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2634,84,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2635,84,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2636,84,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2637,84,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2638,84,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2639,84,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2640,84,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2641,84,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2642,84,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2643,84,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2644,84,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2645,84,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2646,84,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2647,84,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2648,84,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2649,84,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2650,84,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2651,84,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2652,84,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6893,178,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3220,98,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7004,180,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7005,180,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2656,85,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2657,85,'cadre',0,'cms_module_menu_30',0,'bandeau','','connexion','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2658,85,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2659,85,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2660,85,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block; left: 701px; top: 152px; height: 51px; width: 233px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2661,85,'cadre',0,'cms_module_search_22',0,'bandeau_2','','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2662,85,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2663,85,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2664,85,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2665,85,'cadre',0,'cms_module_menu_13',0,'intro','accueil','','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2666,85,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2667,85,'cadre',1,'footer_rss',0,'footer','','footer_link_sup','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2668,85,'cadre',1,'footer_link_sup',0,'footer','footer_rss','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2669,85,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2670,85,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2671,85,'cadre',1,'navigator',0,'footer','footer_link_pmb','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2672,85,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2673,85,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2674,85,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2675,85,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2676,85,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2677,85,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2678,85,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2679,85,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2680,85,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2681,85,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2682,85,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2683,85,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2684,85,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2685,85,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2686,85,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2687,85,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2688,85,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2689,85,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2690,85,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2691,85,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2692,85,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2693,85,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6892,178,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3219,98,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7003,180,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2697,86,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2698,86,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2699,86,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2700,86,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2701,86,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2702,86,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2703,86,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2704,86,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2705,86,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2706,86,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2707,86,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2708,86,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2709,86,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2710,86,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2711,86,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2712,86,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2713,86,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2714,86,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2715,86,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2716,86,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2717,86,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2718,86,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2719,86,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2720,86,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2721,86,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2722,86,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2723,86,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2724,86,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2725,86,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2726,86,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2727,86,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2728,86,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2729,86,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2730,86,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2731,86,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2732,86,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2733,86,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2734,86,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3217,98,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3218,98,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7001,180,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7002,180,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2738,87,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2739,87,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2740,87,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2741,87,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2742,87,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2743,87,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2744,87,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2745,87,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2746,87,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2747,87,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2748,87,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2749,87,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2750,87,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2751,87,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2752,87,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2753,87,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2754,87,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2755,87,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2756,87,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_27','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2757,87,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','intro_message','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2758,87,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2759,87,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2760,87,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2761,87,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2762,87,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2763,87,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2764,87,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2765,87,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2766,87,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2767,87,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2768,87,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2769,87,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2770,87,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2771,87,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2772,87,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2773,87,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2774,87,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2775,87,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6891,178,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3216,98,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7000,180,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2779,88,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2780,88,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2781,88,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2782,88,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2783,88,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2784,88,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2785,88,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2786,88,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2787,88,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2788,88,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2789,88,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2790,88,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2791,88,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2792,88,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2793,88,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2794,88,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2795,88,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2796,88,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2797,88,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2798,88,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2799,88,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2800,88,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2801,88,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2802,88,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2803,88,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2804,88,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2805,88,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2806,88,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2807,88,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2808,88,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2809,88,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2810,88,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2811,88,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2812,88,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2813,88,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2814,88,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2815,88,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2816,88,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6890,178,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3215,98,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6999,180,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2820,89,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2821,89,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2822,89,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2823,89,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2824,89,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2825,89,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2826,89,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2827,89,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2828,89,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2829,89,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2830,89,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2831,89,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2832,89,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2833,89,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2834,89,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2835,89,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2836,89,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2837,89,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2838,89,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_32','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2840,89,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2841,89,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2842,89,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2843,89,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2844,89,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2845,89,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2846,89,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2847,89,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2848,89,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2849,89,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2850,89,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2851,89,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2852,89,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2853,89,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2854,89,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2855,89,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2856,89,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2857,89,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2858,89,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3214,98,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6998,180,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2862,90,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2863,90,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2864,90,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2865,90,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2866,90,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2867,90,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2868,90,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2869,90,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2870,90,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2871,90,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2872,90,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2873,90,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2874,90,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2875,90,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2876,90,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2877,90,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2878,90,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2879,90,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2880,90,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_33','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2881,90,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5877,157,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2883,90,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2884,90,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2885,90,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2886,90,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2887,90,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2888,90,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2889,90,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2890,90,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2891,90,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2892,90,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2893,90,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2894,90,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2895,90,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2896,90,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2897,90,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2898,90,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2899,90,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2900,90,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2901,90,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6888,178,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6889,178,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3213,98,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6996,180,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6997,180,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2905,91,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2906,91,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2907,91,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2908,91,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2909,91,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2910,91,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2911,91,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2912,91,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2913,91,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2914,91,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2915,91,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2916,91,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2917,91,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2918,91,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2919,91,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2920,91,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2921,91,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2922,91,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2923,91,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2924,91,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2925,91,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2926,91,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2927,91,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5876,156,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2929,91,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2930,91,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2931,91,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2932,91,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2933,91,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2934,91,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2935,91,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2936,91,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2937,91,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2938,91,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2939,91,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2940,91,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2941,91,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2942,91,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2943,91,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2944,91,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6995,180,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2948,92,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2949,92,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2950,92,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2951,92,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2952,92,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2953,92,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2954,92,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2955,92,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2956,92,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2957,92,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2958,92,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2959,92,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2960,92,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2961,92,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2962,92,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2963,92,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2964,92,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2965,92,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2966,92,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_33','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2967,92,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2968,92,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2969,92,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2970,92,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5875,156,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2972,92,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2973,92,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2974,92,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2975,92,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2976,92,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2977,92,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2978,92,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2979,92,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2980,92,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2981,92,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2982,92,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2983,92,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2984,92,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2985,92,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2986,92,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2987,92,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6887,178,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','notice','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3211,98,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3212,98,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2991,93,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2992,93,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2993,93,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2994,93,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2995,93,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2996,93,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2997,93,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2998,93,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (2999,93,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3000,93,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3001,93,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3002,93,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3003,93,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3004,93,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3005,93,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3006,93,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3007,93,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3008,93,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3009,93,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_33','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3010,93,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3011,93,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3012,93,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3013,93,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3015,93,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3016,93,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3017,93,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3018,93,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3019,93,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3020,93,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3021,93,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3022,93,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3023,93,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3024,93,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3025,93,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3026,93,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3027,93,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3028,93,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3029,93,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3030,93,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6886,178,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3210,98,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6994,180,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3034,94,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3035,94,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3036,94,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3037,94,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3038,94,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3039,94,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3040,94,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3041,94,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3042,94,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3043,94,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3044,94,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3045,94,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3046,94,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3047,94,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3048,94,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3049,94,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3050,94,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3051,94,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3052,94,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_agenda_33','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3053,94,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3054,94,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3055,94,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3056,94,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5873,156,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5874,156,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3058,94,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3059,94,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3060,94,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3061,94,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3062,94,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3063,94,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3064,94,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3065,94,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3066,94,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3067,94,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3068,94,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3069,94,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3070,94,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3071,94,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3072,94,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3073,94,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3208,98,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3209,98,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6993,180,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3077,95,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3078,95,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3079,95,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3080,95,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3081,95,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3082,95,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3083,95,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3084,95,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3085,95,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3086,95,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3087,95,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3088,95,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3089,95,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3090,95,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3091,95,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3092,95,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3093,95,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3094,95,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3095,95,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3096,95,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3097,95,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3098,95,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3099,95,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5872,156,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3101,95,'cadre',0,'cms_module_article_14',0,'main_hors_footer','resume_panier','intro_message','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3102,95,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3103,95,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3104,95,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3105,95,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3106,95,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3107,95,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3108,95,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3109,95,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3110,95,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3111,95,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3112,95,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3113,95,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3114,95,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3115,95,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3116,95,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6885,178,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6992,180,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3120,96,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3121,96,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3122,96,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3123,96,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3124,96,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3125,96,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3126,96,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3127,96,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3128,96,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3129,96,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3130,96,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3131,96,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3132,96,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3133,96,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3134,96,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3135,96,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3136,96,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3137,96,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3138,96,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_15','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3139,96,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','intro_message','cms_module_recordslist_17','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3140,96,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','cms_module_recordslist_15','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3141,96,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3142,96,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3143,96,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3144,96,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3145,96,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5871,156,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3147,96,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3148,96,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3149,96,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3150,96,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3151,96,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3152,96,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3153,96,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3154,96,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3155,96,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3156,96,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3157,96,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3158,96,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3159,96,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6884,178,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3207,98,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6991,180,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3163,97,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3164,97,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3165,97,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3166,97,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3167,97,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3168,97,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3169,97,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3170,97,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3171,97,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3172,97,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3173,97,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3174,97,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3175,97,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3176,97,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3177,97,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3178,97,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3179,97,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3180,97,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3181,97,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3182,97,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3183,97,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3184,97,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3185,97,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3186,97,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3187,97,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3188,97,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6881,178,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5870,156,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3190,97,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3191,97,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3192,97,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3193,97,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3194,97,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3195,97,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3196,97,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3197,97,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3198,97,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3199,97,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3200,97,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3201,97,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3202,97,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6883,178,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3206,98,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6989,180,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6990,180,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3264,99,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3265,99,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3266,99,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_20','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3268,99,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3269,99,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6882,178,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3271,99,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3272,99,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3273,99,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3274,99,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3275,99,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3276,99,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3277,99,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3278,99,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3279,99,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3280,99,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3281,99,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3282,99,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3284,99,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3285,99,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3286,99,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3287,99,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3288,99,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3289,99,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3290,99,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 156px; width: 220px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3291,100,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3292,100,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3293,100,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3294,100,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3295,100,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3296,100,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3297,100,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3298,100,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3299,100,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3300,100,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3301,100,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3302,100,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3303,100,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3304,100,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3305,100,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3306,100,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3307,100,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3308,100,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3309,100,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3310,100,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 200px; width: 330px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3311,100,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3312,100,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6988,180,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3314,100,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3315,100,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6880,178,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3317,100,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3318,100,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3319,100,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3320,100,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3321,100,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3322,100,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3323,100,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3324,100,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3325,100,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3326,100,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3327,100,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3328,100,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5868,156,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3330,100,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3331,100,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3332,100,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3333,100,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3334,101,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3335,101,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3336,101,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3337,101,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3338,101,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3339,101,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3340,101,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3341,101,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3342,101,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3343,101,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3344,101,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3345,101,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3346,101,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3347,101,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3348,101,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3349,101,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3350,101,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3351,101,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3352,101,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3353,101,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3354,101,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3355,101,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6987,180,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3357,101,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3358,101,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3360,101,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3361,101,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3362,101,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3363,101,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3364,101,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3365,101,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3366,101,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3367,101,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3368,101,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3369,101,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3370,101,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3371,101,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5867,156,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3373,101,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3374,101,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3375,101,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3376,101,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3377,102,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3378,102,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3379,102,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3380,102,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3381,102,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3382,102,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3383,102,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3384,102,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3385,102,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3386,102,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3387,102,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3388,102,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3389,102,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3390,102,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3391,102,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3392,102,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3393,102,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3394,102,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3395,102,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3396,102,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3397,102,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3398,102,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 384px; top: -419px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6986,180,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3400,102,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3401,102,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6879,178,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3403,102,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3404,102,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3405,102,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3406,102,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3407,102,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3408,102,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3409,102,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3410,102,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3411,102,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3412,102,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3413,102,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3414,102,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6985,180,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3416,102,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3417,102,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3418,102,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3419,102,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3420,103,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3421,103,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3422,103,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3423,103,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3424,103,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3425,103,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3426,103,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3427,103,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3428,103,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3429,103,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3430,103,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3431,103,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3432,103,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3433,103,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3434,103,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3435,103,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3436,103,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3437,103,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3438,103,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3439,103,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3440,103,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3441,103,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 383px; top: -419px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3443,103,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3444,103,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3446,103,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3447,103,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3448,103,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3449,103,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3450,103,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3451,103,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3452,103,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3453,103,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3454,103,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3455,103,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3456,103,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3457,103,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5865,156,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3459,103,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3460,103,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3461,103,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3462,103,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3463,104,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3464,104,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3465,104,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3466,104,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3467,104,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3468,104,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3469,104,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3470,104,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3471,104,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3472,104,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3473,104,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3474,104,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3475,104,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3476,104,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3477,104,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3478,104,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3479,104,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3480,104,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3481,104,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3482,104,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3483,104,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 599px; top: -251px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3484,104,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 369px; top: -1564px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3486,104,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3487,104,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6878,178,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3489,104,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3490,104,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3491,104,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3492,104,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3493,104,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3494,104,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3495,104,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3496,104,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3497,104,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3498,104,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3499,104,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3500,104,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3502,104,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3503,104,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3504,104,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3505,104,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3506,105,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3507,105,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3508,105,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3509,105,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3510,105,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3511,105,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3512,105,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3513,105,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3514,105,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3515,105,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3516,105,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3517,105,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3518,105,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3519,105,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3520,105,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3521,105,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3522,105,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3523,105,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3524,105,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3525,105,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3526,105,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 599px; top: -251px; display: block; height: 600px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3527,105,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 369px; top: -1564px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6984,180,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3529,105,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3530,105,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6877,178,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3532,105,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3533,105,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3534,105,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3535,105,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3536,105,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3537,105,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3538,105,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3539,105,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3540,105,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3541,105,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3542,105,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3543,105,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5864,156,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3545,105,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3546,105,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3547,105,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3548,105,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3549,106,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3550,106,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3551,106,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3552,106,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3553,106,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3554,106,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3555,106,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3556,106,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3557,106,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3558,106,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3559,106,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3560,106,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3561,106,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3562,106,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3563,106,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3564,106,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3565,106,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3566,106,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3567,106,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3568,106,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3569,106,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 599px; top: -251px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3570,106,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3572,106,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3573,106,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3575,106,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3576,106,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3577,106,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3578,106,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3579,106,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3580,106,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3581,106,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3582,106,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3583,106,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3584,106,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3585,106,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3586,106,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5863,156,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3588,106,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3589,106,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3590,106,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3591,106,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3592,107,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3593,107,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3594,107,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3595,107,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3596,107,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3597,107,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3598,107,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3599,107,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3600,107,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3601,107,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3602,107,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3603,107,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3604,107,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3605,107,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3606,107,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3607,107,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3608,107,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3609,107,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3610,107,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3611,107,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3612,107,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3613,107,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6983,180,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3615,107,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3616,107,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6876,178,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3618,107,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3619,107,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3620,107,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3621,107,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3622,107,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3623,107,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3624,107,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3625,107,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3626,107,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3627,107,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3628,107,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3629,107,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3631,107,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3632,107,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3633,107,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3634,107,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3635,108,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3636,108,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3637,108,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3638,108,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3639,108,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3640,108,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3641,108,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3642,108,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3643,108,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3644,108,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3645,108,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3646,108,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3647,108,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3648,108,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3649,108,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3650,108,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3651,108,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3652,108,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3653,108,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3654,108,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3655,108,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3656,108,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3657,108,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','','visibility: visible; position: relative; left: -2px; top: -800px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6982,180,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3659,108,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3660,108,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6875,178,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3662,108,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3663,108,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3664,108,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3665,108,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3666,108,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3667,108,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3668,108,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3669,108,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3670,108,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3671,108,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3672,108,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3673,108,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3675,108,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3676,108,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3677,108,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3678,108,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3679,109,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3680,109,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3681,109,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3682,109,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3683,109,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3684,109,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3685,109,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3686,109,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3687,109,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3688,109,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3689,109,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3690,109,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3691,109,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3692,109,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3693,109,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3694,109,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3695,109,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3696,109,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3697,109,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3698,109,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3699,109,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3700,109,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3701,109,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6981,180,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3703,109,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3704,109,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6873,178,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6874,178,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3706,109,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3707,109,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3708,109,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3709,109,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3710,109,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3711,109,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3712,109,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3713,109,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3714,109,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3715,109,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3716,109,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3717,109,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5862,156,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3719,109,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3720,109,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3721,109,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3722,109,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3723,110,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3724,110,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3725,110,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3726,110,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3727,110,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3728,110,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3729,110,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3730,110,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3731,110,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3732,110,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3733,110,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3734,110,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3735,110,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3736,110,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3737,110,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3738,110,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3739,110,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3741,110,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3742,110,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3743,110,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3744,110,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3745,110,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3746,110,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6980,180,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3748,110,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3749,110,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6872,178,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3751,110,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3752,110,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3753,110,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3754,110,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3755,110,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3756,110,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3757,110,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3758,110,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3759,110,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3760,110,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3761,110,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3762,110,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3764,110,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3765,110,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3766,110,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3767,110,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3768,111,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3769,111,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3770,111,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3771,111,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3772,111,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3773,111,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3774,111,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3775,111,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3776,111,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3777,111,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3778,111,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3779,111,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3780,111,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3781,111,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3782,111,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3783,111,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3784,111,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3785,111,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3786,111,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3787,111,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: -1px; top: 0px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3788,111,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3789,111,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3790,111,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3791,111,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3814,112,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3815,112,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3794,111,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3795,111,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3797,111,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3798,111,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3799,111,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3800,111,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3801,111,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3802,111,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3803,111,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3804,111,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3805,111,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3806,111,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3807,111,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3808,111,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5861,156,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3810,111,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3811,111,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3812,111,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3813,111,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3816,112,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3817,112,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3818,112,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3819,112,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3820,112,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3821,112,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3822,112,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3823,112,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3824,112,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3825,112,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3826,112,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3827,112,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3828,112,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3829,112,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3830,112,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3831,112,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3832,112,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3833,112,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3834,112,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3835,112,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3836,112,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3837,112,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 285px; top: -1094px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6978,180,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6979,180,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3839,112,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3840,112,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6871,178,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3842,112,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3843,112,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3844,112,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3845,112,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3846,112,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3847,112,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3848,112,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3849,112,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3850,112,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3851,112,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3852,112,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3853,112,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3855,112,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3856,112,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3857,112,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3858,112,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3859,113,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3860,113,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3861,113,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3862,113,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3863,113,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3864,113,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3865,113,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3866,113,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3867,113,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3868,113,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3869,113,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3870,113,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3871,113,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3872,113,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3873,113,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3874,113,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3875,113,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 600px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3876,113,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3877,113,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3878,113,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3879,113,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3880,113,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3881,113,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3882,113,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 285px; top: -1094px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6977,180,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3884,113,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3885,113,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3887,113,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3888,113,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3889,113,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3890,113,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3891,113,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3892,113,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3893,113,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3894,113,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3895,113,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3896,113,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3897,113,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3898,113,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5860,156,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3900,113,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3901,113,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3902,113,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3903,113,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3904,114,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3905,114,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3906,114,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3907,114,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3908,114,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3909,114,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3910,114,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3911,114,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3912,114,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3913,114,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3914,114,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3915,114,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3916,114,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3917,114,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3918,114,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3919,114,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3920,114,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3921,114,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3922,114,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3923,114,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3924,114,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3925,114,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3926,114,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3927,114,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 285px; top: -1094px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6976,180,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3929,114,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3930,114,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6870,178,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3932,114,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3933,114,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3934,114,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3935,114,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3936,114,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3937,114,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3938,114,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3939,114,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3940,114,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3941,114,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3942,114,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3943,114,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3945,114,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3946,114,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3947,114,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3948,114,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3949,115,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3950,115,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3951,115,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3952,115,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3953,115,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3954,115,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3955,115,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3956,115,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3957,115,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3958,115,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3959,115,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3960,115,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3961,115,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3962,115,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3963,115,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3964,115,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3965,115,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3966,115,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3967,115,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3968,115,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3969,115,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3970,115,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3971,115,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3972,115,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 289px; top: -1115px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6974,180,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6975,180,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3974,115,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3975,115,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6869,177,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3977,115,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3978,115,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3979,115,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3980,115,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3981,115,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3982,115,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3983,115,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3984,115,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3985,115,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3986,115,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3987,115,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3988,115,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5859,156,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3990,115,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3991,115,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3992,115,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3993,115,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3994,116,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3995,116,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3996,116,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3997,116,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3998,116,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (3999,116,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4000,116,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4001,116,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4002,116,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4003,116,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4004,116,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4005,116,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4006,116,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4007,116,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4008,116,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4009,116,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4010,116,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4011,116,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4012,116,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4013,116,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 215px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4014,116,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4015,116,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4016,116,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4017,116,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 289px; top: -1115px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4019,116,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4020,116,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6868,177,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4022,116,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4023,116,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4024,116,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4025,116,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4026,116,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4027,116,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4028,116,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4029,116,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4030,116,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4031,116,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4032,116,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4033,116,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4035,116,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4036,116,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4037,116,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4038,116,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4039,117,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4040,117,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4041,117,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4042,117,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4043,117,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4044,117,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4045,117,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4046,117,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4047,117,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4048,117,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4049,117,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4050,117,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4051,117,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4052,117,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4053,117,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4054,117,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4055,117,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4056,117,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4057,117,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4058,117,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: auto; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4059,117,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4060,117,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4061,117,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4062,117,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 289px; top: -1115px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6973,180,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 35px; display: block; height: 25.35px; width: 133px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4064,117,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4065,117,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6867,177,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4067,117,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4068,117,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4069,117,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4070,117,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4071,117,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4072,117,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4073,117,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4074,117,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4075,117,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4076,117,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4077,117,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4078,117,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5858,156,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4080,117,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4081,117,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4082,117,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4083,117,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4084,118,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4085,118,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4086,118,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4087,118,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4088,118,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4089,118,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4090,118,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4091,118,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4092,118,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4093,118,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4094,118,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4095,118,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4096,118,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4097,118,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4098,118,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4099,118,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4100,118,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4101,118,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4102,118,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4103,118,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: relative; left: 4px; top: -3px; display: block; height: 253px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4104,118,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4105,118,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4106,118,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4107,118,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 289px; top: -1115px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6972,180,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4109,118,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4110,118,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4112,118,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4113,118,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4114,118,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4115,118,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4116,118,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4117,118,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4118,118,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4119,118,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4120,118,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4121,118,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4122,118,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4123,118,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4125,118,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4126,118,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4127,118,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4128,118,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4129,119,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4130,119,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4131,119,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4132,119,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4133,119,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4134,119,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4135,119,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4136,119,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4137,119,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4138,119,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4139,119,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4140,119,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4141,119,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4142,119,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4143,119,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4144,119,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4145,119,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 620px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4146,119,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4147,119,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4148,119,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4149,119,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: relative; left: 587px; top: -249px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4150,119,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_36','visibility: visible; position: relative; left: 376px; top: -786px; height: auto; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4151,119,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: relative; left: -2px; top: -800px; display: block; height: auto; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4152,119,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','','visibility: visible; position: relative; left: 289px; top: -1115px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6971,180,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4154,119,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4155,119,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6866,177,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4157,119,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4158,119,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4159,119,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4160,119,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4161,119,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4162,119,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4163,119,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4164,119,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4165,119,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4166,119,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4167,119,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4168,119,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4170,119,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4171,119,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4172,119,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4173,119,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4174,120,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4175,120,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4176,120,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4177,120,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4178,120,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4179,120,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4180,120,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4181,120,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4182,120,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4183,120,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4184,120,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4185,120,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4186,120,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4187,120,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4188,120,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4189,120,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4190,120,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4191,120,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4192,120,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4193,120,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4194,120,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4195,120,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; height: 215.517px; width: 179px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4196,120,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4197,120,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4199,120,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4200,120,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6865,177,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4202,120,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4203,120,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4204,120,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4205,120,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4206,120,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4207,120,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4208,120,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4209,120,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4210,120,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4211,120,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4212,120,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4213,120,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5857,156,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4215,120,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4216,120,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4217,120,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4218,120,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4219,121,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4220,121,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4221,121,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4222,121,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4223,121,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4224,121,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4225,121,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4226,121,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4227,121,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4228,121,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4229,121,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4230,121,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4231,121,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4232,121,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4233,121,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4234,121,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4235,121,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4236,121,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4237,121,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4238,121,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_recordslist_23','visibility: visible; position: static; left: 12px; top: 12px; display: block; height: auto; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4239,121,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4240,121,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4241,121,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4242,121,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6969,180,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6970,180,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4244,121,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4245,121,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6863,177,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6864,177,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4247,121,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4248,121,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4249,121,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4250,121,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4251,121,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4252,121,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4253,121,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4254,121,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4255,121,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4256,121,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4257,121,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4258,121,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4260,121,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4261,121,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4262,121,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4263,121,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4264,122,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4265,122,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4266,122,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4267,122,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4268,122,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4269,122,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4270,122,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4271,122,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4272,122,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4273,122,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4274,122,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4275,122,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4276,122,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4277,122,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4278,122,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4279,122,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4280,122,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4281,122,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4282,122,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_36','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4283,122,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','intro_message','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4284,122,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_articleslist_21','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4285,122,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 12px; top: 12px; display: block; height: auto; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4286,122,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4287,122,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0px; top: 0px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6967,180,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6968,180,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4289,122,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4290,122,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4292,122,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4293,122,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4294,122,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4295,122,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4296,122,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4297,122,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4298,122,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4299,122,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4300,122,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4301,122,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4302,122,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4303,122,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5856,156,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4305,122,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4306,122,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4307,122,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4308,122,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4309,123,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4310,123,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4311,123,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4312,123,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4313,123,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4314,123,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4315,123,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4316,123,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4317,123,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4318,123,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4319,123,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4320,123,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4321,123,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4322,123,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4323,123,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4324,123,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4325,123,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4326,123,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4327,123,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_36','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4328,123,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','intro_message','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4329,123,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_articleslist_21','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4330,123,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 12px; top: 12px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4331,123,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_21','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4332,123,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0px; top: 0px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6966,180,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4334,123,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4335,123,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6862,177,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4337,123,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4338,123,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4339,123,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4340,123,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4341,123,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4342,123,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4343,123,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4344,123,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4345,123,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4346,123,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4347,123,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4348,123,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4350,123,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4351,123,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4352,123,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4353,123,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4354,124,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4355,124,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4356,124,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4357,124,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4358,124,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4359,124,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4360,124,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4361,124,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4362,124,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4363,124,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4364,124,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4365,124,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4366,124,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4367,124,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4368,124,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4369,124,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4370,124,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4371,124,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4372,124,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4373,124,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4374,124,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4375,124,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4376,124,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_38','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4377,124,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: -31px; top: -381px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4379,124,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4380,124,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6861,177,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4382,124,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4383,124,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4384,124,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4385,124,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4386,124,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4387,124,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4388,124,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4389,124,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4390,124,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4391,124,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4392,124,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4393,124,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5855,156,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4395,124,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4396,124,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4397,124,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4398,124,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4399,125,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4400,125,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4401,125,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4402,125,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4403,125,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4404,125,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4405,125,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4406,125,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4407,125,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4408,125,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4409,125,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4410,125,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4411,125,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4412,125,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4413,125,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4414,125,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4415,125,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4416,125,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4417,125,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4418,125,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4419,125,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4420,125,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4421,125,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_38','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4422,125,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: -31px; top: -381px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6965,180,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4424,125,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4425,125,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6859,177,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6860,177,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4427,125,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4428,125,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4429,125,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4430,125,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4431,125,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4432,125,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4433,125,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4434,125,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4435,125,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4436,125,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4437,125,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4438,125,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5854,156,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4440,125,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4441,125,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4442,125,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4443,125,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4444,126,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4445,126,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4446,126,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4447,126,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4448,126,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4449,126,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4450,126,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4451,126,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4452,126,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4453,126,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4454,126,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4455,126,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4456,126,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4457,126,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4458,126,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4459,126,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4460,126,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4461,126,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4462,126,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4463,126,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4464,126,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4465,126,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4466,126,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_38','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4467,126,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: -31px; top: -381px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6964,180,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4469,126,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4470,126,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6858,177,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4472,126,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4473,126,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4474,126,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4475,126,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4476,126,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4477,126,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4478,126,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4479,126,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4480,126,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4481,126,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4482,126,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4483,126,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5853,156,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4485,126,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4486,126,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4487,126,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4488,126,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4489,127,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4490,127,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4491,127,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4492,127,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4493,127,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4494,127,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4495,127,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4496,127,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4497,127,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4498,127,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4499,127,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4500,127,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4501,127,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4502,127,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4503,127,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4504,127,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4505,127,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4506,127,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4507,127,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4508,127,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4509,127,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4510,127,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4511,127,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_articleslist_38','cms_module_agenda_27','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4512,127,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: -31px; top: -381px; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6963,179,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4514,127,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4515,127,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6857,177,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4517,127,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4518,127,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4519,127,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4520,127,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4521,127,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4522,127,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4523,127,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4524,127,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4525,127,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4526,127,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4527,127,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4528,127,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5852,156,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4530,127,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4531,127,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4532,127,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4533,127,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4534,128,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4535,128,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4536,128,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4537,128,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4538,128,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4539,128,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4540,128,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4541,128,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4542,128,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4543,128,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4544,128,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4545,128,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4546,128,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4547,128,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4548,128,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4549,128,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4550,128,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4551,128,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4552,128,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4553,128,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4554,128,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4555,128,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4556,128,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4557,128,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','cms_module_articleslist_36','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4558,128,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_recordslist_23','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6962,179,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4560,128,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4561,128,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6856,177,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4563,128,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4564,128,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4565,128,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4566,128,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4567,128,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4568,128,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4569,128,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4570,128,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4571,128,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4572,128,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4573,128,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4574,128,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5851,156,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4576,128,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4577,128,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4578,128,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4579,128,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4580,129,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4581,129,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4582,129,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4583,129,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4584,129,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4585,129,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4586,129,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4587,129,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4588,129,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4589,129,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4590,129,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4591,129,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4592,129,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4593,129,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4594,129,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4595,129,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4596,129,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4597,129,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4598,129,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4599,129,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 225px; width: 350px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4600,129,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0pt; top: 0pt; height: 215.517px; width: 179px; margin: 0px 0px 17px 30px; padding: 0px 0px 10px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4601,129,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4602,129,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4603,129,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4604,129,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6961,179,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4606,129,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4607,129,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6855,177,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4609,129,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4610,129,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4611,129,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4612,129,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4613,129,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4614,129,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4615,129,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4616,129,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4617,129,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4618,129,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4619,129,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4620,129,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5850,156,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4622,129,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4623,129,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4624,129,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4625,129,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4626,130,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4627,130,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4628,130,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4629,130,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4630,130,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4631,130,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4632,130,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4633,130,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4634,130,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4635,130,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4636,130,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4637,130,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4638,130,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4639,130,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4640,130,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4641,130,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4642,130,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4643,130,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4644,130,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4645,130,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4646,130,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4647,130,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4648,130,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4649,130,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4650,130,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6960,179,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4652,130,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4653,130,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4655,130,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4656,130,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4657,130,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4658,130,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4659,130,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4660,130,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4661,130,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4662,130,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4663,130,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4664,130,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4665,130,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4666,130,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4668,130,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4669,130,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4670,130,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4671,130,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4672,131,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4673,131,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4674,131,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4675,131,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4676,131,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4677,131,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4678,131,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4679,131,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4680,131,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4681,131,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4682,131,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4683,131,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4684,131,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4685,131,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4686,131,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4687,131,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4688,131,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4689,131,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4690,131,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4691,131,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4692,131,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4693,131,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4694,131,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4695,131,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4696,131,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6958,179,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6959,179,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4698,131,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4699,131,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6854,177,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4701,131,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4702,131,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4703,131,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4704,131,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4705,131,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4706,131,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4707,131,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4708,131,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4709,131,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4710,131,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4711,131,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4712,131,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5849,156,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4714,131,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4715,131,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4716,131,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4717,131,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4718,132,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4719,132,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4720,132,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4721,132,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4722,132,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4723,132,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4724,132,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4725,132,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4726,132,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4727,132,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4728,132,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4729,132,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4730,132,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4731,132,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4732,132,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4733,132,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4734,132,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4735,132,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4736,132,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4737,132,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4738,132,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4739,132,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0pt; top: 0pt; display: block; height: 287.85px; width: 250px; margin: 0px 0px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4740,132,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4741,132,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4742,132,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6957,179,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4744,132,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4745,132,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4747,132,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4748,132,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4749,132,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4750,132,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4751,132,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4752,132,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4753,132,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4754,132,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4755,132,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4756,132,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4757,132,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4758,132,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5848,156,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4760,132,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4761,132,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4762,132,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4763,132,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4764,133,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4765,133,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4766,133,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4767,133,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4768,133,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4769,133,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4770,133,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4771,133,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4772,133,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4773,133,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4774,133,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4775,133,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4776,133,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4777,133,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4778,133,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4779,133,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4780,133,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4781,133,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4782,133,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4783,133,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4784,133,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4785,133,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4786,133,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0pt; top: 0pt; height: auto; width: 270px; margin: 0px 0px 25px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4787,133,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4788,133,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6956,179,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4790,133,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4791,133,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6853,177,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4793,133,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4794,133,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4795,133,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4796,133,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4797,133,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4798,133,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4799,133,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4800,133,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4801,133,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4802,133,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4803,133,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4804,133,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5847,156,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_42','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4806,133,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4807,133,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4808,133,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4809,133,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4810,134,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4811,134,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4812,134,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4813,134,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4814,134,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4815,134,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4816,134,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4817,134,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4818,134,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4819,134,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4820,134,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4821,134,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4822,134,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4823,134,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4824,134,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4825,134,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4826,134,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4827,134,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4828,134,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4829,134,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4830,134,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4831,134,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4832,134,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4833,134,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4834,134,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6954,179,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6955,179,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4836,134,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4837,134,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6852,177,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4839,134,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4840,134,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4841,134,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4842,134,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4843,134,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4844,134,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4845,134,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4846,134,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4847,134,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4848,134,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4849,134,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4850,134,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5846,156,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4852,134,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4853,134,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4854,134,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4855,134,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4856,135,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4857,135,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4858,135,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4859,135,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4860,135,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4861,135,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4862,135,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4863,135,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4864,135,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4865,135,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4866,135,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4867,135,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4868,135,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4869,135,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4870,135,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4871,135,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4872,135,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 565px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4873,135,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4874,135,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4875,135,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4876,135,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 10px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4877,135,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4878,135,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4879,135,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4880,135,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4882,135,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4883,135,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4885,135,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4886,135,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4887,135,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4888,135,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4889,135,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4890,135,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4891,135,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4892,135,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4893,135,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4894,135,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4895,135,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4896,135,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4898,135,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4899,135,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4900,135,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4901,135,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4902,136,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4903,136,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4904,136,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4905,136,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4906,136,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4907,136,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4908,136,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4909,136,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4910,136,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4911,136,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4912,136,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4913,136,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4914,136,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4915,136,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4916,136,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4917,136,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4918,136,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4919,136,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4920,136,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4921,136,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4922,136,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4923,136,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4924,136,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4925,136,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4926,136,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6953,179,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4928,136,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4929,136,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6851,177,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4931,136,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4932,136,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4933,136,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4934,136,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4935,136,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4936,136,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4937,136,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4938,136,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4939,136,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4940,136,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4941,136,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4942,136,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5845,156,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4944,136,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4945,136,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4946,136,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4947,136,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4948,137,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4949,137,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4950,137,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4951,137,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4952,137,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4953,137,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4954,137,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4955,137,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4956,137,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4957,137,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4958,137,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4959,137,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4960,137,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4961,137,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4962,137,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4963,137,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4964,137,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4965,137,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4966,137,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4967,137,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 851px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4968,137,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 0px 0px 3px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4969,137,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4970,137,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4971,137,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4972,137,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6951,179,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6952,179,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4974,137,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4975,137,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4977,137,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4978,137,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4979,137,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4980,137,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4981,137,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4982,137,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4983,137,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4984,137,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4985,137,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4986,137,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4987,137,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4988,137,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5844,156,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4990,137,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4991,137,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4992,137,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4993,137,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4994,138,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4995,138,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4996,138,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4997,138,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4998,138,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (4999,138,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5000,138,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5001,138,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5002,138,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5003,138,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5004,138,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5005,138,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5006,138,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5007,138,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5008,138,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5009,138,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5010,138,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5011,138,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5012,138,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5013,138,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 851px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5014,138,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5015,138,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5016,138,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5017,138,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5018,138,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6949,179,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6950,179,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5020,138,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5021,138,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6850,177,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5023,138,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5024,138,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5025,138,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5026,138,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5027,138,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5028,138,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5029,138,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5030,138,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5031,138,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5032,138,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5033,138,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5034,138,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5036,138,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5037,138,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5038,138,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5039,138,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5040,139,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5041,139,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5042,139,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5043,139,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5044,139,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5045,139,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5046,139,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5047,139,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5048,139,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5049,139,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5050,139,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5051,139,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5052,139,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5053,139,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5054,139,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5055,139,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5056,139,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5057,139,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5058,139,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5059,139,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5060,139,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5061,139,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5062,139,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5063,139,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5064,139,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6947,179,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6948,179,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5066,139,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5067,139,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5069,139,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5070,139,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5071,139,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5072,139,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5073,139,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5074,139,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5075,139,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5076,139,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5077,139,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5078,139,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5079,139,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5080,139,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5843,156,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5082,139,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5083,139,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5084,139,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5085,139,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5086,140,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5087,140,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5088,140,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5089,140,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5090,140,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5091,140,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5092,140,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5093,140,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5094,140,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5095,140,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5096,140,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5097,140,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5098,140,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5099,140,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5100,140,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5101,140,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5102,140,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5103,140,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5104,140,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5105,140,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5106,140,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5107,140,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5108,140,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 20px; padding: 0px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5109,140,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5110,140,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6946,179,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5112,140,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5113,140,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6849,177,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5115,140,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5116,140,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5117,140,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5118,140,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5119,140,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5120,140,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5121,140,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5122,140,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5123,140,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5124,140,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5125,140,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5126,140,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5842,156,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5128,140,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5129,140,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5130,140,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5131,140,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5132,141,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5133,141,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5134,141,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5135,141,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5136,141,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5137,141,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5138,141,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5139,141,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5140,141,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5141,141,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5142,141,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5143,141,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5144,141,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5145,141,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5146,141,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5147,141,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5148,141,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5149,141,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5150,141,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5151,141,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5152,141,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5153,141,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5154,141,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5155,141,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5156,141,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6945,179,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5158,141,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5159,141,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5161,141,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5162,141,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5163,141,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5164,141,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5165,141,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5166,141,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5167,141,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5168,141,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5169,141,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5170,141,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5171,141,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5172,141,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5841,156,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5174,141,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5175,141,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5176,141,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5177,141,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5178,142,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5179,142,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5180,142,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5181,142,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5182,142,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5183,142,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5184,142,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5185,142,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5186,142,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5187,142,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5188,142,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5189,142,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5190,142,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5191,142,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5192,142,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5193,142,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5194,142,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5195,142,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5196,142,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5197,142,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5198,142,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 179px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5199,142,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5200,142,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5201,142,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5202,142,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5204,142,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5205,142,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6848,177,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5207,142,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5208,142,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5209,142,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5210,142,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5211,142,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5212,142,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5213,142,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5214,142,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5215,142,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5216,142,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5217,142,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5218,142,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5840,156,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5220,142,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5221,142,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5222,142,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5223,142,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5224,143,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5225,143,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5226,143,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5227,143,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5228,143,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5229,143,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5230,143,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5231,143,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5232,143,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5233,143,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5234,143,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5235,143,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5236,143,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5237,143,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5238,143,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5239,143,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5240,143,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5241,143,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5242,143,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5243,143,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5244,143,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5245,143,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5246,143,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5247,143,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5248,143,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6944,179,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5250,143,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5251,143,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5253,143,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5254,143,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5255,143,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5256,143,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5257,143,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5258,143,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5259,143,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5260,143,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5261,143,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5262,143,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5263,143,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5264,143,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5839,156,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5266,143,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5267,143,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5268,143,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5269,143,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5270,144,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5271,144,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5272,144,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5273,144,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5274,144,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5275,144,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5276,144,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5277,144,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5278,144,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5279,144,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5280,144,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5281,144,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5282,144,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5283,144,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5284,144,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5285,144,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5286,144,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: 1258.87px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5287,144,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5288,144,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5289,144,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5290,144,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5291,144,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5292,144,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5293,144,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5294,144,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6943,179,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5296,144,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5297,144,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6847,177,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5299,144,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5300,144,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5301,144,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5302,144,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5303,144,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5304,144,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5305,144,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5306,144,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5307,144,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5308,144,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5309,144,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5310,144,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5312,144,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5313,144,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5314,144,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5315,144,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5316,145,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5317,145,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5318,145,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5319,145,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5320,145,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5321,145,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5322,145,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5323,145,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5324,145,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5325,145,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5326,145,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5327,145,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5328,145,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5329,145,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5330,145,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5331,145,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5332,145,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5333,145,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5334,145,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5335,145,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5336,145,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5337,145,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5338,145,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5339,145,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5340,145,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6942,179,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5342,145,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5343,145,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5345,145,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5346,145,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5347,145,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5348,145,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5349,145,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5350,145,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5351,145,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5352,145,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5353,145,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5354,145,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5355,145,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5356,145,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5838,156,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5358,145,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5359,145,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5360,145,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5361,145,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5362,146,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5363,146,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5364,146,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5365,146,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5366,146,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5367,146,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5368,146,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5369,146,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5370,146,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5371,146,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5372,146,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5373,146,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5374,146,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5375,146,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5376,146,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5377,146,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5378,146,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5379,146,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5380,146,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5381,146,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5382,146,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5383,146,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5384,146,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5385,146,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5386,146,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5387,146,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 270px; margin: 0px 0px 15px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5388,146,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5389,146,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5391,146,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5392,146,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5394,146,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5395,146,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5396,146,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5397,146,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5398,146,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5399,146,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5400,146,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5401,146,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5402,146,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5403,146,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5404,146,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5405,146,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5837,156,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5407,146,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5408,147,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5409,147,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5410,147,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5411,147,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5412,147,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5413,147,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5414,147,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5415,147,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5416,147,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5417,147,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5418,147,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5419,147,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5420,147,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5421,147,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_website','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5422,147,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5423,147,'cadre',1,'footer_link_pmb',0,'footer','footer_link_website','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5424,147,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5425,147,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5426,147,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5427,147,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5428,147,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5429,147,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5430,147,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5431,147,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5432,147,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5433,147,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5434,147,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5435,147,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6941,179,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5437,147,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5438,147,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6846,177,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5440,147,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5441,147,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5442,147,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5443,147,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5444,147,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5445,147,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5446,147,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5447,147,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5448,147,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5449,147,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5450,147,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5451,147,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5453,147,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5454,148,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5455,148,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5456,148,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5457,148,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5458,148,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5459,148,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5460,148,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5461,148,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5462,148,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5463,148,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5464,148,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5465,148,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5466,148,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5467,148,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5468,148,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5469,148,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5549,150,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5471,148,'cadre',1,'resume_panier',0,'main_hors_footer','','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5472,148,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5473,148,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5474,148,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5475,148,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5476,148,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5477,148,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5478,148,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5479,148,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5480,148,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5481,148,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5482,148,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6940,179,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5484,148,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5485,148,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5487,148,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5488,148,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5489,148,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5490,148,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5491,148,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5492,148,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5493,148,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5494,148,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5495,148,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5496,148,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5497,148,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5498,148,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5836,156,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5500,148,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5501,149,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5502,149,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5503,149,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5504,149,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5505,149,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5506,149,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5507,149,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5508,149,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5509,149,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5510,149,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5511,149,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5512,149,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5513,149,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5514,149,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5515,149,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5516,149,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5517,149,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5548,150,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5519,149,'cadre',0,'intro_message',0,'main_hors_footer','cms_module_breadcrumb_40','cms_module_articleslist_21','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5520,149,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5521,149,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5522,149,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5523,149,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5524,149,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5525,149,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5526,149,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5527,149,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5528,149,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5529,149,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5531,149,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5532,149,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6845,177,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5534,149,'cadre',0,'author_type',0,'main_hors_footer','id_thes','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5535,149,'cadre',0,'id_thes',0,'main_hors_footer','author_type','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5536,149,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5537,149,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5538,149,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5539,149,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5540,149,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5541,149,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5542,149,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5543,149,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5544,149,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5545,149,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5835,156,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5547,149,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5550,150,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5551,150,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5552,150,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5553,150,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5554,150,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5555,150,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5556,150,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5557,150,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5558,150,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5559,150,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5560,150,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5561,150,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5562,150,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5563,150,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5564,150,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5565,150,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5566,150,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5567,150,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5568,150,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5569,150,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5570,150,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5571,150,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5572,150,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5573,150,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5574,150,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5575,150,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5576,150,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5577,150,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5578,150,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5579,150,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5580,150,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5581,150,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5582,150,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6939,179,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5584,150,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5585,150,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5587,150,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5588,150,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5589,150,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5590,150,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5591,150,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5592,150,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5833,156,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5834,156,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5594,150,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5595,151,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5596,151,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5597,151,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5598,151,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5599,151,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5600,151,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5601,151,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5602,151,'cadre',1,'intro_bibli',0,'intro','','accueil','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5603,151,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5604,151,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5605,151,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5606,151,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5607,151,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5608,151,'cadre',1,'footer_rss',0,'footer','','navigator','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5609,151,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5610,151,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5611,151,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5612,151,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5613,151,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5614,151,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5615,151,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5616,151,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5617,151,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5618,151,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5619,151,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: -197px; top: -480px; display: block; height: auto; width: 158px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5620,151,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5621,151,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5622,151,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5623,151,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5624,151,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5625,151,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5626,151,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5627,151,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5628,151,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5629,151,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6938,179,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5631,151,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5632,151,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5634,151,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5635,151,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5636,151,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5637,151,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5638,151,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5639,151,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5641,151,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5642,152,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5643,152,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5644,152,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5645,152,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5646,152,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5647,152,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5648,152,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5649,152,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5650,152,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5651,152,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5652,152,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5653,152,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5654,152,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5655,152,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5656,152,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5657,152,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5658,152,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5659,152,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5660,152,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5661,152,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5662,152,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5663,152,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5664,152,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5665,152,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5666,152,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: -197px; top: -480px; display: block; height: auto; width: 158px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5667,152,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5668,152,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5669,152,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5670,152,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5671,152,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5672,152,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5673,152,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5674,152,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5675,152,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5676,152,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5678,152,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5679,152,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6844,177,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5681,152,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5682,152,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5683,152,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5684,152,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5685,152,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5686,152,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5832,156,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5688,152,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5689,153,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5690,153,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5691,153,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5692,153,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5693,153,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5694,153,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5695,153,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5696,153,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5697,153,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5698,153,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5699,153,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5700,153,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5701,153,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5702,153,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5703,153,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5704,153,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5705,153,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5706,153,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5707,153,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5708,153,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5709,153,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5710,153,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5711,153,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5712,153,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5713,153,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: absolute; left: -205px; top: 437px; display: block; height: 273.967px; width: 158px; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5714,153,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5715,153,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5716,153,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5717,153,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5718,153,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5719,153,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5720,153,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5721,153,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5722,153,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5723,153,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6937,179,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5725,153,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5726,153,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6843,177,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','cms_module_articleslist_46','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5728,153,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5729,153,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5730,153,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5731,153,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5732,153,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5733,153,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5735,153,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5736,154,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5737,154,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5738,154,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5739,154,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5740,154,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5741,154,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5742,154,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5743,154,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5744,154,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5745,154,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5746,154,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5747,154,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5748,154,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5749,154,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5750,154,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5751,154,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5752,154,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5753,154,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5754,154,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5755,154,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5756,154,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5757,154,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5758,154,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5759,154,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5760,154,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: absolute; left: -197px; top: 442px; display: block; height: 273.967px; width: 158px; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5761,154,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5762,154,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5763,154,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5764,154,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5765,154,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5766,154,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5767,154,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5768,154,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5769,154,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5770,154,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5772,154,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5773,154,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5775,154,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5776,154,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5777,154,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5778,154,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5779,154,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5780,154,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5831,156,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5782,154,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5783,155,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5784,155,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5785,155,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5786,155,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5787,155,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5788,155,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5789,155,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5790,155,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5791,155,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5792,155,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5793,155,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5794,155,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: relative; left: 892px; top: -22px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5795,155,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5796,155,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5797,155,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5798,155,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5799,155,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5800,155,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5801,155,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5802,155,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','resultatrech','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5803,155,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5804,155,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5805,155,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5806,155,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5807,155,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5808,155,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5809,155,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5810,155,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5811,155,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5812,155,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5813,155,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5814,155,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5815,155,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5816,155,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5817,155,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6936,179,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5819,155,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5820,155,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6841,177,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_articleslist_46','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6842,177,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','notice','cms_module_recordslist_44','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5822,155,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5823,155,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5824,155,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5825,155,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5826,155,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5827,155,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5830,156,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5829,155,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5879,157,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5880,157,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5881,157,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5882,157,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5883,157,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5884,157,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5885,157,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: relative; left: 720px; top: -1px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 222px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5886,157,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5887,157,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5888,157,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5889,157,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5890,157,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5891,157,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5892,157,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5893,157,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5894,157,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_20','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5896,157,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5897,157,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5898,157,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5899,157,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5900,157,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5901,157,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5902,157,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5903,157,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5905,157,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5906,157,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5907,157,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5908,157,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5909,157,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5910,157,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5911,157,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5912,157,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5913,157,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5914,157,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5915,157,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5916,157,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5917,157,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5918,157,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5919,157,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5920,157,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5921,157,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5922,157,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5923,157,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5924,158,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5925,158,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5926,158,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5927,158,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5928,158,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5929,158,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5930,158,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5931,158,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5932,158,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5933,158,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5934,158,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5935,158,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5936,158,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5937,158,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5938,158,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5939,158,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5940,158,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5941,158,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5942,158,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5943,158,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5944,158,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5945,158,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5946,158,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5947,158,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6935,179,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5949,158,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5950,158,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5951,158,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5952,158,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5953,158,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5954,158,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5955,158,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5956,158,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6840,177,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','notice','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5958,158,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5959,158,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5960,158,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5961,158,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5962,158,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5963,158,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5964,158,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5965,158,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5966,158,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5967,158,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5968,158,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5969,158,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5970,158,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5971,159,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5972,159,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5973,159,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5974,159,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5975,159,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5976,159,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5977,159,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5978,159,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5979,159,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5980,159,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5981,159,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5982,159,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5983,159,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5984,159,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5985,159,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5986,159,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5987,159,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5988,159,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_section_18','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5989,159,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5990,159,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5991,159,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5992,159,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5993,159,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5994,159,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5995,159,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6934,179,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5997,159,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5998,159,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (5999,159,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6000,159,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6001,159,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6002,159,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6003,159,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6839,177,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6005,159,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6006,159,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6007,159,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6008,159,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6009,159,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6010,159,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6011,159,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6012,159,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6013,159,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6014,159,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6015,159,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6016,159,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6017,159,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6018,160,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6019,160,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6020,160,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6021,160,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6022,160,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6023,160,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6024,160,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6025,160,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6026,160,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6027,160,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6028,160,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6029,160,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6030,160,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6031,160,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6032,160,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6033,160,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6034,160,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6035,160,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6036,160,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6037,160,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6038,160,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6039,160,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6040,160,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6041,160,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 596px; top: 69px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6042,160,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6933,179,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6044,160,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6045,160,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6046,160,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6047,160,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6048,160,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6049,160,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6050,160,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6052,160,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6053,160,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6054,160,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6055,160,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6056,160,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6057,160,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6058,160,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6059,160,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6060,160,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6061,160,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6062,160,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6063,160,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6064,160,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6065,161,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6066,161,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6067,161,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6068,161,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6069,161,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6070,161,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6071,161,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6072,161,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6073,161,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6074,161,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6075,161,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6076,161,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6077,161,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6078,161,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6079,161,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6080,161,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6081,161,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6082,161,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6083,161,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6084,161,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6085,161,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6086,161,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_articleslist_36','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px 40px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6087,161,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_38','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6088,161,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 593px; top: 79px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6089,161,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6932,179,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6091,161,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6092,161,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6093,161,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6094,161,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6095,161,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6096,161,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6097,161,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6838,177,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6099,161,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6100,161,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6101,161,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6102,161,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6103,161,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6104,161,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6105,161,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6106,161,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6107,161,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6108,161,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6109,161,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6110,161,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6111,161,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6112,162,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6113,162,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6114,162,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6115,162,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6116,162,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6117,162,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6118,162,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6119,162,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6120,162,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6121,162,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6122,162,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6123,162,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6124,162,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6125,162,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6126,162,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6127,162,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6128,162,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6129,162,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6130,162,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6131,162,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6132,162,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6133,162,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 275.85px; width: 268px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6134,162,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6135,162,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 593px; top: 79px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6136,162,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6931,179,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6138,162,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6139,162,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6140,162,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6141,162,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6142,162,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6143,162,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6144,162,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6837,177,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6146,162,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6147,162,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6148,162,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6149,162,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6150,162,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6151,162,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6152,162,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6153,162,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6154,162,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6155,162,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6156,162,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6157,162,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6158,162,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6159,163,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6160,163,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6161,163,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6162,163,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6163,163,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6164,163,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6165,163,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6166,163,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6167,163,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6168,163,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6169,163,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6170,163,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6171,163,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6172,163,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6173,163,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6174,163,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6175,163,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6176,163,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6177,163,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6178,163,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6179,163,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: 284.933px; width: 270px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6180,163,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 275.85px; width: 263px; margin: 0px 0px 15px 25px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6181,163,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6182,163,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 593px; top: 79px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6183,163,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6930,179,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6185,163,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6186,163,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6187,163,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6188,163,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6189,163,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6190,163,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6191,163,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6836,177,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6193,163,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6194,163,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6195,163,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6196,163,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6197,163,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6198,163,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6199,163,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6200,163,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6201,163,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6202,163,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6203,163,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6204,163,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6205,163,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6206,164,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6207,164,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6208,164,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6209,164,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6210,164,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6211,164,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6212,164,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6213,164,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6214,164,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6215,164,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6216,164,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6217,164,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6218,164,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6219,164,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6220,164,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6221,164,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6222,164,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6223,164,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6224,164,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6225,164,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6226,164,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6227,164,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6228,164,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6229,164,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 593px; top: 79px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6230,164,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6928,179,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6929,179,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6232,164,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6233,164,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6234,164,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6235,164,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6236,164,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6237,164,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6238,164,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6835,177,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6240,164,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6241,164,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6242,164,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6243,164,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6244,164,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6245,164,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6246,164,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6247,164,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6248,164,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6249,164,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6250,164,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6251,164,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6252,164,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6253,165,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6254,165,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6255,165,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6256,165,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6257,165,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6258,165,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6259,165,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6260,165,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6261,165,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6262,165,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6263,165,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6264,165,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6265,165,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6266,165,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6267,165,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6268,165,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6269,165,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6270,165,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6271,165,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6272,165,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6273,165,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6274,165,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6275,165,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6276,165,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 586px; top: 76px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6277,165,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6927,179,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6279,165,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6280,165,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6281,165,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6282,165,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6283,165,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6284,165,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6285,165,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6834,177,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6287,165,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6288,165,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6289,165,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6290,165,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6291,165,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6292,165,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6293,165,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6294,165,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6295,165,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6296,165,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6297,165,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6298,165,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6299,165,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6300,166,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6301,166,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6302,166,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6303,166,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6304,166,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6305,166,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6306,166,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6307,166,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6308,166,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6309,166,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6310,166,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6311,166,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6312,166,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6313,166,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6314,166,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6315,166,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6316,166,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6317,166,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6318,166,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6319,166,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6320,166,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6321,166,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6322,166,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6323,166,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6324,166,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6926,179,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 32px; display: block; height: 25.35px; width: 133px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6326,166,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6327,166,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6328,166,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6329,166,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6330,166,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6331,166,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6332,166,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6833,177,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6334,166,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6335,166,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6336,166,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6337,166,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6338,166,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 180px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6339,166,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6340,166,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6341,166,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6342,166,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6343,166,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6344,166,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6345,166,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6346,166,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6347,167,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6348,167,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6349,167,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6350,167,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6351,167,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6352,167,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6353,167,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6354,167,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6355,167,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6356,167,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6357,167,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6358,167,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6359,167,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6360,167,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6361,167,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6362,167,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6363,167,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6364,167,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6365,167,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 577px; top: 46px; height: 377px; width: 169px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6366,167,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6367,167,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6368,167,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6369,167,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6370,167,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6371,167,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6372,167,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6373,167,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6374,167,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6376,167,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6377,167,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6378,167,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6379,167,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6380,167,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6381,167,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6382,167,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6384,167,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6385,167,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6386,167,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6387,167,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6388,167,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6389,167,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6390,167,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6391,167,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6392,167,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6393,167,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6394,168,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6395,168,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6396,168,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6397,168,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6398,168,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6399,168,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6400,168,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6401,168,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6402,168,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6403,168,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6404,168,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6405,168,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6406,168,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6407,168,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6408,168,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6409,168,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6410,168,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6411,168,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6412,168,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 587px; top: 60px; height: 377px; width: 159px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6413,168,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6414,168,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6415,168,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6416,168,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6417,168,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6418,168,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6419,168,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6420,168,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6421,168,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6925,179,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6423,168,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6424,168,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6425,168,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6426,168,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6427,168,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6428,168,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6429,168,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6832,177,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6431,168,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6432,168,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6433,168,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6434,168,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6435,168,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6436,168,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6437,168,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6438,168,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6439,168,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6440,168,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6441,169,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6442,169,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6443,169,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6444,169,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6445,169,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6446,169,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6447,169,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6448,169,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6449,169,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6450,169,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6451,169,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6452,169,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6453,169,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6454,169,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6455,169,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6456,169,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6457,169,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6458,169,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6459,169,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 587px; top: 60px; height: 377px; width: 159px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6460,169,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6461,169,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6462,169,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6463,169,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6464,169,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6465,169,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6466,169,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6467,169,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6468,169,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6924,179,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6470,169,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6471,169,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6472,169,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6473,169,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6474,169,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6475,169,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6476,169,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6478,169,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6479,169,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6480,169,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6481,169,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6482,169,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6483,169,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6484,169,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6485,169,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6486,169,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6487,169,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6488,170,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6489,170,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6490,170,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6491,170,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6492,170,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6493,170,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6494,170,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6495,170,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6496,170,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6497,170,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6498,170,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6499,170,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6500,170,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6501,170,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6502,170,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6503,170,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6504,170,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6505,170,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6506,170,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 159px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6507,170,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6508,170,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6509,170,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6510,170,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6511,170,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6512,170,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6513,170,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6514,170,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6515,170,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6923,179,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6517,170,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6518,170,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6519,170,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6520,170,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6521,170,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6522,170,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6523,170,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6831,177,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6525,170,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6526,170,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6527,170,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6528,170,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6529,170,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6530,170,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6531,170,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6532,170,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6533,170,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6534,170,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6535,171,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6536,171,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6537,171,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6538,171,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6539,171,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6540,171,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6541,171,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6542,171,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6543,171,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6544,171,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6545,171,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6546,171,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6547,171,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6548,171,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6549,171,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6550,171,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6551,171,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6552,171,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6553,171,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6554,171,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: relative; left: 0px; top: 0px; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6555,171,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6556,171,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6557,171,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6558,171,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6559,171,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6560,171,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6561,171,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6562,171,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6921,179,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6922,179,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6564,171,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6565,171,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6566,171,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6567,171,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6568,171,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6569,171,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6570,171,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6830,177,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6572,171,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6573,171,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6574,171,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6575,171,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6576,171,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6577,171,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6578,171,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6579,171,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6580,171,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6581,171,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6582,172,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6583,172,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6584,172,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6585,172,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6586,172,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6587,172,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6588,172,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6589,172,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6590,172,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6591,172,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6592,172,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6593,172,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6594,172,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6595,172,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6596,172,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6597,172,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6598,172,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6599,172,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6600,172,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6601,172,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_htmlcode_43','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6630,173,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6603,172,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_htmlcode_43','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6604,172,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6605,172,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6606,172,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6607,172,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6608,172,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6609,172,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6610,172,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6920,179,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6612,172,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6613,172,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6614,172,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6615,172,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6616,172,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6617,172,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6618,172,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6620,172,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6621,172,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6622,172,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6623,172,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6624,172,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6625,172,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6626,172,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6627,172,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6628,172,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6629,172,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6631,173,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6632,173,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6633,173,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6634,173,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6635,173,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6636,173,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6637,173,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6638,173,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6639,173,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6640,173,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6641,173,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6642,173,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6643,173,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6644,173,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6645,173,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6646,173,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6647,173,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_recordslist_17','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6648,173,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6649,173,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6650,173,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6651,173,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6652,173,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6653,173,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6654,173,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6655,173,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6656,173,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6657,173,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6919,179,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6659,173,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6660,173,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6661,173,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6662,173,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6663,173,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6664,173,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6665,173,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6829,177,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6667,173,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6668,173,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6669,173,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6670,173,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6671,173,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6672,173,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6673,173,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6674,173,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6675,173,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6676,173,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6677,174,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6678,174,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6679,174,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6680,174,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6681,174,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6682,174,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6683,174,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6684,174,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6685,174,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6686,174,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6687,174,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6688,174,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6689,174,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6690,174,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6691,174,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6692,174,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6693,174,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6694,174,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','notice','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6695,174,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_24','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6827,177,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6828,177,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6697,174,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','cms_module_recordslist_24','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6698,174,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6699,174,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6700,174,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6701,174,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6702,174,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6703,174,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6704,174,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6705,174,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6706,174,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6707,174,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6918,179,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6709,174,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6710,174,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6711,174,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6712,174,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6713,174,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6714,174,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6715,174,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6716,174,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6717,174,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6718,174,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6719,174,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6720,174,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6721,174,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6722,174,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6723,174,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6724,174,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6725,175,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6726,175,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6727,175,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6728,175,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6729,175,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6730,175,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6731,175,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6732,175,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6733,175,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6734,175,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6735,175,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6736,175,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6737,175,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6738,175,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6739,175,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6740,175,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6741,175,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6742,175,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','notice','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6743,175,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6744,175,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_recordslist_45','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6825,177,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6826,177,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6747,175,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6748,175,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6749,175,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6750,175,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6751,175,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6752,175,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6753,175,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6754,175,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6755,175,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6756,175,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6917,179,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6758,175,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6759,175,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6760,175,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6761,175,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6762,175,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6763,175,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6764,175,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6765,175,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6766,175,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6767,175,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6768,175,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6769,175,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6770,175,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6771,175,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6772,175,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6773,175,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6774,176,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6775,176,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6776,176,'cadre',1,'adresse',0,'bandeau','connexion','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6777,176,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6778,176,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6779,176,'cadre',1,'intro_bibli',0,'intro','','accueil','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6780,176,'cadre',1,'accueil',0,'intro','intro_bibli','','position: relative; left: 867px; top: -12px; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6781,176,'cadre',0,'cms_module_menu_13',0,'intro','accueil','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 64px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6782,176,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 65px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6783,176,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 30px; display: block; height: 25.35px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6784,176,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6785,176,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6786,176,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6787,176,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6788,176,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6789,176,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6790,176,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6791,176,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_articleslist_21','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6792,176,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6793,176,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6794,176,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6795,176,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6796,176,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6797,176,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6798,176,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6799,176,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_recordslist_45','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6823,177,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6824,177,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6802,176,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6803,176,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6804,176,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6805,176,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6807,176,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6808,176,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6809,176,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6810,176,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6811,176,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6812,176,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6813,176,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6814,176,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6815,176,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6816,176,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6817,176,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6818,176,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6819,176,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6820,176,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6821,176,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (6822,176,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7035,181,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7036,181,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7037,181,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7038,181,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7039,181,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7040,181,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7041,181,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7042,181,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7043,181,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7044,181,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7045,181,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7046,181,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7047,181,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7048,181,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7049,181,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7050,181,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7051,181,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7052,181,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7053,181,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7054,181,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7055,181,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7056,181,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7057,181,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7058,182,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7059,182,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7060,182,'cadre',1,'adresse',0,'bandeau','connexion','accueil','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7061,182,'cadre',1,'accueil',0,'bandeau','adresse','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7062,182,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7063,182,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7064,182,'cadre',1,'intro_bibli',0,'intro','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7065,182,'cadre',0,'cms_module_menu_13',0,'intro','intro_bibli','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 86px; display: block; height: 24.45px; width: auto; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7066,182,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 57px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7067,182,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 24px; display: block; height: 25.35px; width: 133px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7068,182,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7069,182,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7070,182,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7071,182,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7072,182,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7073,182,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7074,182,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7075,182,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_section_18','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7076,182,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7077,182,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7078,182,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7079,182,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7080,182,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7081,182,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7082,182,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7083,182,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7084,182,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7085,182,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7086,182,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7087,182,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7088,182,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7089,182,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7090,182,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7091,182,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7092,182,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7093,182,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7094,182,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7095,182,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7096,182,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7097,182,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7098,182,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7099,182,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7100,182,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7101,182,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7102,182,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7103,182,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7104,182,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7105,183,'zone',1,'bandeau',0,'container','intro','bandeau_2','visibility: visible; display: block; left: -10px; top: 240px; height: auto; width: 145px; margin: 0px; padding: 20px; float: none; position: absolute;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7106,183,'cadre',1,'connexion',0,'bandeau','','adresse','position: static; left: 0px; top: 0px; visibility: visible; display: block; height: 121.133px; width: auto; margin: 0px 0px 15px; padding: 0px 0px 10px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7107,183,'cadre',1,'adresse',0,'bandeau','connexion','accueil','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7108,183,'cadre',1,'accueil',0,'bandeau','adresse','','position: static; left: 0pt; top: 0pt; visibility: visible; display: block; height: 26px; width: 100px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7109,183,'zone',1,'bandeau_2',0,'container','bandeau','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7110,183,'zone',1,'intro',0,'container','main','bandeau','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7111,183,'cadre',1,'intro_bibli',0,'intro','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7112,183,'cadre',0,'cms_module_menu_13',0,'intro','intro_bibli','cms_module_search_22','visibility: visible; position: relative; left: 243px; top: 90px; display: block; height: 24.45px; width: 463px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7113,183,'cadre',0,'cms_module_search_22',0,'intro','cms_module_menu_13','cms_module_menu_30','visibility: visible; position: absolute; left: 719px; top: 57px; display: block; height: 51px; margin: 0px; padding: 0px; float: none; width: 250px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7114,183,'cadre',0,'cms_module_menu_30',0,'intro','cms_module_search_22','','visibility: visible; position: absolute; left: 778px; top: 24px; display: block; height: 25.35px; width: 133px; margin: 0px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7115,183,'zone',1,'footer',0,'main','','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7116,183,'cadre',1,'footer_rss',0,'footer','','navigator','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7117,183,'cadre',1,'navigator',0,'footer','footer_rss','footer_link_sup','position: static; left: 0pt; top: 0pt; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7118,183,'cadre',1,'footer_link_sup',0,'footer','navigator','footer_link_pmb','position: relative; left: 0px; top: -1px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7119,183,'cadre',1,'footer_link_pmb',0,'footer','footer_link_sup','','visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7120,183,'zone',1,'main_hors_footer',0,'main','','','visibility: visible; display: block; left: -40px; top: 2px; width: 570px; margin: 0px; padding: 0px 0px 5px; float: none; position: relative; height: auto;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7121,183,'cadre',1,'resume_panier',0,'main_hors_footer','','','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7122,183,'cadre',0,'intro_message',0,'main_hors_footer','resume_panier','cms_module_section_18','position: relative; left: 0px; top: 0px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7123,183,'cadre',0,'cms_module_section_18',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7124,183,'cadre',0,'cms_module_recordslist_23',0,'main_hors_footer','cms_module_htmlcode_39','','visibility: visible; position: absolute; left: 595px; top: 77px; display: block; height: 520px; width: 150px; margin: 0px 0px 25px; padding: 0px; float: none;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7125,183,'cadre',0,'cms_module_htmlcode_39',0,'main_hors_footer','cms_module_articleslist_36','cms_module_recordslist_23','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7126,183,'cadre',0,'cms_module_articleslist_36',0,'main_hors_footer','cms_module_articleslist_38','cms_module_htmlcode_39','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: auto; width: 290px; margin: 0px 0px 15px 20px; padding: 0px; float: left;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7127,183,'cadre',0,'cms_module_articleslist_38',0,'main_hors_footer','cms_module_agenda_27','cms_module_articleslist_36','visibility: visible; position: static; left: 0px; top: 0px; height: auto; width: 250px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7128,183,'cadre',0,'cms_module_agenda_27',0,'main_hors_footer','cms_module_articleslist_21','cms_module_articleslist_38','visibility: visible; position: static; left: 0px; top: 0px; height: 213.7px; width: 179px; margin: 5px 0px 15px 15px; padding: 5px 0px; float: left; display: block; z-index: 9;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7129,183,'cadre',0,'cms_module_articleslist_21',0,'main_hors_footer','intro_message','cms_module_agenda_27','visibility: visible; position: static; left: 0px; top: 0px; display: block; height: 221px; width: 370px; margin: 0px 0px 15px; padding: 0px 0px 5px; float: left; z-index: 9;',1);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7130,183,'cadre',0,'cms_module_recordslist_17',0,'main_hors_footer','intro_message','cms_module_article_14','visibility: visible; position: absolute; left: 590px; top: 63px; height: 377px; width: 155px; margin: 0px 0px 20px; padding: 0px 0px 10px; float: none; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7131,183,'cadre',0,'cms_module_article_14',0,'main_hors_footer','cms_module_recordslist_17','cms_module_recordslist_15','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7132,183,'cadre',0,'cms_module_recordslist_15',0,'main_hors_footer','cms_module_article_14','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7133,183,'cadre',0,'cms_module_record_35',0,'main_hors_footer','cms_module_recordslist_20','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7134,183,'cadre',0,'post_adress',0,'bandeau','connexion','','position: relative; left: 3px; top: -293px;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7135,183,'cadre',0,'cms_module_agenda_33',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7136,183,'cadre',0,'location',0,'main_hors_footer','search','last_entries','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7137,183,'cadre',0,'search',0,'main_hors_footer','resume_panier','location','position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7138,183,'cadre',0,'etageres',0,'main_hors_footer','last_entries','intro_message','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7139,183,'cadre',0,'last_entries',0,'main_hors_footer','location','etageres','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7140,183,'cadre',1,'footer_link_website',0,'footer','footer_link_sup','footer_link_pmb','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7141,183,'cadre',0,'cms_module_articleslist_41',0,'main_hors_footer','id_thes','','visibility: visible; position: relative; left: 0px; top: 0px; display: block; height: auto; width: auto; margin: 0px 0px 25px; padding: 0px; float: none; z-index: 189;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7142,183,'cadre',0,'author_type',0,'main_hors_footer','navbar','id_thes','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7143,183,'cadre',0,'id_thes',0,'main_hors_footer','author_type','cms_module_articleslist_41','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7144,183,'cadre',0,'navbar',0,'main_hors_footer','resultatrech','author_type','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7145,183,'cadre',0,'resultatrech',0,'main_hors_footer','intro_message','navbar','visibility: visible; display: block; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7146,183,'cadre',1,'lvl1',0,'bandeau_2','','facette','position: relative; left: -14px; top: -90px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7147,183,'cadre',1,'facette',0,'bandeau_2','lvl1','','position: relative; left: -15px; top: -73px; visibility: visible; display: block;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7148,183,'cadre',0,'cms_module_articleslist_42',0,'main_hors_footer','intro_message','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7149,183,'cadre',0,'notice',0,'main_hors_footer','intro_message','cms_module_recordslist_44','',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7150,183,'cadre',0,'cms_module_articleslist_46',0,'main_hors_footer','cms_module_recordslist_44','','visibility: visible; position: static; left: 0pt; top: 0pt;',0);
INSERT INTO cms_build (id_build, build_version_num, build_type, build_fixed, build_obj, build_page, build_parent, build_child_before, build_child_after, build_css, build_div) VALUES (7151,183,'cadre',0,'cms_module_recordslist_44',0,'main_hors_footer','notice','cms_module_articleslist_46','visibility: visible; position: static; left: 0pt; top: 0pt; display: block;',0);
/*!40000 ALTER TABLE cms_build ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_cache_cadres`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_cache_cadres (
  cache_cadre_hash varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  cache_cadre_type_content varchar(30) COLLATE utf8_unicode_ci NOT NULL,
  cache_cadre_create_date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  cache_cadre_content mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (cache_cadre_hash,cache_cadre_type_content)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_cache_cadres`
--

LOCK TABLES cms_cache_cadres WRITE;
/*!40000 ALTER TABLE cms_cache_cadres DISABLE KEYS */;
/*!40000 ALTER TABLE cms_cache_cadres ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_cadre_content`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_cadre_content (
  id_cadre_content int(10) unsigned NOT NULL AUTO_INCREMENT,
  cadre_content_hash varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_content_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_content_object varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_content_num_cadre int(10) unsigned NOT NULL DEFAULT '0',
  cadre_content_data mediumtext COLLATE utf8_unicode_ci NOT NULL,
  cadre_content_num_cadre_content int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_cadre_content)
) ENGINE=MyISAM AUTO_INCREMENT=233 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_cadre_content`
--

LOCK TABLES cms_cadre_content WRITE;
/*!40000 ALTER TABLE cms_cadre_content DISABLE KEYS */;
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (68,'eb8fa65d385e7e8a71af6918e08f3482','view','cms_module_common_view_article',14,'a:1:{s:15:\"active_template\";s:779:\"<h3>\n\n{% if fields_type.date_debut.values.0.value %}\n {% if fields_type.date_fin.values.0.value %}\nDu {{fields_type.date_debut.values.0.format_value}} au {{fields_type.date_fin.values.0.format_value}} : \n {% else %}\nLe {{fields_type.date_debut.values.0.format_value}} : \n {% endif %}\n{% endif%}\n{% if fields_type.date.values.0.value %}\nLe {{fields_type.date.values.0.format_value}} : \n{% endif%}\n\n{{title}}</h3>\n\n<img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{logo.large}}\' />\n\n<p>{{resume}}</p>\n<br />\n\n<div class=\"row\">{{content}}</div>\n<br />\n{% if fields_type.identifiant_notice.values.0.value %}\n<a href=\"./index.php?lvl=notice_display&id={{fields_type.identifiant_notice.values.0.value}}\">Voir le document dans le catalogue</a>\n{% endif%}\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (69,'8f23ba3c79256182374bda573dbd6807','condition','cms_module_common_condition_page',14,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (70,'b4b9afc29a065349e7a75c9fc12f6524','selector','cms_module_common_selector_page',14,'s:1:\"4\";',69);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (76,'ccd5992f263c59d2617ef4eb9a5ca137','condition','cms_module_common_condition_page',15,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (77,'08753b34a2a4514944540b184da985d6','selector','cms_module_common_selector_page',15,'s:1:\"4\";',76);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (89,'fa541470ab2098ebea1cc016d5265400','selector','cms_module_common_selector_env_var',18,'s:11:\"id_rubrique\";',88);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (73,'172f25f323c7f76ab42d3e37e3dbfe87','selector','cms_module_common_selector_env_var',15,'s:10:\"id_article\";',72);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (74,'d55e64e43809f69abd3b3f585b7615b3','selector','cms_module_common_selector_section',15,'s:2:\"N;\";',72);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (71,'095de25a55c28918025cfa202011602e','datasource','cms_module_common_datasource_records',15,'a:1:{s:8:\"selector\";s:39:\"cms_module_common_selector_type_article\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (72,'9926c0f7333894580f1869c4394c29c0','selector','cms_module_common_selector_type_article',15,'a:3:{s:14:\"type_editorial\";s:1:\"2\";s:20:\"type_editorial_field\";s:1:\"1\";s:12:\"sub_selector\";s:34:\"cms_module_common_selector_env_var\";}',71);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (66,'e5fd56514b64fa540308cf90d03cfa2b','datasource','cms_module_common_datasource_article',14,'a:1:{s:8:\"selector\";s:34:\"cms_module_common_selector_env_var\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (67,'af30b6cbad2349fafc3308669b98375f','selector','cms_module_common_selector_env_var',14,'s:10:\"id_article\";',66);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (181,'84d67e2fba6c618f0d1dd007d1fcb217','selector','cms_module_common_selector_page',36,'s:1:\"3\";',180);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (170,'a0fc849a763200c7bde64ee165e07679','datasource','cms_module_common_datasource_articles_sections',21,'a:4:{s:7:\"sort_by\";s:16:\"publication_date\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"4\";s:8:\"selector\";s:35:\"cms_module_common_selector_sections\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (91,'2e9d1730296875f15cb2f2252df543d1','condition','cms_module_common_condition_page',18,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (92,'b37ee50fa4c003f9152eff86c35ee511','selector','cms_module_common_selector_page',18,'s:1:\"6\";',91);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (196,'652f38cfd5a862ae41608fdf319497a3','view','cms_module_common_view_recordslist',15,'a:2:{s:13:\"used_template\";s:1:\"1\";s:15:\"active_template\";s:159:\"{% if records %}\n<h3>Toutes les nouveautés</h3>\n{% endif %}\n\n{% for record in records %}\n<blockquote>{{record.content}}</blockquote>\n<br />\n<hr>\n{% endfor %}\n\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (180,'f5a06f83ebb48f402146ee2823ff8faf','condition','cms_module_common_condition_page',36,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (90,'ff5de9ae00cc708192f2f425ecd0d571','view','cms_module_common_view_section',18,'a:2:{s:5:\"links\";a:2:{s:7:\"section\";a:2:{s:4:\"page\";s:1:\"6\";s:3:\"var\";s:11:\"id_rubrique\";}s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:737:\"<h2>{{title}}</h2>\n<img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{logo.large}}\' />\n<p>{{resume}}</p>\n<div class=\"row\">{{content}}</div>\n  <ul>\n   {% for child in children %}\n    <li><a href=\'{{child.link}}\'>{{child.title}}</a></li>\n   {% endfor %}\n  </ul>\n\n   {% for article in articles %}\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\n<h3>{{article.title}}</h3>\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\n<p>{{article.resume}}</p>\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\n</div>\n   {% endfor %}\n<div class=\"row\"></div>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (83,'f882f4dc895a25c8aacfa887bae0ed9a','datasource','cms_module_common_datasource_records_categories',17,'a:1:{s:8:\"selector\";s:34:\"cms_module_common_selector_env_var\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (84,'c8f17015f7de51eb4f537238d18d13db','selector','cms_module_common_selector_env_var',17,'s:10:\"id_article\";',83);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (85,'21eaf5bfc1f07a9278d240b38ea59da2','view','cms_module_recordslist_view_carousel',17,'a:9:{s:5:\"links\";a:1:{s:6:\"notice\";a:2:{s:4:\"page\";s:1:\"7\";s:3:\"var\";s:9:\"id_notice\";}}s:4:\"mode\";s:8:\"vertical\";s:5:\"speed\";s:4:\"3000\";s:5:\"pause\";s:4:\"4000\";s:16:\"display_quantity\";s:1:\"2\";s:14:\"slide_quantity\";s:1:\"2\";s:9:\"autostart\";s:1:\"1\";s:3:\"css\";s:0:\"\";s:15:\"active_template\";s:372:\"{% if records %}\n<h3>Sur le même sujet</h3>\n{% endif %}\n\n<ul id=\'carousel_{{id}}\'>\n	{% for record in records %}\n		<li class=\'{{id}}_item\'>\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\n{{record.title}}\n<br />\n			</a>\n		</li>\n	{% endfor %}\n</ul>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (86,'f78306d275f0a418034e10b82fdcb1a0','condition','cms_module_common_condition_page',17,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (87,'e6b065a39f8303700d1ffc17aba542bc','selector','cms_module_common_selector_page',17,'s:1:\"4\";',86);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (88,'ec1cd870bc94e0eed225e5458dc433e1','datasource','cms_module_common_datasource_section',18,'a:1:{s:8:\"selector\";s:34:\"cms_module_common_selector_env_var\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (63,'0198c2305fd81df7f73fa764dce69f3b','datasource','cms_module_menu_datasource_menu_editorial',13,'a:3:{s:9:\"max_depth\";s:1:\"3\";s:5:\"links\";a:1:{s:7:\"section\";a:2:{s:4:\"page\";s:1:\"6\";s:3:\"var\";s:11:\"id_rubrique\";}}s:8:\"selector\";s:32:\"cms_module_menu_selector_section\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (64,'8567942d26a71c077a95ef9815a9aea2','selector','cms_module_menu_selector_section',13,'s:2:\"12\";',63);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (65,'15cf9d2706b2a6ab85cd66b6a59262c7','view','cms_module_menu_view_menu',13,'s:2:\"N;\";',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (104,'099b9830dd875e33096827f92aea7948','selector','cms_module_common_selector_articles',21,'a:4:{i:0;s:1:\"1\";i:1;s:1:\"2\";i:2;s:2:\"11\";i:3;s:1:\"7\";}',103);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (105,'97514ee2810b079e029046d25566b68b','view','cms_module_articleslist_view_carousel',21,'a:10:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:4:\"mode\";s:4:\"fade\";s:5:\"speed\";s:4:\"2000\";s:5:\"pause\";s:4:\"5500\";s:16:\"display_quantity\";s:1:\"1\";s:14:\"slide_quantity\";s:1:\"1\";s:9:\"autostart\";s:1:\"1\";s:3:\"css\";s:0:\"\";s:15:\"active_template\";s:452:\"<h2>Actualités</h2>\n<ul id=\'carousel_{{id}}\'>\n	{% for record in records %}\n		<li class=\'{{id}}_item\' style=\"height:200px\">\n<h3>{{record.title}}</h3>\n<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\"{{record.title}}\"><img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{record.logo.large}}\' /></a>\n{{record.resume}}\n<a style=\"text-align:right;\" href=\"{{record.link}}\">Lire la suite...</a>\n		</li>\n	{% endfor %}\n</ul>\";s:13:\"used_template\";s:1:\"0\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (106,'af40c975df5a2cb10f8fc23498b56508','condition','cms_module_common_condition_page',21,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (107,'923de26c5a78802d3e88896b116633e4','selector','cms_module_common_selector_page',21,'s:1:\"3\";',106);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (108,'b3d745bf27775fdc704f8dcf93607657','datasource','cms_module_search_datasource_search',22,'a:1:{s:8:\"selector\";s:31:\"cms_module_search_selector_dest\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (109,'0c3fe17577b89816d2793ad094b16b53','selector','cms_module_search_selector_dest',22,'a:2:{i:0;s:12:\"search_dest1\";i:1;s:12:\"search_dest2\";}',108);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (110,'24a5df2c9aa0ac9c71d21ef02cd956e7','view','cms_module_search_view_search',22,'s:2:\"N;\";',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (145,'c3d735c65c2c97ec98532c57ae4c267e','condition','cms_module_common_condition_page',27,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (146,'42f1a04589069c3e114ed1ecf351c313','selector','cms_module_common_selector_page',27,'s:1:\"3\";',145);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (113,'54b38f89e545cde31b8319fcd3a75e62','datasource','cms_module_common_datasource_records',23,'a:1:{s:8:\"selector\";s:33:\"cms_module_common_selector_shelve\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (114,'adfda9b0ab2ea0faf8041f05b29d715f','selector','cms_module_common_selector_shelve',23,'s:1:\"3\";',113);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (115,'a3a69397d2b421f0cdb15841442aa3c2','view','cms_module_recordslist_view_carousel',23,'a:10:{s:5:\"links\";a:1:{s:6:\"notice\";a:2:{s:4:\"page\";s:1:\"7\";s:3:\"var\";s:9:\"id_notice\";}}s:4:\"mode\";s:8:\"vertical\";s:5:\"speed\";s:4:\"3000\";s:5:\"pause\";s:4:\"3000\";s:16:\"display_quantity\";s:1:\"3\";s:14:\"slide_quantity\";s:1:\"1\";s:9:\"autostart\";s:1:\"1\";s:3:\"css\";s:0:\"\";s:15:\"active_template\";s:341:\"<ul id=\'carousel_{{id}}\'>\n	{% for record in records %}\n		<li class=\'{{id}}_item\'>\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\' style=\"text-align:center;\">\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\n{{record.title}}\n<br />\n			</a>\n		</li>\n	{% endfor %}\n</ul>\";s:13:\"used_template\";s:1:\"0\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (116,'be40f23e110a323fcfaad6e5537c602c','condition','cms_module_common_condition_page',23,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (117,'ce55f68e9edb0ca17fcb047533f4edd0','selector','cms_module_common_selector_page',23,'s:1:\"3\";',116);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (208,'74bbfd97875718b19730630cf96a4923','condition','cms_module_common_condition_page',42,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (139,'ab158999a4b5329570412e72b9c79491','datasource','cms_module_menu_datasource_menu',30,'a:1:{s:8:\"selector\";s:29:\"cms_module_menu_selector_menu\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (140,'a1d614b3448eff7c54774fc442efbf5e','selector','cms_module_menu_selector_menu',30,'s:5:\"menu1\";',139);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (132,'9d73449a0c4f0dd8e2adefe3af501a1e','datasource','cms_module_agenda_datasource_agenda',27,'a:1:{s:8:\"selector\";s:36:\"cms_module_agenda_selector_calendars\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (133,'2267ae958c1614473ba056a4c2583a3a','selector','cms_module_agenda_selector_calendars',27,'a:2:{i:0;s:9:\"calendar1\";i:1;s:9:\"calendar2\";}',132);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (134,'a23554e6187d48f09d1a6500d380c28a','view','cms_module_agenda_view_calendar',27,'a:2:{s:5:\"links\";a:2:{s:5:\"event\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}s:10:\"eventslist\";a:2:{s:4:\"page\";s:1:\"9\";s:3:\"var\";s:7:\"id_date\";}}s:25:\"nb_displayed_events_under\";s:1:\"0\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (141,'2e13d1ea88e3de6edd3552e256d39253','view','cms_module_menu_view_menu',30,'s:2:\"N;\";',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (206,'5391ce82b479912a582eee9e8b08406c','selector','cms_module_common_selector_search_result',42,'s:2:\"N;\";',205);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (207,'7b19d51557c55a5322aaac0e5ab11eb1','view','cms_module_common_view_articleslist',42,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:643:\"<h3>Résultat de la recherche</h3>\n{% if articles %}\n   {% for article in articles %}\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\n<h3>{{article.title}}</h3>\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\n<p>{{article.resume}}</p>\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\n</div>\n   {% endfor %}\n<div class=\"row\"></div>\n{% else %}\n<br />\nPas de résultats\n<br />\n<a href=\"./index.php?search_type_asked=simple_search\">>> Rechercher dans le catalogue</a>\n{% endif %}\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (205,'807e7feb6d0079f75793e213ba096fc8','datasource','cms_module_common_datasource_searcharticles',42,'a:4:{s:7:\"sort_by\";s:4:\"pert\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"0\";s:8:\"selector\";s:40:\"cms_module_common_selector_search_result\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (152,'a085319aad988a30e4a12b6aa2704bc7','datasource','cms_module_agenda_datasource_agenda',33,'a:1:{s:8:\"selector\";s:41:\"cms_module_agenda_selector_calendars_date\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (153,'0adeaeb4ad6eeea5d724c83d4968d436','selector','cms_module_common_selector_env_var',33,'s:7:\"id_date\";',152);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (154,'637c485eade18c18df1c13fec66d55b2','view','cms_module_agenda_view_eventslist',33,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:511:\"<div>\n{% for event in events %}\n<h3>\n{% if event.event_start.format_value %}\n {% if event.event_end.format_value %}\nDu {{event.event_start.format_value}} au {{event.event_end.format_value}}\n {% else %}\nLe {{event.event_start.format_value}}\n {% endif %}\n{% endif%} : {{event.title}}\n</h3>\n<blockquote>\n<a href=\'{{event.link}}\'><img style=\"float:left;margin-right:5px;\" src=\'{{event.logo.vign}}\'/></a>\n<p>{{event.resume}}</p>\n<br/>\n<div class=\"row\">{{event.content}}</div>\n</blockquote>\n<br />\n{% endfor %}\n</div>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (155,'5ac9882fdd4052d7c20e1536f0c297f1','condition','cms_module_common_condition_page',33,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (156,'0256c915941e9d0212d429d442cf00fe','selector','cms_module_common_selector_page',33,'s:1:\"9\";',155);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (157,'6c3acdc502e283375f70a86b7d1814d0','selector','cms_module_agenda_selector_calendars_date',33,'s:2:\"N;\";',152);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (158,'8297bf009179dc74f9203900368863a7','selector','cms_module_agenda_selector_calendars',33,'a:2:{i:0;s:9:\"calendar1\";i:1;s:9:\"calendar2\";}',157);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (159,'3c5ee825b2560ed6977fb5c68cfaa6b3','selector','cms_module_common_selector_env_var',33,'s:7:\"id_date\";',157);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (171,'d41bc624d0e94dc3eed31b6740a1f597','selector','cms_module_common_selector_sections',21,'a:4:{i:0;s:1:\"4\";i:1;s:1:\"5\";i:2;s:1:\"8\";i:3;s:1:\"9\";}',170);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (172,'f85636e761f4398b2447145fa602fc14','datasource','cms_module_common_datasource_record',35,'a:1:{s:8:\"selector\";s:34:\"cms_module_common_selector_env_var\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (173,'6a9bca44e27e60a564de511a8a2fce17','selector','cms_module_common_selector_env_var',35,'s:9:\"id_notice\";',172);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (174,'278ff6655d25e53fc7ca7861147db091','view','cms_module_common_view_record',35,'a:2:{s:13:\"used_template\";s:1:\"0\";s:15:\"active_template\";s:69:\"<p>{{record.header}}</p>\n<blockquote>{{record.content}}</blockquote>\n\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (175,'2ccb5bbac4b29d69e8f3f1ea27a2b604','condition','cms_module_common_condition_page',35,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (176,'9d1cda64f47a48a5dc355c9651e16b43','selector','cms_module_common_selector_page',35,'s:1:\"7\";',175);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (177,'a8cf96354034c2f98292d91b1d2051ba','datasource','cms_module_common_datasource_articles_sections',36,'a:4:{s:7:\"sort_by\";s:16:\"publication_date\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"5\";s:8:\"selector\";s:35:\"cms_module_common_selector_sections\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (178,'41766086b1ef02df8177f843888cbfc5','selector','cms_module_common_selector_sections',36,'a:1:{i:0;s:2:\"13\";}',177);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (179,'bcd06190d70c2d19fd370aa66648ef79','view','cms_module_common_view_articleslist',36,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:140:\"<h2>Brèves</h2>\n<hr>\n{% for article in articles %}\n<h4>{{article.title}}</h4>\n<blockquote>{{article.resume}}</blockquote>\n<hr>\n{% endfor %}\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (193,'22aa235dc2ef5755ae81f964920f8f06','view','cms_module_htmlcode_view_htmlcode',39,'a:1:{s:8:\"htmlcode\";s:25:\"<div class=\\\'row\\\'></div>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (194,'f28a2a974e880c7cbdec10b1b14cf27a','condition','cms_module_common_condition_page',39,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (195,'954cbade289cdd55dc6c733df9c65340','selector','cms_module_common_selector_page',39,'s:1:\"3\";',194);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (192,'69ee506f1177090083cb3b04aa33d56f','datasource','cms_module_htmlcode_datasource_htmlcode',39,'a:1:{s:8:\"selector\";s:0:\"\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (187,'d3c2f826561a3f1f0a78f83c14592dc5','datasource','cms_module_common_datasource_articles_sections',38,'a:4:{s:7:\"sort_by\";s:16:\"publication_date\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"4\";s:8:\"selector\";s:35:\"cms_module_common_selector_sections\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (188,'40e2e81a1c8b9f554360fba8e5fd4197','selector','cms_module_common_selector_sections',38,'a:1:{i:0;s:1:\"7\";}',187);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (189,'64c4c3e6b1f22471df59b06fe9613197','view','cms_module_common_view_articleslist',38,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:314:\"<h2>Nouveautés</h2>\n{% for article in articles %}\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;text-align:center;\">\n<a href=\"{{article.link}}\">\n<img style=\"width:90px;\" src=\'{{article.logo.large}}\'/>\n<h4>{{article.title}}</h4>\n</a>\n</div>\n{% endfor %}\n<div class=\"row\"></div>\n\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (190,'2b59fe226433ad484e3171dcccb3cd77','condition','cms_module_common_condition_page',38,'a:1:{s:8:\"selector\";s:31:\"cms_module_common_selector_page\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (191,'6d267e5fe8fd3b863d9ac8c8096bc16a','selector','cms_module_common_selector_page',38,'s:1:\"3\";',190);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (200,'4ac516dcd9b777f530198136ec20094a','datasource','cms_module_common_datasource_searcharticles',41,'a:4:{s:7:\"sort_by\";s:4:\"pert\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"4\";s:8:\"selector\";s:40:\"cms_module_common_selector_search_result\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (201,'5f12872704015b16aace9d315448b95f','selector','cms_module_common_selector_search_result',41,'s:2:\"N;\";',200);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (202,'a3dda7258cca5b28d5346230a5e5fed1','view','cms_module_common_view_articleslist',41,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:498:\"{% if articles %}\n<h3>Lire aussi...</h3>\n{% endif %}\n   {% for article in articles %}\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\n<h3>{{article.title}}</h3>\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\n<p>{{article.resume}}</p>\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\n</div>\n   {% endfor %}\n<div class=\"row\"></div>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (203,'66246d4ede37dd5c81a8667fab1cac17','condition','cms_module_common_condition_lvl',41,'a:1:{s:8:\"selector\";s:30:\"cms_module_common_selector_lvl\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (204,'3ba7c410e2590bcc9b60d43a341b797a','selector','cms_module_common_selector_lvl',41,'a:1:{i:0;s:12:\"more_results\";}',203);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (209,'38ae68f5687af3e9c77d53b783827933','selector','cms_module_common_selector_page',42,'s:2:\"11\";',208);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (215,'322c9411bdd1531eb8a300de5c438b90','selector','cms_module_common_selector_principal_author',44,'a:1:{s:12:\"sub_selector\";s:43:\"cms_module_common_selector_record_permalink\";}',214);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (214,'5a41eca552b5085dd6b99e8e2a7bc604','datasource','cms_module_common_datasource_records_author',44,'a:1:{s:8:\"selector\";s:43:\"cms_module_common_selector_principal_author\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (216,'b96d87cfc5b056a08db0d3f260f0c0c7','selector','cms_module_common_selector_record_permalink',44,'s:2:\"N;\";',215);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (217,'7a7d907cdf3313beff95facf1b1c6510','selector','cms_module_common_selector_record',44,'s:2:\"N;\";',215);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (218,'2d8b5265c22fe9a5197faef9153f2307','selector','cms_module_common_selector_env_var',44,'s:2:\"N;\";',215);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (219,'4c9c6e66ef380ff5e35c3745eec750a2','view','cms_module_recordslist_view_carousel',44,'a:9:{s:5:\"links\";a:1:{s:6:\"notice\";a:2:{s:4:\"page\";s:1:\"7\";s:3:\"var\";s:9:\"id_notice\";}}s:4:\"mode\";s:10:\"horizontal\";s:5:\"speed\";s:4:\"3000\";s:5:\"pause\";s:4:\"3000\";s:16:\"display_quantity\";s:1:\"6\";s:14:\"slide_quantity\";s:1:\"1\";s:9:\"autostart\";s:0:\"\";s:3:\"css\";s:0:\"\";s:15:\"active_template\";s:368:\"{% if records %}\n<h3>Du même auteur</h3>\n{% endif %}\n\n<ul id=\'carousel_{{id}}\'>\n	{% for record in records %}\n		<li class=\'{{id}}_item\'>\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\n<img style=\"max-width:120px;max-height:95px;text-align:center;\" src=\'{{record.vign}}\'/><br />\n{{record.title}}\n<br />\n			</a>\n		</li>\n	{% endfor %}\n</ul>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (220,'154a35a148bed3cbd02362f5434a91b3','condition','cms_module_common_condition_lvl',44,'a:1:{s:8:\"selector\";s:30:\"cms_module_common_selector_lvl\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (221,'fec77c2fd4a06818df24fa4c5e2631b8','selector','cms_module_common_selector_lvl',44,'a:1:{i:0;s:14:\"notice_display\";}',220);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (228,'831240608c678b496fc56ac895f0794a','condition','cms_module_common_condition_lvl',46,'a:1:{s:8:\"selector\";s:30:\"cms_module_common_selector_lvl\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (229,'af73ab8e8d60781710d390277ab70370','selector','cms_module_common_selector_lvl',46,'a:1:{i:0;s:14:\"notice_display\";}',228);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (230,'f06975f4ca11163b101ccf6faf0320cb','datasource','cms_module_common_datasource_articles_categories',46,'a:4:{s:7:\"sort_by\";s:16:\"publication_date\";s:10:\"sort_order\";s:4:\"desc\";s:15:\"nb_max_elements\";s:1:\"4\";s:8:\"selector\";s:43:\"cms_module_common_selector_record_permalink\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (231,'9198c8dbaeaf9dbaf87b5aff9da6cb0d','selector','cms_module_common_selector_record_permalink',46,'s:2:\"N;\";',230);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (232,'a075058039fdaa037e863cc2adc0b2a5','view','cms_module_common_view_articleslist',46,'a:2:{s:5:\"links\";a:1:{s:7:\"article\";a:2:{s:4:\"page\";s:1:\"4\";s:3:\"var\";s:10:\"id_article\";}}s:15:\"active_template\";s:498:\"{% if articles %}\n<h3>Lire aussi...</h3>\n{% endif %}\n   {% for article in articles %}\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\n<h3>{{article.title}}</h3>\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\n<p>{{article.resume}}</p>\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\n</div>\n   {% endfor %}\n<div class=\"row\"></div>\";}',0);
INSERT INTO cms_cadre_content (id_cadre_content, cadre_content_hash, cadre_content_type, cadre_content_object, cadre_content_num_cadre, cadre_content_data, cadre_content_num_cadre_content) VALUES (227,'16f3fea6bd5c7df0da44800d9a5b4268','selector','cms_module_common_selector_article',15,'s:2:\"N;\";',72);
/*!40000 ALTER TABLE cms_cadre_content ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_cadres`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_cadres (
  id_cadre int(10) unsigned NOT NULL AUTO_INCREMENT,
  cadre_hash varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_object varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_fixed int(11) NOT NULL DEFAULT '0',
  cadre_styles mediumtext COLLATE utf8_unicode_ci NOT NULL,
  cadre_dom_parent varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_dom_after varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_url mediumtext COLLATE utf8_unicode_ci NOT NULL,
  cadre_memo_url int(11) NOT NULL DEFAULT '0',
  cadre_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cadre_modcache varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'get_post_view',
  PRIMARY KEY (id_cadre)
) ENGINE=MyISAM AUTO_INCREMENT=47 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_cadres`
--

LOCK TABLES cms_cadres WRITE;
/*!40000 ALTER TABLE cms_cadres DISABLE KEYS */;
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (15,'7cee07c752293c5c3a10ea5933841824','cms_module_recordslist','Etagère associée à un article',0,'','','','index.php?&lvl=cmspage&pageid=4&id_article=12',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (17,'d13ae47fc09a29a25fa71e23fddaa2af','cms_module_recordslist','Notices dans la même catégorie qu\'un article',0,'','','','index.php?&lvl=cmspage&pageid=4&id_article=12',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (18,'3ee1f436ea90d84e28882de88b22370f','cms_module_section','Affichage d\'une rubrique',0,'','','','index.php?&cms_build_activate=1&lvl=cmspage&pageid=6',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (14,'0ba1c679ef0a942a8c46c7ca9beb1ea4','cms_module_article','Affichage d\'un article',0,'','','','index.php?&lvl=cmspage&pageid=4&id_article=12',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (35,'7a500d1118d04f755af97084592cdd00','cms_module_record','Affichage d\'une notice',0,'','','','index.php?&cms_build_activate=1&lvl=cmspage&pageid=7',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (13,'7910f8bd37627154f20c5a7d7c6befa4','cms_module_menu','Menu',1,'','','','',0,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (21,'a0bd3b38f50b8aaa8c6d70bbce732e96','cms_module_articleslist','Carrousel d\'articles (accueil)',0,'','','','index.php?',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (22,'bab6872c66fb7ea7c8e69e4c67845c42','cms_module_search','Barre de recherche simple',1,'','','','index.php?&cms_build_activate=1&lvl=cmspage&pageid=3',0,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (23,'1d5aa8c215a8d7b47fce6cbfacfcc66d','cms_module_recordslist','Carrousel de notices (nouveautés - accueil)',0,'','','','index.php?',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (27,'b1ca78dbb7341ae614689fb29fc643e0','cms_module_agenda','Agenda (accueil)',0,'','','','index.php?',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (30,'1d9ae0474fd852afd8822f0b4edfb597','cms_module_menu','Bouton recherche avancée',1,'','','','',0,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (42,'239ed22636b22d7bca3307e00181c87f','cms_module_articleslist','Résultats d\'articles (recherche articles)',0,'','','','index.php?&lvl=cmspage&pageid=7',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (33,'7112b224a0119ab251bf5653dd13547a','cms_module_agenda','Liste d\'événements (agenda)',0,'','','','index.php?&lvl=cmspage&pageid=9&id_date=2012-10-31',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (36,'c5e4abc4e0629c1d2fdf38806905d36a','cms_module_articleslist','Liste de brèves (accueil)',0,'','','','index.php?&database=bibliportail&cms_build_activate=1&build_id_version=173',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (41,'20383a2f044ffe24b7ba3f28a7527556','cms_module_articleslist','Résultats d\'articles (recherche notices)',0,'','','','index.php?&cms_build_activate=1&lvl=cmspage&pageid=3',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (38,'a9ff73d4658da2ebb2eef63450a27f99','cms_module_articleslist','Liste d\'articles - sélections (accueil)',0,'','','','index.php?&database=bibliportail&cms_build_activate=1&build_id_version=173',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (39,'f378759be5c4bdd9fb8fcb38fde5ef27','cms_module_htmlcode','[class row accueil]',0,'','','','index.php?',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (44,'fabbfce7d0fd1f4ead43c41e0e0ec1d9','cms_module_recordslist','Notices du même auteur',0,'','','','index.php?&lvl=notice_display&id=112',1,'','get_post_view');
INSERT INTO cms_cadres (id_cadre, cadre_hash, cadre_object, cadre_name, cadre_fixed, cadre_styles, cadre_dom_parent, cadre_dom_after, cadre_url, cadre_memo_url, cadre_classement, cadre_modcache) VALUES (46,'178cd897a777a6e33b4ce8982733ba40','cms_module_articleslist','Articles dans la même catégorie que la notice',0,'','','','index.php?&lvl=notice_display&id=90',1,'','get_post_view');
/*!40000 ALTER TABLE cms_cadres ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_collections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_collections (
  id_collection int(10) unsigned NOT NULL AUTO_INCREMENT,
  collection_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collection_description text COLLATE utf8_unicode_ci NOT NULL,
  collection_num_parent int(11) NOT NULL DEFAULT '0',
  collection_num_storage int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_collection),
  KEY i_cms_collection_title (collection_title)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_collections`
--

LOCK TABLES cms_collections WRITE;
/*!40000 ALTER TABLE cms_collections DISABLE KEYS */;
/*!40000 ALTER TABLE cms_collections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_documents`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_documents (
  id_document int(10) unsigned NOT NULL AUTO_INCREMENT,
  document_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_description text COLLATE utf8_unicode_ci NOT NULL,
  document_filename varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_mimetype varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_filesize int(11) NOT NULL DEFAULT '0',
  document_vignette mediumblob NOT NULL,
  document_url text COLLATE utf8_unicode_ci NOT NULL,
  document_path varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_create_date date NOT NULL DEFAULT '0000-00-00',
  document_num_storage int(11) NOT NULL DEFAULT '0',
  document_type_object varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_num_object int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_document),
  KEY i_cms_document_title (document_title)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_documents`
--

LOCK TABLES cms_documents WRITE;
/*!40000 ALTER TABLE cms_documents DISABLE KEYS */;
/*!40000 ALTER TABLE cms_documents ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_documents_links`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_documents_links (
  document_link_type_object varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  document_link_num_object int(11) NOT NULL DEFAULT '0',
  document_link_num_document int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (document_link_type_object,document_link_num_object,document_link_num_document)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_documents_links`
--

LOCK TABLES cms_documents_links WRITE;
/*!40000 ALTER TABLE cms_documents_links DISABLE KEYS */;
/*!40000 ALTER TABLE cms_documents_links ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp),
  KEY i_num_type (num_type)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_custom`
--

LOCK TABLES cms_editorial_custom WRITE;
/*!40000 ALTER TABLE cms_editorial_custom DISABLE KEYS */;
INSERT INTO cms_editorial_custom (idchamp, num_type, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (1,2,'etagere','Etagère associée','query_list','integer','<OPTIONS FOR=\"query_list\">\r\n <QUERY><![CDATA[select idetagere, name from etagere order by 2]]></QUERY>\r\n <MULTIPLE>no</MULTIPLE>\r\n <AUTORITE>no</AUTORITE>\r\n <CHECKBOX>no</CHECKBOX>\r\n <INSERTAUTHORIZED>no</INSERTAUTHORIZED>\r\n <OPTIMIZE_QUERY>no</OPTIMIZE_QUERY>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[Choisissez une étagère]]></UNSELECT_ITEM>\r\n <CHECKBOX_NB_ON_LINE></CHECKBOX_NB_ON_LINE>\r\n <FIELD0>idetagere</FIELD0>\r\n <FIELD1>name</FIELD1>\r\n</OPTIONS>',0,0,1,0,0,0,100,0);
INSERT INTO cms_editorial_custom (idchamp, num_type, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (2,3,'date_debut','Date de début','date_box','date','<OPTIONS FOR=\"date_box\">\r\n <DEFAULT_TODAY>yes</DEFAULT_TODAY>\r\n</OPTIONS> ',0,0,1,0,0,0,100,0);
INSERT INTO cms_editorial_custom (idchamp, num_type, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (3,3,'date_fin','Date de fin','date_box','date','<OPTIONS FOR=\"date_box\">\r\n <DEFAULT_TODAY>yes</DEFAULT_TODAY>\r\n</OPTIONS> ',0,0,2,0,0,0,100,0);
INSERT INTO cms_editorial_custom (idchamp, num_type, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (4,5,'identifiant_notice','Identifiant de la notice','text','small_text','<OPTIONS FOR=\"text\">\r\n <SIZE>10</SIZE>\r\n <MAXSIZE>6</MAXSIZE>\r\n <REPEATABLE>0</REPEATABLE>\r\n</OPTIONS> ',0,0,1,0,0,0,100,0);
INSERT INTO cms_editorial_custom (idchamp, num_type, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (5,6,'date','Date de l\'événement','date_box','date','<OPTIONS FOR=\"date_box\"></OPTIONS> ',0,0,1,0,0,0,100,0);
/*!40000 ALTER TABLE cms_editorial_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_custom_lists (
  cms_editorial_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  cms_editorial_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  cms_editorial_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (cms_editorial_custom_champ),
  KEY editorial_champ_list_value (cms_editorial_custom_champ,cms_editorial_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_custom_lists`
--

LOCK TABLES cms_editorial_custom_lists WRITE;
/*!40000 ALTER TABLE cms_editorial_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE cms_editorial_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_custom_values (
  cms_editorial_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  cms_editorial_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  cms_editorial_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  cms_editorial_custom_text mediumtext COLLATE utf8_unicode_ci,
  cms_editorial_custom_integer int(11) DEFAULT NULL,
  cms_editorial_custom_date date DEFAULT NULL,
  cms_editorial_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (cms_editorial_custom_champ),
  KEY editorial_custom_origine (cms_editorial_custom_origine),
  KEY i_ccv_st (cms_editorial_custom_small_text),
  KEY i_ccv_t (cms_editorial_custom_text(255)),
  KEY i_ccv_i (cms_editorial_custom_integer),
  KEY i_ccv_d (cms_editorial_custom_date),
  KEY i_ccv_f (cms_editorial_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_custom_values`
--

LOCK TABLES cms_editorial_custom_values WRITE;
/*!40000 ALTER TABLE cms_editorial_custom_values DISABLE KEYS */;
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,3,NULL,NULL,4,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,13,NULL,NULL,5,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,16,NULL,NULL,8,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,15,NULL,NULL,7,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (4,17,'88',NULL,NULL,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (4,18,'104',NULL,NULL,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,24,NULL,NULL,9,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (4,12,'129',NULL,NULL,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (4,4,'128',NULL,NULL,NULL,NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (2,1,NULL,NULL,NULL,'2012-12-01',NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (3,1,NULL,NULL,NULL,'2013-03-31',NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (5,11,NULL,NULL,NULL,'2012-12-21',NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (5,2,NULL,NULL,NULL,'2013-01-09',NULL);
INSERT INTO cms_editorial_custom_values (cms_editorial_custom_champ, cms_editorial_custom_origine, cms_editorial_custom_small_text, cms_editorial_custom_text, cms_editorial_custom_integer, cms_editorial_custom_date, cms_editorial_custom_float) VALUES (1,14,NULL,NULL,6,NULL,NULL);
/*!40000 ALTER TABLE cms_editorial_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_fields_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_fields_global_index (
  num_obj int(10) unsigned NOT NULL DEFAULT '0',
  `type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  code_champ int(3) NOT NULL DEFAULT '0',
  code_ss_champ int(3) NOT NULL DEFAULT '0',
  ordre int(4) NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  pond int(4) NOT NULL DEFAULT '100',
  lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (num_obj,`type`,code_champ,code_ss_champ,ordre),
  KEY i_value (`value`(255))
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_fields_global_index`
--

LOCK TABLES cms_editorial_fields_global_index WRITE;
/*!40000 ALTER TABLE cms_editorial_fields_global_index DISABLE KEYS */;
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',1,0,0,'Cultures d\'Afrique noire contemporaine',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',2,0,0,'Venez découvrir la richesse culturelle de l\'Afrique noire auourd\'hui !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',3,0,0,'<p>\nFusce egestas vestibulum neque et faucibus. Integer commodo pretium \nporttitor. Phasellus varius dui at neque dignissim a fermentum magna \nluctus. Nulla facilisi. Cras erat nulla, ullamcorper in tincidunt eget, \ndignissim nec nisl. Nam ut dui nunc. Etiam in enim a sapien fermentum \naccumsan. Donec semper magna non tellus porttitor ultricies nec et \nlorem. Fusce ac felis odio. Cras eu urna nulla. Sed quis dignissim \nmagna. Praesent ultricies, dui et viverra facilisis, elit dui volutpat \narcu, venenatis malesuada justo velit a mi.\n</p>\n<p>\nUt quis volutpat est. Vestibulum ante ipsum primis in faucibus orci \nluctus et ultrices posuere cubilia Curae; Cras congue, dolor eget \ngravida congue, diam ante cursus nisi, nec dictum odio mauris et leo. \nPellentesque nisl massa, facilisis a varius facilisis, laoreet eget \nfelis. Fusce non orci laoreet sem congue vulputate at vel justo. Integer\n at mi lorem, in accumsan ipsum. Pellentesque ullamcorper semper \nlaoreet. Integer et dui felis, ut faucibus diam. Suspendisse blandit \nmollis elit sed posuere. Sed vitae erat et dui tempus egestas.\n</p>',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',5,1,0,'Evénement sur une période',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',6,1,0,'Afrique',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',1,0,0,'Animations',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (1,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',1,0,0,'Lisez 5 fruits et légumes par jour !',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',2,0,0,'Dans l\'assiette,<br />La courgette<br />C\'est ennuyant !<br />Mais dans les livres,<br />C\'est bien plus amusant !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',3,0,0,'La bibliothèque vous propose :<br /><br /><blockquote>Une heure du conte potagère !<br /><br />Et des ateliers de création avec fruits et légumes du marché...<br /></blockquote>',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',5,1,0,'Evénement à une date précise',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',6,1,0,'Légumes',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',1,0,0,'Sélections',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (2,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',1,0,0,'Fiction adultes',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',2,0,0,'Découvrez les nouveautés du rayon adultes en romans, livres audio, BD<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',3,0,0,'<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',1,0,0,'Infos pratiques',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (3,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',1,0,0,'Poisson rouge',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',2,0,0,'Le meilleur site de jeux en ligne pour les tout-petits !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',3,0,0,'Fusce egestas vestibulum neque et faucibus. Integer commodo pretium \nporttitor. Phasellus varius dui at neque dignissim a fermentum magna \nluctus. Nulla facilisi. Cras erat nulla, ullamcorper in tincidunt eget, \ndignissim nec nisl. Nam ut dui nunc. Etiam in enim a sapien fermentum \naccumsan. <br /><br />Donec semper magna non tellus porttitor ultricies nec et \nlorem. Fusce ac felis odio. Cras eu urna nulla. Sed quis dignissim \nmagna. Praesent ultricies, dui et viverra facilisis, elit dui volutpat \narcu, venenatis malesuada justo velit a mi.',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',5,1,0,'Coup de coeur',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',6,1,0,'Jeux et jouets',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',1,0,0,'Evénements',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (4,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',1,0,0,'Nouveautés CD et DVD',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',2,0,0,'Nouveautés CD et DVD',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',3,0,0,'Afficher une étagère !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',1,0,0,'Heure du conte',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (5,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',1,0,0,'Fantasy et SF',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',2,0,0,'Des classiques !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',3,0,0,'Afficher une étagère !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',1,0,0,'Animations jeunesse',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (6,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',1,0,0,'Mais que font les bibliothécaires ?',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',2,0,0,'Non non les bibliothécaires ne passent pas leur temps à lire et à jouer à Star Wars avec leurs douchettes laser !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',3,0,0,'<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',6,1,0,'Bibliothéconomie',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',1,0,0,'Nouveautés',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (7,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',1,0,0,'Nous trouver',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',3,0,0,'&lt;iframe width=&quot;425&quot; height=&quot;350&quot; frameborder=&quot;0&quot; scrolling=&quot;no&quot; marginheight=&quot;0&quot; marginwidth=&quot;0&quot; src=&quot;http://maps.google.fr/maps?f=q&amp;amp;source=s_q&amp;amp;hl=fr&amp;amp;geocode=&amp;amp;q=PMB+Services,+Ch%C3%A2teau-du-Loir&amp;amp;aq=0&amp;amp;oq=pmb+services+&amp;amp;sll=46.22475,2.0517&amp;amp;sspn=25.816925,67.631836&amp;amp;ie=UTF8&amp;amp;hq=PMB+Services,+Ch%C3%A2teau-du-Loir&amp;amp;hnear=&amp;amp;radius=15000&amp;amp;t=m&amp;amp;ll=47.684112,0.428123&amp;amp;spn=0.080896,0.145912&amp;amp;z=12&amp;amp;output=embed&quot;&gt;&lt;/iframe&gt;&lt;br /&gt;&lt;small&gt;&lt;a href=&quot;http://maps.google.fr/maps?f=q&amp;amp;source=embed&amp;amp;hl=fr&amp;amp;geocode=&amp;amp;q=PMB+Services,+Ch%C3%A2teau-du-Loir&amp;amp;aq=0&amp;amp;oq=pmb+services+&amp;amp;sll=46.22475,2.0517&amp;amp;sspn=25.816925,67.631836&amp;amp;ie=UTF8&amp;amp;hq=PMB+Services,+Ch%C3%A2teau-du-Loir&amp;amp;hnear=&amp;amp;radius=15000&amp;amp;t=m&amp;amp;ll=47.684112,0.428123&amp;amp;spn=0.080896,0.145912&amp;amp;z=12&quot; style=&quot;color:#0000FF;text-align:left&quot;&gt;Agrandir le plan&lt;/a&gt;&lt;/small&gt;',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',1,0,0,'Coups de coeur',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (8,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',1,0,0,'Horaires',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',2,0,0,'La bibliothèque est ouverte tous les jours...<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',3,0,0,'Tableau des horaires<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',1,0,0,'La bibliothèque',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (9,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',1,0,0,'Comment s\'inscrire ?',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',2,0,0,'Comment s\'inscrire ?<br /><br />Pour quels services ?<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',3,0,0,'Contenu du règlement de la bibliothèque<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',1,0,0,'Inscription et prêt',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (10,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',1,0,0,'Projections : journée Tim Burton',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',2,0,0,'L\'après-midi pour les enfants,<br />Le soir pour les grands !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',3,0,0,'Au programme :<br /><br />Les noces funèbres<br /><br />Beetlejuice<br /><br />Big Fish<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',5,1,0,'Evénement à une date précise',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',6,1,0,'Cinéma',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',1,0,0,'Nous trouver',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (11,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',1,0,0,'Georges : petit-petit-petit magazine',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',2,0,0,'Le concept de Georges :<br />\nBienvenue dans l\'univers de Georges, petit petit petit magazine, \nrevue alternative trimestrielle créée par les Éditions Grains de Sel, \npour les enfants ni trop petits ni trop grands.<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',3,0,0,'Mais qui est Georges ?<br />\n\nUn magazine décalé et exigeant qui stimule la curiosité et revisite les traitements traditionnels des magazines pour enfants.<br />\n\n<br />\n\nQuels sont ses atouts ?<br />\n\nUn graphisme épuré  et un thème original pour chaque numéro, sur un beau\n papier offset et recyclé, avec des illustrateurs aux univers sensibles \net un second degré qui séduit les enfants (et même leurs parents).<br />\n\n<br />\n\nComment se présente-t-il ?<br />\n\nPartie 1 : des HISTOIRES vraies, courtes, longues ou à l\'envers.<br />\n\nPartie 2 : des JEUX à colorier, calculer ou déchiffrer autour du thème du numéro.<br />\n\nPartie 3 : des RUBRIQUES-À-BRAC pour découvrir des métiers, langues \nétrangères, scènes de films ou expériences scientifiques, mais de façon \ntoujours farfelue !',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',5,1,0,'Coup de coeur',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',6,1,0,'Jeux et jouets',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',1,0,0,'Menu principal',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (12,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',1,0,0,'Fiction jeunesse',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',2,0,0,'Découvrez les nouveautés du rayon jeunesse en albums, BD, romans',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',1,0,0,'Brèves',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (13,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',1,0,0,'Documentaires',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',2,0,0,'Découvrez nos nouveaux documentaires, pour grands et petits<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',1,0,0,'Archives',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',2,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',5,1,0,'Rubrique',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (14,'section',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',1,0,0,'Musique',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',2,0,0,'Découvrez nos nouveautés du rayon musique<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (15,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',1,0,0,'Cinéma',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',2,0,0,'Découvrez nos nouveautés du rayon cinéma<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (16,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',1,0,0,'Des bibliothèques pleines de fantômes',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',2,0,0,'Avez-vous peur de mourir dans votre sommeil, enseveli sous l\'écroulement\n de votre bibliothèque ? Classez-vous les volumes par \nthème, langue, auteur, date de parution, format ou selon un autre \ncritère de vous seul connu ?',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',3,0,0,'Autant de graves questions se posant à cette espèce en voie de \ndisparition : les bibliomanes, qui, outre la passion de posséder les \nlivres, ont celle de les lire. Les bibliothèques sont des êtres vivants à\n l\'image de notre complexité intérieure. Elles finissent par composer un\n labyrinthe dont pour notre plus grand, et dangereux, plaisir nous \npouvons très bien ne plus sortir. Dans ce petit traité sur l\'art de \nvivre avec trop de livres apparaissent, parmi nombre d\'autres, Pessoa \ntentant de devenir bibliothécaire, Matisse postulant au poste de \n«contrôleur du droit des pauvres» ou encore le capitaine Achab et le \nmystère de sa jambe abandonnée à Moby Dick. En fait, ces milliers de \npages qui occupent nos étagères sont peuplées de fantômes bien vivants \nqui, une fois rencontrés, ne nous quittent plus.',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',5,1,0,'Coup de coeur',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',6,1,0,'Bibliothéconomie',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (17,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',1,0,0,'Les annales du disque-monde',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',2,0,0,'Le disque-monde est plat, porté par quatre éléphants debout sur le dos\n d\'une tortue naviguant dans le cosmos. Tout le monde le sait et \nquoiqu\'en disent certaines sectes, c\'est la vérité. <br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',3,0,0,'<p>Les héros de ce monde sont à son image : atypiques.<br /> Rincevent, \nmagicien malchanceux froussard et raté, ne connaît qu\'un seul sort mais \nil n\'ose pas le lancer car il pourrait tout détruire.<br /> Mémé \nCiredutemps, sorcière d\'un certain âge, ne peut que diriger tous ceux \nqui l\'entourent, elle ne fait d\'ailleurs que très rarement usage de sa \nmagie car tout le monde la connaît et lui obéit.<br /> La Mort, la faucheuse avec son grand suaire et sa faux bien aiguisée, grande humaniste incomprise.  </p>Pratchett\n consacre chacun de ses romans à un de ces personnages même s\'il arrive \nqu\'ils se rencontrent de temps en temps, car tout est possible dans cet \nunivers totalement fou et plein d\'humour !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',5,1,0,'Coup de coeur',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',6,1,0,'Fantastique et merveilleux',110,'fr_FR');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (18,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',1,0,0,'Fermeture exceptionnelle',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',2,0,0,'Le jour de Noël, et aussi le jour de l\'an<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (19,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',1,0,0,'Vous avez le droit d\'emprunter des documents !',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',2,0,0,'10 prêts en tout dont maximum 5 livres, 5 CD pour une durée de 3 semaines<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (20,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',1,0,0,'Encore un exemple de brève',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',2,0,0,'Ceci est une brève !<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (21,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',1,0,0,'Flash info',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',2,0,0,'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer mattis eleifend lorem, ut tristique leo...',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (22,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',1,0,0,'Et une dernière pour la route',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',2,0,0,'Ceci est aussi une brève<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',5,1,0,'Information',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (23,'article',8,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',1,0,0,'Périodiques',130,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',2,0,0,'Découvrez nos nouveautés du rayon périodiques<br />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',3,0,0,'<br _moz_editor_bogus_node=\"TRUE\" />',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',4,1,0,'Publié',50,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',5,1,0,'Sélection',60,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',7,0,0,'0000-00-00 00:00:00',100,'');
INSERT INTO cms_editorial_fields_global_index (num_obj, type, code_champ, code_ss_champ, ordre, value, pond, lang) VALUES (24,'article',8,0,0,'0000-00-00 00:00:00',100,'');
/*!40000 ALTER TABLE cms_editorial_fields_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_publications_states`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_publications_states (
  id_publication_state int(10) unsigned NOT NULL AUTO_INCREMENT,
  editorial_publication_state_label varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  editorial_publication_state_opac_show int(1) NOT NULL DEFAULT '0',
  editorial_publication_state_auth_opac_show int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_publication_state)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_publications_states`
--

LOCK TABLES cms_editorial_publications_states WRITE;
/*!40000 ALTER TABLE cms_editorial_publications_states DISABLE KEYS */;
INSERT INTO cms_editorial_publications_states (id_publication_state, editorial_publication_state_label, editorial_publication_state_opac_show, editorial_publication_state_auth_opac_show) VALUES (1,'Brouillon',0,0);
INSERT INTO cms_editorial_publications_states (id_publication_state, editorial_publication_state_label, editorial_publication_state_opac_show, editorial_publication_state_auth_opac_show) VALUES (2,'Publié',1,0);
/*!40000 ALTER TABLE cms_editorial_publications_states ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_types`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_types (
  id_editorial_type int(10) unsigned NOT NULL AUTO_INCREMENT,
  editorial_type_element varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  editorial_type_label varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  editorial_type_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  editorial_type_extension text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_editorial_type),
  KEY i_editorial_type_element (editorial_type_element)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_types`
--

LOCK TABLES cms_editorial_types WRITE;
/*!40000 ALTER TABLE cms_editorial_types DISABLE KEYS */;
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (1,'section','Rubrique','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (2,'article','Sélection','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (3,'article','Evénement sur une période','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (4,'article','Information','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (5,'article','Coup de coeur','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (6,'article','Evénement à une date précise','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (7,'article_generic','CP pour Article','','');
INSERT INTO cms_editorial_types (id_editorial_type, editorial_type_element, editorial_type_label, editorial_type_comment, editorial_type_extension) VALUES (8,'section_generic','CP pour Rubrique','','');
/*!40000 ALTER TABLE cms_editorial_types ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_editorial_words_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_editorial_words_global_index (
  num_obj int(10) unsigned NOT NULL DEFAULT '0',
  `type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  code_champ int(11) NOT NULL DEFAULT '0',
  code_ss_champ int(11) NOT NULL DEFAULT '0',
  num_word int(11) NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  position int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (num_obj,`type`,code_champ,code_ss_champ,num_word,position)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_editorial_words_global_index`
--

LOCK TABLES cms_editorial_words_global_index WRITE;
/*!40000 ALTER TABLE cms_editorial_words_global_index DISABLE KEYS */;
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',1,0,999,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',1,0,1758,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',1,0,3016,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',1,0,3017,130,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,999,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,1274,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,1714,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,1758,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,2718,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,2719,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,2998,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,3020,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',2,0,3021,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,193,100,60);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,325,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,536,100,88);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,566,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,1230,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,1542,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3261,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3262,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3263,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3264,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3265,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3266,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3267,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3268,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3269,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3270,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3271,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3272,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3273,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3274,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3275,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3276,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3277,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3278,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3279,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3280,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3281,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3282,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3283,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3284,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3285,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3286,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3287,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3288,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3289,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3290,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3291,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3292,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3293,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3294,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3295,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3296,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3297,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3298,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3299,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3300,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3301,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3302,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3303,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3304,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3305,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3306,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3307,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3308,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3309,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3310,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3311,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3312,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3313,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3314,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3315,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3316,100,61);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3317,100,62);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3318,100,63);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3319,100,64);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3320,100,65);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3321,100,66);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3322,100,67);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3323,100,68);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3324,100,69);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3325,100,70);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3326,100,71);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3327,100,72);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3328,100,73);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3329,100,74);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3330,100,75);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3331,100,76);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3332,100,77);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3333,100,78);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3334,100,79);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3335,100,80);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3336,100,81);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3337,100,82);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3338,100,83);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3339,100,84);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3340,100,85);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3341,100,86);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',3,0,3342,100,87);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',5,1,418,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',5,1,948,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',5,1,3179,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',5,1,3182,60,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',6,1,56,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',1,0,3012,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (1,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,260,130,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,331,130,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,1367,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,2290,130,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,2298,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',1,0,3025,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,100,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,161,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,193,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,284,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,348,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,476,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,603,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,2998,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,3026,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,3028,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,3029,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',2,0,3030,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,99,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,148,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,234,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,773,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2134,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2290,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2298,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2299,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2958,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,2998,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,3027,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,3031,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,3032,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',3,0,3033,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',5,1,948,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',5,1,1432,60,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',5,1,1861,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',5,1,3179,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',5,1,3180,60,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',6,1,2572,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',1,0,3007,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (2,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',1,0,53,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',1,0,208,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,53,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,77,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,392,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,603,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,1030,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,1280,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,2998,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',2,0,3113,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',1,0,3008,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',1,0,3009,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (3,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',1,0,2326,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',1,0,2896,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,354,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,629,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,760,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,2938,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,2998,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,3109,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,3110,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',2,0,3111,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,566,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,1230,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,1542,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,2998,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3261,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3262,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3263,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3264,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3265,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3266,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3267,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3268,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3269,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3270,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3271,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3272,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3273,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3274,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3275,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3276,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3277,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3278,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3279,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3280,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3281,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3282,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3283,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3284,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3285,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3286,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3287,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3288,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3289,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3290,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3291,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3292,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3293,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3294,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3295,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3296,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3297,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3298,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3299,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3300,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3301,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3302,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3303,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3304,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3305,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3306,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3307,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3308,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3309,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3310,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3311,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3312,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3313,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3314,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',3,0,3315,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',5,1,1044,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',5,1,1254,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',5,1,2762,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',6,1,2899,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',6,1,2900,110,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',1,0,630,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (4,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',1,0,117,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',1,0,1280,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',1,0,1322,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',2,0,117,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',2,0,1280,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',2,0,1322,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',3,0,2152,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',3,0,2998,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',3,0,3037,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',1,0,148,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',1,0,234,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (5,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',1,0,3038,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',1,0,3039,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',2,0,2998,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',2,0,3040,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',3,0,2152,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',3,0,2998,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',3,0,3037,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',1,0,1801,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',1,0,3012,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (6,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',1,0,284,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',1,0,368,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',1,0,1931,130,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',1,0,2661,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,269,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,270,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,314,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,472,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,566,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,773,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,858,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,1161,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,1931,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,2998,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3041,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3042,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3043,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3044,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3045,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',2,0,3046,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',6,1,2585,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',1,0,1280,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (7,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',1,0,553,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',1,0,647,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,17,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,31,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,216,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,240,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,349,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,393,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,403,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,512,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,602,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,794,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,826,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,1111,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,1265,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,1433,100,65);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,1660,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,2547,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,2663,100,72);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,2998,100,62);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3048,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3049,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3050,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3051,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3052,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3053,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3054,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3055,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3056,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3057,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3058,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3059,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3060,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3061,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3062,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3063,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3064,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3065,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3066,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3067,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3068,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3069,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3070,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3071,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3072,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3073,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3074,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3075,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3076,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3077,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3078,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3079,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3080,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3081,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3082,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3083,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3084,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3085,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3086,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3087,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3088,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3089,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3090,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3091,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3092,100,60);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3093,100,61);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3094,100,63);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3095,100,64);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3096,100,66);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3097,100,67);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3098,100,68);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3099,100,69);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3100,100,70);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',3,0,3101,100,71);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',1,0,1044,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',1,0,3013,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (8,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',1,0,3014,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,99,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,193,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,426,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,1215,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,2998,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',2,0,3102,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',3,0,2998,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',3,0,3014,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',3,0,3103,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',1,0,99,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (9,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',1,0,393,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',1,0,2736,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',1,0,3105,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,354,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,393,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,403,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,2736,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,2920,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,2998,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',2,0,3105,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',3,0,99,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',3,0,2998,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',3,0,3015,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',3,0,3022,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',1,0,1045,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',1,0,3104,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (10,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',1,0,478,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',1,0,2419,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',1,0,2420,130,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',1,0,3106,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,185,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,354,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,681,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,2065,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,2998,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,3107,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',2,0,3108,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,705,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2490,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2501,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2502,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2511,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2512,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',3,0,2998,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',5,1,948,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',5,1,1432,60,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',5,1,1861,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',5,1,3179,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',5,1,3180,60,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',6,1,2485,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',1,0,553,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',1,0,647,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (11,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',1,0,341,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',1,0,1467,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',1,0,2902,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,161,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,185,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,331,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,341,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,354,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,473,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,629,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,681,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,946,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,1047,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,1467,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2435,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2602,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2902,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2903,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2904,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2905,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2906,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2907,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2908,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2909,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',2,0,2998,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,3,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,17,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,21,100,60);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,82,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,185,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,193,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,228,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,242,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,270,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,284,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,299,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,324,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,354,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,370,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,399,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,404,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,412,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,418,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,561,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,712,100,72);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,773,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,778,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,853,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1047,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1096,100,71);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1274,100,63);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1467,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1658,100,68);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1680,100,64);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1742,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,1764,100,65);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2281,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2409,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2606,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2736,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2902,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2912,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2913,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2914,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2915,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2916,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2917,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2918,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2919,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2920,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2921,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2922,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2923,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2924,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2925,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2926,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2927,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2928,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2929,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2930,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2931,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2932,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2933,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2934,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2935,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2936,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2937,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2938,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2939,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2940,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2941,100,61);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2942,100,62);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2943,100,66);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2944,100,67);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2945,100,69);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2946,100,70);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2947,100,73);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',3,0,2998,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',5,1,1044,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',5,1,1254,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',5,1,2762,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',6,1,2899,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',6,1,2900,110,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',1,0,3163,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',1,0,3184,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (12,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',1,0,208,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',1,0,1801,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,392,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,1030,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,1146,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,1280,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,1801,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',2,0,3113,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',1,0,3164,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (13,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',1,0,178,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,178,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,354,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,629,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,681,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,1198,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,1982,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,2998,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',1,0,3185,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',2,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',5,1,3006,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (14,'section',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',1,0,311,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,311,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,1198,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,1280,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,2998,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',2,0,3113,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (15,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',1,0,132,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,132,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,1198,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,1280,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,2998,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',2,0,3113,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (16,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',1,0,1957,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',1,0,2130,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',1,0,2131,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,99,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,161,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,324,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,331,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,405,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,561,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,662,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,1011,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,1224,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,1432,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,1614,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,1792,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2133,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2134,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2135,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2136,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2137,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2138,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2139,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2140,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2144,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2145,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2146,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2147,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2148,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',2,0,2149,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,83,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,100,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,118,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,121,100,78);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,123,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,161,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,180,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,202,100,77);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,226,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,314,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,324,100,67);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,327,100,80);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,331,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,341,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,348,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,354,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,370,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,394,100,72);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,399,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,412,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,418,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,473,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,542,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,553,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,556,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,558,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,560,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,603,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,609,100,86);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,622,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,644,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,679,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,720,100,68);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,773,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,791,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,838,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,858,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,876,100,74);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1087,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1181,100,79);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1198,100,82);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1226,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1227,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1299,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1674,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1691,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1892,100,60);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,1957,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2131,100,85);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2155,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2156,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2157,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2158,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2159,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2160,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2161,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2162,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2163,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2164,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2165,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2166,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2167,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2168,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2169,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2170,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2171,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2172,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2173,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2174,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2175,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2176,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2177,100,61);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2178,100,62);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2179,100,63);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2180,100,64);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2181,100,65);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2182,100,66);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2183,100,69);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2184,100,70);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2185,100,71);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2186,100,73);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2187,100,75);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2188,100,76);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2189,100,81);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2190,100,83);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2191,100,84);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2192,100,87);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',3,0,2193,100,88);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',5,1,1044,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',5,1,1254,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',5,1,2762,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',6,1,2585,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (17,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',1,0,305,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',1,0,1347,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',1,0,2394,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,161,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,162,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,193,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,305,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,331,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,367,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,418,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,476,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,520,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,760,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,1125,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,1347,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,2998,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3118,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3119,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3120,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3121,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3122,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3123,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3124,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3125,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3126,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3127,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',2,0,3128,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,100,100,58);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,118,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,121,100,68);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,122,100,79);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,144,100,16);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,161,100,78);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,193,100,76);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,202,100,43);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,226,100,55);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,242,100,21);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,280,100,50);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,283,100,49);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,284,100,20);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,299,100,30);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,305,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,314,100,15);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,325,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,339,100,69);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,364,100,17);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,368,100,36);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,370,100,40);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,392,100,67);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,393,100,70);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,394,100,48);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,399,100,73);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,404,100,66);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,405,100,18);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,411,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,412,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,426,100,38);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,470,100,34);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,472,100,24);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,697,100,60);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,703,100,22);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,715,100,83);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,760,100,28);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,769,100,72);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,773,100,54);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,883,100,52);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,916,100,42);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1047,100,80);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1124,100,26);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1161,100,75);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1299,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1656,100,64);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1674,100,45);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1743,100,23);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1873,100,44);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1902,100,19);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1920,100,84);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,1971,100,47);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,2040,100,82);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,2150,100,35);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,2395,100,63);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,2612,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,2998,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3135,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3136,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3137,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3138,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3139,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3140,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3141,100,25);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3142,100,27);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3143,100,29);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3144,100,31);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3145,100,32);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3146,100,33);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3147,100,37);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3148,100,39);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3149,100,41);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3150,100,46);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3151,100,51);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3152,100,53);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3153,100,56);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3154,100,57);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3155,100,59);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3156,100,61);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3157,100,62);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3158,100,65);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3159,100,71);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3160,100,74);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3161,100,77);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',3,0,3162,100,81);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',5,1,1044,60,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',5,1,1254,60,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',5,1,2762,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',6,1,2570,110,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',6,1,2571,110,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (18,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',1,0,763,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',1,0,3165,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',2,0,260,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',2,0,591,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',2,0,1422,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',2,0,2998,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',2,0,3166,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (19,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',1,0,1248,130,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',1,0,2133,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',1,0,2134,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',1,0,2181,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',1,0,3167,130,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,21,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,117,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,180,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,354,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,603,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,760,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,1367,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,2432,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,2998,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,3168,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,3169,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,3170,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',2,0,3171,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (20,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',1,0,720,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',1,0,3172,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',1,0,3173,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',2,0,193,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',2,0,2998,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',2,0,3173,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',2,0,3174,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (21,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',1,0,3175,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',1,0,3176,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3266,100,9);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3288,100,12);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3298,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3309,100,8);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3317,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3325,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3332,100,14);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3343,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3344,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3345,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3346,100,7);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3347,100,10);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3348,100,11);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',2,0,3349,100,13);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (22,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',1,0,354,130,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',1,0,1304,130,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',1,0,2686,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',2,0,193,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',2,0,591,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',2,0,2998,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',2,0,3173,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',2,0,3174,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',5,1,1294,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (23,'article',8,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',1,0,3183,130,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,1198,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,1280,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,2998,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,3112,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,3113,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',2,0,3183,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,2998,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,2999,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,3000,100,3);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,3001,100,4);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,3002,100,5);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',3,0,3003,100,6);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',4,1,789,50,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',5,1,1786,60,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',7,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',7,0,3005,100,2);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',8,0,3004,100,1);
INSERT INTO cms_editorial_words_global_index (num_obj, type, code_champ, code_ss_champ, num_word, pond, position) VALUES (24,'article',8,0,3005,100,2);
/*!40000 ALTER TABLE cms_editorial_words_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_hash`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_hash (
  `hash` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`hash`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_hash`
--

LOCK TABLES cms_hash WRITE;
/*!40000 ALTER TABLE cms_hash DISABLE KEYS */;
INSERT INTO cms_hash (hash) VALUES ('0198c2305fd81df7f73fa764dce69f3b');
INSERT INTO cms_hash (hash) VALUES ('0256c915941e9d0212d429d442cf00fe');
INSERT INTO cms_hash (hash) VALUES ('06c75b0d6e435bf6b73d1bed6d496af6');
INSERT INTO cms_hash (hash) VALUES ('08753b34a2a4514944540b184da985d6');
INSERT INTO cms_hash (hash) VALUES ('095de25a55c28918025cfa202011602e');
INSERT INTO cms_hash (hash) VALUES ('099b9830dd875e33096827f92aea7948');
INSERT INTO cms_hash (hash) VALUES ('0adeaeb4ad6eeea5d724c83d4968d436');
INSERT INTO cms_hash (hash) VALUES ('0b94f3dc58895a6f8d22e0b14ff89449');
INSERT INTO cms_hash (hash) VALUES ('0ba1c679ef0a942a8c46c7ca9beb1ea4');
INSERT INTO cms_hash (hash) VALUES ('0c3fe17577b89816d2793ad094b16b53');
INSERT INTO cms_hash (hash) VALUES ('0f52d89b452bf328bc9e8f9e74d39f59');
INSERT INTO cms_hash (hash) VALUES ('154a35a148bed3cbd02362f5434a91b3');
INSERT INTO cms_hash (hash) VALUES ('15cf9d2706b2a6ab85cd66b6a59262c7');
INSERT INTO cms_hash (hash) VALUES ('16f3fea6bd5c7df0da44800d9a5b4268');
INSERT INTO cms_hash (hash) VALUES ('172f25f323c7f76ab42d3e37e3dbfe87');
INSERT INTO cms_hash (hash) VALUES ('178cd897a777a6e33b4ce8982733ba40');
INSERT INTO cms_hash (hash) VALUES ('1837b2d62c5d42f97ca06bca762db3e4');
INSERT INTO cms_hash (hash) VALUES ('1ae1c5f61aa187ff34f713ef1efad53b');
INSERT INTO cms_hash (hash) VALUES ('1d5aa8c215a8d7b47fce6cbfacfcc66d');
INSERT INTO cms_hash (hash) VALUES ('1d9ae0474fd852afd8822f0b4edfb597');
INSERT INTO cms_hash (hash) VALUES ('20383a2f044ffe24b7ba3f28a7527556');
INSERT INTO cms_hash (hash) VALUES ('2174c7f77408788e6e2d53f516b22e21');
INSERT INTO cms_hash (hash) VALUES ('21eaf5bfc1f07a9278d240b38ea59da2');
INSERT INTO cms_hash (hash) VALUES ('2267ae958c1614473ba056a4c2583a3a');
INSERT INTO cms_hash (hash) VALUES ('22aa235dc2ef5755ae81f964920f8f06');
INSERT INTO cms_hash (hash) VALUES ('239ed22636b22d7bca3307e00181c87f');
INSERT INTO cms_hash (hash) VALUES ('24a5df2c9aa0ac9c71d21ef02cd956e7');
INSERT INTO cms_hash (hash) VALUES ('278ff6655d25e53fc7ca7861147db091');
INSERT INTO cms_hash (hash) VALUES ('2b59fe226433ad484e3171dcccb3cd77');
INSERT INTO cms_hash (hash) VALUES ('2ccb5bbac4b29d69e8f3f1ea27a2b604');
INSERT INTO cms_hash (hash) VALUES ('2d8b5265c22fe9a5197faef9153f2307');
INSERT INTO cms_hash (hash) VALUES ('2e13d1ea88e3de6edd3552e256d39253');
INSERT INTO cms_hash (hash) VALUES ('2e9d1730296875f15cb2f2252df543d1');
INSERT INTO cms_hash (hash) VALUES ('322c9411bdd1531eb8a300de5c438b90');
INSERT INTO cms_hash (hash) VALUES ('348486cc763b31f6c4b502c3b4314e42');
INSERT INTO cms_hash (hash) VALUES ('35fb5d441fefa3686fc8940046514026');
INSERT INTO cms_hash (hash) VALUES ('38ae68f5687af3e9c77d53b783827933');
INSERT INTO cms_hash (hash) VALUES ('3ba7c410e2590bcc9b60d43a341b797a');
INSERT INTO cms_hash (hash) VALUES ('3c5ee825b2560ed6977fb5c68cfaa6b3');
INSERT INTO cms_hash (hash) VALUES ('3ee1f436ea90d84e28882de88b22370f');
INSERT INTO cms_hash (hash) VALUES ('40e2e81a1c8b9f554360fba8e5fd4197');
INSERT INTO cms_hash (hash) VALUES ('41766086b1ef02df8177f843888cbfc5');
INSERT INTO cms_hash (hash) VALUES ('42f1a04589069c3e114ed1ecf351c313');
INSERT INTO cms_hash (hash) VALUES ('44a3d79f8053c182098d4bd7c339ea8d');
INSERT INTO cms_hash (hash) VALUES ('4ac516dcd9b777f530198136ec20094a');
INSERT INTO cms_hash (hash) VALUES ('4c9c6e66ef380ff5e35c3745eec750a2');
INSERT INTO cms_hash (hash) VALUES ('5391ce82b479912a582eee9e8b08406c');
INSERT INTO cms_hash (hash) VALUES ('54b38f89e545cde31b8319fcd3a75e62');
INSERT INTO cms_hash (hash) VALUES ('5a41eca552b5085dd6b99e8e2a7bc604');
INSERT INTO cms_hash (hash) VALUES ('5ac9882fdd4052d7c20e1536f0c297f1');
INSERT INTO cms_hash (hash) VALUES ('5f12872704015b16aace9d315448b95f');
INSERT INTO cms_hash (hash) VALUES ('637c485eade18c18df1c13fec66d55b2');
INSERT INTO cms_hash (hash) VALUES ('64c4c3e6b1f22471df59b06fe9613197');
INSERT INTO cms_hash (hash) VALUES ('652f38cfd5a862ae41608fdf319497a3');
INSERT INTO cms_hash (hash) VALUES ('66246d4ede37dd5c81a8667fab1cac17');
INSERT INTO cms_hash (hash) VALUES ('69ee506f1177090083cb3b04aa33d56f');
INSERT INTO cms_hash (hash) VALUES ('6a9bca44e27e60a564de511a8a2fce17');
INSERT INTO cms_hash (hash) VALUES ('6c3acdc502e283375f70a86b7d1814d0');
INSERT INTO cms_hash (hash) VALUES ('6d267e5fe8fd3b863d9ac8c8096bc16a');
INSERT INTO cms_hash (hash) VALUES ('7112b224a0119ab251bf5653dd13547a');
INSERT INTO cms_hash (hash) VALUES ('74bbfd97875718b19730630cf96a4923');
INSERT INTO cms_hash (hash) VALUES ('7910f8bd37627154f20c5a7d7c6befa4');
INSERT INTO cms_hash (hash) VALUES ('7a500d1118d04f755af97084592cdd00');
INSERT INTO cms_hash (hash) VALUES ('7a7d907cdf3313beff95facf1b1c6510');
INSERT INTO cms_hash (hash) VALUES ('7b19d51557c55a5322aaac0e5ab11eb1');
INSERT INTO cms_hash (hash) VALUES ('7cee07c752293c5c3a10ea5933841824');
INSERT INTO cms_hash (hash) VALUES ('7fd148362db9ab41ec57bbaed1f5c331');
INSERT INTO cms_hash (hash) VALUES ('807e7feb6d0079f75793e213ba096fc8');
INSERT INTO cms_hash (hash) VALUES ('8297bf009179dc74f9203900368863a7');
INSERT INTO cms_hash (hash) VALUES ('831240608c678b496fc56ac895f0794a');
INSERT INTO cms_hash (hash) VALUES ('84d67e2fba6c618f0d1dd007d1fcb217');
INSERT INTO cms_hash (hash) VALUES ('8567942d26a71c077a95ef9815a9aea2');
INSERT INTO cms_hash (hash) VALUES ('8d2a957c7c0154851d25e8ddd22b01bd');
INSERT INTO cms_hash (hash) VALUES ('8f23ba3c79256182374bda573dbd6807');
INSERT INTO cms_hash (hash) VALUES ('9198c8dbaeaf9dbaf87b5aff9da6cb0d');
INSERT INTO cms_hash (hash) VALUES ('923de26c5a78802d3e88896b116633e4');
INSERT INTO cms_hash (hash) VALUES ('954cbade289cdd55dc6c733df9c65340');
INSERT INTO cms_hash (hash) VALUES ('97514ee2810b079e029046d25566b68b');
INSERT INTO cms_hash (hash) VALUES ('9926c0f7333894580f1869c4394c29c0');
INSERT INTO cms_hash (hash) VALUES ('9d1cda64f47a48a5dc355c9651e16b43');
INSERT INTO cms_hash (hash) VALUES ('9d73449a0c4f0dd8e2adefe3af501a1e');
INSERT INTO cms_hash (hash) VALUES ('9ecfe7bf4dbf49d4a1c06af16c79b765');
INSERT INTO cms_hash (hash) VALUES ('a009d0ba2c9f870ff5c3c738a471b916');
INSERT INTO cms_hash (hash) VALUES ('a075058039fdaa037e863cc2adc0b2a5');
INSERT INTO cms_hash (hash) VALUES ('a085319aad988a30e4a12b6aa2704bc7');
INSERT INTO cms_hash (hash) VALUES ('a0bd3b38f50b8aaa8c6d70bbce732e96');
INSERT INTO cms_hash (hash) VALUES ('a0fc849a763200c7bde64ee165e07679');
INSERT INTO cms_hash (hash) VALUES ('a1d614b3448eff7c54774fc442efbf5e');
INSERT INTO cms_hash (hash) VALUES ('a23554e6187d48f09d1a6500d380c28a');
INSERT INTO cms_hash (hash) VALUES ('a3a69397d2b421f0cdb15841442aa3c2');
INSERT INTO cms_hash (hash) VALUES ('a3dda7258cca5b28d5346230a5e5fed1');
INSERT INTO cms_hash (hash) VALUES ('a40b018df61ae754936ada085e323646');
INSERT INTO cms_hash (hash) VALUES ('a7ff1dbe48408fea5dbbd570430ca54c');
INSERT INTO cms_hash (hash) VALUES ('a8cf96354034c2f98292d91b1d2051ba');
INSERT INTO cms_hash (hash) VALUES ('a9ff73d4658da2ebb2eef63450a27f99');
INSERT INTO cms_hash (hash) VALUES ('ab158999a4b5329570412e72b9c79491');
INSERT INTO cms_hash (hash) VALUES ('ab5d40a3d3b8dea2a8feb410842ef2ba');
INSERT INTO cms_hash (hash) VALUES ('adfda9b0ab2ea0faf8041f05b29d715f');
INSERT INTO cms_hash (hash) VALUES ('af30b6cbad2349fafc3308669b98375f');
INSERT INTO cms_hash (hash) VALUES ('af40c975df5a2cb10f8fc23498b56508');
INSERT INTO cms_hash (hash) VALUES ('af73ab8e8d60781710d390277ab70370');
INSERT INTO cms_hash (hash) VALUES ('b1ca78dbb7341ae614689fb29fc643e0');
INSERT INTO cms_hash (hash) VALUES ('b37ee50fa4c003f9152eff86c35ee511');
INSERT INTO cms_hash (hash) VALUES ('b3d745bf27775fdc704f8dcf93607657');
INSERT INTO cms_hash (hash) VALUES ('b4b9afc29a065349e7a75c9fc12f6524');
INSERT INTO cms_hash (hash) VALUES ('b96d87cfc5b056a08db0d3f260f0c0c7');
INSERT INTO cms_hash (hash) VALUES ('bab6872c66fb7ea7c8e69e4c67845c42');
INSERT INTO cms_hash (hash) VALUES ('bcd06190d70c2d19fd370aa66648ef79');
INSERT INTO cms_hash (hash) VALUES ('be40f23e110a323fcfaad6e5537c602c');
INSERT INTO cms_hash (hash) VALUES ('c3d735c65c2c97ec98532c57ae4c267e');
INSERT INTO cms_hash (hash) VALUES ('c5e4abc4e0629c1d2fdf38806905d36a');
INSERT INTO cms_hash (hash) VALUES ('c8f17015f7de51eb4f537238d18d13db');
INSERT INTO cms_hash (hash) VALUES ('cc9cfe2e1704186e526aeac60962cfd0');
INSERT INTO cms_hash (hash) VALUES ('ccd5992f263c59d2617ef4eb9a5ca137');
INSERT INTO cms_hash (hash) VALUES ('ce55f68e9edb0ca17fcb047533f4edd0');
INSERT INTO cms_hash (hash) VALUES ('d13ae47fc09a29a25fa71e23fddaa2af');
INSERT INTO cms_hash (hash) VALUES ('d3c2f826561a3f1f0a78f83c14592dc5');
INSERT INTO cms_hash (hash) VALUES ('d41bc624d0e94dc3eed31b6740a1f597');
INSERT INTO cms_hash (hash) VALUES ('d55e64e43809f69abd3b3f585b7615b3');
INSERT INTO cms_hash (hash) VALUES ('d9f1af72256f69ff93b8760c69f98196');
INSERT INTO cms_hash (hash) VALUES ('dc2f45cb6d307b4271d6736ee62246e2');
INSERT INTO cms_hash (hash) VALUES ('e13d2d7370b8f636db4a91b9a95b0df6');
INSERT INTO cms_hash (hash) VALUES ('e5fd56514b64fa540308cf90d03cfa2b');
INSERT INTO cms_hash (hash) VALUES ('e6b065a39f8303700d1ffc17aba542bc');
INSERT INTO cms_hash (hash) VALUES ('eae19fa4ff432636ba44e0a0437400c7');
INSERT INTO cms_hash (hash) VALUES ('eb8fa65d385e7e8a71af6918e08f3482');
INSERT INTO cms_hash (hash) VALUES ('ec1cd870bc94e0eed225e5458dc433e1');
INSERT INTO cms_hash (hash) VALUES ('efc1707ceca893eb2d7804c3abd89f0e');
INSERT INTO cms_hash (hash) VALUES ('f06975f4ca11163b101ccf6faf0320cb');
INSERT INTO cms_hash (hash) VALUES ('f28a2a974e880c7cbdec10b1b14cf27a');
INSERT INTO cms_hash (hash) VALUES ('f378759be5c4bdd9fb8fcb38fde5ef27');
INSERT INTO cms_hash (hash) VALUES ('f5a06f83ebb48f402146ee2823ff8faf');
INSERT INTO cms_hash (hash) VALUES ('f78306d275f0a418034e10b82fdcb1a0');
INSERT INTO cms_hash (hash) VALUES ('f85636e761f4398b2447145fa602fc14');
INSERT INTO cms_hash (hash) VALUES ('f882f4dc895a25c8aacfa887bae0ed9a');
INSERT INTO cms_hash (hash) VALUES ('fa541470ab2098ebea1cc016d5265400');
INSERT INTO cms_hash (hash) VALUES ('fabbfce7d0fd1f4ead43c41e0e0ec1d9');
INSERT INTO cms_hash (hash) VALUES ('fcfe834ffc06fa3e6b835251133a6a13');
INSERT INTO cms_hash (hash) VALUES ('fec77c2fd4a06818df24fa4c5e2631b8');
INSERT INTO cms_hash (hash) VALUES ('ff5de9ae00cc708192f2f425ecd0d571');
/*!40000 ALTER TABLE cms_hash ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_managed_modules`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_managed_modules (
  managed_module_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  managed_module_box mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (managed_module_name)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_managed_modules`
--

LOCK TABLES cms_managed_modules WRITE;
/*!40000 ALTER TABLE cms_managed_modules DISABLE KEYS */;
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_menu','a:1:{s:6:\"module\";a:1:{s:5:\"menus\";a:1:{s:5:\"menu1\";a:2:{s:4:\"name\";s:18:\"Recherche avancée\";s:5:\"items\";a:1:{i:0;a:4:{s:2:\"id\";s:1:\"1\";s:5:\"title\";s:20:\"Recherche avancÃ©e\";s:4:\"link\";s:43:\"./index.php?search_type_asked=simple_search\";s:4:\"type\";s:3:\"url\";}}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_search','a:1:{s:6:\"module\";a:1:{s:12:\"search_dests\";a:2:{s:12:\"search_dest1\";a:2:{s:4:\"name\";s:17:\"Dans le catalogue\";s:4:\"page\";s:1:\"0\";}s:12:\"search_dest2\";a:2:{s:4:\"name\";s:17:\"Dans les articles\";s:4:\"page\";s:2:\"11\";}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_carousel','a:1:{s:5:\"views\";a:1:{s:33:\"cms_module_carousel_view_carousel\";a:1:{s:9:\"templates\";a:0:{}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_agenda','a:2:{s:6:\"module\";a:1:{s:9:\"calendars\";a:2:{s:9:\"calendar1\";a:5:{s:4:\"name\";s:4:\"Expo\";s:5:\"color\";s:7:\"#D6DE39\";s:4:\"type\";s:1:\"3\";s:10:\"start_date\";s:1:\"2\";s:8:\"end_date\";s:1:\"3\";}s:9:\"calendar2\";a:5:{s:4:\"name\";s:10:\"Evénement\";s:5:\"color\";s:7:\"#F0A935\";s:4:\"type\";s:1:\"6\";s:10:\"start_date\";s:1:\"5\";s:8:\"end_date\";s:1:\"0\";}}}s:5:\"views\";a:1:{s:33:\"cms_module_agenda_view_eventslist\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:2:{s:4:\"name\";s:58:\"Affichage d\'une liste d\'événements à partir de l\'agenda\";s:7:\"content\";s:530:\"<div>\r\n{% for event in events %}\r\n<h3>\r\n{% if event.event_start.format_value %}\r\n {% if event.event_end.format_value %}\r\nDu {{event.event_start.format_value}} au {{event.event_end.format_value}}\r\n {% else %}\r\nLe {{event.event_start.format_value}}\r\n {% endif %}\r\n{% endif%} : {{event.title}}\r\n</h3>\r\n<blockquote>\r\n<a href=\'{{event.link}}\'><img style=\"float:left;margin-right:5px;\" src=\'{{event.logo.vign}}\'/></a>\r\n<p>{{event.resume}}</p>\r\n<br/>\r\n<div class=\"row\">{{event.content}}</div>\r\n</blockquote>\r\n<br />\r\n{% endfor %}\r\n</div>\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_record','a:1:{s:5:\"views\";a:1:{s:29:\"cms_module_common_view_record\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:2:{s:4:\"name\";s:22:\"Affichage d\'une notice\";s:7:\"content\";s:71:\"<p>{{record.header}}</p>\r\n<blockquote>{{record.content}}</blockquote>\r\n\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_section','a:1:{s:5:\"views\";a:1:{s:30:\"cms_module_common_view_section\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:2:{s:4:\"name\";s:24:\"Affichage d\'une rubrique\";s:7:\"content\";s:755:\"<h2>{{title}}</h2>\r\n<img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{logo.large}}\' />\r\n<p>{{resume}}</p>\r\n<div class=\"row\">{{content}}</div>\r\n  <ul>\r\n   {% for child in children %}\r\n    <li><a href=\'{{child.link}}\'>{{child.title}}</a></li>\r\n   {% endfor %}\r\n  </ul>\r\n\r\n   {% for article in articles %}\r\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\r\n<h3>{{article.title}}</h3>\r\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\r\n<p>{{article.resume}}</p>\r\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\r\n</div>\r\n   {% endfor %}\r\n<div class=\"row\"></div>\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_article','a:1:{s:5:\"views\";a:1:{s:30:\"cms_module_common_view_article\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:2:{s:4:\"name\";s:22:\"Affichage d\'un article\";s:7:\"content\";s:803:\"<h3>\r\n\r\n{% if fields_type.date_debut.values.0.value %}\r\n {% if fields_type.date_fin.values.0.value %}\r\nDu {{fields_type.date_debut.values.0.format_value}} au {{fields_type.date_fin.values.0.format_value}} : \r\n {% else %}\r\nLe {{fields_type.date_debut.values.0.format_value}} : \r\n {% endif %}\r\n{% endif%}\r\n{% if fields_type.date.values.0.value %}\r\nLe {{fields_type.date.values.0.format_value}} : \r\n{% endif%}\r\n\r\n{{title}}</h3>\r\n\r\n<img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{logo.large}}\' />\r\n\r\n<p>{{resume}}</p>\r\n<br />\r\n\r\n<div class=\"row\">{{content}}</div>\r\n<br />\r\n{% if fields_type.identifiant_notice.values.0.value %}\r\n<a href=\"./index.php?lvl=notice_display&id={{fields_type.identifiant_notice.values.0.value}}\">Voir le document dans le catalogue</a>\r\n{% endif%}\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_articleslist','a:1:{s:5:\"views\";a:2:{s:35:\"cms_module_common_view_articleslist\";a:1:{s:9:\"templates\";a:4:{s:9:\"template1\";a:2:{s:4:\"name\";s:42:\"Liste d\'articles - sélections nouveautés\";s:7:\"content\";s:322:\"<h2>Nouveautés</h2>\r\n{% for article in articles %}\r\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;text-align:center;\">\r\n<a href=\"{{article.link}}\">\r\n<img style=\"width:90px;\" src=\'{{article.logo.large}}\'/>\r\n<h4>{{article.title}}</h4>\r\n</a>\r\n</div>\r\n{% endfor %}\r\n<div class=\"row\"></div>\";}s:9:\"template2\";a:2:{s:4:\"name\";s:16:\"Liste de brèves\";s:7:\"content\";s:146:\"<h2>Brèves</h2>\r\n<hr>\r\n{% for article in articles %}\r\n<h4>{{article.title}}</h4>\r\n<blockquote>{{article.resume}}</blockquote>\r\n<hr>\r\n{% endfor %}\";}s:9:\"template3\";a:2:{s:4:\"name\";s:48:\"Liste d\'articles - résultats recherche articles\";s:7:\"content\";s:659:\"<h3>Résultat de la recherche</h3>\r\n{% if articles %}\r\n   {% for article in articles %}\r\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\r\n<h3>{{article.title}}</h3>\r\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\r\n<p>{{article.resume}}</p>\r\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\r\n</div>\r\n   {% endfor %}\r\n<div class=\"row\"></div>\r\n{% else %}\r\n<br />\r\nPas de résultats\r\n<br />\r\n<a href=\"./index.php?search_type_asked=simple_search\">>> Rechercher dans le catalogue</a>\r\n{% endif %}\";}s:9:\"template4\";a:2:{s:4:\"name\";s:49:\"Liste d\'articles - résultats recherche catalogue\";s:7:\"content\";s:509:\"{% if articles %}\r\n<h3>Lire aussi...</h3>\r\n{% endif %}\r\n   {% for article in articles %}\r\n<div style=\"width:49%;margin-right:1%;float:left;margin-bottom:5px;margin-top:5px;\">\r\n<h3>{{article.title}}</h3>\r\n<a href=\'{{article.link}}\' alt=\'{{article.title}}\' title=\"{{article.title}}\"><img style=\"float:left;margin-right:5px;\" src=\'{{article.logo.vign}}\' /></a>\r\n<p>{{article.resume}}</p>\r\n<a style=\"text-align:right;\" href=\"{{article.link}}\">Lire la suite...</a>\r\n</div>\r\n   {% endfor %}\r\n<div class=\"row\"></div>\";}}}s:37:\"cms_module_articleslist_view_carousel\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:3:{s:4:\"name\";s:29:\"Actualités en page d\'accueil\";s:7:\"content\";s:462:\"<h2>Actualités</h2>\r\n<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\' style=\"height:200px\">\r\n<h3>{{record.title}}</h3>\r\n<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\"{{record.title}}\"><img style=\"float:left;margin-right:5px;max-height:200px;max-width:200px;\" src=\'{{record.logo.large}}\' /></a>\r\n{{record.resume}}\r\n<a style=\"text-align:right;\" href=\"{{record.link}}\">Lire la suite...</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_recordslist','a:1:{s:5:\"views\";a:2:{s:36:\"cms_module_recordslist_view_carousel\";a:1:{s:9:\"templates\";a:5:{s:9:\"template1\";a:3:{s:4:\"name\";s:23:\"Notices du même auteur\";s:7:\"content\";s:382:\"{% if records %}\r\n<h3>Du même auteur</h3>\r\n{% endif %}\r\n\r\n<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\'>\r\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\r\n<img style=\"max-width:120px;max-height:95px;text-align:center;\" src=\'{{record.vign}}\'/><br />\r\n{{record.title}}\r\n<br />\r\n			</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}s:9:\"template2\";a:3:{s:4:\"name\";s:18:\"Notices similaires\";s:7:\"content\";s:378:\"{% if records %}\r\n<h3>Voir aussi</h3>\r\n{% endif %}\r\n\r\n<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\'>\r\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\r\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\r\n{{record.title}}\r\n<br />\r\n			</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}s:9:\"template3\";a:3:{s:4:\"name\";s:30:\"Notices sur la même étagère\";s:7:\"content\";s:390:\"{% if records %}\r\n<h3>Sur la même étagère</h3>\r\n{% endif %}\r\n\r\n<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\'>\r\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\r\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\r\n{{record.title}}\r\n<br />\r\n			</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}s:9:\"template4\";a:3:{s:4:\"name\";s:29:\"Nouveautés en page d\'accueil\";s:7:\"content\";s:351:\"<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\'>\r\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\' style=\"text-align:center;\">\r\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\r\n{{record.title}}\r\n<br />\r\n			</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}s:9:\"template5\";a:3:{s:4:\"name\";s:32:\"Notices dans la même catégorie\";s:7:\"content\";s:386:\"{% if records %}\r\n<h3>Sur le même sujet</h3>\r\n{% endif %}\r\n\r\n<ul id=\'carousel_{{id}}\'>\r\n	{% for record in records %}\r\n		<li class=\'{{id}}_item\'>\r\n			<a href=\'{{record.link}}\' alt=\'{{record.title}}\' title=\'{{record.title}}\'>\r\n<img style=\"max-width:120px;max-height:120px;text-align:center;\" src=\'{{record.vign}}\'/><br />\r\n{{record.title}}\r\n<br />\r\n			</a>\r\n		</li>\r\n	{% endfor %}\r\n</ul>\";s:3:\"css\";s:789:\"#{{identifiant_dom_du_cadre}} {\r\n	overflow : hidden;\r\n}\r\n		\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n#{{identifiant_dom_du_cadre}} ul li {\r\n	text-align: center;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper {\r\n	width : inherit !important;\r\n	height : inherit !important;\r\n}\r\n\r\n#{{identifiant_dom_du_cadre}} ul li a {\r\n	display: block;\r\n	width: 150px;\r\n	margin: 0 auto;\r\n	text-align: center;\r\n	text-decoration: none;\r\n}\r\n/* pour l\'image vide...*/\r\n#{{identifiant_dom_du_cadre}} .bx-wrapper ul li a img {\r\n	height: 145px;\r\n	background-repeat: no-repeat;\r\n	-moz-box-shadow: 1px 1px 2px #cccccc;\r\n    -o-box-shadow: 1px 1px 2px #cccccc;\r\n    -webkit-box-shadow: 1px 1px 2px #cccccc;\r\n    box-shadow: 1px 1px 2px #cccccc;\r\n}\";}}}s:34:\"cms_module_common_view_recordslist\";a:1:{s:9:\"templates\";a:1:{s:9:\"template1\";a:2:{s:4:\"name\";s:16:\"Liste de notices\";s:7:\"content\";s:168:\"{% if records %}\r\n<h3>Toutes les nouveautés :</h3>\r\n{% endif %}\r\n\r\n{% for record in records %}\r\n<blockquote>{{record.content}}</blockquote>\r\n<br />\r\n<hr>\r\n{% endfor %}\";}}}}}');
INSERT INTO cms_managed_modules (managed_module_name, managed_module_box) VALUES ('cms_module_metadatas','a:1:{s:6:\"module\";a:1:{s:9:\"metadatas\";a:2:{s:10:\"metadatas1\";a:5:{s:6:\"prefix\";s:2:\"og\";s:4:\"name\";s:19:\"Open Graph Protocol\";s:5:\"items\";a:7:{s:5:\"title\";a:3:{s:5:\"label\";s:5:\"titre\";s:4:\"desc\";s:5:\"Titre\";s:16:\"default_template\";s:9:\"{{title}}\";}s:4:\"type\";a:3:{s:5:\"label\";s:4:\"type\";s:4:\"desc\";s:4:\"Type\";s:16:\"default_template\";s:8:\"{{type}}\";}s:5:\"image\";a:3:{s:5:\"label\";s:4:\"logo\";s:4:\"desc\";s:17:\"Lien vers le logo\";s:16:\"default_template\";s:12:\"{{logo_url}}\";}s:3:\"url\";a:3:{s:5:\"label\";s:4:\"lien\";s:4:\"desc\";s:4:\"Lien\";s:16:\"default_template\";s:8:\"{{link}}\";}s:11:\"description\";a:3:{s:5:\"label\";s:11:\"description\";s:4:\"desc\";s:8:\"Résumé\";s:16:\"default_template\";s:10:\"{{resume}}\";}s:6:\"locale\";a:3:{s:5:\"label\";s:6:\"locale\";s:4:\"desc\";s:6:\"Langue\";s:16:\"default_template\";s:0:\"\";}s:9:\"site_name\";a:3:{s:5:\"label\";s:9:\"site_name\";s:4:\"desc\";s:11:\"Nom du site\";s:16:\"default_template\";s:0:\"\";}}s:9:\"separator\";s:1:\":\";s:14:\"group_template\";s:65:\"<meta property=\'{{key_metadata}}\' content=\'{{value_metadata}}\' />\";}s:10:\"metadatas2\";a:5:{s:6:\"prefix\";s:7:\"twitter\";s:4:\"name\";s:13:\"Twitter Cards\";s:5:\"items\";a:5:{s:5:\"title\";a:3:{s:5:\"label\";s:5:\"titre\";s:4:\"desc\";s:5:\"Titre\";s:16:\"default_template\";s:9:\"{{title}}\";}s:4:\"card\";a:3:{s:5:\"label\";s:4:\"card\";s:4:\"desc\";s:8:\"Résumé\";s:16:\"default_template\";s:0:\"\";}s:11:\"description\";a:3:{s:5:\"label\";s:11:\"description\";s:4:\"desc\";s:11:\"Description\";s:16:\"default_template\";s:10:\"{{resume}}\";}s:5:\"image\";a:3:{s:5:\"label\";s:4:\"logo\";s:4:\"desc\";s:17:\"Lien vers le logo\";s:16:\"default_template\";s:12:\"{{logo_url}}\";}s:4:\"site\";a:3:{s:5:\"label\";s:4:\"site\";s:4:\"desc\";s:4:\"Site\";s:16:\"default_template\";s:0:\"\";}}s:9:\"separator\";s:1:\":\";s:14:\"group_template\";s:61:\"<meta name=\'{{key_metadata}}\' content=\'{{value_metadata}}\' />\";}}}}');
/*!40000 ALTER TABLE cms_managed_modules ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_modules_extensions_datas`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_modules_extensions_datas (
  id_extension_datas int(10) NOT NULL AUTO_INCREMENT,
  extension_datas_module varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  extension_datas_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  extension_datas_type_element varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  extension_datas_num_element int(10) NOT NULL DEFAULT '0',
  extension_datas_datas blob,
  PRIMARY KEY (id_extension_datas)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_modules_extensions_datas`
--

LOCK TABLES cms_modules_extensions_datas WRITE;
/*!40000 ALTER TABLE cms_modules_extensions_datas DISABLE KEYS */;
/*!40000 ALTER TABLE cms_modules_extensions_datas ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_pages`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_pages (
  id_page int(10) unsigned NOT NULL AUTO_INCREMENT,
  page_hash varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  page_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  page_description mediumtext COLLATE utf8_unicode_ci NOT NULL,
  page_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_page)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_pages`
--

LOCK TABLES cms_pages WRITE;
/*!40000 ALTER TABLE cms_pages DISABLE KEYS */;
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (3,'fcfe834ffc06fa3e6b835251133a6a13','Page d\'accueil','','');
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (4,'efc1707ceca893eb2d7804c3abd89f0e','Page qui affiche un article et une liste de notices','','');
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (7,'9ecfe7bf4dbf49d4a1c06af16c79b765','Page qui affiche une notice','','');
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (6,'a7ff1dbe48408fea5dbbd570430ca54c','Page qui affiche une rubrique','','');
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (9,'a009d0ba2c9f870ff5c3c738a471b916','Page qui affiche une liste d\'evenements','','');
INSERT INTO cms_pages (id_page, page_hash, page_name, page_description, page_classement) VALUES (11,'35fb5d441fefa3686fc8940046514026','Page qui affiche une liste d\'articles (resultat)','','');
/*!40000 ALTER TABLE cms_pages ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_pages_env`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_pages_env (
  page_env_num_page int(10) unsigned NOT NULL AUTO_INCREMENT,
  page_env_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  page_env_id_selector varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (page_env_num_page)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_pages_env`
--

LOCK TABLES cms_pages_env WRITE;
/*!40000 ALTER TABLE cms_pages_env DISABLE KEYS */;
/*!40000 ALTER TABLE cms_pages_env ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_sections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_sections (
  id_section int(10) unsigned NOT NULL AUTO_INCREMENT,
  section_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  section_resume mediumtext COLLATE utf8_unicode_ci NOT NULL,
  section_logo mediumblob NOT NULL,
  section_publication_state varchar(50) COLLATE utf8_unicode_ci NOT NULL,
  section_start_date datetime DEFAULT NULL,
  section_end_date datetime DEFAULT NULL,
  section_num_parent int(11) NOT NULL DEFAULT '0',
  section_num_type int(10) unsigned NOT NULL DEFAULT '0',
  section_creation_date date DEFAULT NULL,
  section_order int(10) unsigned DEFAULT '0',
  section_update_timestamp timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (id_section),
  KEY i_cms_section_title (section_title),
  KEY i_cms_section_publication_state (section_publication_state),
  KEY i_cms_section_num_parent (section_num_parent)
) ENGINE=MyISAM AUTO_INCREMENT=15 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_sections`
--

LOCK TABLES cms_sections WRITE;
/*!40000 ALTER TABLE cms_sections DISABLE KEYS */;
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (1,'Animations','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',12,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (2,'Sélections','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',12,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (3,'Infos pratiques','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',12,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (4,'Evénements','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',1,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (5,'Heure du conte','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',1,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (7,'Nouveautés','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',2,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (8,'Coups de coeur','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',2,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (9,'La bibliothèque','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',3,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (10,'Inscription et prêt','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',3,1,'2012-10-25',0,'2012-10-24 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (12,'Menu principal','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',0,1,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (13,'Brèves','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',0,1,'2012-10-26',0,'2012-10-25 22:00:00');
INSERT INTO cms_sections (id_section, section_title, section_resume, section_logo, section_publication_state, section_start_date, section_end_date, section_num_parent, section_num_type, section_creation_date, section_order, section_update_timestamp) VALUES (14,'Archives','<br _moz_editor_bogus_node=\"TRUE\" />','','2','0000-00-00 00:00:00','0000-00-00 00:00:00',0,1,'2012-11-17',0,'2012-11-16 23:00:00');
/*!40000 ALTER TABLE cms_sections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_sections_descriptors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_sections_descriptors (
  num_section int(11) NOT NULL DEFAULT '0',
  num_noeud int(11) NOT NULL DEFAULT '0',
  section_descriptor_order int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_section,num_noeud)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_sections_descriptors`
--

LOCK TABLES cms_sections_descriptors WRITE;
/*!40000 ALTER TABLE cms_sections_descriptors DISABLE KEYS */;
/*!40000 ALTER TABLE cms_sections_descriptors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_vars`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_vars (
  id_var int(10) unsigned NOT NULL AUTO_INCREMENT,
  var_num_page int(10) unsigned NOT NULL DEFAULT '0',
  var_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  var_comment varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_var)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_vars`
--

LOCK TABLES cms_vars WRITE;
/*!40000 ALTER TABLE cms_vars DISABLE KEYS */;
INSERT INTO cms_vars (id_var, var_num_page, var_name, var_comment) VALUES (6,4,'id_article','Identifiant de l\'article');
INSERT INTO cms_vars (id_var, var_num_page, var_name, var_comment) VALUES (7,7,'id_notice','Identifiant de la notice');
INSERT INTO cms_vars (id_var, var_num_page, var_name, var_comment) VALUES (4,6,'id_rubrique','Identifiant de la rubrique');
INSERT INTO cms_vars (id_var, var_num_page, var_name, var_comment) VALUES (10,9,'id_date','Identifiant de date');
/*!40000 ALTER TABLE cms_vars ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cms_version`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE cms_version (
  id_version int(10) unsigned NOT NULL AUTO_INCREMENT,
  version_cms_num int(10) unsigned NOT NULL DEFAULT '0',
  version_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  version_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  version_public int(10) unsigned NOT NULL DEFAULT '0',
  version_user int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_version)
) ENGINE=MyISAM AUTO_INCREMENT=184 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cms_version`
--

LOCK TABLES cms_version WRITE;
/*!40000 ALTER TABLE cms_version DISABLE KEYS */;
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (1,1,'2012-10-25 09:38:52','Création',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (2,1,'2012-10-25 11:07:29','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (3,1,'2012-10-25 11:08:10','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (4,1,'2012-10-25 11:11:37','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (5,1,'2012-10-25 11:12:22','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (6,1,'2012-10-25 11:40:20','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (7,1,'2012-10-25 12:19:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (8,1,'2012-10-25 12:20:41','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (9,1,'2012-10-25 12:22:47','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (10,1,'2012-10-25 12:24:06','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (11,1,'2012-10-25 12:36:23','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (12,1,'2012-10-25 12:37:46','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (13,1,'2012-10-25 13:30:58','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (14,1,'2012-10-25 13:43:07','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (15,1,'2012-10-25 13:43:37','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (16,1,'2012-10-25 13:45:23','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (17,1,'2012-10-25 13:48:55','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (18,1,'2012-10-25 13:55:56','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (19,1,'2012-10-25 13:59:02','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (20,1,'2012-10-25 13:59:30','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (21,1,'2012-10-25 13:59:52','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (22,1,'2012-10-25 14:00:36','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (23,1,'2012-10-25 14:03:07','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (24,1,'2012-10-25 14:07:28','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (25,1,'2012-10-25 14:08:44','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (26,1,'2012-10-25 14:10:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (27,1,'2012-10-25 14:13:15','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (28,1,'2012-10-25 14:14:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (29,1,'2012-10-25 14:14:38','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (30,1,'2012-10-25 14:16:57','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (31,1,'2012-10-25 14:19:27','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (32,1,'2012-10-25 14:23:19','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (33,1,'2012-10-25 14:25:59','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (34,1,'2012-10-25 14:26:58','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (35,1,'2012-10-25 14:30:53','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (36,1,'2012-10-25 14:31:41','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (37,1,'2012-10-25 14:41:25','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (38,1,'2012-10-25 14:42:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (39,1,'2012-10-25 14:44:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (40,1,'2012-10-25 14:47:50','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (41,1,'2012-10-25 14:48:52','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (42,1,'2012-10-25 14:49:51','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (43,1,'2012-10-25 14:51:43','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (44,1,'2012-10-25 14:55:36','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (45,1,'2012-10-25 14:58:23','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (46,1,'2012-10-25 14:59:09','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (47,1,'2012-10-25 15:00:46','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (48,1,'2012-10-25 15:01:15','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (49,1,'2012-10-25 15:01:53','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (50,1,'2012-10-25 15:04:25','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (51,1,'2012-10-25 15:05:12','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (52,1,'2012-10-25 15:07:19','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (53,1,'2012-10-25 15:08:25','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (54,1,'2012-10-25 15:09:28','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (55,1,'2012-10-25 15:10:43','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (56,1,'2012-10-25 15:14:32','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (57,1,'2012-10-25 15:24:22','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (58,1,'2012-10-25 15:26:03','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (59,1,'2012-10-25 15:31:11','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (60,1,'2012-10-25 15:35:16','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (61,1,'2012-10-25 15:38:46','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (62,1,'2012-10-25 15:41:09','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (63,1,'2012-10-25 15:43:28','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (64,1,'2012-10-25 15:44:16','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (65,1,'2012-10-25 15:45:08','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (66,1,'2012-10-25 15:45:34','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (67,1,'2012-10-25 15:45:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (68,1,'2012-10-25 15:47:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (69,1,'2012-10-25 16:02:27','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (70,1,'2012-10-25 16:03:29','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (71,1,'2012-10-25 16:09:54','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (72,1,'2012-10-25 16:10:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (73,1,'2012-10-25 16:13:15','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (74,1,'2012-10-25 16:14:53','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (75,1,'2012-10-25 16:15:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (76,1,'2012-10-25 16:19:34','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (77,1,'2012-10-25 16:24:08','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (78,1,'2012-10-25 16:28:59','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (79,1,'2012-10-25 16:33:16','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (80,1,'2012-10-25 16:36:35','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (81,1,'2012-10-25 16:40:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (82,1,'2012-10-25 17:01:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (83,1,'2012-10-25 17:03:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (84,1,'2012-10-25 17:06:29','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (85,1,'2012-10-25 17:08:50','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (86,1,'2012-10-25 17:20:48','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (87,1,'2012-10-25 17:23:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (88,1,'2012-10-25 17:30:30','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (89,1,'2012-10-25 17:32:14','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (90,1,'2012-10-25 17:33:10','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (91,1,'2012-10-25 17:34:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (92,1,'2012-10-25 17:35:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (93,1,'2012-10-25 17:36:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (94,1,'2012-10-25 17:37:48','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (95,1,'2012-10-25 18:24:41','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (96,1,'2012-10-26 10:30:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (97,1,'2012-10-26 10:33:07','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (98,1,'2012-10-26 10:41:23','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (99,1,'2012-10-26 10:53:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (100,1,'2012-10-26 15:35:12','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (101,1,'2012-10-26 15:44:55','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (102,1,'2012-10-26 15:52:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (103,1,'2012-10-26 15:53:24','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (104,1,'2012-10-26 15:55:23','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (105,1,'2012-10-26 15:57:02','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (106,1,'2012-10-26 15:59:08','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (107,1,'2012-10-26 16:00:43','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (108,1,'2012-10-26 16:07:48','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (109,1,'2012-10-26 16:10:20','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (110,1,'2012-10-26 16:23:52','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (111,1,'2012-10-26 16:26:14','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (112,1,'2012-10-26 16:28:24','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (113,1,'2012-10-26 16:29:47','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (114,1,'2012-10-26 16:33:06','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (115,1,'2012-10-26 16:44:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (116,1,'2012-10-26 16:50:48','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (117,1,'2012-10-26 16:54:12','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (118,1,'2012-10-26 16:55:18','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (119,1,'2012-10-26 16:56:11','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (120,1,'2012-10-26 17:01:06','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (121,1,'2012-10-26 17:02:28','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (122,1,'2012-10-26 17:04:35','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (123,1,'2012-10-26 17:11:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (124,1,'2012-10-26 17:13:21','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (125,1,'2012-10-26 17:19:08','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (126,1,'2012-10-26 17:19:54','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (127,1,'2012-10-26 17:20:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (128,1,'2012-10-26 17:23:20','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (129,1,'2012-10-26 17:24:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (130,1,'2012-10-27 10:24:56','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (131,1,'2012-10-27 10:25:48','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (132,1,'2012-10-27 10:26:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (133,1,'2012-10-27 10:26:58','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (134,1,'2012-10-27 10:27:56','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (135,1,'2012-10-27 10:28:28','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (136,1,'2012-10-27 10:29:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (137,1,'2012-10-27 10:31:15','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (138,1,'2012-10-27 10:31:42','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (139,1,'2012-10-27 10:32:09','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (140,1,'2012-10-27 10:32:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (141,1,'2012-10-27 10:33:53','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (142,1,'2012-10-27 10:35:26','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (143,1,'2012-10-27 10:36:56','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (144,1,'2012-10-27 10:37:20','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (145,1,'2012-10-27 10:46:26','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (146,1,'2012-10-27 11:47:25','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (147,1,'2012-10-27 12:21:49','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (148,1,'2012-10-27 13:09:33','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (149,1,'2012-10-27 13:11:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (150,1,'2012-10-27 13:14:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (151,1,'2012-10-27 13:16:31','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (152,1,'2012-10-27 13:24:05','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (153,1,'2012-10-27 13:27:24','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (154,1,'2012-10-27 13:28:09','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (155,1,'2012-10-27 13:29:21','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (156,1,'2012-10-27 13:40:09','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (157,1,'2012-10-27 13:57:37','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (158,1,'2012-10-27 14:00:13','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (159,1,'2012-10-27 14:11:04','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (160,1,'2012-10-27 17:29:26','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (161,1,'2012-10-27 17:35:26','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (162,1,'2012-10-27 17:37:15','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (163,1,'2012-10-27 17:38:19','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (164,1,'2012-10-27 17:41:35','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (165,1,'2012-10-27 17:43:22','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (166,1,'2012-10-27 17:43:45','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (167,1,'2012-10-27 18:24:57','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (168,1,'2012-10-27 18:26:10','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (169,1,'2012-10-27 18:27:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (170,1,'2012-10-27 18:27:26','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (171,1,'2012-10-27 18:27:56','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (172,1,'2012-10-27 18:32:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (173,1,'2012-10-27 18:32:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (174,1,'2012-10-28 18:42:11','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (175,1,'2012-10-28 18:45:06','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (176,1,'2012-10-28 18:53:39','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (177,1,'2012-11-20 14:35:27','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (178,1,'2012-11-20 15:23:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (179,1,'2012-12-11 13:59:01','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (180,1,'2012-12-11 13:59:20','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (181,1,'2012-12-11 17:42:32','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (182,1,'2012-12-11 17:58:55','',0,1);
INSERT INTO cms_version (id_version, version_cms_num, version_date, version_comment, version_public, version_user) VALUES (183,1,'2012-12-11 18:00:33','',0,1);
/*!40000 ALTER TABLE cms_version ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collection_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collection_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collection_custom`
--

LOCK TABLES collection_custom WRITE;
/*!40000 ALTER TABLE collection_custom DISABLE KEYS */;
/*!40000 ALTER TABLE collection_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collection_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collection_custom_lists (
  collection_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  collection_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  collection_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (collection_custom_champ),
  KEY editorial_champ_list_value (collection_custom_champ,collection_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collection_custom_lists`
--

LOCK TABLES collection_custom_lists WRITE;
/*!40000 ALTER TABLE collection_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE collection_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collection_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collection_custom_values (
  collection_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  collection_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  collection_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  collection_custom_text text COLLATE utf8_unicode_ci,
  collection_custom_integer int(11) DEFAULT NULL,
  collection_custom_date date DEFAULT NULL,
  collection_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (collection_custom_champ),
  KEY editorial_custom_origine (collection_custom_origine),
  KEY i_ccv_st (collection_custom_small_text),
  KEY i_ccv_t (collection_custom_text(255)),
  KEY i_ccv_i (collection_custom_integer),
  KEY i_ccv_d (collection_custom_date),
  KEY i_ccv_f (collection_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collection_custom_values`
--

LOCK TABLES collection_custom_values WRITE;
/*!40000 ALTER TABLE collection_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE collection_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collections (
  collection_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  collection_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collection_parent mediumint(8) unsigned NOT NULL DEFAULT '0',
  collection_issn varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_coll mediumtext COLLATE utf8_unicode_ci,
  collection_web mediumtext COLLATE utf8_unicode_ci NOT NULL,
  collection_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  authority_import_denied int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (collection_id),
  KEY collection_name (collection_name),
  KEY collection_parent (collection_parent)
) ENGINE=MyISAM AUTO_INCREMENT=29 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collections`
--

LOCK TABLES collections WRITE;
/*!40000 ALTER TABLE collections DISABLE KEYS */;
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (4,'Écoutez lire',13,'',' ecoutez lire ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (5,'Collection dirigée par Henri Gougaud',6,'',' collection dirigee par henri gougaud ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (6,'Un Livre, un cd',9,'1766-148X',' livre cd ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (7,'Crea.jeunesse',6,'',' crea jeunesse ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (8,'Bayou',13,'',' bayou ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (9,'Fragments',15,'',' fragments ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (10,'L.d.p.jeunesse',17,'',' p jeunesse ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (12,'Sagesse d\'un métier',19,'',' sagesse metier ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (13,'Le métier de',20,'',' metier ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (14,'Que sais-je ?',21,'',' que sais je ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (16,'Collection Série noire',13,'',' collection serie noire ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (17,'Folio cadet',23,'',' folio cadet ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (18,'Les encyclopes',26,'',' encyclopes ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (19,'À petits petons',9,'',' petits petons ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (20,'Kididoc',29,'',' kididoc ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (21,'Folio',13,'',' folio ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (24,'Littérature étrangère',35,'',' litterature etrangere ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (25,'Revue dada',36,'',' revue dada ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (26,'Album',37,'',' album ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (27,'Mes Premières Découvertes de la Musique',38,'',' mes premieres decouvertes musique ','','',0);
INSERT INTO collections (collection_id, collection_name, collection_parent, collection_issn, index_coll, collection_web, collection_comment, authority_import_denied) VALUES (28,'Collection Warner',40,'',' collection warner ','','',0);
/*!40000 ALTER TABLE collections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collections_state`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collections_state (
  collstate_id int(8) NOT NULL AUTO_INCREMENT,
  id_serial mediumint(8) unsigned NOT NULL DEFAULT '0',
  location_id smallint(5) unsigned NOT NULL DEFAULT '0',
  state_collections mediumtext COLLATE utf8_unicode_ci NOT NULL,
  collstate_emplacement int(8) unsigned NOT NULL DEFAULT '0',
  collstate_type int(8) unsigned NOT NULL DEFAULT '0',
  collstate_origine varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collstate_cote varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collstate_archive varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collstate_statut int(8) unsigned NOT NULL DEFAULT '0',
  collstate_lacune mediumtext COLLATE utf8_unicode_ci NOT NULL,
  collstate_note mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (collstate_id),
  KEY i_colls_arc (collstate_archive),
  KEY i_colls_empl (collstate_emplacement),
  KEY i_colls_type (collstate_type),
  KEY i_colls_orig (collstate_origine),
  KEY i_colls_cote (collstate_cote),
  KEY i_colls_stat (collstate_statut),
  KEY i_colls_serial (id_serial),
  KEY i_colls_loc (location_id)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collections_state`
--

LOCK TABLES collections_state WRITE;
/*!40000 ALTER TABLE collections_state DISABLE KEYS */;
INSERT INTO collections_state (collstate_id, id_serial, location_id, state_collections, collstate_emplacement, collstate_type, collstate_origine, collstate_cote, collstate_archive, collstate_statut, collstate_lacune, collstate_note) VALUES (2,124,1,'T. 28, n° 5, 1983 -',4,2,'','','',3,'','');
INSERT INTO collections_state (collstate_id, id_serial, location_id, state_collections, collstate_emplacement, collstate_type, collstate_origine, collstate_cote, collstate_archive, collstate_statut, collstate_lacune, collstate_note) VALUES (3,120,1,'N° 393, 2011 ; N° 402, 2012 - ',2,1,'','PER GEO','',1,'','');
INSERT INTO collections_state (collstate_id, id_serial, location_id, state_collections, collstate_emplacement, collstate_type, collstate_origine, collstate_cote, collstate_archive, collstate_statut, collstate_lacune, collstate_note) VALUES (4,129,1,'2012 -',1,1,'','PER J GEO','',1,'','');
INSERT INTO collections_state (collstate_id, id_serial, location_id, state_collections, collstate_emplacement, collstate_type, collstate_origine, collstate_cote, collstate_archive, collstate_statut, collstate_lacune, collstate_note) VALUES (5,132,1,'1 année',1,1,'','PER STU','',1,'','');
/*!40000 ALTER TABLE collections_state ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collstate_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collstate_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) NOT NULL DEFAULT '0',
  search int(11) NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collstate_custom`
--

LOCK TABLES collstate_custom WRITE;
/*!40000 ALTER TABLE collstate_custom DISABLE KEYS */;
/*!40000 ALTER TABLE collstate_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collstate_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collstate_custom_lists (
  collstate_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  collstate_custom_list_value varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  collstate_custom_list_lib varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ordre int(11) NOT NULL DEFAULT '0',
  KEY collstate_custom_champ (collstate_custom_champ),
  KEY i_ccl_lv (collstate_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collstate_custom_lists`
--

LOCK TABLES collstate_custom_lists WRITE;
/*!40000 ALTER TABLE collstate_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE collstate_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `collstate_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE collstate_custom_values (
  collstate_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  collstate_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  collstate_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  collstate_custom_text mediumtext COLLATE utf8_unicode_ci,
  collstate_custom_integer int(11) DEFAULT NULL,
  collstate_custom_date date DEFAULT NULL,
  collstate_custom_float float DEFAULT NULL,
  KEY collstate_custom_champ (collstate_custom_champ),
  KEY collstate_custom_origine (collstate_custom_origine),
  KEY i_ccv_st (collstate_custom_small_text),
  KEY i_ccv_t (collstate_custom_text(255)),
  KEY i_ccv_i (collstate_custom_integer),
  KEY i_ccv_d (collstate_custom_date),
  KEY i_ccv_f (collstate_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `collstate_custom_values`
--

LOCK TABLES collstate_custom_values WRITE;
/*!40000 ALTER TABLE collstate_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE collstate_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comptes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE comptes (
  id_compte int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  type_compte_id int(10) unsigned NOT NULL DEFAULT '0',
  solde decimal(16,2) DEFAULT '0.00',
  prepay_mnt decimal(16,2) NOT NULL DEFAULT '0.00',
  proprio_id int(10) unsigned NOT NULL DEFAULT '0',
  droits mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_compte),
  KEY i_cpt_proprio_id (proprio_id)
) ENGINE=MyISAM AUTO_INCREMENT=17 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comptes`
--

LOCK TABLES comptes WRITE;
/*!40000 ALTER TABLE comptes DISABLE KEYS */;
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (1,'Created on 2012-10-24',2,0.00,0.00,9,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (2,'Created on 2012-10-24',1,0.00,0.00,9,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (3,'Created on 2012-10-24',1,0.00,0.00,10,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (4,'Created on 2012-10-24',2,0.00,0.00,10,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (5,'Created on 2012-10-24',1,0.00,0.00,6,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (6,'Created on 2012-10-24',2,0.00,0.00,6,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (7,'Created on 2012-10-24',1,0.00,0.00,1,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (8,'Created on 2012-10-24',2,0.00,0.00,1,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (9,'Created on 2012-10-24',1,0.00,0.00,5,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (10,'Created on 2012-10-24',2,0.00,0.00,5,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (11,'Created on 2012-10-24',1,0.00,0.00,4,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (12,'Created on 2012-10-24',2,0.00,0.00,4,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (13,'Created on 2012-10-24',1,0.00,0.00,2,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (14,'Created on 2012-10-24',2,0.00,0.00,2,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (15,'Created on 2012-11-20',1,0.00,0.00,7,'');
INSERT INTO comptes (id_compte, libelle, type_compte_id, solde, prepay_mnt, proprio_id, droits) VALUES (16,'Created on 2012-11-20',2,0.00,0.00,7,'');
/*!40000 ALTER TABLE comptes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  repository int(11) NOT NULL DEFAULT '0',
  timeout int(11) NOT NULL DEFAULT '5',
  retry int(11) NOT NULL DEFAULT '3',
  ttl int(11) NOT NULL DEFAULT '1440',
  PRIMARY KEY (connector_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors`
--

LOCK TABLES connectors WRITE;
/*!40000 ALTER TABLE connectors DISABLE KEYS */;
/*!40000 ALTER TABLE connectors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_categ`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_categ (
  connectors_categ_id smallint(5) NOT NULL AUTO_INCREMENT,
  connectors_categ_name varchar(64) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  opac_expanded smallint(6) NOT NULL DEFAULT '0',
  PRIMARY KEY (connectors_categ_id)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_categ`
--

LOCK TABLES connectors_categ WRITE;
/*!40000 ALTER TABLE connectors_categ DISABLE KEYS */;
INSERT INTO connectors_categ (connectors_categ_id, connectors_categ_name, opac_expanded) VALUES (1,'Catalogues de bibliothèques',1);
INSERT INTO connectors_categ (connectors_categ_id, connectors_categ_name, opac_expanded) VALUES (2,'Sources non disponibles pour la recherche externe',0);
INSERT INTO connectors_categ (connectors_categ_id, connectors_categ_name, opac_expanded) VALUES (3,'Bases de données et archives ouvertes',1);
/*!40000 ALTER TABLE connectors_categ ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_categ_sources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_categ_sources (
  num_categ smallint(6) NOT NULL DEFAULT '0',
  num_source smallint(6) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_categ,num_source),
  KEY i_num_source (num_source)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_categ_sources`
--

LOCK TABLES connectors_categ_sources WRITE;
/*!40000 ALTER TABLE connectors_categ_sources DISABLE KEYS */;
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (1,5);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (1,6);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (2,1);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (2,2);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (2,3);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (2,4);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (3,7);
INSERT INTO connectors_categ_sources (num_categ, num_source) VALUES (3,8);
/*!40000 ALTER TABLE connectors_categ_sources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out (
  connectors_out_id int(11) NOT NULL AUTO_INCREMENT,
  connectors_out_config longblob NOT NULL,
  PRIMARY KEY (connectors_out_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out`
--

LOCK TABLES connectors_out WRITE;
/*!40000 ALTER TABLE connectors_out DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_oai_deleted_records`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_oai_deleted_records (
  num_set int(11) unsigned NOT NULL DEFAULT '0',
  num_notice int(11) unsigned NOT NULL DEFAULT '0',
  deletion_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (num_set,num_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_oai_deleted_records`
--

LOCK TABLES connectors_out_oai_deleted_records WRITE;
/*!40000 ALTER TABLE connectors_out_oai_deleted_records DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_oai_deleted_records ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_oai_tokens`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_oai_tokens (
  connectors_out_oai_token_token varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  connectors_out_oai_token_environnement mediumtext COLLATE utf8_unicode_ci NOT NULL,
  connectors_out_oai_token_expirationdate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (connectors_out_oai_token_token)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_oai_tokens`
--

LOCK TABLES connectors_out_oai_tokens WRITE;
/*!40000 ALTER TABLE connectors_out_oai_tokens DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_oai_tokens ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_setcache_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_setcache_values (
  connectors_out_setcache_values_cachenum int(11) NOT NULL DEFAULT '0',
  connectors_out_setcache_values_value int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (connectors_out_setcache_values_cachenum,connectors_out_setcache_values_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_setcache_values`
--

LOCK TABLES connectors_out_setcache_values WRITE;
/*!40000 ALTER TABLE connectors_out_setcache_values DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_setcache_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_setcaches`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_setcaches (
  connectors_out_setcache_id int(11) NOT NULL AUTO_INCREMENT,
  connectors_out_setcache_setnum int(11) NOT NULL DEFAULT '0',
  connectors_out_setcache_lifeduration int(4) NOT NULL DEFAULT '0',
  connectors_out_setcache_lifeduration_unit enum('seconds','minutes','hours','days','weeks','months') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'seconds',
  connectors_out_setcache_lastupdatedate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (connectors_out_setcache_id),
  UNIQUE KEY connectors_out_setcache_setnum (connectors_out_setcache_setnum)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_setcaches`
--

LOCK TABLES connectors_out_setcaches WRITE;
/*!40000 ALTER TABLE connectors_out_setcaches DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_setcaches ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_setcateg_sets`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_setcateg_sets (
  connectors_out_setcategset_setnum int(11) NOT NULL,
  connectors_out_setcategset_categnum int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (connectors_out_setcategset_setnum,connectors_out_setcategset_categnum)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_setcateg_sets`
--

LOCK TABLES connectors_out_setcateg_sets WRITE;
/*!40000 ALTER TABLE connectors_out_setcateg_sets DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_setcateg_sets ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_setcategs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_setcategs (
  connectors_out_setcateg_id int(11) NOT NULL AUTO_INCREMENT,
  connectors_out_setcateg_name varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connectors_out_setcateg_id),
  UNIQUE KEY connectors_out_setcateg_name (connectors_out_setcateg_name)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_setcategs`
--

LOCK TABLES connectors_out_setcategs WRITE;
/*!40000 ALTER TABLE connectors_out_setcategs DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_setcategs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_sets`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_sets (
  connector_out_set_id int(11) NOT NULL AUTO_INCREMENT,
  connector_out_set_caption varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  connector_out_set_type int(4) NOT NULL DEFAULT '0',
  connector_out_set_config longblob NOT NULL,
  being_refreshed int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (connector_out_set_id),
  UNIQUE KEY connector_out_set_caption (connector_out_set_caption)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_sets`
--

LOCK TABLES connectors_out_sets WRITE;
/*!40000 ALTER TABLE connectors_out_sets DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_sets ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_sources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_sources (
  connectors_out_source_id int(11) NOT NULL AUTO_INCREMENT,
  connectors_out_sources_connectornum int(11) NOT NULL DEFAULT '0',
  connectors_out_source_name varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  connectors_out_source_comment varchar(200) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  connectors_out_source_config longblob NOT NULL,
  PRIMARY KEY (connectors_out_source_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_sources`
--

LOCK TABLES connectors_out_sources WRITE;
/*!40000 ALTER TABLE connectors_out_sources DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_sources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_out_sources_esgroups`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_out_sources_esgroups (
  connectors_out_source_esgroup_sourcenum int(11) NOT NULL DEFAULT '0',
  connectors_out_source_esgroup_esgroupnum int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (connectors_out_source_esgroup_sourcenum,connectors_out_source_esgroup_esgroupnum)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_out_sources_esgroups`
--

LOCK TABLES connectors_out_sources_esgroups WRITE;
/*!40000 ALTER TABLE connectors_out_sources_esgroups DISABLE KEYS */;
/*!40000 ALTER TABLE connectors_out_sources_esgroups ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connectors_sources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE connectors_sources (
  source_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  id_connector varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  parameters longtext COLLATE utf8_unicode_ci NOT NULL,
  `comment` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  repository int(11) NOT NULL DEFAULT '0',
  timeout int(11) NOT NULL DEFAULT '5',
  retry int(11) NOT NULL DEFAULT '3',
  ttl int(11) NOT NULL DEFAULT '1440',
  opac_allowed int(3) unsigned NOT NULL DEFAULT '0',
  rep_upload int(11) NOT NULL DEFAULT '0',
  upload_doc_num int(11) NOT NULL DEFAULT '1',
  enrichment int(11) NOT NULL DEFAULT '0',
  opac_affiliate_search int(11) NOT NULL DEFAULT '0',
  opac_selected int(3) unsigned NOT NULL DEFAULT '0',
  type_enrichment_allowed mediumtext COLLATE utf8_unicode_ci NOT NULL,
  ico_notice varchar(256) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  last_sync_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (source_id)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connectors_sources`
--

LOCK TABLES connectors_sources WRITE;
/*!40000 ALTER TABLE connectors_sources DISABLE KEYS */;
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (1,'google_book','a:2:{s:5:\"width\";i:500;s:6:\"height\";i:500;}','','Google Book',2,5,3,1800,1,0,0,1,0,0,'a:1:{i:0;s:5:\"books\";}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (2,'babelio','a:0:{}','','Babélio',2,5,3,1800,1,0,1,1,0,0,'a:2:{i:0;s:8:\"citation\";i:1;s:8:\"critique\";}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (3,'wikipedia','a:0:{}','','Wikipédia',2,5,3,1800,1,0,1,1,0,0,'a:2:{i:0;s:4:\"wiki\";i:1;s:3:\"bio\";}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (4,'youtube','a:0:{}','','YouTube',2,5,3,1800,1,0,1,1,0,0,'a:1:{i:0;s:7:\"youtube\";}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (5,'z3950','a:10:{s:3:\"url\";s:12:\"z3950.bnf.fr\";s:10:\"z3950_base\";s:9:\"TOUT-UTF8\";s:11:\"z3950_login\";s:5:\"Z3950\";s:14:\"z3950_password\";s:9:\"Z3950_BNF\";s:17:\"z3950_max_notices\";s:3:\"100\";s:12:\"z3950_format\";s:7:\"UNIMARC\";s:10:\"z3950_port\";s:4:\"2211\";s:13:\"z3950_convert\";s:1:\"0\";s:12:\"z3950_profil\";s:11:\"very_simple\";s:10:\"z3950_bib1\";a:546:{s:19:\"bib1_200a_BOOLEAN_0\";s:1:\"4\";s:19:\"bib1_200a_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_0\";s:1:\"4\";s:21:\"bib1_200a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_0\";s:1:\"4\";s:19:\"bib1_200a_ENDWITH_1\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_2\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_3\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_4\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_5\";s:0:\"\";s:17:\"bib1_200a_EXACT_0\";s:1:\"4\";s:17:\"bib1_200a_EXACT_1\";s:0:\"\";s:17:\"bib1_200a_EXACT_2\";s:0:\"\";s:17:\"bib1_200a_EXACT_3\";s:0:\"\";s:17:\"bib1_200a_EXACT_4\";s:0:\"\";s:17:\"bib1_200a_EXACT_5\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_0\";s:25:\"4,5,1003,7,8,1214,1018,21\";s:18:\"bib1_XXX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_5\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_0\";s:4:\"1003\";s:18:\"bib1_7XX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_0\";s:4:\"1003\";s:20:\"bib1_7XX_STARTWITH_1\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_2\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_3\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_4\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_5\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_0\";s:4:\"1003\";s:18:\"bib1_7XX_ENDWITH_1\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_2\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_3\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_4\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_5\";s:0:\"\";s:16:\"bib1_7XX_EXACT_0\";s:4:\"1003\";s:16:\"bib1_7XX_EXACT_1\";s:0:\"\";s:16:\"bib1_7XX_EXACT_2\";s:0:\"\";s:16:\"bib1_7XX_EXACT_3\";s:0:\"\";s:16:\"bib1_7XX_EXACT_4\";s:0:\"\";s:16:\"bib1_7XX_EXACT_5\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_0\";s:4:\"1018\";s:19:\"bib1_210c_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_0\";s:4:\"1018\";s:21:\"bib1_210c_STARTWITH_1\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_2\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_3\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_4\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_5\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_0\";s:4:\"1018\";s:19:\"bib1_210c_ENDWITH_1\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_2\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_3\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_4\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_5\";s:0:\"\";s:17:\"bib1_210c_EXACT_0\";s:4:\"1018\";s:17:\"bib1_210c_EXACT_1\";s:0:\"\";s:17:\"bib1_210c_EXACT_2\";s:0:\"\";s:17:\"bib1_210c_EXACT_3\";s:0:\"\";s:17:\"bib1_210c_EXACT_4\";s:0:\"\";s:17:\"bib1_210c_EXACT_5\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_0\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_1\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_2\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_3\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_4\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_5\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_0\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_1\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_2\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_3\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_4\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_5\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_0\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_1\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_2\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_3\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_4\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_5\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_0\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_1\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_2\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_3\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_4\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_5\";s:0:\"\";s:17:\"bib1_210d_EXACT_0\";s:0:\"\";s:17:\"bib1_210d_EXACT_1\";s:0:\"\";s:17:\"bib1_210d_EXACT_2\";s:0:\"\";s:17:\"bib1_210d_EXACT_3\";s:0:\"\";s:17:\"bib1_210d_EXACT_4\";s:0:\"\";s:17:\"bib1_210d_EXACT_5\";s:0:\"\";s:14:\"bib1_210d_EQ_0\";s:0:\"\";s:14:\"bib1_210d_EQ_1\";s:0:\"\";s:14:\"bib1_210d_EQ_2\";s:0:\"\";s:14:\"bib1_210d_EQ_3\";s:0:\"\";s:14:\"bib1_210d_EQ_4\";s:0:\"\";s:14:\"bib1_210d_EQ_5\";s:0:\"\";s:14:\"bib1_210d_LT_0\";s:0:\"\";s:14:\"bib1_210d_LT_1\";s:0:\"\";s:14:\"bib1_210d_LT_2\";s:0:\"\";s:14:\"bib1_210d_LT_3\";s:0:\"\";s:14:\"bib1_210d_LT_4\";s:0:\"\";s:14:\"bib1_210d_LT_5\";s:0:\"\";s:14:\"bib1_210d_GT_0\";s:0:\"\";s:14:\"bib1_210d_GT_1\";s:0:\"\";s:14:\"bib1_210d_GT_2\";s:0:\"\";s:14:\"bib1_210d_GT_3\";s:0:\"\";s:14:\"bib1_210d_GT_4\";s:0:\"\";s:14:\"bib1_210d_GT_5\";s:0:\"\";s:16:\"bib1_210d_LTEQ_0\";s:0:\"\";s:16:\"bib1_210d_LTEQ_1\";s:0:\"\";s:16:\"bib1_210d_LTEQ_2\";s:0:\"\";s:16:\"bib1_210d_LTEQ_3\";s:0:\"\";s:16:\"bib1_210d_LTEQ_4\";s:0:\"\";s:16:\"bib1_210d_LTEQ_5\";s:0:\"\";s:16:\"bib1_210d_GTEQ_0\";s:0:\"\";s:16:\"bib1_210d_GTEQ_1\";s:0:\"\";s:16:\"bib1_210d_GTEQ_2\";s:0:\"\";s:16:\"bib1_210d_GTEQ_3\";s:0:\"\";s:16:\"bib1_210d_GTEQ_4\";s:0:\"\";s:16:\"bib1_210d_GTEQ_5\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_0\";s:1:\"5\";s:23:\"bib1_225a410t_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_0\";s:1:\"5\";s:25:\"bib1_225a410t_STARTWITH_1\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_2\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_3\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_4\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_5\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_0\";s:1:\"5\";s:23:\"bib1_225a410t_ENDWITH_1\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_2\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_3\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_4\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_5\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_0\";s:1:\"5\";s:21:\"bib1_225a410t_EXACT_1\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_2\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_3\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_4\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_5\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_0\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_0\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_1\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_2\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_3\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_4\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_5\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_0\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_1\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_2\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_3\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_4\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_5\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_0\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_1\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_2\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_3\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_4\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_5\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_0\";s:1:\"5\";s:19:\"bib1_461t_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_0\";s:1:\"5\";s:21:\"bib1_461t_STARTWITH_1\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_2\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_3\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_4\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_5\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_0\";s:1:\"5\";s:19:\"bib1_461t_ENDWITH_1\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_2\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_3\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_4\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_5\";s:0:\"\";s:17:\"bib1_461t_EXACT_0\";s:1:\"5\";s:17:\"bib1_461t_EXACT_1\";s:0:\"\";s:17:\"bib1_461t_EXACT_2\";s:0:\"\";s:17:\"bib1_461t_EXACT_3\";s:0:\"\";s:17:\"bib1_461t_EXACT_4\";s:0:\"\";s:17:\"bib1_461t_EXACT_5\";s:0:\"\";s:14:\"bib1_461t_EQ_0\";s:1:\"5\";s:14:\"bib1_461t_EQ_1\";s:0:\"\";s:14:\"bib1_461t_EQ_2\";s:0:\"\";s:14:\"bib1_461t_EQ_3\";s:0:\"\";s:14:\"bib1_461t_EQ_4\";s:0:\"\";s:14:\"bib1_461t_EQ_5\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_0\";s:8:\"7,8,1214\";s:21:\"bib1_010a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_0\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_0\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_0\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_1\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_2\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_3\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_4\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_5\";s:0:\"\";s:17:\"bib1_500a_EXACT_0\";s:0:\"\";s:17:\"bib1_500a_EXACT_1\";s:0:\"\";s:17:\"bib1_500a_EXACT_2\";s:0:\"\";s:17:\"bib1_500a_EXACT_3\";s:0:\"\";s:17:\"bib1_500a_EXACT_4\";s:0:\"\";s:17:\"bib1_500a_EXACT_5\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_300_STARTWITH_0\";s:0:\"\";s:20:\"bib1_300_STARTWITH_1\";s:0:\"\";s:20:\"bib1_300_STARTWITH_2\";s:0:\"\";s:20:\"bib1_300_STARTWITH_3\";s:0:\"\";s:20:\"bib1_300_STARTWITH_4\";s:0:\"\";s:20:\"bib1_300_STARTWITH_5\";s:0:\"\";s:18:\"bib1_300_ENDWITH_0\";s:0:\"\";s:18:\"bib1_300_ENDWITH_1\";s:0:\"\";s:18:\"bib1_300_ENDWITH_2\";s:0:\"\";s:18:\"bib1_300_ENDWITH_3\";s:0:\"\";s:18:\"bib1_300_ENDWITH_4\";s:0:\"\";s:18:\"bib1_300_ENDWITH_5\";s:0:\"\";s:16:\"bib1_300_EXACT_0\";s:0:\"\";s:16:\"bib1_300_EXACT_1\";s:0:\"\";s:16:\"bib1_300_EXACT_2\";s:0:\"\";s:16:\"bib1_300_EXACT_3\";s:0:\"\";s:16:\"bib1_300_EXACT_4\";s:0:\"\";s:16:\"bib1_300_EXACT_5\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_327_STARTWITH_0\";s:0:\"\";s:20:\"bib1_327_STARTWITH_1\";s:0:\"\";s:20:\"bib1_327_STARTWITH_2\";s:0:\"\";s:20:\"bib1_327_STARTWITH_3\";s:0:\"\";s:20:\"bib1_327_STARTWITH_4\";s:0:\"\";s:20:\"bib1_327_STARTWITH_5\";s:0:\"\";s:18:\"bib1_327_ENDWITH_0\";s:0:\"\";s:18:\"bib1_327_ENDWITH_1\";s:0:\"\";s:18:\"bib1_327_ENDWITH_2\";s:0:\"\";s:18:\"bib1_327_ENDWITH_3\";s:0:\"\";s:18:\"bib1_327_ENDWITH_4\";s:0:\"\";s:18:\"bib1_327_ENDWITH_5\";s:0:\"\";s:16:\"bib1_327_EXACT_0\";s:0:\"\";s:16:\"bib1_327_EXACT_1\";s:0:\"\";s:16:\"bib1_327_EXACT_2\";s:0:\"\";s:16:\"bib1_327_EXACT_3\";s:0:\"\";s:16:\"bib1_327_EXACT_4\";s:0:\"\";s:16:\"bib1_327_EXACT_5\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_330_STARTWITH_0\";s:0:\"\";s:20:\"bib1_330_STARTWITH_1\";s:0:\"\";s:20:\"bib1_330_STARTWITH_2\";s:0:\"\";s:20:\"bib1_330_STARTWITH_3\";s:0:\"\";s:20:\"bib1_330_STARTWITH_4\";s:0:\"\";s:20:\"bib1_330_STARTWITH_5\";s:0:\"\";s:18:\"bib1_330_ENDWITH_0\";s:0:\"\";s:18:\"bib1_330_ENDWITH_1\";s:0:\"\";s:18:\"bib1_330_ENDWITH_2\";s:0:\"\";s:18:\"bib1_330_ENDWITH_3\";s:0:\"\";s:18:\"bib1_330_ENDWITH_4\";s:0:\"\";s:18:\"bib1_330_ENDWITH_5\";s:0:\"\";s:16:\"bib1_330_EXACT_0\";s:0:\"\";s:16:\"bib1_330_EXACT_1\";s:0:\"\";s:16:\"bib1_330_EXACT_2\";s:0:\"\";s:16:\"bib1_330_EXACT_3\";s:0:\"\";s:16:\"bib1_330_EXACT_4\";s:0:\"\";s:16:\"bib1_330_EXACT_5\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_0\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_1\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_2\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_3\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_4\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_5\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_0\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_1\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_2\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_3\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_4\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_5\";s:0:\"\";s:16:\"bib1_3XX_EXACT_0\";s:0:\"\";s:16:\"bib1_3XX_EXACT_1\";s:0:\"\";s:16:\"bib1_3XX_EXACT_2\";s:0:\"\";s:16:\"bib1_3XX_EXACT_3\";s:0:\"\";s:16:\"bib1_3XX_EXACT_4\";s:0:\"\";s:16:\"bib1_3XX_EXACT_5\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_0\";s:2:\"21\";s:18:\"bib1_60X_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_0\";s:2:\"21\";s:20:\"bib1_60X_STARTWITH_1\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_2\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_3\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_4\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_5\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_0\";s:2:\"21\";s:18:\"bib1_60X_ENDWITH_1\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_2\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_3\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_4\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_5\";s:0:\"\";s:16:\"bib1_60X_EXACT_0\";s:2:\"21\";s:16:\"bib1_60X_EXACT_1\";s:0:\"\";s:16:\"bib1_60X_EXACT_2\";s:0:\"\";s:16:\"bib1_60X_EXACT_3\";s:0:\"\";s:16:\"bib1_60X_EXACT_4\";s:0:\"\";s:16:\"bib1_60X_EXACT_5\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_0\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_0\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_1\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_2\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_3\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_4\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_5\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_0\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_1\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_2\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_3\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_4\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_5\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_0\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_1\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_2\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_3\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_4\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_5\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_0\";s:2:\"21\";s:18:\"bib1_610_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_610_STARTWITH_0\";s:2:\"21\";s:20:\"bib1_610_STARTWITH_1\";s:0:\"\";s:20:\"bib1_610_STARTWITH_2\";s:0:\"\";s:20:\"bib1_610_STARTWITH_3\";s:0:\"\";s:20:\"bib1_610_STARTWITH_4\";s:0:\"\";s:20:\"bib1_610_STARTWITH_5\";s:0:\"\";s:18:\"bib1_610_ENDWITH_0\";s:2:\"21\";s:18:\"bib1_610_ENDWITH_1\";s:0:\"\";s:18:\"bib1_610_ENDWITH_2\";s:0:\"\";s:18:\"bib1_610_ENDWITH_3\";s:0:\"\";s:18:\"bib1_610_ENDWITH_4\";s:0:\"\";s:18:\"bib1_610_ENDWITH_5\";s:0:\"\";s:16:\"bib1_610_EXACT_0\";s:2:\"21\";s:16:\"bib1_610_EXACT_1\";s:0:\"\";s:16:\"bib1_610_EXACT_2\";s:0:\"\";s:16:\"bib1_610_EXACT_3\";s:0:\"\";s:16:\"bib1_610_EXACT_4\";s:0:\"\";s:16:\"bib1_610_EXACT_5\";s:0:\"\";s:14:\"bib1_101a_EQ_0\";s:2:\"54\";s:14:\"bib1_101a_EQ_1\";s:0:\"\";s:14:\"bib1_101a_EQ_2\";s:0:\"\";s:14:\"bib1_101a_EQ_3\";s:0:\"\";s:14:\"bib1_101a_EQ_4\";s:0:\"\";s:14:\"bib1_101a_EQ_5\";s:0:\"\";s:14:\"bib1_101c_EQ_0\";s:0:\"\";s:14:\"bib1_101c_EQ_1\";s:0:\"\";s:14:\"bib1_101c_EQ_2\";s:0:\"\";s:14:\"bib1_101c_EQ_3\";s:0:\"\";s:14:\"bib1_101c_EQ_4\";s:0:\"\";s:14:\"bib1_101c_EQ_5\";s:0:\"\";s:12:\"bib1_bl_EQ_0\";s:0:\"\";s:12:\"bib1_bl_EQ_1\";s:0:\"\";s:12:\"bib1_bl_EQ_2\";s:0:\"\";s:12:\"bib1_bl_EQ_3\";s:0:\"\";s:12:\"bib1_bl_EQ_4\";s:0:\"\";s:12:\"bib1_bl_EQ_5\";s:0:\"\";s:12:\"bib1_dt_EQ_0\";s:4:\"1031\";s:12:\"bib1_dt_EQ_1\";s:0:\"\";s:12:\"bib1_dt_EQ_2\";s:0:\"\";s:12:\"bib1_dt_EQ_3\";s:0:\"\";s:12:\"bib1_dt_EQ_4\";s:0:\"\";s:12:\"bib1_dt_EQ_5\";s:0:\"\";s:19:\"bib1_FORBIDDEN_EQ_0\";N;s:19:\"bib1_FORBIDDEN_EQ_1\";N;s:19:\"bib1_FORBIDDEN_EQ_2\";N;s:19:\"bib1_FORBIDDEN_EQ_3\";N;s:19:\"bib1_FORBIDDEN_EQ_4\";N;s:19:\"bib1_FORBIDDEN_EQ_5\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_0\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_1\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_2\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_3\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_4\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_5\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_0\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_1\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_2\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_3\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_4\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_5\";N;s:22:\"bib1_FORBIDDEN_EXACT_0\";N;s:22:\"bib1_FORBIDDEN_EXACT_1\";N;s:22:\"bib1_FORBIDDEN_EXACT_2\";N;s:22:\"bib1_FORBIDDEN_EXACT_3\";N;s:22:\"bib1_FORBIDDEN_EXACT_4\";N;s:22:\"bib1_FORBIDDEN_EXACT_5\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_0\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_1\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_2\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_3\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_4\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_5\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_0\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_1\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_2\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_3\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_4\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_5\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_0\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_1\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_2\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_3\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_4\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_5\";N;s:19:\"bib1_FORBIDDEN_LT_0\";N;s:19:\"bib1_FORBIDDEN_LT_1\";N;s:19:\"bib1_FORBIDDEN_LT_2\";N;s:19:\"bib1_FORBIDDEN_LT_3\";N;s:19:\"bib1_FORBIDDEN_LT_4\";N;s:19:\"bib1_FORBIDDEN_LT_5\";N;s:19:\"bib1_FORBIDDEN_GT_0\";N;s:19:\"bib1_FORBIDDEN_GT_1\";N;s:19:\"bib1_FORBIDDEN_GT_2\";N;s:19:\"bib1_FORBIDDEN_GT_3\";N;s:19:\"bib1_FORBIDDEN_GT_4\";N;s:19:\"bib1_FORBIDDEN_GT_5\";N;s:21:\"bib1_FORBIDDEN_LTEQ_0\";N;s:21:\"bib1_FORBIDDEN_LTEQ_1\";N;s:21:\"bib1_FORBIDDEN_LTEQ_2\";N;s:21:\"bib1_FORBIDDEN_LTEQ_3\";N;s:21:\"bib1_FORBIDDEN_LTEQ_4\";N;s:21:\"bib1_FORBIDDEN_LTEQ_5\";N;s:21:\"bib1_FORBIDDEN_GTEQ_0\";N;s:21:\"bib1_FORBIDDEN_GTEQ_1\";N;s:21:\"bib1_FORBIDDEN_GTEQ_2\";N;s:21:\"bib1_FORBIDDEN_GTEQ_3\";N;s:21:\"bib1_FORBIDDEN_GTEQ_4\";N;s:21:\"bib1_FORBIDDEN_GTEQ_5\";N;s:12:\"bib1_dc_EQ_0\";s:0:\"\";s:12:\"bib1_dc_EQ_1\";s:0:\"\";s:12:\"bib1_dc_EQ_2\";s:0:\"\";s:12:\"bib1_dc_EQ_3\";s:0:\"\";s:12:\"bib1_dc_EQ_4\";s:0:\"\";s:12:\"bib1_dc_EQ_5\";s:0:\"\";s:12:\"bib1_dc_LT_0\";s:0:\"\";s:12:\"bib1_dc_LT_1\";s:0:\"\";s:12:\"bib1_dc_LT_2\";s:0:\"\";s:12:\"bib1_dc_LT_3\";s:0:\"\";s:12:\"bib1_dc_LT_4\";s:0:\"\";s:12:\"bib1_dc_LT_5\";s:0:\"\";s:12:\"bib1_dc_GT_0\";s:0:\"\";s:12:\"bib1_dc_GT_1\";s:0:\"\";s:12:\"bib1_dc_GT_2\";s:0:\"\";s:12:\"bib1_dc_GT_3\";s:0:\"\";s:12:\"bib1_dc_GT_4\";s:0:\"\";s:12:\"bib1_dc_GT_5\";s:0:\"\";s:14:\"bib1_dc_LTEQ_0\";s:0:\"\";s:14:\"bib1_dc_LTEQ_1\";s:0:\"\";s:14:\"bib1_dc_LTEQ_2\";s:0:\"\";s:14:\"bib1_dc_LTEQ_3\";s:0:\"\";s:14:\"bib1_dc_LTEQ_4\";s:0:\"\";s:14:\"bib1_dc_LTEQ_5\";s:0:\"\";s:14:\"bib1_dc_GTEQ_0\";s:0:\"\";s:14:\"bib1_dc_GTEQ_1\";s:0:\"\";s:14:\"bib1_dc_GTEQ_2\";s:0:\"\";s:14:\"bib1_dc_GTEQ_3\";s:0:\"\";s:14:\"bib1_dc_GTEQ_4\";s:0:\"\";s:14:\"bib1_dc_GTEQ_5\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_0\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_1\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_2\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_3\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_4\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_5\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_0\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_1\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_2\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_3\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_4\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_5\";s:0:\"\";}}','','BnF',2,15,3,1800,1,0,1,0,0,1,'a:0:{}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (6,'z3950','a:10:{s:3:\"url\";s:20:\"carmin.sudoc.abes.fr\";s:10:\"z3950_base\";s:15:\"ABES-Z39-PUBLIC\";s:11:\"z3950_login\";s:0:\"\";s:14:\"z3950_password\";s:0:\"\";s:17:\"z3950_max_notices\";s:3:\"100\";s:12:\"z3950_format\";s:7:\"UNIMARC\";s:10:\"z3950_port\";s:3:\"210\";s:13:\"z3950_convert\";s:1:\"0\";s:12:\"z3950_profil\";s:11:\"very_simple\";s:10:\"z3950_bib1\";a:546:{s:19:\"bib1_200a_BOOLEAN_0\";s:1:\"4\";s:19:\"bib1_200a_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_200a_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_0\";s:1:\"4\";s:21:\"bib1_200a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_200a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_0\";s:1:\"4\";s:19:\"bib1_200a_ENDWITH_1\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_2\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_3\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_4\";s:0:\"\";s:19:\"bib1_200a_ENDWITH_5\";s:0:\"\";s:17:\"bib1_200a_EXACT_0\";s:1:\"4\";s:17:\"bib1_200a_EXACT_1\";s:0:\"\";s:17:\"bib1_200a_EXACT_2\";s:0:\"\";s:17:\"bib1_200a_EXACT_3\";s:0:\"\";s:17:\"bib1_200a_EXACT_4\";s:0:\"\";s:17:\"bib1_200a_EXACT_5\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_0\";s:25:\"4,5,1003,7,8,1214,1018,21\";s:18:\"bib1_XXX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_XXX_BOOLEAN_5\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_0\";s:4:\"1003\";s:18:\"bib1_7XX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_7XX_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_0\";s:4:\"1003\";s:20:\"bib1_7XX_STARTWITH_1\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_2\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_3\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_4\";s:0:\"\";s:20:\"bib1_7XX_STARTWITH_5\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_0\";s:4:\"1003\";s:18:\"bib1_7XX_ENDWITH_1\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_2\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_3\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_4\";s:0:\"\";s:18:\"bib1_7XX_ENDWITH_5\";s:0:\"\";s:16:\"bib1_7XX_EXACT_0\";s:4:\"1003\";s:16:\"bib1_7XX_EXACT_1\";s:0:\"\";s:16:\"bib1_7XX_EXACT_2\";s:0:\"\";s:16:\"bib1_7XX_EXACT_3\";s:0:\"\";s:16:\"bib1_7XX_EXACT_4\";s:0:\"\";s:16:\"bib1_7XX_EXACT_5\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_0\";s:4:\"1018\";s:19:\"bib1_210c_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_210c_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_0\";s:4:\"1018\";s:21:\"bib1_210c_STARTWITH_1\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_2\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_3\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_4\";s:0:\"\";s:21:\"bib1_210c_STARTWITH_5\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_0\";s:4:\"1018\";s:19:\"bib1_210c_ENDWITH_1\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_2\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_3\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_4\";s:0:\"\";s:19:\"bib1_210c_ENDWITH_5\";s:0:\"\";s:17:\"bib1_210c_EXACT_0\";s:4:\"1018\";s:17:\"bib1_210c_EXACT_1\";s:0:\"\";s:17:\"bib1_210c_EXACT_2\";s:0:\"\";s:17:\"bib1_210c_EXACT_3\";s:0:\"\";s:17:\"bib1_210c_EXACT_4\";s:0:\"\";s:17:\"bib1_210c_EXACT_5\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_0\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_1\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_2\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_3\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_4\";s:0:\"\";s:29:\"bib1_210d_CONTAINS_AT_LEAST_5\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_0\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_1\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_2\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_3\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_4\";s:0:\"\";s:24:\"bib1_210d_CONTAINS_ALL_5\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_0\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_1\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_2\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_3\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_4\";s:0:\"\";s:21:\"bib1_210d_STARTWITH_5\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_0\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_1\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_2\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_3\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_4\";s:0:\"\";s:19:\"bib1_210d_ENDWITH_5\";s:0:\"\";s:17:\"bib1_210d_EXACT_0\";s:0:\"\";s:17:\"bib1_210d_EXACT_1\";s:0:\"\";s:17:\"bib1_210d_EXACT_2\";s:0:\"\";s:17:\"bib1_210d_EXACT_3\";s:0:\"\";s:17:\"bib1_210d_EXACT_4\";s:0:\"\";s:17:\"bib1_210d_EXACT_5\";s:0:\"\";s:14:\"bib1_210d_EQ_0\";s:0:\"\";s:14:\"bib1_210d_EQ_1\";s:0:\"\";s:14:\"bib1_210d_EQ_2\";s:0:\"\";s:14:\"bib1_210d_EQ_3\";s:0:\"\";s:14:\"bib1_210d_EQ_4\";s:0:\"\";s:14:\"bib1_210d_EQ_5\";s:0:\"\";s:14:\"bib1_210d_LT_0\";s:0:\"\";s:14:\"bib1_210d_LT_1\";s:0:\"\";s:14:\"bib1_210d_LT_2\";s:0:\"\";s:14:\"bib1_210d_LT_3\";s:0:\"\";s:14:\"bib1_210d_LT_4\";s:0:\"\";s:14:\"bib1_210d_LT_5\";s:0:\"\";s:14:\"bib1_210d_GT_0\";s:0:\"\";s:14:\"bib1_210d_GT_1\";s:0:\"\";s:14:\"bib1_210d_GT_2\";s:0:\"\";s:14:\"bib1_210d_GT_3\";s:0:\"\";s:14:\"bib1_210d_GT_4\";s:0:\"\";s:14:\"bib1_210d_GT_5\";s:0:\"\";s:16:\"bib1_210d_LTEQ_0\";s:0:\"\";s:16:\"bib1_210d_LTEQ_1\";s:0:\"\";s:16:\"bib1_210d_LTEQ_2\";s:0:\"\";s:16:\"bib1_210d_LTEQ_3\";s:0:\"\";s:16:\"bib1_210d_LTEQ_4\";s:0:\"\";s:16:\"bib1_210d_LTEQ_5\";s:0:\"\";s:16:\"bib1_210d_GTEQ_0\";s:0:\"\";s:16:\"bib1_210d_GTEQ_1\";s:0:\"\";s:16:\"bib1_210d_GTEQ_2\";s:0:\"\";s:16:\"bib1_210d_GTEQ_3\";s:0:\"\";s:16:\"bib1_210d_GTEQ_4\";s:0:\"\";s:16:\"bib1_210d_GTEQ_5\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_0\";s:1:\"5\";s:23:\"bib1_225a410t_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_225a410t_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_0\";s:1:\"5\";s:25:\"bib1_225a410t_STARTWITH_1\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_2\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_3\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_4\";s:0:\"\";s:25:\"bib1_225a410t_STARTWITH_5\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_0\";s:1:\"5\";s:23:\"bib1_225a410t_ENDWITH_1\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_2\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_3\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_4\";s:0:\"\";s:23:\"bib1_225a410t_ENDWITH_5\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_0\";s:1:\"5\";s:21:\"bib1_225a410t_EXACT_1\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_2\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_3\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_4\";s:0:\"\";s:21:\"bib1_225a410t_EXACT_5\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_0\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_225i411t_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_0\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_1\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_2\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_3\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_4\";s:0:\"\";s:25:\"bib1_225i411t_STARTWITH_5\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_0\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_1\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_2\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_3\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_4\";s:0:\"\";s:23:\"bib1_225i411t_ENDWITH_5\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_0\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_1\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_2\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_3\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_4\";s:0:\"\";s:21:\"bib1_225i411t_EXACT_5\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_0\";s:1:\"5\";s:19:\"bib1_461t_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_461t_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_0\";s:1:\"5\";s:21:\"bib1_461t_STARTWITH_1\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_2\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_3\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_4\";s:0:\"\";s:21:\"bib1_461t_STARTWITH_5\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_0\";s:1:\"5\";s:19:\"bib1_461t_ENDWITH_1\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_2\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_3\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_4\";s:0:\"\";s:19:\"bib1_461t_ENDWITH_5\";s:0:\"\";s:17:\"bib1_461t_EXACT_0\";s:1:\"5\";s:17:\"bib1_461t_EXACT_1\";s:0:\"\";s:17:\"bib1_461t_EXACT_2\";s:0:\"\";s:17:\"bib1_461t_EXACT_3\";s:0:\"\";s:17:\"bib1_461t_EXACT_4\";s:0:\"\";s:17:\"bib1_461t_EXACT_5\";s:0:\"\";s:14:\"bib1_461t_EQ_0\";s:1:\"5\";s:14:\"bib1_461t_EQ_1\";s:0:\"\";s:14:\"bib1_461t_EQ_2\";s:0:\"\";s:14:\"bib1_461t_EQ_3\";s:0:\"\";s:14:\"bib1_461t_EQ_4\";s:0:\"\";s:14:\"bib1_461t_EQ_5\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_0\";s:8:\"7,8,1214\";s:21:\"bib1_010a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_010a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_0\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_1\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_2\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_3\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_4\";s:0:\"\";s:19:\"bib1_500a_BOOLEAN_5\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_0\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_1\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_2\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_3\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_4\";s:0:\"\";s:21:\"bib1_500a_STARTWITH_5\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_0\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_1\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_2\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_3\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_4\";s:0:\"\";s:19:\"bib1_500a_ENDWITH_5\";s:0:\"\";s:17:\"bib1_500a_EXACT_0\";s:0:\"\";s:17:\"bib1_500a_EXACT_1\";s:0:\"\";s:17:\"bib1_500a_EXACT_2\";s:0:\"\";s:17:\"bib1_500a_EXACT_3\";s:0:\"\";s:17:\"bib1_500a_EXACT_4\";s:0:\"\";s:17:\"bib1_500a_EXACT_5\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_300_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_300_STARTWITH_0\";s:0:\"\";s:20:\"bib1_300_STARTWITH_1\";s:0:\"\";s:20:\"bib1_300_STARTWITH_2\";s:0:\"\";s:20:\"bib1_300_STARTWITH_3\";s:0:\"\";s:20:\"bib1_300_STARTWITH_4\";s:0:\"\";s:20:\"bib1_300_STARTWITH_5\";s:0:\"\";s:18:\"bib1_300_ENDWITH_0\";s:0:\"\";s:18:\"bib1_300_ENDWITH_1\";s:0:\"\";s:18:\"bib1_300_ENDWITH_2\";s:0:\"\";s:18:\"bib1_300_ENDWITH_3\";s:0:\"\";s:18:\"bib1_300_ENDWITH_4\";s:0:\"\";s:18:\"bib1_300_ENDWITH_5\";s:0:\"\";s:16:\"bib1_300_EXACT_0\";s:0:\"\";s:16:\"bib1_300_EXACT_1\";s:0:\"\";s:16:\"bib1_300_EXACT_2\";s:0:\"\";s:16:\"bib1_300_EXACT_3\";s:0:\"\";s:16:\"bib1_300_EXACT_4\";s:0:\"\";s:16:\"bib1_300_EXACT_5\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_327_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_327_STARTWITH_0\";s:0:\"\";s:20:\"bib1_327_STARTWITH_1\";s:0:\"\";s:20:\"bib1_327_STARTWITH_2\";s:0:\"\";s:20:\"bib1_327_STARTWITH_3\";s:0:\"\";s:20:\"bib1_327_STARTWITH_4\";s:0:\"\";s:20:\"bib1_327_STARTWITH_5\";s:0:\"\";s:18:\"bib1_327_ENDWITH_0\";s:0:\"\";s:18:\"bib1_327_ENDWITH_1\";s:0:\"\";s:18:\"bib1_327_ENDWITH_2\";s:0:\"\";s:18:\"bib1_327_ENDWITH_3\";s:0:\"\";s:18:\"bib1_327_ENDWITH_4\";s:0:\"\";s:18:\"bib1_327_ENDWITH_5\";s:0:\"\";s:16:\"bib1_327_EXACT_0\";s:0:\"\";s:16:\"bib1_327_EXACT_1\";s:0:\"\";s:16:\"bib1_327_EXACT_2\";s:0:\"\";s:16:\"bib1_327_EXACT_3\";s:0:\"\";s:16:\"bib1_327_EXACT_4\";s:0:\"\";s:16:\"bib1_327_EXACT_5\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_330_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_330_STARTWITH_0\";s:0:\"\";s:20:\"bib1_330_STARTWITH_1\";s:0:\"\";s:20:\"bib1_330_STARTWITH_2\";s:0:\"\";s:20:\"bib1_330_STARTWITH_3\";s:0:\"\";s:20:\"bib1_330_STARTWITH_4\";s:0:\"\";s:20:\"bib1_330_STARTWITH_5\";s:0:\"\";s:18:\"bib1_330_ENDWITH_0\";s:0:\"\";s:18:\"bib1_330_ENDWITH_1\";s:0:\"\";s:18:\"bib1_330_ENDWITH_2\";s:0:\"\";s:18:\"bib1_330_ENDWITH_3\";s:0:\"\";s:18:\"bib1_330_ENDWITH_4\";s:0:\"\";s:18:\"bib1_330_ENDWITH_5\";s:0:\"\";s:16:\"bib1_330_EXACT_0\";s:0:\"\";s:16:\"bib1_330_EXACT_1\";s:0:\"\";s:16:\"bib1_330_EXACT_2\";s:0:\"\";s:16:\"bib1_330_EXACT_3\";s:0:\"\";s:16:\"bib1_330_EXACT_4\";s:0:\"\";s:16:\"bib1_330_EXACT_5\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_0\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_3XX_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_0\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_1\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_2\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_3\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_4\";s:0:\"\";s:20:\"bib1_3XX_STARTWITH_5\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_0\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_1\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_2\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_3\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_4\";s:0:\"\";s:18:\"bib1_3XX_ENDWITH_5\";s:0:\"\";s:16:\"bib1_3XX_EXACT_0\";s:0:\"\";s:16:\"bib1_3XX_EXACT_1\";s:0:\"\";s:16:\"bib1_3XX_EXACT_2\";s:0:\"\";s:16:\"bib1_3XX_EXACT_3\";s:0:\"\";s:16:\"bib1_3XX_EXACT_4\";s:0:\"\";s:16:\"bib1_3XX_EXACT_5\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_0\";s:2:\"21\";s:18:\"bib1_60X_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_60X_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_0\";s:2:\"21\";s:20:\"bib1_60X_STARTWITH_1\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_2\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_3\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_4\";s:0:\"\";s:20:\"bib1_60X_STARTWITH_5\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_0\";s:2:\"21\";s:18:\"bib1_60X_ENDWITH_1\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_2\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_3\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_4\";s:0:\"\";s:18:\"bib1_60X_ENDWITH_5\";s:0:\"\";s:16:\"bib1_60X_EXACT_0\";s:2:\"21\";s:16:\"bib1_60X_EXACT_1\";s:0:\"\";s:16:\"bib1_60X_EXACT_2\";s:0:\"\";s:16:\"bib1_60X_EXACT_3\";s:0:\"\";s:16:\"bib1_60X_EXACT_4\";s:0:\"\";s:16:\"bib1_60X_EXACT_5\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_0\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_1\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_2\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_3\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_4\";s:0:\"\";s:23:\"bib1_676a686a_BOOLEAN_5\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_0\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_1\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_2\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_3\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_4\";s:0:\"\";s:25:\"bib1_676a686a_STARTWITH_5\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_0\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_1\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_2\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_3\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_4\";s:0:\"\";s:23:\"bib1_676a686a_ENDWITH_5\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_0\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_1\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_2\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_3\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_4\";s:0:\"\";s:21:\"bib1_676a686a_EXACT_5\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_0\";s:2:\"21\";s:18:\"bib1_610_BOOLEAN_1\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_2\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_3\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_4\";s:0:\"\";s:18:\"bib1_610_BOOLEAN_5\";s:0:\"\";s:20:\"bib1_610_STARTWITH_0\";s:2:\"21\";s:20:\"bib1_610_STARTWITH_1\";s:0:\"\";s:20:\"bib1_610_STARTWITH_2\";s:0:\"\";s:20:\"bib1_610_STARTWITH_3\";s:0:\"\";s:20:\"bib1_610_STARTWITH_4\";s:0:\"\";s:20:\"bib1_610_STARTWITH_5\";s:0:\"\";s:18:\"bib1_610_ENDWITH_0\";s:2:\"21\";s:18:\"bib1_610_ENDWITH_1\";s:0:\"\";s:18:\"bib1_610_ENDWITH_2\";s:0:\"\";s:18:\"bib1_610_ENDWITH_3\";s:0:\"\";s:18:\"bib1_610_ENDWITH_4\";s:0:\"\";s:18:\"bib1_610_ENDWITH_5\";s:0:\"\";s:16:\"bib1_610_EXACT_0\";s:2:\"21\";s:16:\"bib1_610_EXACT_1\";s:0:\"\";s:16:\"bib1_610_EXACT_2\";s:0:\"\";s:16:\"bib1_610_EXACT_3\";s:0:\"\";s:16:\"bib1_610_EXACT_4\";s:0:\"\";s:16:\"bib1_610_EXACT_5\";s:0:\"\";s:14:\"bib1_101a_EQ_0\";s:2:\"54\";s:14:\"bib1_101a_EQ_1\";s:0:\"\";s:14:\"bib1_101a_EQ_2\";s:0:\"\";s:14:\"bib1_101a_EQ_3\";s:0:\"\";s:14:\"bib1_101a_EQ_4\";s:0:\"\";s:14:\"bib1_101a_EQ_5\";s:0:\"\";s:14:\"bib1_101c_EQ_0\";s:0:\"\";s:14:\"bib1_101c_EQ_1\";s:0:\"\";s:14:\"bib1_101c_EQ_2\";s:0:\"\";s:14:\"bib1_101c_EQ_3\";s:0:\"\";s:14:\"bib1_101c_EQ_4\";s:0:\"\";s:14:\"bib1_101c_EQ_5\";s:0:\"\";s:12:\"bib1_bl_EQ_0\";s:0:\"\";s:12:\"bib1_bl_EQ_1\";s:0:\"\";s:12:\"bib1_bl_EQ_2\";s:0:\"\";s:12:\"bib1_bl_EQ_3\";s:0:\"\";s:12:\"bib1_bl_EQ_4\";s:0:\"\";s:12:\"bib1_bl_EQ_5\";s:0:\"\";s:12:\"bib1_dt_EQ_0\";s:4:\"1031\";s:12:\"bib1_dt_EQ_1\";s:0:\"\";s:12:\"bib1_dt_EQ_2\";s:0:\"\";s:12:\"bib1_dt_EQ_3\";s:0:\"\";s:12:\"bib1_dt_EQ_4\";s:0:\"\";s:12:\"bib1_dt_EQ_5\";s:0:\"\";s:19:\"bib1_FORBIDDEN_EQ_0\";N;s:19:\"bib1_FORBIDDEN_EQ_1\";N;s:19:\"bib1_FORBIDDEN_EQ_2\";N;s:19:\"bib1_FORBIDDEN_EQ_3\";N;s:19:\"bib1_FORBIDDEN_EQ_4\";N;s:19:\"bib1_FORBIDDEN_EQ_5\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_0\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_1\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_2\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_3\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_4\";N;s:25:\"bib1_FORBIDDEN_CONTAINS_5\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_0\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_1\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_2\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_3\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_4\";N;s:26:\"bib1_FORBIDDEN_STARTWITH_5\";N;s:22:\"bib1_FORBIDDEN_EXACT_0\";N;s:22:\"bib1_FORBIDDEN_EXACT_1\";N;s:22:\"bib1_FORBIDDEN_EXACT_2\";N;s:22:\"bib1_FORBIDDEN_EXACT_3\";N;s:22:\"bib1_FORBIDDEN_EXACT_4\";N;s:22:\"bib1_FORBIDDEN_EXACT_5\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_0\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_1\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_2\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_3\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_4\";N;s:24:\"bib1_FORBIDDEN_ENDWITH_5\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_0\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_1\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_2\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_3\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_4\";N;s:34:\"bib1_FORBIDDEN_CONTAINS_AT_LEAST_5\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_0\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_1\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_2\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_3\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_4\";N;s:29:\"bib1_FORBIDDEN_CONTAINS_ALL_5\";N;s:19:\"bib1_FORBIDDEN_LT_0\";N;s:19:\"bib1_FORBIDDEN_LT_1\";N;s:19:\"bib1_FORBIDDEN_LT_2\";N;s:19:\"bib1_FORBIDDEN_LT_3\";N;s:19:\"bib1_FORBIDDEN_LT_4\";N;s:19:\"bib1_FORBIDDEN_LT_5\";N;s:19:\"bib1_FORBIDDEN_GT_0\";N;s:19:\"bib1_FORBIDDEN_GT_1\";N;s:19:\"bib1_FORBIDDEN_GT_2\";N;s:19:\"bib1_FORBIDDEN_GT_3\";N;s:19:\"bib1_FORBIDDEN_GT_4\";N;s:19:\"bib1_FORBIDDEN_GT_5\";N;s:21:\"bib1_FORBIDDEN_LTEQ_0\";N;s:21:\"bib1_FORBIDDEN_LTEQ_1\";N;s:21:\"bib1_FORBIDDEN_LTEQ_2\";N;s:21:\"bib1_FORBIDDEN_LTEQ_3\";N;s:21:\"bib1_FORBIDDEN_LTEQ_4\";N;s:21:\"bib1_FORBIDDEN_LTEQ_5\";N;s:21:\"bib1_FORBIDDEN_GTEQ_0\";N;s:21:\"bib1_FORBIDDEN_GTEQ_1\";N;s:21:\"bib1_FORBIDDEN_GTEQ_2\";N;s:21:\"bib1_FORBIDDEN_GTEQ_3\";N;s:21:\"bib1_FORBIDDEN_GTEQ_4\";N;s:21:\"bib1_FORBIDDEN_GTEQ_5\";N;s:12:\"bib1_dc_EQ_0\";s:0:\"\";s:12:\"bib1_dc_EQ_1\";s:0:\"\";s:12:\"bib1_dc_EQ_2\";s:0:\"\";s:12:\"bib1_dc_EQ_3\";s:0:\"\";s:12:\"bib1_dc_EQ_4\";s:0:\"\";s:12:\"bib1_dc_EQ_5\";s:0:\"\";s:12:\"bib1_dc_LT_0\";s:0:\"\";s:12:\"bib1_dc_LT_1\";s:0:\"\";s:12:\"bib1_dc_LT_2\";s:0:\"\";s:12:\"bib1_dc_LT_3\";s:0:\"\";s:12:\"bib1_dc_LT_4\";s:0:\"\";s:12:\"bib1_dc_LT_5\";s:0:\"\";s:12:\"bib1_dc_GT_0\";s:0:\"\";s:12:\"bib1_dc_GT_1\";s:0:\"\";s:12:\"bib1_dc_GT_2\";s:0:\"\";s:12:\"bib1_dc_GT_3\";s:0:\"\";s:12:\"bib1_dc_GT_4\";s:0:\"\";s:12:\"bib1_dc_GT_5\";s:0:\"\";s:14:\"bib1_dc_LTEQ_0\";s:0:\"\";s:14:\"bib1_dc_LTEQ_1\";s:0:\"\";s:14:\"bib1_dc_LTEQ_2\";s:0:\"\";s:14:\"bib1_dc_LTEQ_3\";s:0:\"\";s:14:\"bib1_dc_LTEQ_4\";s:0:\"\";s:14:\"bib1_dc_LTEQ_5\";s:0:\"\";s:14:\"bib1_dc_GTEQ_0\";s:0:\"\";s:14:\"bib1_dc_GTEQ_1\";s:0:\"\";s:14:\"bib1_dc_GTEQ_2\";s:0:\"\";s:14:\"bib1_dc_GTEQ_3\";s:0:\"\";s:14:\"bib1_dc_GTEQ_4\";s:0:\"\";s:14:\"bib1_dc_GTEQ_5\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_0\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_1\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_2\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_3\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_4\";s:0:\"\";s:20:\"bib1_856u_CONTAINS_5\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_0\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_1\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_2\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_3\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_4\";s:0:\"\";s:20:\"bib1_461v_CONTAINS_5\";s:0:\"\";}}','','Sudoc',2,15,3,1800,1,0,1,0,0,0,'a:0:{}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (7,'oai','a:6:{s:3:\"url\";s:33:\"http://oai.bnf.fr/oai2/OAIHandler\";s:14:\"clean_base_url\";s:1:\"1\";s:4:\"sets\";a:1:{i:0;s:22:\"gallica:corpus:afrique\";}s:7:\"formats\";s:6:\"oai_dc\";s:11:\"del_deleted\";s:1:\"0\";s:13:\"xsl_transform\";N;}','','Gallica',1,5,3,1800,1,0,1,0,1,0,'a:0:{}','','0000-00-00 00:00:00');
INSERT INTO connectors_sources (source_id, id_connector, parameters, comment, name, repository, timeout, retry, ttl, opac_allowed, rep_upload, upload_doc_num, enrichment, opac_affiliate_search, opac_selected, type_enrichment_allowed, ico_notice, last_sync_date) VALUES (8,'entrez','a:4:{s:15:\"entrez_database\";s:0:\"\";s:17:\"entrez_maxresults\";i:100;s:15:\"entrez_operator\";i:2;s:13:\"xsl_transform\";N;}','','PubMed',2,5,3,1800,1,0,1,0,0,0,'a:0:{}','','0000-00-00 00:00:00');
/*!40000 ALTER TABLE connectors_sources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coordonnees`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE coordonnees (
  id_contact int(8) unsigned NOT NULL AUTO_INCREMENT,
  type_coord int(1) unsigned NOT NULL DEFAULT '0',
  num_entite int(5) unsigned NOT NULL DEFAULT '0',
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  contact varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  adr1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  adr2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cp varchar(15) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ville varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  etat varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  pays varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tel1 varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tel2 varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  fax varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  email varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaires mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (id_contact),
  KEY i_num_entite (num_entite)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coordonnees`
--

LOCK TABLES coordonnees WRITE;
/*!40000 ALTER TABLE coordonnees DISABLE KEYS */;
/*!40000 ALTER TABLE coordonnees ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes (
  id_demande int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_demandeur int(10) unsigned NOT NULL DEFAULT '0',
  theme_demande int(3) NOT NULL DEFAULT '0',
  type_demande int(3) NOT NULL DEFAULT '0',
  etat_demande int(3) NOT NULL DEFAULT '0',
  date_demande date NOT NULL DEFAULT '0000-00-00',
  date_prevue date NOT NULL DEFAULT '0000-00-00',
  deadline_demande date NOT NULL DEFAULT '0000-00-00',
  titre_demande varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  sujet_demande mediumtext COLLATE utf8_unicode_ci NOT NULL,
  progression mediumint(3) NOT NULL DEFAULT '0',
  num_user_cloture mediumint(3) NOT NULL DEFAULT '0',
  num_notice int(10) NOT NULL DEFAULT '0',
  dmde_read_gestion int(1) unsigned NOT NULL DEFAULT '0',
  reponse_finale text COLLATE utf8_unicode_ci,
  dmde_read_opac int(1) unsigned NOT NULL DEFAULT '0',
  demande_note_num int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_demande),
  KEY i_num_demandeur (num_demandeur),
  KEY i_date_demande (date_demande),
  KEY i_deadline_demande (deadline_demande)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes`
--

LOCK TABLES demandes WRITE;
/*!40000 ALTER TABLE demandes DISABLE KEYS */;
/*!40000 ALTER TABLE demandes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_actions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_actions (
  id_action int(10) unsigned NOT NULL AUTO_INCREMENT,
  type_action int(3) NOT NULL DEFAULT '0',
  statut_action int(3) NOT NULL DEFAULT '0',
  sujet_action varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  detail_action mediumtext COLLATE utf8_unicode_ci NOT NULL,
  date_action date NOT NULL DEFAULT '0000-00-00',
  deadline_action date NOT NULL DEFAULT '0000-00-00',
  temps_passe float DEFAULT NULL,
  cout mediumint(3) NOT NULL DEFAULT '0',
  progression_action mediumint(3) NOT NULL DEFAULT '0',
  prive_action int(1) NOT NULL DEFAULT '0',
  num_demande int(10) NOT NULL DEFAULT '0',
  actions_num_user int(10) unsigned NOT NULL DEFAULT '0',
  actions_type_user tinyint(4) unsigned NOT NULL DEFAULT '0',
  actions_read_opac int(11) NOT NULL DEFAULT '0',
  actions_read_gestion int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_action),
  KEY i_date_action (date_action),
  KEY i_deadline_action (deadline_action),
  KEY i_num_demande (num_demande),
  KEY i_actions_user (actions_num_user,actions_type_user)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_actions`
--

LOCK TABLES demandes_actions WRITE;
/*!40000 ALTER TABLE demandes_actions DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_actions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_custom`
--

LOCK TABLES demandes_custom WRITE;
/*!40000 ALTER TABLE demandes_custom DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_custom_lists (
  demandes_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  demandes_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  demandes_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY i_demandes_custom_champ (demandes_custom_champ),
  KEY i_demandes_champ_list_value (demandes_custom_champ,demandes_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_custom_lists`
--

LOCK TABLES demandes_custom_lists WRITE;
/*!40000 ALTER TABLE demandes_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_custom_values (
  demandes_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  demandes_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  demandes_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  demandes_custom_text text COLLATE utf8_unicode_ci,
  demandes_custom_integer int(11) DEFAULT NULL,
  demandes_custom_date date DEFAULT NULL,
  demandes_custom_float float DEFAULT NULL,
  KEY i_demandes_custom_champ (demandes_custom_champ),
  KEY i_demandes_custom_origine (demandes_custom_origine)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_custom_values`
--

LOCK TABLES demandes_custom_values WRITE;
/*!40000 ALTER TABLE demandes_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_notes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_notes (
  id_note int(10) unsigned NOT NULL AUTO_INCREMENT,
  prive int(1) NOT NULL DEFAULT '0',
  rapport int(1) NOT NULL DEFAULT '0',
  contenu mediumtext COLLATE utf8_unicode_ci NOT NULL,
  date_note datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  num_action int(10) NOT NULL DEFAULT '0',
  num_note_parent int(10) NOT NULL DEFAULT '0',
  notes_num_user int(10) unsigned NOT NULL DEFAULT '0',
  notes_type_user tinyint(4) unsigned NOT NULL DEFAULT '0',
  notes_read_gestion int(1) unsigned NOT NULL DEFAULT '0',
  notes_read_opac int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_note),
  KEY i_date_note (date_note),
  KEY i_num_action (num_action),
  KEY i_num_note_parent (num_note_parent),
  KEY i_notes_user (notes_num_user,notes_type_user)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_notes`
--

LOCK TABLES demandes_notes WRITE;
/*!40000 ALTER TABLE demandes_notes DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_notes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_theme`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_theme (
  id_theme int(10) unsigned NOT NULL AUTO_INCREMENT,
  libelle_theme varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_theme)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_theme`
--

LOCK TABLES demandes_theme WRITE;
/*!40000 ALTER TABLE demandes_theme DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_theme ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_type`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_type (
  id_type int(10) unsigned NOT NULL AUTO_INCREMENT,
  libelle_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  allowed_actions text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_type)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_type`
--

LOCK TABLES demandes_type WRITE;
/*!40000 ALTER TABLE demandes_type DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_type ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `demandes_users`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE demandes_users (
  num_user int(10) NOT NULL DEFAULT '0',
  num_demande int(10) NOT NULL DEFAULT '0',
  date_creation date NOT NULL DEFAULT '0000-00-00',
  users_statut int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_user,num_demande)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `demandes_users`
--

LOCK TABLES demandes_users WRITE;
/*!40000 ALTER TABLE demandes_users DISABLE KEYS */;
/*!40000 ALTER TABLE demandes_users ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docs_codestat`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docs_codestat (
  idcode smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  codestat_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  statisdoc_codage_import char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  statisdoc_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (idcode),
  KEY statisdoc_owner (statisdoc_owner)
) ENGINE=MyISAM AUTO_INCREMENT=13 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docs_codestat`
--

LOCK TABLES docs_codestat WRITE;
/*!40000 ALTER TABLE docs_codestat DISABLE KEYS */;
INSERT INTO docs_codestat (idcode, codestat_libelle, statisdoc_codage_import, statisdoc_owner) VALUES (10,'Indéterminé','u',0);
INSERT INTO docs_codestat (idcode, codestat_libelle, statisdoc_codage_import, statisdoc_owner) VALUES (11,'Jeunes','j',0);
INSERT INTO docs_codestat (idcode, codestat_libelle, statisdoc_codage_import, statisdoc_owner) VALUES (12,'Adultes','a',0);
/*!40000 ALTER TABLE docs_codestat ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docs_location`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docs_location (
  idlocation smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  location_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  locdoc_codage_import varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  locdoc_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  location_pic varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  location_visible_opac tinyint(1) NOT NULL DEFAULT '1',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  adr1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  adr2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  cp varchar(15) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  town varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  state varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  country varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  phone varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  email varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  website varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  logo varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaire mediumtext COLLATE utf8_unicode_ci NOT NULL,
  transfert_ordre smallint(2) unsigned NOT NULL DEFAULT '9999',
  transfert_statut_defaut smallint(5) unsigned NOT NULL DEFAULT '0',
  num_infopage int(6) unsigned NOT NULL DEFAULT '0',
  css_style varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_num int(11) NOT NULL DEFAULT '0',
  surloc_used tinyint(1) NOT NULL DEFAULT '0',
  show_a2z int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (idlocation),
  KEY locdoc_owner (locdoc_owner)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docs_location`
--

LOCK TABLES docs_location WRITE;
/*!40000 ALTER TABLE docs_location DISABLE KEYS */;
INSERT INTO docs_location (idlocation, location_libelle, locdoc_codage_import, locdoc_owner, location_pic, location_visible_opac, name, adr1, adr2, cp, town, state, country, phone, email, website, logo, commentaire, transfert_ordre, transfert_statut_defaut, num_infopage, css_style, surloc_num, surloc_used, show_a2z) VALUES (1,'Bibliothèque PMB Services','',0,'',1,'Bibliothèque test de PMB','PMB Services','ZI de Mont/Loir','72500','CHATEAU DU LOIR','','France','02 43 440 660','pmb@sigb.net','http://www.sigb.net/','logo_default.jpg','',9999,0,0,'',0,0,0);
/*!40000 ALTER TABLE docs_location ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docs_section`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docs_section (
  idsection smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  section_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  sdoc_codage_import varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  sdoc_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  section_pic varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  section_visible_opac tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (idsection),
  KEY sdoc_owner (sdoc_owner)
) ENGINE=MyISAM AUTO_INCREMENT=32 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docs_section`
--

LOCK TABLES docs_section WRITE;
/*!40000 ALTER TABLE docs_section DISABLE KEYS */;
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (10,'Documentaires','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (30,'Réserve','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (13,'Romans Jeunes','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (16,'Bandes-dessinées Adultes','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (31,'Revues','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (19,'Fonds Régional','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (20,'Bandes-dessinées Jeunes','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (29,'Vidéothèque','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (23,'Romans Large vue','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (24,'Romans Adultes','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (26,'Albums','',0,'',1);
INSERT INTO docs_section (idsection, section_libelle, sdoc_codage_import, sdoc_owner, section_pic, section_visible_opac) VALUES (28,'Discothèque','',0,'',1);
/*!40000 ALTER TABLE docs_section ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docs_statut`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docs_statut (
  idstatut smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  statut_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  statut_libelle_opac varchar(255) COLLATE utf8_unicode_ci DEFAULT '',
  pret_flag tinyint(4) NOT NULL DEFAULT '1',
  statusdoc_codage_import char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  statusdoc_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  transfert_flag tinyint(4) unsigned NOT NULL DEFAULT '1',
  statut_visible_opac tinyint(1) unsigned NOT NULL DEFAULT '1',
  statut_allow_resa int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (idstatut),
  KEY statusdoc_owner (statusdoc_owner)
) ENGINE=MyISAM AUTO_INCREMENT=16 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docs_statut`
--

LOCK TABLES docs_statut WRITE;
/*!40000 ALTER TABLE docs_statut DISABLE KEYS */;
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (1,'Empruntable','',1,'',0,0,1,1);
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (2,'En cours d\'import/saisie','En traitement',0,'',0,0,1,1);
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (11,'En réparation','En réparation',0,'',0,0,1,0);
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (12,'Perdu','',0,'',0,0,0,0);
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (13,'Consultation sur place','Consultation sur place',0,'',0,0,1,0);
INSERT INTO docs_statut (idstatut, statut_libelle, statut_libelle_opac, pret_flag, statusdoc_codage_import, statusdoc_owner, transfert_flag, statut_visible_opac, statut_allow_resa) VALUES (15,'Pilon','',0,'',0,0,0,0);
/*!40000 ALTER TABLE docs_statut ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docs_type`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docs_type (
  idtyp_doc int(5) unsigned NOT NULL AUTO_INCREMENT,
  tdoc_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  duree_pret smallint(6) NOT NULL DEFAULT '31',
  duree_resa int(6) unsigned NOT NULL DEFAULT '15',
  tdoc_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  tdoc_codage_import varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tarif_pret decimal(16,2) NOT NULL DEFAULT '0.00',
  short_loan_duration int(6) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (idtyp_doc)
) ENGINE=MyISAM AUTO_INCREMENT=22 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docs_type`
--

LOCK TABLES docs_type WRITE;
/*!40000 ALTER TABLE docs_type DISABLE KEYS */;
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (1,'Livre',14,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (19,'Livre audio',31,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (13,'CD',14,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (14,'DVD',5,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (21,'Livre-CD',31,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (20,'Jeu',31,15,0,'',0.00,1);
INSERT INTO docs_type (idtyp_doc, tdoc_libelle, duree_pret, duree_resa, tdoc_owner, tdoc_codage_import, tarif_pret, short_loan_duration) VALUES (18,'Revue',8,5,0,'',0.00,1);
/*!40000 ALTER TABLE docs_type ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docsloc_section`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docsloc_section (
  num_section int(5) unsigned NOT NULL DEFAULT '0',
  num_location int(5) unsigned NOT NULL DEFAULT '0',
  num_pclass int(10) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_section,num_location)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docsloc_section`
--

LOCK TABLES docsloc_section WRITE;
/*!40000 ALTER TABLE docsloc_section DISABLE KEYS */;
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (10,1,1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (13,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (16,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (19,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (20,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (31,1,0);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (23,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (24,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (26,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (28,1,-1);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (30,1,0);
INSERT INTO docsloc_section (num_section, num_location, num_pclass) VALUES (29,1,-1);
/*!40000 ALTER TABLE docsloc_section ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_categories`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_categories (
  id_category int(10) unsigned NOT NULL AUTO_INCREMENT,
  category_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  category_num_parent int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_category)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_categories`
--

LOCK TABLES docwatch_categories WRITE;
/*!40000 ALTER TABLE docwatch_categories DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_categories ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_datasources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_datasources (
  id_datasource int(10) unsigned NOT NULL AUTO_INCREMENT,
  datasource_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  datasource_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  datasource_ttl int(10) unsigned NOT NULL DEFAULT '0',
  datasource_last_date datetime DEFAULT NULL,
  datasource_parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  datasource_num_category int(10) unsigned NOT NULL DEFAULT '0',
  datasource_default_interesting int(10) unsigned NOT NULL DEFAULT '0',
  datasource_clean_html int(10) unsigned NOT NULL DEFAULT '1',
  datasource_num_watch int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_datasource),
  KEY i_docwatch_datasource_title (datasource_title)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_datasources`
--

LOCK TABLES docwatch_datasources WRITE;
/*!40000 ALTER TABLE docwatch_datasources DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_datasources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_items`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_items (
  id_item int(10) unsigned NOT NULL AUTO_INCREMENT,
  item_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  item_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  item_summary mediumtext COLLATE utf8_unicode_ci NOT NULL,
  item_content mediumtext COLLATE utf8_unicode_ci NOT NULL,
  item_added_date datetime DEFAULT NULL,
  item_publication_date datetime DEFAULT NULL,
  item_hash varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  item_url varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  item_logo_url varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  item_status int(10) unsigned NOT NULL DEFAULT '0',
  item_interesting int(10) unsigned NOT NULL DEFAULT '0',
  item_num_article int(10) unsigned NOT NULL DEFAULT '0',
  item_num_section int(10) unsigned NOT NULL DEFAULT '0',
  item_num_notice int(10) unsigned NOT NULL DEFAULT '0',
  item_num_datasource int(10) unsigned NOT NULL DEFAULT '0',
  item_num_watch int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_item),
  KEY i_docwatch_item_type (item_type),
  KEY i_docwatch_item_title (item_title),
  KEY i_docwatch_item_num_article (item_num_article),
  KEY i_docwatch_item_num_section (item_num_section),
  KEY i_docwatch_item_num_notice (item_num_notice),
  KEY i_docwatch_item_num_watch (item_num_watch)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_items`
--

LOCK TABLES docwatch_items WRITE;
/*!40000 ALTER TABLE docwatch_items DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_items ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_items_descriptors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_items_descriptors (
  num_item int(10) unsigned NOT NULL DEFAULT '0',
  num_noeud int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_item,num_noeud)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_items_descriptors`
--

LOCK TABLES docwatch_items_descriptors WRITE;
/*!40000 ALTER TABLE docwatch_items_descriptors DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_items_descriptors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_items_tags`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_items_tags (
  num_item int(10) unsigned NOT NULL DEFAULT '0',
  num_tag int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_item,num_tag)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_items_tags`
--

LOCK TABLES docwatch_items_tags WRITE;
/*!40000 ALTER TABLE docwatch_items_tags DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_items_tags ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_selectors`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_selectors (
  id_selector int(10) unsigned NOT NULL AUTO_INCREMENT,
  selector_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  selector_num_datasource int(10) unsigned NOT NULL DEFAULT '0',
  selector_parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_selector)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_selectors`
--

LOCK TABLES docwatch_selectors WRITE;
/*!40000 ALTER TABLE docwatch_selectors DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_selectors ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_tags`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_tags (
  id_tag int(10) unsigned NOT NULL AUTO_INCREMENT,
  tag_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_tag)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_tags`
--

LOCK TABLES docwatch_tags WRITE;
/*!40000 ALTER TABLE docwatch_tags DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_tags ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `docwatch_watches`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE docwatch_watches (
  id_watch int(10) unsigned NOT NULL AUTO_INCREMENT,
  watch_title varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  watch_owner int(10) unsigned NOT NULL DEFAULT '0',
  watch_allowed_users varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  watch_num_category int(10) unsigned NOT NULL DEFAULT '0',
  watch_last_date datetime DEFAULT NULL,
  watch_ttl int(10) unsigned NOT NULL DEFAULT '0',
  watch_desc text COLLATE utf8_unicode_ci NOT NULL,
  watch_logo_url varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  watch_record_default_type char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  watch_record_default_status int(10) unsigned NOT NULL DEFAULT '0',
  watch_article_default_parent int(10) unsigned NOT NULL DEFAULT '0',
  watch_article_default_content_type int(10) unsigned NOT NULL DEFAULT '0',
  watch_article_default_publication_status int(10) unsigned NOT NULL DEFAULT '0',
  watch_section_default_parent int(10) unsigned NOT NULL DEFAULT '0',
  watch_section_default_content_type int(10) unsigned NOT NULL DEFAULT '0',
  watch_section_default_publication_status int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_watch),
  KEY i_docwatch_watch_title (watch_title)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `docwatch_watches`
--

LOCK TABLES docwatch_watches WRITE;
/*!40000 ALTER TABLE docwatch_watches DISABLE KEYS */;
/*!40000 ALTER TABLE docwatch_watches ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `dsi_archive`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE dsi_archive (
  num_banette_arc int(10) unsigned NOT NULL DEFAULT '0',
  num_notice_arc int(10) unsigned NOT NULL DEFAULT '0',
  date_diff_arc date NOT NULL DEFAULT '0000-00-00',
  PRIMARY KEY (num_banette_arc,num_notice_arc,date_diff_arc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `dsi_archive`
--

LOCK TABLES dsi_archive WRITE;
/*!40000 ALTER TABLE dsi_archive DISABLE KEYS */;
/*!40000 ALTER TABLE dsi_archive ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `editions_states`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE editions_states (
  id_editions_state int(10) unsigned NOT NULL AUTO_INCREMENT,
  editions_state_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  editions_state_num_classement int(11) NOT NULL DEFAULT '0',
  editions_state_used_datasource varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  editions_state_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  editions_state_fieldslist mediumtext COLLATE utf8_unicode_ci NOT NULL,
  editions_state_fieldsparams mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_editions_state)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `editions_states`
--

LOCK TABLES editions_states WRITE;
/*!40000 ALTER TABLE editions_states DISABLE KEYS */;
/*!40000 ALTER TABLE editions_states ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr (
  id_empr int(10) unsigned NOT NULL AUTO_INCREMENT,
  empr_cb varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  empr_nom varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_prenom varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_adr1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_adr2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_cp varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_ville varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_pays varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_mail varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_tel1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_tel2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_prof varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_year int(4) unsigned NOT NULL DEFAULT '0',
  empr_categ smallint(5) unsigned NOT NULL DEFAULT '0',
  empr_codestat smallint(5) unsigned NOT NULL DEFAULT '0',
  empr_creation datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  empr_modif date NOT NULL DEFAULT '0000-00-00',
  empr_sexe tinyint(3) unsigned NOT NULL DEFAULT '0',
  empr_login varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_password varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_password_is_encrypted int(1) NOT NULL DEFAULT '0',
  empr_digest varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_date_adhesion date DEFAULT NULL,
  empr_date_expiration date DEFAULT NULL,
  empr_msg text COLLATE utf8_unicode_ci,
  empr_lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'fr_FR',
  empr_ldap tinyint(1) unsigned DEFAULT '0',
  type_abt int(1) NOT NULL DEFAULT '0',
  last_loan_date date DEFAULT NULL,
  empr_location int(6) unsigned NOT NULL DEFAULT '1',
  date_fin_blocage date NOT NULL DEFAULT '0000-00-00',
  total_loans bigint(20) unsigned NOT NULL DEFAULT '0',
  empr_statut bigint(20) unsigned NOT NULL DEFAULT '1',
  cle_validation varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  empr_sms int(1) unsigned NOT NULL DEFAULT '0',
  empr_subscription_action text COLLATE utf8_unicode_ci,
  PRIMARY KEY (id_empr),
  UNIQUE KEY empr_cb (empr_cb),
  KEY empr_nom (empr_nom),
  KEY empr_date_adhesion (empr_date_adhesion),
  KEY empr_date_expiration (empr_date_expiration),
  KEY i_empr_categ (empr_categ),
  KEY i_empr_codestat (empr_codestat),
  KEY i_empr_location (empr_location),
  KEY i_empr_statut (empr_statut),
  KEY i_empr_typabt (type_abt)
) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr`
--

LOCK TABLES empr WRITE;
/*!40000 ALTER TABLE empr DISABLE KEYS */;
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (1,'100001','Chewbacca','\"Chewie\"','Millenium Faucon','Deuxième tourelle gauche','01000','StarwarsTown','','','','','Pilote',1900,8,4,'2012-10-22 00:00:00','2012-10-24',1,'100001','1',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'2012-11-20',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (2,'100002','Solo','Han','Millenium Faucon','Cabine du commandant','01000','StarWarsTown','','','','','',1960,7,4,'2012-10-22 00:00:00','2012-10-24',1,'hsolo','hsolo',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'0000-00-00',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (3,'100003','Skywalker','Luke','','','01000','StarWarsTown','','','','','',1970,7,4,'2012-10-22 00:00:00','2012-10-22',1,'lskywalker','lskywalker',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'0000-00-00',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (4,'100004','Leia','Princess','','','01000','StarWarsTown','','','','','',1972,7,4,'2012-10-22 00:00:00','2012-10-24',2,'100004','4',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'0000-00-00',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (5,'100005','Kenobi','Obiwan','','','01000','StarWarsTown','','','','','',1930,7,4,'2012-10-22 00:00:00','2012-10-24',1,'100005','5',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'0000-00-00',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (6,'100000','ROBERT','Eric','PMB Services','','72500','CHATEAU DU LOIR','','erobert@sigb.net','02 43 440 660','','Développeur PMB',0,7,3,'2012-10-22 00:00:00','2012-10-24',1,'erobert','1967',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'0000-00-00',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (7,'100007','TETART','Florent','PMB Services','','72500','CHATEAU DU LOIR','','ftetart@sigb.net','','','Développeur PMB',1972,7,3,'2012-10-22 00:00:00','2012-10-22',1,'ftetart','727272',0,'','2012-10-22','2013-10-22','','fr_FR',0,0,'2012-11-20',1,'0000-00-00',0,1,'',0,NULL);
INSERT INTO empr (id_empr, empr_cb, empr_nom, empr_prenom, empr_adr1, empr_adr2, empr_cp, empr_ville, empr_pays, empr_mail, empr_tel1, empr_tel2, empr_prof, empr_year, empr_categ, empr_codestat, empr_creation, empr_modif, empr_sexe, empr_login, empr_password, empr_password_is_encrypted, empr_digest, empr_date_adhesion, empr_date_expiration, empr_msg, empr_lang, empr_ldap, type_abt, last_loan_date, empr_location, date_fin_blocage, total_loans, empr_statut, cle_validation, empr_sms, empr_subscription_action) VALUES (10,'100008','BENARD','Camille','PMB Services','','72500','CHATEAU DU LOIR','','cbenard@sigb.net','','','Formatrice',1985,7,3,'2012-10-24 10:58:04','2012-10-24',2,'cbenard','1985',0,'','2012-10-24','2013-10-24','','fr_FR',0,0,'2012-11-20',1,'0000-00-00',0,1,'',0,NULL);
/*!40000 ALTER TABLE empr ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_caddie`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_caddie (
  idemprcaddie int(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(100) COLLATE utf8_unicode_ci DEFAULT NULL,
  `comment` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  autorisations longtext COLLATE utf8_unicode_ci,
  empr_caddie_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (idemprcaddie)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_caddie`
--

LOCK TABLES empr_caddie WRITE;
/*!40000 ALTER TABLE empr_caddie DISABLE KEYS */;
INSERT INTO empr_caddie (idemprcaddie, name, comment, autorisations, empr_caddie_classement) VALUES (2,'Exemple de panier de lecteurs','','1','');
/*!40000 ALTER TABLE empr_caddie ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_caddie_content`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_caddie_content (
  empr_caddie_id int(8) unsigned NOT NULL DEFAULT '0',
  object_id int(10) unsigned NOT NULL DEFAULT '0',
  flag varchar(10) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (empr_caddie_id,object_id),
  KEY object_id (object_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_caddie_content`
--

LOCK TABLES empr_caddie_content WRITE;
/*!40000 ALTER TABLE empr_caddie_content DISABLE KEYS */;
INSERT INTO empr_caddie_content (empr_caddie_id, object_id, flag) VALUES (1,1,'');
/*!40000 ALTER TABLE empr_caddie_content ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_caddie_procs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_caddie_procs (
  idproc smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  `type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'SELECT',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  requete blob NOT NULL,
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  autorisations longtext COLLATE utf8_unicode_ci,
  parameters mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (idproc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_caddie_procs`
--

LOCK TABLES empr_caddie_procs WRITE;
/*!40000 ALTER TABLE empr_caddie_procs DISABLE KEYS */;
/*!40000 ALTER TABLE empr_caddie_procs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_categ`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_categ (
  id_categ_empr smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  duree_adhesion int(10) unsigned DEFAULT '365',
  tarif_abt decimal(16,2) NOT NULL DEFAULT '0.00',
  age_min int(3) unsigned NOT NULL DEFAULT '0',
  age_max int(3) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_categ_empr)
) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_categ`
--

LOCK TABLES empr_categ WRITE;
/*!40000 ALTER TABLE empr_categ DISABLE KEYS */;
INSERT INTO empr_categ (id_categ_empr, libelle, duree_adhesion, tarif_abt, age_min, age_max) VALUES (7,'Individuel payant',365,10.00,0,0);
INSERT INTO empr_categ (id_categ_empr, libelle, duree_adhesion, tarif_abt, age_min, age_max) VALUES (8,'Individuel gratuit',365,0.00,0,0);
INSERT INTO empr_categ (id_categ_empr, libelle, duree_adhesion, tarif_abt, age_min, age_max) VALUES (9,'Personnel',365,0.00,0,0);
INSERT INTO empr_categ (id_categ_empr, libelle, duree_adhesion, tarif_abt, age_min, age_max) VALUES (10,'Collectivité',365,0.00,0,0);
/*!40000 ALTER TABLE empr_categ ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_codestat`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_codestat (
  idcode smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'DEFAULT',
  PRIMARY KEY (idcode)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_codestat`
--

LOCK TABLES empr_codestat WRITE;
/*!40000 ALTER TABLE empr_codestat DISABLE KEYS */;
INSERT INTO empr_codestat (idcode, libelle) VALUES (3,'Commune');
INSERT INTO empr_codestat (idcode, libelle) VALUES (4,'Hors commune');
/*!40000 ALTER TABLE empr_codestat ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_custom`
--

LOCK TABLES empr_custom WRITE;
/*!40000 ALTER TABLE empr_custom DISABLE KEYS */;
INSERT INTO empr_custom (idchamp, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (1,'cp_commentaire','Commentaire','comment','text','<OPTIONS FOR=\"comment\">\r\n <COLS>100</COLS>\r\n <ROWS>4</ROWS>\r\n <MAXSIZE>1000</MAXSIZE>\r\n</OPTIONS> ',0,0,1,0,0,0,100,0);
/*!40000 ALTER TABLE empr_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_custom_lists (
  empr_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  empr_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  empr_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY empr_custom_champ (empr_custom_champ),
  KEY i_ecl_lv (empr_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_custom_lists`
--

LOCK TABLES empr_custom_lists WRITE;
/*!40000 ALTER TABLE empr_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE empr_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_custom_values (
  empr_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  empr_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  empr_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  empr_custom_text mediumtext COLLATE utf8_unicode_ci,
  empr_custom_integer int(11) DEFAULT NULL,
  empr_custom_date date DEFAULT NULL,
  empr_custom_float float DEFAULT NULL,
  KEY empr_custom_champ (empr_custom_champ),
  KEY empr_custom_origine (empr_custom_origine),
  KEY i_ecv_st (empr_custom_small_text),
  KEY i_ecv_t (empr_custom_text(255)),
  KEY i_ecv_i (empr_custom_integer),
  KEY i_ecv_d (empr_custom_date),
  KEY i_ecv_f (empr_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_custom_values`
--

LOCK TABLES empr_custom_values WRITE;
/*!40000 ALTER TABLE empr_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE empr_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_grilles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_grilles (
  empr_grille_categ int(5) NOT NULL DEFAULT '0',
  empr_grille_location int(5) NOT NULL DEFAULT '0',
  empr_grille_format longtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (empr_grille_categ,empr_grille_location)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_grilles`
--

LOCK TABLES empr_grilles WRITE;
/*!40000 ALTER TABLE empr_grilles DISABLE KEYS */;
/*!40000 ALTER TABLE empr_grilles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_groupe`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_groupe (
  empr_id int(6) unsigned NOT NULL DEFAULT '0',
  groupe_id int(6) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (empr_id,groupe_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_groupe`
--

LOCK TABLES empr_groupe WRITE;
/*!40000 ALTER TABLE empr_groupe DISABLE KEYS */;
INSERT INTO empr_groupe (empr_id, groupe_id) VALUES (10,0);
/*!40000 ALTER TABLE empr_groupe ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empr_statut`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empr_statut (
  idstatut smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  statut_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  allow_loan tinyint(4) NOT NULL DEFAULT '1',
  allow_loan_hist tinyint(4) unsigned NOT NULL DEFAULT '0',
  allow_book tinyint(4) NOT NULL DEFAULT '1',
  allow_opac tinyint(4) NOT NULL DEFAULT '1',
  allow_dsi tinyint(4) NOT NULL DEFAULT '1',
  allow_dsi_priv tinyint(4) NOT NULL DEFAULT '1',
  allow_sugg tinyint(4) NOT NULL DEFAULT '1',
  allow_dema tinyint(4) unsigned NOT NULL DEFAULT '1',
  allow_prol tinyint(4) NOT NULL DEFAULT '1',
  allow_avis tinyint(4) unsigned NOT NULL DEFAULT '1',
  allow_tag tinyint(4) unsigned NOT NULL DEFAULT '1',
  allow_pwd tinyint(4) unsigned NOT NULL DEFAULT '1',
  allow_liste_lecture tinyint(4) unsigned NOT NULL DEFAULT '0',
  allow_self_checkout tinyint(4) unsigned NOT NULL DEFAULT '0',
  allow_self_checkin tinyint(4) unsigned NOT NULL DEFAULT '0',
  allow_serialcirc int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (idstatut)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empr_statut`
--

LOCK TABLES empr_statut WRITE;
/*!40000 ALTER TABLE empr_statut DISABLE KEYS */;
INSERT INTO empr_statut (idstatut, statut_libelle, allow_loan, allow_loan_hist, allow_book, allow_opac, allow_dsi, allow_dsi_priv, allow_sugg, allow_dema, allow_prol, allow_avis, allow_tag, allow_pwd, allow_liste_lecture, allow_self_checkout, allow_self_checkin, allow_serialcirc) VALUES (1,'Actif',1,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0);
INSERT INTO empr_statut (idstatut, statut_libelle, allow_loan, allow_loan_hist, allow_book, allow_opac, allow_dsi, allow_dsi_priv, allow_sugg, allow_dema, allow_prol, allow_avis, allow_tag, allow_pwd, allow_liste_lecture, allow_self_checkout, allow_self_checkin, allow_serialcirc) VALUES (2,'Interdit',0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
/*!40000 ALTER TABLE empr_statut ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `empty_words_calculs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE empty_words_calculs (
  id_calcul int(9) unsigned NOT NULL AUTO_INCREMENT,
  date_calcul date NOT NULL DEFAULT '0000-00-00',
  php_empty_words mediumtext COLLATE utf8_unicode_ci NOT NULL,
  nb_notices_calcul mediumint(8) unsigned NOT NULL DEFAULT '0',
  archive_calcul tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_calcul)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `empty_words_calculs`
--

LOCK TABLES empty_words_calculs WRITE;
/*!40000 ALTER TABLE empty_words_calculs DISABLE KEYS */;
/*!40000 ALTER TABLE empty_words_calculs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entites`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entites (
  id_entite int(5) unsigned NOT NULL AUTO_INCREMENT,
  type_entite int(3) unsigned NOT NULL DEFAULT '0',
  num_bibli int(5) unsigned NOT NULL DEFAULT '0',
  raison_sociale varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaires mediumtext COLLATE utf8_unicode_ci,
  siret varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  naf varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  rcs varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tva varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_cp_client varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_cp_compta varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  site_web varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  logo varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  autorisations longtext COLLATE utf8_unicode_ci NOT NULL,
  num_frais int(8) unsigned NOT NULL DEFAULT '0',
  num_paiement int(8) unsigned NOT NULL DEFAULT '0',
  index_entite mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_entite),
  KEY raison_sociale (raison_sociale)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entites`
--

LOCK TABLES entites WRITE;
/*!40000 ALTER TABLE entites DISABLE KEYS */;
/*!40000 ALTER TABLE entites ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_1`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_1 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_1`
--

LOCK TABLES entrepot_source_1 WRITE;
/*!40000 ALTER TABLE entrepot_source_1 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_1 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_2`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_2 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_2`
--

LOCK TABLES entrepot_source_2 WRITE;
/*!40000 ALTER TABLE entrepot_source_2 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_2 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_3`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_3 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_3`
--

LOCK TABLES entrepot_source_3 WRITE;
/*!40000 ALTER TABLE entrepot_source_3 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_3 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_4`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_4 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_4`
--

LOCK TABLES entrepot_source_4 WRITE;
/*!40000 ALTER TABLE entrepot_source_4 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_4 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_5`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_5 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_5`
--

LOCK TABLES entrepot_source_5 WRITE;
/*!40000 ALTER TABLE entrepot_source_5 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_5 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_6`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_6 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_6`
--

LOCK TABLES entrepot_source_6 WRITE;
/*!40000 ALTER TABLE entrepot_source_6 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_6 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_7`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_7 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_7`
--

LOCK TABLES entrepot_source_7 WRITE;
/*!40000 ALTER TABLE entrepot_source_7 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_7 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepot_source_8`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepot_source_8 (
  connector_id varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) unsigned NOT NULL DEFAULT '0',
  ref varchar(220) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_import datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  ufield char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_ind char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  usubfield char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  field_order int(10) unsigned NOT NULL DEFAULT '0',
  subfield_order int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  i_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  recid bigint(20) unsigned NOT NULL DEFAULT '0',
  search_id varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (connector_id,source_id,ref,ufield,usubfield,field_order,subfield_order,search_id),
  KEY usubfield (usubfield),
  KEY ufield_2 (ufield,usubfield),
  KEY recid_2 (recid,ufield,usubfield),
  KEY source_id (source_id),
  KEY i_recid_source_id (recid,source_id),
  KEY i_ref (ref)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepot_source_8`
--

LOCK TABLES entrepot_source_8 WRITE;
/*!40000 ALTER TABLE entrepot_source_8 DISABLE KEYS */;
/*!40000 ALTER TABLE entrepot_source_8 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `entrepots_localisations`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE entrepots_localisations (
  loc_id int(11) NOT NULL AUTO_INCREMENT,
  loc_code varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  loc_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  loc_visible tinyint(1) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (loc_id),
  UNIQUE KEY loc_code (loc_code)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `entrepots_localisations`
--

LOCK TABLES entrepots_localisations WRITE;
/*!40000 ALTER TABLE entrepots_localisations DISABLE KEYS */;
/*!40000 ALTER TABLE entrepots_localisations ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `equations`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE equations (
  id_equation int(9) unsigned NOT NULL AUTO_INCREMENT,
  num_classement int(8) unsigned NOT NULL DEFAULT '1',
  nom_equation text COLLATE utf8_unicode_ci NOT NULL,
  comment_equation varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  requete blob NOT NULL,
  proprio_equation int(9) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_equation)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `equations`
--

LOCK TABLES equations WRITE;
/*!40000 ALTER TABLE equations DISABLE KEYS */;
/*!40000 ALTER TABLE equations ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `error_log`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE error_log (
  error_date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  error_origin varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  error_text mediumtext COLLATE utf8_unicode_ci
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `error_log`
--

LOCK TABLES error_log WRITE;
/*!40000 ALTER TABLE error_log DISABLE KEYS */;
/*!40000 ALTER TABLE error_log ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_cache`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_cache (
  escache_groupname varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  escache_unique_id varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  escache_value int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (escache_groupname,escache_unique_id,escache_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_cache`
--

LOCK TABLES es_cache WRITE;
/*!40000 ALTER TABLE es_cache DISABLE KEYS */;
/*!40000 ALTER TABLE es_cache ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_cache_blob`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_cache_blob (
  es_cache_objectref varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_objecttype int(11) NOT NULL DEFAULT '0',
  es_cache_objectformat varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_owner varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_creationdate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  es_cache_expirationdate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  es_cache_content mediumblob NOT NULL,
  PRIMARY KEY (es_cache_objectref,es_cache_objecttype,es_cache_objectformat,es_cache_owner),
  KEY cache_index (es_cache_owner,es_cache_objectformat,es_cache_objecttype)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_cache_blob`
--

LOCK TABLES es_cache_blob WRITE;
/*!40000 ALTER TABLE es_cache_blob DISABLE KEYS */;
/*!40000 ALTER TABLE es_cache_blob ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_cache_int`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_cache_int (
  es_cache_objectref varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_objecttype int(11) NOT NULL DEFAULT '0',
  es_cache_objectformat varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_owner varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_cache_creationdate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  es_cache_expirationdate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  es_cache_content int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (es_cache_objectref,es_cache_objecttype,es_cache_objectformat,es_cache_owner),
  KEY cache_index (es_cache_owner,es_cache_objectformat,es_cache_objecttype)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_cache_int`
--

LOCK TABLES es_cache_int WRITE;
/*!40000 ALTER TABLE es_cache_int DISABLE KEYS */;
/*!40000 ALTER TABLE es_cache_int ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_converted_cache`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_converted_cache (
  es_converted_cache_objecttype int(11) NOT NULL DEFAULT '0',
  es_converted_cache_objectref int(11) NOT NULL DEFAULT '0',
  es_converted_cache_format varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_converted_cache_value mediumtext COLLATE utf8_unicode_ci NOT NULL,
  es_converted_cache_bestbefore datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (es_converted_cache_objecttype,es_converted_cache_objectref,es_converted_cache_format)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_converted_cache`
--

LOCK TABLES es_converted_cache WRITE;
/*!40000 ALTER TABLE es_converted_cache DISABLE KEYS */;
/*!40000 ALTER TABLE es_converted_cache ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_esgroup_esusers`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_esgroup_esusers (
  esgroupuser_groupnum int(11) NOT NULL DEFAULT '0',
  esgroupuser_usertype int(4) NOT NULL DEFAULT '0',
  esgroupuser_usernum int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (esgroupuser_usernum,esgroupuser_groupnum,esgroupuser_usertype)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_esgroup_esusers`
--

LOCK TABLES es_esgroup_esusers WRITE;
/*!40000 ALTER TABLE es_esgroup_esusers DISABLE KEYS */;
/*!40000 ALTER TABLE es_esgroup_esusers ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_esgroups`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_esgroups (
  esgroup_id int(11) NOT NULL AUTO_INCREMENT,
  esgroup_name varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  esgroup_fullname varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  esgroup_pmbusernum int(5) NOT NULL DEFAULT '0',
  PRIMARY KEY (esgroup_id),
  UNIQUE KEY esgroup_name (esgroup_name)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_esgroups`
--

LOCK TABLES es_esgroups WRITE;
/*!40000 ALTER TABLE es_esgroups DISABLE KEYS */;
/*!40000 ALTER TABLE es_esgroups ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_esusers`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_esusers (
  esuser_id int(11) NOT NULL AUTO_INCREMENT,
  esuser_username varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  esuser_password varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  esuser_fullname varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  esuser_groupnum int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (esuser_id),
  UNIQUE KEY esuser_username (esuser_username)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_esusers`
--

LOCK TABLES es_esusers WRITE;
/*!40000 ALTER TABLE es_esusers DISABLE KEYS */;
/*!40000 ALTER TABLE es_esusers ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_methods`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_methods (
  id_method int(10) unsigned NOT NULL AUTO_INCREMENT,
  groupe varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  method varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  available smallint(5) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_method)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_methods`
--

LOCK TABLES es_methods WRITE;
/*!40000 ALTER TABLE es_methods DISABLE KEYS */;
/*!40000 ALTER TABLE es_methods ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_methods_users`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_methods_users (
  num_method int(10) unsigned NOT NULL DEFAULT '0',
  num_user int(10) unsigned NOT NULL DEFAULT '0',
  anonymous smallint(6) DEFAULT '0',
  PRIMARY KEY (num_method,num_user)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_methods_users`
--

LOCK TABLES es_methods_users WRITE;
/*!40000 ALTER TABLE es_methods_users DISABLE KEYS */;
/*!40000 ALTER TABLE es_methods_users ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_searchcache`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_searchcache (
  es_searchcache_searchid varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_searchcache_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  es_searchcache_serializedsearch mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (es_searchcache_searchid)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_searchcache`
--

LOCK TABLES es_searchcache WRITE;
/*!40000 ALTER TABLE es_searchcache DISABLE KEYS */;
/*!40000 ALTER TABLE es_searchcache ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `es_searchsessions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE es_searchsessions (
  es_searchsession_id varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_searchsession_searchnum varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_searchsession_searchrealm varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  es_searchsession_pmbuserid int(11) NOT NULL DEFAULT '-1',
  es_searchsession_opacemprid int(11) NOT NULL DEFAULT '-1',
  es_searchsession_lastseendate datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (es_searchsession_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `es_searchsessions`
--

LOCK TABLES es_searchsessions WRITE;
/*!40000 ALTER TABLE es_searchsessions DISABLE KEYS */;
/*!40000 ALTER TABLE es_searchsessions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `etagere`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE etagere (
  idetagere int(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `comment` blob NOT NULL,
  validite int(1) unsigned NOT NULL DEFAULT '0',
  validite_date_deb date NOT NULL DEFAULT '0000-00-00',
  validite_date_fin date NOT NULL DEFAULT '0000-00-00',
  visible_accueil int(1) unsigned NOT NULL DEFAULT '1',
  autorisations longtext COLLATE utf8_unicode_ci,
  id_tri int(11) NOT NULL,
  thumbnail_url mediumblob NOT NULL,
  etagere_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (idetagere),
  KEY i_id_tri (id_tri)
) ENGINE=MyISAM AUTO_INCREMENT=10 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `etagere`
--

LOCK TABLES etagere WRITE;
/*!40000 ALTER TABLE etagere DISABLE KEYS */;
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (3,'Nouveautés','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (4,'Nouveautés fiction adultes','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (5,'Nouveautés fiction jeunesse','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (6,'Nouveautés documentaires','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (7,'Nouveautés CD','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (8,'Nouveautés DVD','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
INSERT INTO etagere (idetagere, name, comment, validite, validite_date_deb, validite_date_fin, visible_accueil, autorisations, id_tri, thumbnail_url, etagere_classement) VALUES (9,'Nouveautés périodiques','',1,'0000-00-00','0000-00-00',0,'1',0,'','');
/*!40000 ALTER TABLE etagere ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `etagere_caddie`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE etagere_caddie (
  etagere_id int(8) unsigned NOT NULL DEFAULT '0',
  caddie_id int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (etagere_id,caddie_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `etagere_caddie`
--

LOCK TABLES etagere_caddie WRITE;
/*!40000 ALTER TABLE etagere_caddie DISABLE KEYS */;
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (3,12);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (4,13);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (5,14);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (6,15);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (7,16);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (8,17);
INSERT INTO etagere_caddie (etagere_id, caddie_id) VALUES (9,18);
/*!40000 ALTER TABLE etagere_caddie ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `exemplaires`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE exemplaires (
  expl_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  expl_cb varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  expl_notice int(10) unsigned NOT NULL DEFAULT '0',
  expl_bulletin int(10) unsigned NOT NULL DEFAULT '0',
  expl_typdoc int(5) unsigned NOT NULL DEFAULT '0',
  expl_cote varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  expl_section smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_statut smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_location smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_codestat smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_date_depot date NOT NULL DEFAULT '0000-00-00',
  expl_date_retour date NOT NULL DEFAULT '0000-00-00',
  expl_note text COLLATE utf8_unicode_ci NOT NULL,
  expl_prix varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  expl_owner mediumint(8) unsigned NOT NULL DEFAULT '0',
  expl_lastempr int(10) unsigned NOT NULL DEFAULT '0',
  last_loan_date date DEFAULT NULL,
  create_date datetime NOT NULL DEFAULT '2005-01-01 00:00:00',
  update_date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  type_antivol int(1) unsigned NOT NULL DEFAULT '0',
  transfert_location_origine smallint(5) unsigned NOT NULL DEFAULT '0',
  transfert_statut_origine smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_comment mediumtext COLLATE utf8_unicode_ci,
  expl_nbparts int(8) unsigned NOT NULL DEFAULT '1',
  expl_retloc smallint(5) unsigned NOT NULL DEFAULT '0',
  expl_abt_num int(10) unsigned NOT NULL DEFAULT '0',
  transfert_section_origine smallint(5) NOT NULL DEFAULT '0',
  PRIMARY KEY (expl_id),
  UNIQUE KEY expl_cb (expl_cb),
  KEY expl_typdoc (expl_typdoc),
  KEY expl_cote (expl_cote),
  KEY expl_notice (expl_notice),
  KEY expl_codestat (expl_codestat),
  KEY expl_owner (expl_owner),
  KEY expl_bulletin (expl_bulletin),
  KEY i_expl_location (expl_location),
  KEY i_expl_section (expl_section),
  KEY i_expl_statut (expl_statut),
  KEY i_expl_lastempr (expl_lastempr)
) ENGINE=MyISAM AUTO_INCREMENT=99 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `exemplaires`
--

LOCK TABLES exemplaires WRITE;
/*!40000 ALTER TABLE exemplaires DISABLE KEYS */;
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (70,'000034',89,0,1,'640 BEL',10,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:51:07','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (69,'000033',90,0,1,'910 J NAN',10,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:50:05','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (68,'000032',95,0,1,'A COR',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:47:57','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (67,'000031',95,0,1,'A COR',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:47:46','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (66,'000030',91,0,1,'A GOU',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:47:29','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (64,'000028',93,0,1,'A GAY',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:46:15','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (65,'000029',92,0,1,'BD J GUE',20,1,1,11,'0000-00-00','0000-00-00','','',1,0,'2012-11-20','2012-10-24 15:46:57','2015-05-18 09:14:16',0,1,1,'',1,0,0,20);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (63,'000027',93,0,1,'A GAY',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:46:03','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (62,'000026',94,0,1,'580 J GUI',10,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:44:59','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (61,'000025',95,0,1,'A COR',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:42:34','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (60,'000024',96,0,1,'640 J LOU',10,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:41:59','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (59,'000023',97,0,1,'640 J SER',10,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:40:56','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (58,'000022',98,0,1,'640 J TEY',10,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:40:04','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (57,'000021',99,0,1,'740 FRE',10,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:37:53','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (56,'000020',100,0,1,'740 J FRE',10,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:36:34','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (55,'000019',101,0,1,'A BRA',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:35:11','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (54,'000018',102,0,1,'A GRA',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:34:08','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (52,'000016',104,0,1,'RX PRA',24,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:31:12','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (53,'000017',103,0,1,'RX BRA',24,1,1,12,'0000-00-00','0000-00-00','','',2,0,'2012-11-20','2012-10-24 15:32:35','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (51,'000015',105,0,1,'RX PRA',24,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:30:15','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (50,'000014',106,0,1,'P BUR',10,1,1,12,'0000-00-00','0000-00-00','','',2,0,'2012-11-20','2012-10-24 15:28:12','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (49,'000013',107,0,18,'700 J TIM',10,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:24:29','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (48,'000012',108,0,1,'700 DEB',10,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:22:58','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (47,'000011',109,0,1,'780 J SIL',10,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:21:13','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (46,'000010',119,0,13,'9.1 AMA',28,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:15:23','2015-05-18 09:14:16',0,1,1,'',1,0,0,28);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (45,'000009',118,0,13,'9.1 KEI',28,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:12:02','2015-05-18 09:14:16',0,1,1,'',1,0,0,28);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (44,'000008',117,0,13,'9.1 TRA',28,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:10:29','2015-05-18 09:14:16',0,1,1,'',1,0,0,28);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (43,'000007',116,0,13,'9.1 LO',28,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:08:49','2015-05-18 09:14:16',0,1,1,'',1,0,0,28);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (42,'000006',115,0,13,'9.1 MAK',28,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:06:05','2015-05-18 09:14:16',0,1,1,'',1,0,0,28);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (41,'000005',114,0,14,'DVDJ CHAR',29,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:00:33','2015-05-18 09:14:16',0,1,1,'',1,0,0,29);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (38,'000002',112,0,14,'DVD BIG',29,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 14:55:48','2015-05-18 09:14:16',0,1,1,'',1,0,0,29);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (39,'000003',111,0,14,'DVD BEE',29,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 14:56:07','2015-05-18 09:14:16',0,1,1,'',1,0,0,29);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (40,'000004',113,0,14,'DVDJ NOC',29,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 14:58:15','2015-05-18 09:14:16',0,1,1,'',1,0,0,29);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (37,'000001',110,0,14,'DVD EDW',29,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 14:49:39','2015-05-18 09:14:16',0,1,1,'',1,0,0,29);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (71,'000036',88,0,1,'020 BON',10,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:53:02','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (72,'000037',87,0,1,'RJ MAH',13,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:53:51','2015-05-18 09:14:16',0,1,1,'',1,0,0,13);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (73,'000038',86,0,1,'RP BEI',24,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:54:44','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (74,'000039',85,0,1,'JR BRI',13,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:56:03','2015-05-18 09:14:16',0,1,1,'',1,0,0,13);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (75,'000040',84,0,1,'020 PAL',10,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:56:41','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (76,'000041',83,0,1,'020 ASS',10,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:57:56','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (77,'000042',83,0,1,'020 ASS',30,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 15:58:06','2015-05-18 09:14:16',0,1,1,'',1,0,0,30);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (78,'000044',82,0,1,'020 MEL',10,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 15:58:46','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (79,'000045',81,0,1,'RJP HEI',13,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:00:11','2015-05-18 09:14:16',0,1,1,'',1,0,0,13);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (80,'000046',80,0,1,'RJ GUD',13,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:01:15','2015-05-18 09:14:16',0,1,1,'',1,0,0,13);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (81,'000047',79,0,1,'A GRA',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:03:09','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (82,'000048',78,0,1,'R MAR',24,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 16:04:11','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (83,'000049',77,0,1,'R MAB',24,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:04:54','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (84,'000050',76,0,1,'BD ABO',16,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:05:39','2015-05-18 09:14:16',0,1,1,'',1,0,0,16);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (85,'000051',75,0,1,'BD ABO',16,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:06:17','2015-05-18 09:14:16',0,1,1,'',1,0,0,16);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (86,'000052',74,0,1,'A DEB',26,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:07:32','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (87,'000053',74,0,1,'A DEB',26,1,1,11,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 16:07:46','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (88,'000054',73,0,1,'A DED',26,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:08:33','2015-05-18 09:14:16',0,1,1,'',1,0,0,26);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (89,'000056',72,0,21,'780 J GRO',10,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:10:14','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (90,'000057',71,0,1,'960 DEP',10,1,1,12,'0000-00-00','0000-00-00','','',1,0,'2012-11-20','2012-10-24 16:11:51','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (91,'000058',70,0,1,'960 ZAI',10,1,1,12,'0000-00-00','0000-00-00','','',1,0,NULL,'2012-10-24 16:13:32','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (92,'000059',69,0,1,'C BAA',10,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:14:22','2015-05-18 09:14:16',0,1,1,'',1,0,0,10);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (93,'000060',68,0,19,'RA BLI',24,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 16:15:37','2015-05-18 09:14:16',0,1,1,'',1,0,0,24);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (94,'P000002',0,5,18,'PER GEO',31,1,1,12,'0000-00-00','0000-00-00','','',2,0,'2012-11-20','2012-10-24 17:27:03','2015-05-18 09:14:16',0,1,1,'',0,0,0,31);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (95,'P000003',0,4,18,'PER GEO',31,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 17:27:22','2015-05-18 09:14:16',0,1,1,'',0,0,0,31);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (96,'P000004',0,9,18,'PER J GEO',31,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 18:12:58','2015-05-18 09:14:16',0,1,1,'',0,0,0,31);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (97,'P000005',0,10,18,'PER J GEO',31,1,1,11,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-24 18:14:42','2015-05-18 09:14:16',0,1,1,'',0,0,0,31);
INSERT INTO exemplaires (expl_id, expl_cb, expl_notice, expl_bulletin, expl_typdoc, expl_cote, expl_section, expl_statut, expl_location, expl_codestat, expl_date_depot, expl_date_retour, expl_note, expl_prix, expl_owner, expl_lastempr, last_loan_date, create_date, update_date, type_antivol, transfert_location_origine, transfert_statut_origine, expl_comment, expl_nbparts, expl_retloc, expl_abt_num, transfert_section_origine) VALUES (98,'P000006',0,11,18,'PER STU',31,1,1,12,'0000-00-00','0000-00-00','','',2,0,NULL,'2012-10-25 09:23:28','2015-05-18 09:14:16',0,1,1,'',0,0,0,31);
/*!40000 ALTER TABLE exemplaires ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `exemplaires_temp`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE exemplaires_temp (
  cb varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  sess varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  UNIQUE KEY cb (cb)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `exemplaires_temp`
--

LOCK TABLES exemplaires_temp WRITE;
/*!40000 ALTER TABLE exemplaires_temp DISABLE KEYS */;
/*!40000 ALTER TABLE exemplaires_temp ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `exercices`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE exercices (
  id_exercice int(8) unsigned NOT NULL AUTO_INCREMENT,
  num_entite int(5) unsigned NOT NULL DEFAULT '0',
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_debut date NOT NULL DEFAULT '2006-01-01',
  date_fin date NOT NULL DEFAULT '2006-01-01',
  statut int(3) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_exercice)
) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `exercices`
--

LOCK TABLES exercices WRITE;
/*!40000 ALTER TABLE exercices DISABLE KEYS */;
/*!40000 ALTER TABLE exercices ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `expl_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE expl_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `expl_custom`
--

LOCK TABLES expl_custom WRITE;
/*!40000 ALTER TABLE expl_custom DISABLE KEYS */;
INSERT INTO expl_custom (idchamp, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (1,'cp_date_acquisition','Date d\'acquisition','date_box','date','<OPTIONS FOR=\"date_box\"></OPTIONS> ',0,0,1,0,1,0,100,0);
INSERT INTO expl_custom (idchamp, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (2,'cp_date_pilon','Date de pilon','date_box','date','<OPTIONS FOR=\"date_box\">\r\n <DEFAULT_TODAY>yes</DEFAULT_TODAY>\r\n</OPTIONS> ',0,0,2,0,1,0,100,0);
INSERT INTO expl_custom (idchamp, name, titre, type, datatype, options, multiple, obligatoire, ordre, search, export, exclusion_obligatoire, pond, opac_sort) VALUES (3,'cp_origine','Origine','list','small_text','<OPTIONS FOR=\"list\">\r\n <MULTIPLE>no</MULTIPLE>\r\n <AUTORITE>no</AUTORITE>\r\n <CHECKBOX>no</CHECKBOX>\r\n <NUM_AUTO>no</NUM_AUTO>\r\n <UNSELECT_ITEM VALUE=\"\"><![CDATA[Choisissez une origine]]></UNSELECT_ITEM>\r\n <DEFAULT_VALUE></DEFAULT_VALUE>\r\n <CHECKBOX_NB_ON_LINE></CHECKBOX_NB_ON_LINE>\r\n</OPTIONS>',0,0,3,0,1,0,100,0);
/*!40000 ALTER TABLE expl_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `expl_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE expl_custom_lists (
  expl_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  expl_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  expl_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY expl_custom_champ (expl_custom_champ),
  KEY i_excl_lv (expl_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `expl_custom_lists`
--

LOCK TABLES expl_custom_lists WRITE;
/*!40000 ALTER TABLE expl_custom_lists DISABLE KEYS */;
INSERT INTO expl_custom_lists (expl_custom_champ, expl_custom_list_value, expl_custom_list_lib, ordre) VALUES (3,'ACH','Achat',1);
INSERT INTO expl_custom_lists (expl_custom_champ, expl_custom_list_value, expl_custom_list_lib, ordre) VALUES (3,'DON','Don',2);
INSERT INTO expl_custom_lists (expl_custom_champ, expl_custom_list_value, expl_custom_list_lib, ordre) VALUES (3,'DEP','Dépôt',3);
/*!40000 ALTER TABLE expl_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `expl_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE expl_custom_values (
  expl_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  expl_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  expl_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  expl_custom_text mediumtext COLLATE utf8_unicode_ci,
  expl_custom_integer int(11) DEFAULT NULL,
  expl_custom_date date DEFAULT NULL,
  expl_custom_float float DEFAULT NULL,
  KEY expl_custom_champ (expl_custom_champ),
  KEY expl_custom_origine (expl_custom_origine),
  KEY i_excv_st (expl_custom_small_text),
  KEY i_excv_t (expl_custom_text(255)),
  KEY i_excv_i (expl_custom_integer),
  KEY i_excv_d (expl_custom_date),
  KEY i_excv_f (expl_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `expl_custom_values`
--

LOCK TABLES expl_custom_values WRITE;
/*!40000 ALTER TABLE expl_custom_values DISABLE KEYS */;
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,37,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,37,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,41,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,38,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,39,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,39,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,40,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,41,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,42,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,42,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,43,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,44,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,44,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,45,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,46,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,46,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,47,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,47,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,48,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,49,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,49,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,50,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,50,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,51,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,52,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,53,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,53,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,52,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,54,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,54,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,55,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,55,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,56,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,57,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,56,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,58,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,59,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,58,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,60,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,60,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,61,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,61,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,62,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,62,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,63,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,63,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,64,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,64,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,65,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,66,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,66,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,67,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,67,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,68,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,68,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,69,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,70,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,70,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,71,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,71,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,72,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,72,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,73,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,73,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,74,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,74,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,75,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,76,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,76,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,77,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,77,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,78,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,79,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,79,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,80,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,80,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,81,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,81,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,82,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,83,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,83,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,84,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,84,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,85,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,85,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,86,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,86,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,87,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,88,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,88,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,89,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,89,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,90,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,91,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,91,'DEP',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,92,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,92,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,93,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,93,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,94,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,94,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,95,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,95,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,96,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,96,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,97,NULL,NULL,NULL,'2012-10-24',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,97,'ACH',NULL,NULL,NULL,NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (1,98,NULL,NULL,NULL,'2012-10-25',NULL);
INSERT INTO expl_custom_values (expl_custom_champ, expl_custom_origine, expl_custom_small_text, expl_custom_text, expl_custom_integer, expl_custom_date, expl_custom_float) VALUES (3,98,'ACH',NULL,NULL,NULL,NULL);
/*!40000 ALTER TABLE expl_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum (
  explnum_id int(11) unsigned NOT NULL AUTO_INCREMENT,
  explnum_notice mediumint(8) unsigned NOT NULL DEFAULT '0',
  explnum_bulletin int(8) unsigned NOT NULL DEFAULT '0',
  explnum_nom varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_mimetype varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_url mediumtext COLLATE utf8_unicode_ci NOT NULL,
  explnum_data mediumblob,
  explnum_vignette mediumblob,
  explnum_extfichier varchar(20) COLLATE utf8_unicode_ci DEFAULT '',
  explnum_nomfichier mediumtext COLLATE utf8_unicode_ci,
  explnum_statut int(5) unsigned NOT NULL DEFAULT '0',
  explnum_index_sew longtext COLLATE utf8_unicode_ci NOT NULL,
  explnum_index_wew longtext COLLATE utf8_unicode_ci NOT NULL,
  explnum_repertoire int(8) NOT NULL DEFAULT '0',
  explnum_path mediumtext COLLATE utf8_unicode_ci NOT NULL,
  explnum_docnum_statut smallint(5) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (explnum_id),
  KEY explnum_notice (explnum_notice),
  KEY explnum_bulletin (explnum_bulletin),
  KEY explnum_repertoire (explnum_repertoire),
  KEY i_explnum_nomfichier (explnum_nomfichier(30)),
  FULLTEXT KEY i_f_explnumwew (explnum_index_wew)
) ENGINE=MyISAM AUTO_INCREMENT=16 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum`
--

LOCK TABLES explnum WRITE;
/*!40000 ALTER TABLE explnum DISABLE KEYS */;
INSERT INTO explnum (explnum_id, explnum_notice, explnum_bulletin, explnum_nom, explnum_mimetype, explnum_url, explnum_data, explnum_vignette, explnum_extfichier, explnum_nomfichier, explnum_statut, explnum_index_sew, explnum_index_wew, explnum_repertoire, explnum_path, explnum_docnum_statut) VALUES (4,125,0,'Lire l\'article en ligne','URL','http://bbf.enssib.fr/consulter/bbf-2010-06-0041-010','','','','',0,'  ','',0,'',1);
INSERT INTO explnum (explnum_id, explnum_notice, explnum_bulletin, explnum_nom, explnum_mimetype, explnum_url, explnum_data, explnum_vignette, explnum_extfichier, explnum_nomfichier, explnum_statut, explnum_index_sew, explnum_index_wew, explnum_repertoire, explnum_path, explnum_docnum_statut) VALUES (5,126,0,'Lire l\'article en ligne','URL','http://bbf.enssib.fr/consulter/bbf-2010-06-0020-004','','','','',0,'  ','',0,'',1);
INSERT INTO explnum (explnum_id, explnum_notice, explnum_bulletin, explnum_nom, explnum_mimetype, explnum_url, explnum_data, explnum_vignette, explnum_extfichier, explnum_nomfichier, explnum_statut, explnum_index_sew, explnum_index_wew, explnum_repertoire, explnum_path, explnum_docnum_statut) VALUES (15,127,0,'Lire l\'article en ligne','URL','http://bbf.enssib.fr/consulter/bbf-2012-05-0056-011','','','','',0,'  ','',0,'',1);
INSERT INTO explnum (explnum_id, explnum_notice, explnum_bulletin, explnum_nom, explnum_mimetype, explnum_url, explnum_data, explnum_vignette, explnum_extfichier, explnum_nomfichier, explnum_statut, explnum_index_sew, explnum_index_wew, explnum_repertoire, explnum_path, explnum_docnum_statut) VALUES (10,135,0,'Ebook format E-pub','application/epub+zip','', ,'','epub','820145269_Epub.epub',0,'','',0,'',1);
INSERT INTO explnum (explnum_id, explnum_notice, explnum_bulletin, explnum_nom, explnum_mimetype, explnum_url, explnum_data, explnum_vignette, explnum_extfichier, explnum_nomfichier, explnum_statut, explnum_index_sew, explnum_index_wew, explnum_repertoire, explnum_path, explnum_docnum_statut) VALUES (9,136,0,'Ebook format E-pub','application/epub+zip','', ,'','epub','Baudelairefleursdumal.epub',0,'','',0,'',1);
/*!40000 ALTER TABLE explnum ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_doc`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_doc (
  id_explnum_doc int(8) unsigned NOT NULL AUTO_INCREMENT,
  explnum_doc_nomfichier mediumtext COLLATE utf8_unicode_ci NOT NULL,
  explnum_doc_mimetype varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_doc_data mediumblob NOT NULL,
  explnum_doc_extfichier varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_doc_url mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_explnum_doc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_doc`
--

LOCK TABLES explnum_doc WRITE;
/*!40000 ALTER TABLE explnum_doc DISABLE KEYS */;
/*!40000 ALTER TABLE explnum_doc ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_doc_actions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_doc_actions (
  num_explnum_doc int(10) NOT NULL DEFAULT '0',
  num_action int(10) NOT NULL DEFAULT '0',
  prive int(1) NOT NULL DEFAULT '0',
  rapport int(1) NOT NULL DEFAULT '0',
  num_explnum int(10) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_explnum_doc,num_action)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_doc_actions`
--

LOCK TABLES explnum_doc_actions WRITE;
/*!40000 ALTER TABLE explnum_doc_actions DISABLE KEYS */;
/*!40000 ALTER TABLE explnum_doc_actions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_doc_sugg`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_doc_sugg (
  num_explnum_doc int(10) NOT NULL DEFAULT '0',
  num_suggestion int(10) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_explnum_doc,num_suggestion)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_doc_sugg`
--

LOCK TABLES explnum_doc_sugg WRITE;
/*!40000 ALTER TABLE explnum_doc_sugg DISABLE KEYS */;
/*!40000 ALTER TABLE explnum_doc_sugg ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_location`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_location (
  num_explnum int(10) NOT NULL DEFAULT '0',
  num_location int(10) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_explnum,num_location)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_location`
--

LOCK TABLES explnum_location WRITE;
/*!40000 ALTER TABLE explnum_location DISABLE KEYS */;
INSERT INTO explnum_location (num_explnum, num_location) VALUES (2,1);
/*!40000 ALTER TABLE explnum_location ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_segments`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_segments (
  explnum_segment_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  explnum_segment_explnum_num int(10) unsigned NOT NULL DEFAULT '0',
  explnum_segment_speaker_num int(10) unsigned NOT NULL DEFAULT '0',
  explnum_segment_start double NOT NULL DEFAULT '0',
  explnum_segment_duration double NOT NULL DEFAULT '0',
  explnum_segment_end double NOT NULL DEFAULT '0',
  PRIMARY KEY (explnum_segment_id),
  KEY i_ensg_explnum_num (explnum_segment_explnum_num),
  KEY i_ensg_speaker (explnum_segment_speaker_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_segments`
--

LOCK TABLES explnum_segments WRITE;
/*!40000 ALTER TABLE explnum_segments DISABLE KEYS */;
/*!40000 ALTER TABLE explnum_segments ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_speakers`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_speakers (
  explnum_speaker_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  explnum_speaker_explnum_num int(10) unsigned NOT NULL DEFAULT '0',
  explnum_speaker_speaker_num varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_speaker_gender varchar(1) COLLATE utf8_unicode_ci DEFAULT '',
  explnum_speaker_author int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (explnum_speaker_id),
  KEY i_ensk_explnum_num (explnum_speaker_explnum_num),
  KEY i_ensk_author (explnum_speaker_author)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_speakers`
--

LOCK TABLES explnum_speakers WRITE;
/*!40000 ALTER TABLE explnum_speakers DISABLE KEYS */;
/*!40000 ALTER TABLE explnum_speakers ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `explnum_statut`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE explnum_statut (
  id_explnum_statut smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  gestion_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  opac_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  class_html varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  explnum_visible_opac tinyint(1) NOT NULL DEFAULT '1',
  explnum_visible_opac_abon tinyint(1) NOT NULL DEFAULT '0',
  explnum_consult_opac tinyint(1) NOT NULL DEFAULT '1',
  explnum_consult_opac_abon tinyint(1) NOT NULL DEFAULT '0',
  explnum_download_opac tinyint(1) NOT NULL DEFAULT '1',
  explnum_download_opac_abon tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_explnum_statut)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `explnum_statut`
--

LOCK TABLES explnum_statut WRITE;
/*!40000 ALTER TABLE explnum_statut DISABLE KEYS */;
INSERT INTO explnum_statut (id_explnum_statut, gestion_libelle, opac_libelle, class_html, explnum_visible_opac, explnum_visible_opac_abon, explnum_consult_opac, explnum_consult_opac_abon, explnum_download_opac, explnum_download_opac_abon) VALUES (1,'Sans statut particulier','','',1,0,1,0,1,0);
/*!40000 ALTER TABLE explnum_statut ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `external_count`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE external_count (
  rid bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  recid varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_id int(11) NOT NULL,
  PRIMARY KEY (rid),
  KEY recid (recid)
) ENGINE=MyISAM AUTO_INCREMENT=6497 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `external_count`
--

LOCK TABLES external_count WRITE;
/*!40000 ALTER TABLE external_count DISABLE KEYS */;
INSERT INTO external_count (rid, recid, source_id) VALUES (1,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb33409493k/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106270v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34515z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34514m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328566125/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (7,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345138',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (8,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34512x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (9,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326804969/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (10,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84220r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (11,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103770k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (12,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049596',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (13,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (14,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103767w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (15,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106287v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (16,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (17,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106260h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (18,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106286g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (19,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038731',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (20,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104940f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (21,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720521/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (22,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105690h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (23,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105689k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (24,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057450',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (25,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103586k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (26,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103587z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (27,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035856',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (28,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103588b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (29,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74436g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (30,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044520',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (31,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044855',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (32,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104907q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (33,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104905z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (34,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049083',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (35,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104909g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (36,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104906b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (37,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062730',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (38,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104487x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (39,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591537',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (40,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200851z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (41,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104662z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (42,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326950044/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (43,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046687',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (44,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047285',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (45,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104664q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (46,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104663b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (47,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104671x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (48,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104670j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (49,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104667v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (50,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104666g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (51,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104669m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (52,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046653',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (53,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (54,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104675f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (55,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (56,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042591',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (57,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104384g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (58,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104440w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (59,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103737v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (60,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (61,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104953x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (62,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104911s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (63,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105353b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (64,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104808s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (65,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106261w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (66,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104918f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (67,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (68,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104914x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (69,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049549',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (70,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49679w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (71,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043909',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (72,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106205b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (73,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84097s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (74,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048540',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (75,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105354q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (76,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104489p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (77,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044889',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (78,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95347h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (79,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k91437h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (80,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106209v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (81,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104381b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (82,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82435v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (83,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82434h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (84,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104442n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (85,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (86,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048048',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (87,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (88,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104805n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (89,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (90,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34461v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (91,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344746',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (92,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34460h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (93,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34467x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (94,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344599',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (95,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34470t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (96,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34469m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (97,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34473v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (98,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344626',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (99,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34458z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (101,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105762j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (102,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (103,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104267m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (104,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105759v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (105,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67054t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (106,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85219s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (107,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85218f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (108,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104382q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (109,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (110,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104517t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (111,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037654',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (112,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39817p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (113,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398139',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (114,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056763',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (115,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056797',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (116,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105693n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (117,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105682x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (118,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105695d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (119,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105681j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (120,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105684p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105687t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056805',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056941',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (124,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105673z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (125,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105686f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (126,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056839',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (127,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105675q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (128,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720552/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (129,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105674b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (130,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105678v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (131,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105677g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056852',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106283b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037476',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (135,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056203',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105660g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056237',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (138,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105663m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105647f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105666r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105612h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105669w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105631t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105615n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056627',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105618s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105634z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056462',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (149,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056496',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056114',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105651h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056148',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105635b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105670t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105654n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105638g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105657s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056504',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105622v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (160,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328169156/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (161,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056538',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056373',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (163,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105626c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105642j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105629h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105661v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105645p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105648t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105613w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056415',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105665c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056449',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056250',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056284',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105668h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105630f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105633k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (178,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105617d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105652w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (180,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105636q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (181,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056640',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105639v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056674',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (184,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056326',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105672k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (186,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105656d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (188,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056195',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105691w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105659j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105621g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105640s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056716',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (194,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105643x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105627r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056551',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056585',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036030',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66361p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106158w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042489',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104969j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049685',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104970g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030937',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103780x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104994p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049952',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398181',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105866c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105870f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103551n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103549b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103572q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k3700445',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037387',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56886948',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104777h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (223,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34425274b/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (224,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047806',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104778w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (227,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63971x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63970k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639410',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639441',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639472',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63962z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63964n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63961m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63969c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63950z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639608',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63952n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63958q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63955p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63957c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63954b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639650',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639519',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63940n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63949r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63946q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63943p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (253,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34349269z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63948d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63945c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (256,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63942b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (259,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103634d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5608582h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036331',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104372c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104370m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744087',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037217',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82789m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82792h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82793v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82790t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k827915',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104408j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62076x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104264g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104529x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (276,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103575v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (277,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103574g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (278,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103718j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (279,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037531',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (280,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104098d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (281,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104110x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104847s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042455',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104246j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103720v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103719x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104412m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048137',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063438',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105867r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (294,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058684',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k823180',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82317n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104451m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (298,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044507',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053341',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103593s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104729j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103722m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39669c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035733',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104799z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39674z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103766h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (310,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104475t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39673m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k392051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035911',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105753k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106157h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k289312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104550j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (319,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82678p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84614x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104727s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104535r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103623p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104936c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038807',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496776',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104261b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105754z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30797q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104117k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104816c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053430',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104118z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048930',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104894c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104119b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84112v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104526s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105348w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049562',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104745q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104943k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104738h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045186',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104249p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104849j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (349,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047539',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104923w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104920r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049214',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (353,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104922h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106162z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k293638',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104850g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104800r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053375',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104115t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496803',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104498n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104507g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045063',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105885p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105844x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104853m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104472p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104478z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036017',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103602m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043880',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104422z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104423b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104421k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103369d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104985q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103754d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103755s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104521w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105750f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104996f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104997t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (387,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104731v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103883c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104525d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048574',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035555',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106441t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1064426',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39678b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043710',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104369p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043689',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044944',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105330h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49684g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103695v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104897h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104867g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103775g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103776v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103557x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (411,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103732z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103583f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048663',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104130m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (415,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044431',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036187',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048875',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104888j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034219',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105858s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105855n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058548',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105857d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103457m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104511j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104992x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049939',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104962w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104895r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048828',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105758g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036891',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105335d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105336s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104939h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104375h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39671x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2000804',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (440,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103595j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104872x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049515',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103579c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104367x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104516f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037620',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104751j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103763c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058425',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104090c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049384',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105892w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035610',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103772b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39679p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035521',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103571b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044690',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104103q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103895g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105699x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103757j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037607',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104101z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104255h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744056',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (468,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74404v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103559p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103635s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104479b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104274t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103725r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39805p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040801',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104462b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035644',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104085x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106344n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042633',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104244s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042667',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044342',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044329',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (486,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104541k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104492c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049303',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044719',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033634',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035691',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105876q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k26770x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104874p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104934m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104932v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (497,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049337',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (498,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200844r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (499,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5673310q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (500,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k824366',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (501,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104551x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (502,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103865f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (503,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104100k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (504,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841047',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (505,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84103w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (506,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496896',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (507,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104859w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (508,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82440f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (509,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104232p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (510,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048451',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (511,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30859f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (512,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103764r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (513,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049295',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (514,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041255',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (515,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058773',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (516,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058650',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (517,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398092',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (518,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037230',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (519,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396759',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (520,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103874d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (521,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105888t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (522,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104376w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (523,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037921',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (524,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398108',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (525,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030903',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (526,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5525439j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (527,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104260z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (528,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104466v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (529,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044677',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (530,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063930',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (531,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104871j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (532,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104950s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (533,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104387m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (534,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103752n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (535,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040793',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (536,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037429',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (537,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104807d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (538,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103420x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (539,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104519k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (540,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103773q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (541,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200850k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (542,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104431x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (543,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105339x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (544,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104846d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (545,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044643',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (546,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058815',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (547,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105331w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (548,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104424q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (549,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104430j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (550,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105344c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (551,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39676n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (552,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103584t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (553,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103739m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (554,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106154c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (555,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105751t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (556,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060618',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (557,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042680',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (558,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104439z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (559,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103592d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (560,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045542',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (561,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82386g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (562,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106060w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (563,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104500t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (564,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106203k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (565,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106200f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (566,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106201t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (567,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106199n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (568,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062026',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (569,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061988',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (570,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062162',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (571,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104087p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (572,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057615',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (573,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104730g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (574,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104514p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (575,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104958t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (576,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104448x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (577,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044130',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (578,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104983z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (579,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048739',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (580,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104945b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (581,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104447j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (582,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103091g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (583,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k75667j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (584,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k842275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (585,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047929',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (586,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49798f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (587,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k25566w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (588,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103416v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (589,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034143',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (590,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106284q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (591,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062853',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (592,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103893q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (593,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (594,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062675',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (595,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106161k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (596,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048485',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (597,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95348v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (598,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103092v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (599,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103554s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (600,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103565h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (601,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104547v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (602,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104271p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (603,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042722',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (604,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038718',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (605,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104877t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (606,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105756q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (607,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103637j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (608,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058904',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (609,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105883x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (610,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103364h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (611,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043791',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (612,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103412b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (613,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (614,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104378n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (615,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103614q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (616,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200835s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (617,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103577m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (618,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104946q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (619,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104453c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (620,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104802h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (621,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104124s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (622,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104865q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (623,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103878x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (624,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103604c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (625,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036106',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (626,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037306',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (627,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103724c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (628,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053506',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (629,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104534c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (630,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057526',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (631,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045139',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (632,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036967',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (633,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103884r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (634,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200198t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (635,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103691b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (636,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (637,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104948g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (638,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k823049',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (639,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104252c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (640,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104399q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (641,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103892b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (642,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103891z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (643,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103749z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (644,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104987g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (645,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104988v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (646,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103138c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (647,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104459n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (648,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040924',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (649,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048841',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (650,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048998',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (651,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036229',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (652,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053464',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (653,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037298',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (654,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044978',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (655,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103785t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (656,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105891h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (657,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104493r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (658,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103741x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (659,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1050979',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (660,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041077',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (661,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104856r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (662,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104658w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (663,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104814m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (664,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2001996',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (665,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104444d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (666,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035809',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (667,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103769n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (668,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104892m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (669,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104089f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (670,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047416',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (671,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104496w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (672,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104121n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (673,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105763x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (674,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398150',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (675,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2000838',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (676,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103630w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (677,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036318',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (678,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035432',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (679,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (680,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104952j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (681,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104253r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (682,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103748k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (683,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104391p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (684,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106602f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (685,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73217d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (686,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1066826',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (687,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104373r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (688,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104858h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (689,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104876f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (690,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045241',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (691,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82005t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (692,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105351k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (693,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045398',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (694,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106534x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (695,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (696,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104486j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (697,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103413q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (698,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104102b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (699,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104082s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (700,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104916p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (701,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105333n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (702,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5675366q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (703,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053328',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (704,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105222m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (705,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049897',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (706,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105862v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (707,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049863',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (708,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044732',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (709,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044808',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (710,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104957f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (711,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103632n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (712,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104910d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (713,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041132',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (714,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104114f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (715,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852429',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (716,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104258n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (717,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036276',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (718,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103628k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (719,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103629z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (720,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049172',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (721,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033846',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (722,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103385k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (723,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049159',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (724,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104991j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (725,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84129k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (726,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049002',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (727,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061564',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (728,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049350',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (729,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104863z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (730,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104883n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (731,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28488n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (732,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k284770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (733,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103581p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (734,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104445s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (735,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104129p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (736,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104256w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (737,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042544',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (738,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044465',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (739,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106210s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (740,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39811m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (741,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103611k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (742,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103771z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (743,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104902t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (744,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038854',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (745,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103886h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (746,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103568n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (747,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104405d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (748,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104961h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (749,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k279983',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (750,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28011z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (751,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (752,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28010m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (753,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28013n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (754,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28019q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (755,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28016p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (756,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28018c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (757,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28015b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (758,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280129',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (759,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28001n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (760,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28007q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (761,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28004p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (762,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28006c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (763,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28003b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (764,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28009d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (765,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280171',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (766,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280140',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (767,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280009',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (768,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280082',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (769,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (770,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280020',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (771,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k27999f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (772,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28020x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (773,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28023z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (774,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28022m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (775,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106206q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (776,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104438k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (777,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104436t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (778,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044376',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (779,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045364',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (780,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54367321',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (781,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048150',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (782,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048752',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (783,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104470x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (784,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104949v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (785,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104247x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (786,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104505q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (787,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048786',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (788,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106204z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (789,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104393f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (790,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106342w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (791,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103365w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (792,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104864b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (793,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105356g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (794,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041166',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (795,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106259k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (796,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104265v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (797,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036933',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (798,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103563r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (799,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104123d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (800,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103740j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (801,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045317',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (802,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104964n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (803,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049638',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (804,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105220v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (805,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104868v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (806,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k735742',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (807,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044075',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (808,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104523n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (809,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5668016f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (810,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048103',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (811,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048095',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (812,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103694g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (813,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49687h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (814,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043867',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (815,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104811g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (816,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058637',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (817,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200838x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (818,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037777',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (819,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104885d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (820,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033668',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (821,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104886s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (822,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61533s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (823,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61530r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (824,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327699551/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (825,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61532f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (826,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k78025p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (827,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k78024b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (828,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61521s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (829,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61524t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (830,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61527v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (831,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61526h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (832,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61523g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (833,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615313',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (834,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61529j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (835,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k780261',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (836,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61518w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (837,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (838,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615255',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (839,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615224',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (840,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048705',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (841,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103621x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (842,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28834t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (843,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28831s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (844,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28837v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (845,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28836h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (846,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28833g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (847,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28830f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (848,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28839j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (849,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288413',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (850,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28822t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (851,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28828w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (852,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28825v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (853,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28824h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (854,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28821g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (855,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040712',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (856,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038799',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (857,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103743p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (858,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105338j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (859,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048964',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (860,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104465g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (861,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103746t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (862,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048014',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (863,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049125',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (864,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035992',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (865,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106268j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (866,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040882',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (867,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045152',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (868,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106208g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (869,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044418',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (870,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103589q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (871,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104851v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (872,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104463q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (873,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045406',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (874,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035979',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (875,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105760s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (876,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048917',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (877,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104410v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (878,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105878g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (879,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82020q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (880,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103875s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (881,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103570z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (882,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103758x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (883,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103745f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (884,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104913j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (885,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82441s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (886,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39670k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (887,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104740t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (888,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103617v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (889,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060631',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (890,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (891,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106282z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (892,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104967s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (893,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85239d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (894,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105887f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (895,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042578',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (896,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103872n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (897,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044588',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (898,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037518',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (899,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049905',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (900,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045529',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (901,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103761m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (902,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103566w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (903,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042709',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (904,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037866',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (905,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k75938s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (906,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288386',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (907,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288355',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (908,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288324',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (909,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28827j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (910,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28816w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (911,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28819x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (912,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288204',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (913,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288235',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (914,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288266',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (915,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288297',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (916,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28815j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (917,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28818k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (918,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28843s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (919,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28840r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (920,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288177',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (921,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288146',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (922,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28842f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (923,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595363',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (924,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759530m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (925,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759537h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (926,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759538x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (927,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759539b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (928,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595400',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (929,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759541d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (930,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759542t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (931,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595311',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (932,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759532f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (933,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759533v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (934,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595348',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (935,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759535p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (936,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759138j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (937,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759139z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (938,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759140m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (939,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591411',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (940,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759142f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (941,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759143v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (942,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591448',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (943,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591463',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (944,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759147h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (945,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759148x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (946,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759250b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (947,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592525',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (948,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759253k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (949,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759251r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (950,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592540',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (951,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759255d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (952,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759256t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (953,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592577',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (954,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759258n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (955,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591144',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (956,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759118s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (957,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759115j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (958,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759116z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (959,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759117c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (960,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759779j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (961,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759380t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (962,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593817',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (963,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593832',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (964,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759382n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (965,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759645d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (966,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596440',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (967,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759376x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (968,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596388',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (969,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759375h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (970,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759639p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (971,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759640b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (972,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759641r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (973,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759377b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (974,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593795',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (975,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596425',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (976,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759643k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (977,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595756',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (978,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759576m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (979,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595771',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (980,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759578f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (981,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759579v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (982,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759574s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (983,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759814j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (984,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759815z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (985,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759816c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (986,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759691n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (987,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759671w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (988,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (989,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596796',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (990,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759673q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (991,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596744',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (992,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759675j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (993,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759676z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (994,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759677c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (995,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759678s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (996,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (997,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759585k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (998,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595845',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (999,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590868',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1000,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597554',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1001,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759242s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1002,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592436',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1003,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759244m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1004,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592451',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1005,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759246f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1006,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759247v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1007,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592488',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1008,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759249p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1009,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1010,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759260q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1011,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592614',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1012,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759262j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1013,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591307',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1014,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759131n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1015,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759134w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1016,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591359',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1017,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759136q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1018,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591374',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1019,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759149b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1020,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591856',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1021,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759177n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1022,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591782',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1023,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759179g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1024,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591804',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1025,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759181j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1026,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759182z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1027,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759241c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1028,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594160',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1029,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759418t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1030,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594197',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1031,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759417d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1032,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759849r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1033,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591233',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1034,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759124h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1035,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759125x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1036,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759126b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1037,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759127r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1038,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759493s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1039,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594946',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1040,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594998',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1041,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759500g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1042,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759501w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1043,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595029',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1044,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595044',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1045,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595860',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1046,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759587d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1047,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759588t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1048,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595897',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1049,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759590w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1050,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595919',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1051,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759592q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1052,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759853n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1053,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598542',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1054,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759855g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1055,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591129',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1056,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594694',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1057,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759470s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1058,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1059,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759232d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1060,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759233t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1061,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592347',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1062,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759235n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1063,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592362',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1064,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759237g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1065,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759238w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1066,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592399',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1067,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759240z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1068,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759230k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1069,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592273',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1070,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759228h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1071,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759229x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1072,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594679',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1073,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759468q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1074,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1075,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759221m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1076,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592221',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1077,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759223f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1078,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759224v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1079,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592258',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1080,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759226p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1081,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759846h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1082,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759526q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1083,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595274',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1084,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759528j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1085,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759529z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1086,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595437',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1087,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759523g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1088,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759524w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1089,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595259',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1090,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759625n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1091,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759623t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1092,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596247',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1093,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759495m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1094,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594961',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1095,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759497f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1096,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759498v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1097,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759510v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1098,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759122p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1099,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591196',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1100,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759120v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1101,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592703',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1102,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759271h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1103,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759272x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1104,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759273b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1105,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759336d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1106,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759337t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1107,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593387',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1108,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759339n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1109,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593298',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1110,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759330x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1111,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759331b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1112,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759332r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1113,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593335',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1114,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759334k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1115,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593350',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1116,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759389j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1117,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593884',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1118,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759387q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1119,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1120,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759373p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1121,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593743',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1122,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759384g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1123,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759385w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1124,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593869',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1125,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759403c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1126,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1127,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759364q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1128,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593654',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1129,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759366j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1130,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759402z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1131,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759401j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1132,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759367z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1133,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759368c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1134,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759369s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1135,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759370f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1136,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759371v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1137,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759263z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1138,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759264c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1139,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759265s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1140,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592666',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1141,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759267m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1142,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591285',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1143,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759129k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1144,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759186m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1145,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591871',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1146,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759188f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1147,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759189v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1148,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759190h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1149,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759191x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1150,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759192b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1151,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759193r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1152,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591945',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1153,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592095',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1154,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759210t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1155,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759212n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1156,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592132',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1157,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759214g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1158,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759215w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1159,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1160,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759217q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1161,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592184',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1162,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759219j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1163,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759195k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1164,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591960',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1165,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759197d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1166,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759198t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1167,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759201v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1168,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592028',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1169,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759203p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1170,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1171,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759205h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1172,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759206x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1173,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759207b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1174,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759208r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1175,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591626',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1176,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759163m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1177,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1178,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759166v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1179,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759168p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1180,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759170r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1181,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759172k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1182,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759174d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1183,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759175t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1184,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1185,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591730',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1186,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1187,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591693',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1188,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591678',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1189,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759165f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1190,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759161s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1191,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759160c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1192,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759159q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1193,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591589',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1194,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759152t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1195,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759154n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1196,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591552',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1197,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759156g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1198,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759157w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1199,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591500',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1200,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759151d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1201,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759429m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1202,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594308',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1203,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759431p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1204,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594323',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1205,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759433h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1206,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759426c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1207,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759424j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1208,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759422q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1209,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759459r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1210,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759461t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1211,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594627',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1212,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759458b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1213,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593602',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1214,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759361g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1215,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759362w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1216,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593491',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1217,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759350p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1218,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1219,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759352h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1220,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759353x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1221,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759354b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1222,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759355r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1223,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1224,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759357k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1225,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593580',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1226,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759359d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1227,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759398h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1228,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759399x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1229,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594004',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1230,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593906',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1231,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759391m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1232,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593921',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1233,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759393f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1234,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759394v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1235,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593958',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1236,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759396p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1237,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593973',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1238,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592896',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1239,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759290v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1240,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592918',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1241,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759292p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1242,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592933',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1243,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759294h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1244,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759295x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1245,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759296b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1246,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593409',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1247,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759341q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1248,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593424',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1249,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759343j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1250,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759344z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1251,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759345c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1252,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759346s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1253,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759348m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1254,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592844',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1255,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759285j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1256,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759286z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1257,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759287c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1258,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759288s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1259,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759505j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1260,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759507c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1261,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593172',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1262,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759318g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1263,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759319w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1264,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593083',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1265,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759309h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1266,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1267,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759311k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1268,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593120',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1269,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759313d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1270,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759314t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1271,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593157',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1272,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759316n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1273,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759307p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1274,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759506z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1275,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759278d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1276,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759279t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1277,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759280g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1278,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1279,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759321z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1280,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759322c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1281,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593246',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1282,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759325m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1283,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593261',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1284,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759327f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1285,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759328v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1286,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593068',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1287,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759320j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1288,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593031',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1289,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759304f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1290,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759305v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1291,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759302m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1292,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759300s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1293,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592985',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1294,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759281w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1295,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1296,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759276k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1297,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592755',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1298,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759274r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1299,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1300,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759269f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1301,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596106',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1302,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759611m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1303,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596121',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1304,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759599m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1305,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595986',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1306,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759597s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1307,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759546g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1308,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759547w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1309,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595489',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1310,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759549q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1311,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759550c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1312,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759551s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1313,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595526',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1314,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759553m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1315,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595541',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1316,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759555f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1317,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595934',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1318,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759594j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1319,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759595z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1320,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759596c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1321,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759850d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1322,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759516b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1323,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759517r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1324,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595185',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1325,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759108d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1326,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759109t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1327,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759519k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1328,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595207',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1329,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759521n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1330,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595222',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1331,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759481k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1332,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759472m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1333,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594731',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1334,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759096n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1335,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759474f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1336,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594768',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1337,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759486n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1338,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594872',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1339,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759488g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1340,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759489w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1341,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759490j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1342,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594783',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1343,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759479h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1344,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594805',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1345,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759477p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1346,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759475v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1347,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759098g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1348,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590957',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1349,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594820',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1350,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759483d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1351,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759484t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1352,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594857',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1353,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594716',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1354,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759491z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1355,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759492c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1356,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759508s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1357,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595096',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1358,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595118',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1359,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759512p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1360,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595133',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1361,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759514h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1362,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759515x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1363,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759409v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1364,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759410h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1365,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759411x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1366,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759412b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1367,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759413r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1368,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594145',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1369,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759415k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1370,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591055',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1371,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594538',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1372,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759454p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1373,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594553',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1374,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759456h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1375,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759457x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1376,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759452v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1377,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759451f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1378,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594501',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1379,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759449c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1380,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759448z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1381,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594449',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1382,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759445q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1383,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594464',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1384,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759447j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1385,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759435b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1386,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759436r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1387,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759438k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1388,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594056',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1389,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759406m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1390,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594071',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1391,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759408f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1392,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759442g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1393,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759443w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1394,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594390',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1395,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594375',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1396,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759434x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1397,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594234',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1398,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759425z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1399,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759427s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1400,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1401,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759685x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1402,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759686b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1403,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759687r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1404,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1405,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759684h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1406,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596818',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1407,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759682p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1408,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596670',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1409,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759668d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1410,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759669t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1411,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759670g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1412,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759680v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1413,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759663b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1414,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759664r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1415,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596655',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1416,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759666k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1417,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759662x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1418,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596262',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1419,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759627g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1420,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759628w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1421,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759630z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1422,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759631c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1423,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759632s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1424,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596336',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1425,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759634m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1426,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759654c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1427,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759655s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1428,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596566',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1429,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759657m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1430,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596581',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1431,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759659f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1432,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596603',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1433,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759661h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1434,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596922',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1435,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759693g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1436,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759694w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1437,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596959',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1438,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759696q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1439,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596974',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1440,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759698j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1441,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759699z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1442,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597005',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1443,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596907',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1444,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596351',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1445,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759636f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1446,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759637v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1447,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759646t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1448,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596477',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1449,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759648n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1450,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596492',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1451,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759650q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1452,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596514',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1453,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759652j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1454,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759653z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1455,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759856w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1456,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598579',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1457,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596158',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1458,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596173',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1459,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759567n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1460,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595682',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1461,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759569g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1462,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595704',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1463,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759571j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1464,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759572z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1465,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595578',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1466,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759558p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1467,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595593',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1468,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759560r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1469,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595615',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1470,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759562k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1471,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595630',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1472,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759564d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1473,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759565t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1474,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595667',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1475,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759556v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1476,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759619x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1477,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759620k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1478,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596210',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1479,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759622d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1480,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759618h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1481,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759616p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1482,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759544n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1483,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595452',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1484,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759573c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1485,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759580h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1486,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759582b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1487,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759600t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1488,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596017',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1489,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759602n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1490,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596032',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1491,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759604g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1492,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759605w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1493,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596069',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1494,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759583r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1495,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759581x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1496,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759614v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1497,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759613f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1498,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759607q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1499,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596084',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1500,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759609j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1501,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1502,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759792d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1503,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759793t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1504,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597947',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1505,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759795n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1506,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597806',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1507,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759781m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1508,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597821',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1509,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759760f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1510,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759761v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1511,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597628',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1512,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759763p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1513,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597643',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1514,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759765h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1515,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759766x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1516,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759767b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1517,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759768r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1518,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597695',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1519,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759770t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1520,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597717',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1521,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759772n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1522,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597732',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1523,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759774g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1524,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759775w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1525,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597769',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1526,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759759s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1527,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759751g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1528,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759752w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1529,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597539',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1530,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759754q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1531,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759756j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1532,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597376',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1533,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759738m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1534,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597391',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1535,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759740p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1536,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597413',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1537,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759742h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1538,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759743x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1539,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597465',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1540,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759747k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1541,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597480',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1542,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759749d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1543,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759718v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1544,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759720x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1545,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597309',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1546,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759731q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1547,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597324',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1548,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759733j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1549,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759734z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1550,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759735c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1551,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759736s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1552,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759722r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1553,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597235',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1554,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759724k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1555,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597250',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1556,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759726d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1557,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759727t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1558,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597287',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1559,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759729n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1560,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759721b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1561,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597198',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1562,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759710j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1563,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759711z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1564,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759712c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1565,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759713s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1566,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597146',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1567,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759715m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1568,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1569,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759717f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1570,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1571,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759812q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1572,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598134',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1573,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759817s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1574,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759805k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1575,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598060',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1576,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759807d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1577,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759808t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1578,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759810w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1579,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759701k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1580,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597020',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1581,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759703d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1582,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759704t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1583,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597057',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1584,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759706n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1585,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597072',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1586,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759708g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1587,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759709w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1588,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598045',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1589,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759803r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1590,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759802b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1591,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759801x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1592,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759800h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1593,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597962',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1594,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759797g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1595,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759798w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1596,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597999',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1597,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759777q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1598,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597784',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1599,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596885',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1600,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759689k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1601,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39819c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1602,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200086d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1603,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200082w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1604,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2000851',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1605,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39812z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1606,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103782p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1607,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103608w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1608,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759110g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1609,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1610,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759826r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1611,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759758c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1612,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759757z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1613,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759745r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1614,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759744b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1615,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759466w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1616,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759465g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1617,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759460d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1618,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594412',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1619,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759440n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1620,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759102x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1621,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b5901137b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1622,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104944z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1623,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759848b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1624,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759847x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1625,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759851t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1626,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598186',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1627,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598453',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1628,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759832g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1629,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759833w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1630,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598349',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1631,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759835q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1632,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598364',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1633,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759837j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1634,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759838z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1635,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759839c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1636,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598401',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1637,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759841f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1638,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759842v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1639,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598438',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1640,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759844p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1641,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1642,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759819m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1643,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759821p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1644,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598223',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1645,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759823h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1646,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759824x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1647,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759825b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1648,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759828k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1649,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598290',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1650,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759830n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1651,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1652,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759783f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1653,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759784v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1654,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597858',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1655,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759786p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1656,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597873',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1657,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759788h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1658,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759789x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1659,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759790k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1660,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5623728d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1661,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037264',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1662,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5623700b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1663,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103727h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1664,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104397z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1665,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104748v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1666,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047505',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1667,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104380z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1668,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103596x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1669,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69771t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1670,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69941f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1671,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699198',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1672,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698566',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1673,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697934',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1674,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69921t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1675,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049261',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1676,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049248',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1677,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61867x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1678,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61866k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1679,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104927d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1680,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104925n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1681,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106389x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1682,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201028c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1683,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105211w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1684,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105210h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1685,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047327',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1686,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2010257',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1687,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105213n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1688,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057649',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1689,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105215d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1690,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2010270',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1691,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105219x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1692,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105329k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1693,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052128',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1694,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105218j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1695,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052141',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1696,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052175',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1697,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105209k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1698,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201024v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1699,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104733m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1700,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201026m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1701,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69797h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1702,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69804z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1703,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69911h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1704,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698268',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1705,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69947h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1706,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69777w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1707,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69884f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1708,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697996',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1709,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1710,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69927w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1711,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69864t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1712,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698504',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1713,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699496',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1714,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698070',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1715,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698864',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1716,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69951r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1717,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69908m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1718,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69845j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1719,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69782g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1720,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1721,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69825x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1722,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69932g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1723,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698477',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1724,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697845',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1725,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69798v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1726,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69912v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1727,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69806n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1728,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699345',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1729,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69948v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1730,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69885s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1731,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698713',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1732,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69779k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1733,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69830h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1734,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69929k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1735,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69866h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1736,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69810w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1737,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698326',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1738,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69909z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1739,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69846w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1740,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69783t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1741,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69953f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1742,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69890c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1743,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698686',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1744,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69933t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1745,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69870r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1746,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69827m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1747,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698922',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1748,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69914j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1749,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69851g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1750,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698299',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1751,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697667',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1752,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69808b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1753,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69887g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1754,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69831v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1755,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699167',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1756,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698535',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1757,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69867v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1758,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697903',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1759,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69974d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1760,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1761,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69812k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1762,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699403',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1763,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69891q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1764,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69848k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1765,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69785h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1766,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698148',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1767,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69828z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1768,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69935h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1769,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69872f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1770,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697876',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1771,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1772,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69915w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1773,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69852t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1774,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699376',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1775,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69809p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1776,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69888t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1777,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698744',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1778,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69833j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1779,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69770g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1780,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69869j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1781,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69813x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1782,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69920g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1783,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698357',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1784,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69849x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1785,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697725',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1786,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69786v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1787,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69893d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1788,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69900v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1789,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699225',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1790,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69936v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1791,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69873s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1792,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69767k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1793,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698953',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1794,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69917k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1795,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69854h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1796,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32826375m/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1797,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69791f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1798,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697698',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1799,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1800,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69834w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1801,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043956',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1802,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b5901183k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1803,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759104r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1804,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104112p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1805,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105098p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1806,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105100v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1807,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1050992',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1808,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105853w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1809,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200197f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1810,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104435f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1811,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84228h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1812,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042510',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1813,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049473',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1814,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104919t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1815,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104490m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1816,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200834d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1817,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2008318',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1818,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699434',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1819,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69815m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1820,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698802',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1821,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69894r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1822,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69788j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1823,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69902j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1824,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698179',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1825,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69768x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1826,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69938j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1827,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69875g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1828,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699047',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1829,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69918x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1830,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698415',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1831,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69855v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1832,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69792s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1833,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698775',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1834,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69800k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1835,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69942s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1836,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69836k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1837,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69773h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1838,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698028',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1839,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69816z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1840,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69923h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1841,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698388',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1842,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69860f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1843,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697756',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1844,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69789w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1845,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69896f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1846,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69903w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1847,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69840t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1848,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699256',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1849,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69939w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1850,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69876t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1851,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698190',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1852,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698984',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1853,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69821j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1854,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69857j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1855,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69794g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1856,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69801x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1857,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698237',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1858,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69837x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1859,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69944g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1860,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69774v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1861,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69881d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1862,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698597',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1863,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697965',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1864,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1865,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69924v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1866,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69861s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1867,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69818n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1868,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699465',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1869,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69897s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1870,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1871,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69905k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1872,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69842h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1873,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69878h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1874,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69822w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1875,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699078',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1876,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698446',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1877,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69858w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1878,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69795t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1879,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697814',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1880,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69945t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1881,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699314',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1882,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69803m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1883,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69882r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1884,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69839m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1885,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69776j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1886,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698059',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1887,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69926j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1888,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69863g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1889,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k697787',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1890,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69899g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1891,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69906x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1892,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69843v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1893,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69780s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1894,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69950d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1895,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699287',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1896,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k698655',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1897,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69879v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1898,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69930s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1899,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69824k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1900,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k699523',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1901,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104396k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1902,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957468',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1903,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957437',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1904,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957406',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1905,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95738n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1906,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95735m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1907,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95757x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1908,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95754w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1909,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95751v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1910,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957379',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1911,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957348',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1912,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95748z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1913,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95745x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1914,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95742w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1915,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95768k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1916,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95765j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1917,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95762h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1918,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957677',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1919,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957646',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1920,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957615',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1921,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95736z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1922,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95733x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1923,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95759m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1924,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95756k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1925,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95753j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1926,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95750h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1927,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103600v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1928,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84094r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1929,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591997',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1930,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759463n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1931,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759503q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1932,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597502',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1933,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759323s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1934,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106281k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1935,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2001962',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1936,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k134274j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1937,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047463',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1938,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104273f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1939,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k134275x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1940,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39808q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1941,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104520h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1942,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83137z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1943,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83136m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1944,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103692q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1945,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104076z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1946,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104077b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1947,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104269c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1948,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038676',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1949,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103866t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1950,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104803w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1951,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103544f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1952,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103545t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1953,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104855c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1954,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759145p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1955,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103736g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1956,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037353',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1957,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105201j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1958,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052039',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1959,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104414c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1960,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037743',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1961,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106055f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1962,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34517n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1963,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345180',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1964,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34519b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1965,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32856286m/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1966,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28950b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1967,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28951p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1968,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103784f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1969,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b86260711',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1970,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104542z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1971,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b8626070m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1972,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104781k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1973,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104782z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1974,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32734040p/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1975,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104783b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1976,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035589',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1977,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104553p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1978,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105874z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1979,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105875b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1980,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67137h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1981,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb343985327/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1982,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67141r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1983,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67140d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1984,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671783',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1985,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67144s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1986,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67143f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1987,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671334',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1988,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67146g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1989,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671365',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1990,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671396',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1991,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67132s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1992,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671423',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1993,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k671454',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1994,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67135t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1995,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67134g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1996,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67138v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1997,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594642',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1998,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104937r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (1999,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49688v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2000,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057573',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2001,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k861966',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2002,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84371x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2003,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84370k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2004,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86200m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2005,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86192t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2006,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86195v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2007,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k861904',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2008,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86189x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2009,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86188k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2010,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86209q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2011,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k822599',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2012,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82257m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2013,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86205b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2014,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86194h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2015,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2016,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84361m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2017,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84364n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2018,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104790j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2019,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2020,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84362z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2021,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84366b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2022,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843759',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2023,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84374z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2024,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104081d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2025,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k75303g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2026,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103734q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2027,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035945',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2028,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104941t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2029,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047497',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2030,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86146n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2031,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033600',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2032,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037832',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2033,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2034,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103778m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2035,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106440f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2036,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104528j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2037,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852382',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2038,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044554',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2039,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044766',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2040,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104798k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2041,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038888',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2042,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105340v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2043,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103890k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2044,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103889n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2045,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k861877',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2046,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84698s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2047,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84670d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2048,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104385v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2049,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103881m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2050,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038820',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2051,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060542',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2052,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85339p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2053,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85342k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2054,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k853417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2055,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85340w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2056,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85224c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2057,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85221b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2058,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85222p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2059,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852231',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2060,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852142',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2061,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85245b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2062,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85216r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2063,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85234p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2064,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852351',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2065,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852022',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2066,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103361c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2067,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66139z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2068,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85246p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2069,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85236c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2070,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85200c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2071,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85201q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2072,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85243n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2073,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852440',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2074,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85206f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2075,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85203d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2076,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85204r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2077,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852053',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2078,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852084',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2079,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85209g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2080,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85233b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2081,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852320',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2082,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046598',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2083,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106062n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2084,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k98686z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2085,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759091k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2086,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k99049b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2087,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590883',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2088,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k97003j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2089,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957588',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2090,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957390',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2091,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957557',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2092,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957526',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2093,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95747m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2094,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95744k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2095,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95769x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2096,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95741j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2097,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95766w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2098,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95763v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2099,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95760t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k957499',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2101,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k98288j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2102,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k44270g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2103,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590905',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2104,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590920',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2105,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759099w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2106,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591003',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2107,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759101h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2108,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759084f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2109,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759085v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2110,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759087p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2111,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590831',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2112,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759080s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2113,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590794',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2114,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759071t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2115,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590727',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2116,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759073n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2117,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759075g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2118,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759076w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2119,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590779',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2120,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759078q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k99053k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103590n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103612z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2124,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103613b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2125,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104787v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2126,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036098',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2127,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103607h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2128,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103355j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2129,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036153',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2130,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103620j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2131,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036242',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103619m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103383t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103380p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2135,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033812',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103379r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103382f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2138,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103353s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103352d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103349q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103348b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033456',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033511',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103344t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103350n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103347z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103346k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103358p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2149,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033579',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063917',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84640g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104427v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044253',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104426g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84616m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84635w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k845975',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84609b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86203n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2160,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k846007',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2161,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84598h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84355p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2163,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84358q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044991',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86208c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k843519',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84352n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k861935',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346695',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34622h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346633',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34677s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34671q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346246',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34658h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2178,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb343749904/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34652f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2180,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34638w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2181,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34632t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34619m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346544',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2184,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5693014w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34682c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2186,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34668t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34662r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2188,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34649j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34629x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34643g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346842',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34623v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346455',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2194,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34679g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34673d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34659v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34653s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34634h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346753',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104530v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34683q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346366',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346304',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34644t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34625j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346664',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346602',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34674r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346277',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346215',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34655g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34635v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34616k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346575',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34685d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34665s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346188',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34646h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34626w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34640f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34620t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2223,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346811',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2224,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346486',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346424',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34676f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2227,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34670c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34656t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34650r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34637j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346784',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34631g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34617x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346722',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34680p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346397',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346335',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34667g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34661d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34647v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34641s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56929902',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34628k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37710h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37645w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376180',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376676',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37626m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377126',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37620j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376614',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37600x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2253,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37695f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37726w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37675t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2256,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37720t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37607b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2259,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376227',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37707m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37656j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37701j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376974',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37636x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37650g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376912',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376091',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377099',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k737916',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104400h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104744b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106056t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060576',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105755b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k862071',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2276,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b55002606b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2277,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b55002605w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2278,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b5901138r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2279,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759103b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2280,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b55002607s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2281,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b55002604f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057047',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057395',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105735n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105700q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105737d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105738s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057060',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105703v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105702g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057348',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057403',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049604',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2294,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105705m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057361',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057013',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104928s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2298,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759082m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045487',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105882j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37737j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376525',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37686g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37731g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37717x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37680d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37666v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37711v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37660s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2310,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34424377d/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376138',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37647k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376885',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377335',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37641h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37627z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376823',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37621w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2319,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37696s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37690q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37608p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37728k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37602m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376436',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37722h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37708z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37657w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37671f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37702w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37651t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376049',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37638m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37632j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376734',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37612x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37738w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37732t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37619b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37681r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376347',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37719m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37668j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37713j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37648x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37662g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37642v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37629n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2349,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377157',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37623k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376645',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37698g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2353,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37729x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37603z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37692d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37678v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37723v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37672s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376258',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37659k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37704k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37653h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37639z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376060',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377068',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37614m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376556',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377006',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37689h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37734h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37669w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37714w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37663t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377366',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37644j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376854',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377304',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37699t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37693r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376467',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37605n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37725j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376405',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37674g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2387,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37705x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37654v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376018',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377277',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37635k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376765',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37615z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376703',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37735v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37684s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376378',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376316',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37716k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37665h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104588m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398677',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104556t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045843',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045877',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104559z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104573c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39859m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39856k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104576h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2411,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39878w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104592p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39875v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39872t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2415,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34446531j/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104579n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104560w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398588',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045720',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045919',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398557',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045754',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045788',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104564d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104580k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39869x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104567j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39866w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104583q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39863v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39860t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004871',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200479f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201222q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201221b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201225v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201224g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200490q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004782',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2440,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34349684z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200493v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200492g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012233',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200481r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200480c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012267',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200484w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200483h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004913',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004947',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200486n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200489s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200488d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004824',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2004858',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012191',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200477p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201220z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105864m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062628',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104789m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106278w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106275r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106274c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062806',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104904k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049036',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2468,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058459',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106266s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106277h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012445',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012309',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201237z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201236k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201239q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201238b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012322',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012356',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201227m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201229c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104623z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104622k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104625q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104624b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201240n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2486,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb37131292d/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2012280',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104628v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104627g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046216',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201231p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104619w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046263',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104618h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201234t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k201233f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2497,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k376587',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2498,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37617n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2499,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377037',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2500,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37611k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2501,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200832n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2502,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105869h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2503,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103598p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2504,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058862',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2505,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035780',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2506,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1031370',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2507,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103562c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2508,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034567',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2509,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041221',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2510,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104409x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2511,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034177',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2512,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106059z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2513,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106058k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2514,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103556j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2515,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39814n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2516,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k205908k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2517,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2008331',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2518,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106392m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2519,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103542p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2520,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061606',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2521,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105861g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2522,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037599',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2523,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062073',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2524,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103605r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2525,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061598',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2526,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104984b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2527,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103750w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2528,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052217',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2529,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103370b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2530,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058896',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2531,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104483d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2532,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104484s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2533,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104481n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2534,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044821',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2535,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036365',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2536,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1066012',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2537,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104262q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2538,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058849',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2539,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106155r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2540,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39816b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2541,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103547k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2542,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106213x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2543,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058603',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2544,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103371q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2545,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105879v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2546,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035419',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2547,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104250m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2548,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103418m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2549,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104108m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2550,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033723',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2551,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759093d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2552,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85225q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2553,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852262',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2554,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106265d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2555,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105352z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2556,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106598h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2557,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106600p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2558,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106599w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2559,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327543805/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2560,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104532m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2561,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045330',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2562,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103367n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2563,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104127x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2564,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104880h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2565,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104881w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2566,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104879k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2567,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104586v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2568,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39880f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2569,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045631',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2570,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045665',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2571,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045699',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2572,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104571m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2573,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104555f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2574,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104590x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2575,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104574r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2576,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39857x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2577,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104558k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2578,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104577w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2579,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045890',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2580,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045707',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2581,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39874h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2582,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39877j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2583,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39871g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2584,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104594f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2585,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045576',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2586,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104562n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2587,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398797',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2588,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398766',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2589,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104581z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2590,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398735',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2591,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045932',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2592,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398704',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2593,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104568x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2594,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104582b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2595,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045618',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2596,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39868k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2597,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39865j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2598,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39862h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2599,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104585g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2600,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39881s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2601,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200084n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2602,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104099s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2603,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104508v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2604,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104105g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2605,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037790',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2606,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103538m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2607,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62092947',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2608,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591070',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2609,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b8468336v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2610,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048616',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2611,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035822',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2612,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105852h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2613,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b8469641h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2614,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759133g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2615,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759297r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2616,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2617,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84088t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2618,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104901f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2619,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105880s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2620,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106605k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2621,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106603t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2622,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1066046',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2623,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035508',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2624,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035678',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2625,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85241z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2626,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104398b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2627,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2628,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759200f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2629,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104495h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2630,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b530230394',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2631,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759111w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2632,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103415g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2633,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6225495n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2634,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343998',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2635,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344448',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2636,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34403p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2637,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343936',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2638,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34472h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2639,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34452w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2640,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344250',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2641,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104976r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2642,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34439p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2643,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34388m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2644,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34433m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2645,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34382j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2646,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34414b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2647,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104980t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2648,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344359',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2649,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343847',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2650,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34398x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2651,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34443x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2652,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34457m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2653,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344568',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2654,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328267851/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2655,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37767g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2656,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37761d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2657,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37764f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2658,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37783q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2659,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37780p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2660,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1052230',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2661,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377695',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2662,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377664',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2663,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377633',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2664,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377602',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2665,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37758h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2666,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37755g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2667,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37777s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2668,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37752f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2669,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37774r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2670,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37771q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2671,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377575',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2672,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377544',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2673,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2674,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37749j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2675,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37746h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2676,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37768t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2677,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37743g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2678,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37740f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2679,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37762r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2680,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37782c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2681,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377486',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2682,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377455',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2683,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377424',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2684,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37759v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2685,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37756t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2686,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377811',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2687,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37753s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2688,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37750r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2689,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37779g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2690,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37776f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2691,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37773d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2692,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37770c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2693,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377397',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2694,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37599j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2695,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377784',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2696,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377753',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2697,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37747v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2698,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37744t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2699,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k377722',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2700,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37741s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2701,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104133r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2702,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104179d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2703,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104159q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2704,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041946',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2705,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042065',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2706,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041556',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2707,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104183g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2708,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104189r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2709,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104144g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2710,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041857',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2711,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104193t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2712,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104205s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2713,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041467',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2714,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104174h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2715,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104154t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2716,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042018',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2717,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041509',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2718,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041700',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2719,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041768',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2720,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104184v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2721,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041378',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2722,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104165j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2723,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104145v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2724,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104200w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2725,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041611',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2726,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041679',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2727,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104195k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2728,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104175w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2729,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041480',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2730,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104156k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2731,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104136w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2732,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34392v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2733,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2734,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34379n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2735,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34424n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2736,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345107',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2737,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34405c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2738,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104971v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2739,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2740,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34454k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2741,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34389z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2742,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34434z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2743,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34383w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2744,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344072',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2745,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104978h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2746,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344010',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2747,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34415p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2748,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049740',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2749,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344370',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2750,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2751,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34445m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2752,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34394j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2753,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34426b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2754,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344479',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2755,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34406q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2756,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343967',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2757,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2758,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34400n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2759,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343905',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2760,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344281',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2761,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34436n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2762,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104979w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2763,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34385k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2764,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34430k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2765,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34410z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2766,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34417c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2767,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345091',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2768,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343878',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2769,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344328',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2770,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2771,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34511k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2772,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34446z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2773,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34395w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2774,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34440w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2775,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344192',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2776,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344130',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2777,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34427p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2778,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34421m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2779,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34408d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2780,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344490',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2781,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34402b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2782,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k343789',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2783,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344239',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2784,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34451j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2785,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34386x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2786,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34431x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2787,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34380v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2788,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32878283g/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2789,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34438b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2790,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344041',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2791,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34418q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2792,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344537',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2793,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049774',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2794,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34448n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2795,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34397k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2796,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34442k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2797,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34377z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2798,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34422z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2799,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34429c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2800,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34409r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2801,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038197',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2802,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037989',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2803,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103821j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2804,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103840v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2805,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103808h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2806,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103824p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2807,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103827t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2808,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038587',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2809,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038205',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2810,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103844c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2811,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038239',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2812,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038040',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2813,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038074',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2814,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103847h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2815,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103812k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2816,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103831w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2817,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103815q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2818,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038430',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2819,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038464',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2820,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103818v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2821,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2822,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103797x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2823,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038116',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2824,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103851k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2825,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103835d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2826,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103854q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2827,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103838j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2828,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103857v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2829,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103803m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2830,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038506',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2831,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103822x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2832,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103806r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2833,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038341',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2834,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103809w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2835,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038375',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2836,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038027',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2837,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103842m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2838,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103826f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2839,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103845r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2840,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103829k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2841,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328592223/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2842,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103848w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2843,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103810t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2844,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2845,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103813z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2846,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038252',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2847,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2848,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103830h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2849,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103814b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2850,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103833n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2851,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103817g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2852,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103852z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2853,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103836s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2854,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103796j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2855,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103839x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2856,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103799p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2857,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103853b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2858,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038328',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2859,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038163',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2860,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103731k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2861,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104072f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2862,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041912',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2863,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042031',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2864,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041522',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2865,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104180b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2866,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104160n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2867,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104140z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2868,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041781',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2869,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104166x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2870,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104186m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2871,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104141b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2872,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041391',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2873,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104147m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2874,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041823',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2875,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104190p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2876,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104202n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2877,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104196z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2878,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104171c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2879,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104151p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2880,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041692',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2881,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104197b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2882,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104177n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2883,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104157z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2884,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104132c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2885,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104158b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2886,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104138n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2887,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041734',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2888,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104181q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2889,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041993',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2890,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041344',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2891,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104162d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2892,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104142q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2893,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104168p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2894,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104149c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2895,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041645',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2896,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104192f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2897,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104172r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2898,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104204d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2899,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104198q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2900,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104153f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2901,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5694361w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2902,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34734s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2903,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347203',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2904,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042366',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2905,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34565h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2906,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34608z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2907,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345316',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2908,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34545w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2909,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042408',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2910,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56908866',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2911,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345676',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2912,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34526m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2913,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5691321f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2914,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345912',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2915,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34613j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2916,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34550g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2917,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2918,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34586g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2919,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34530v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2920,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346157',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2921,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345525',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2922,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34566v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2923,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34736g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2924,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345885',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2925,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34590q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2926,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347385',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2927,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34547k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2928,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042421',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2929,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34740q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2930,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34527z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2931,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34571f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2932,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2933,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346006',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2934,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34614w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2935,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34551t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2936,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34721f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2937,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34587t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2938,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345734',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2939,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104237k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2940,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34737t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2941,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347234',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2942,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34532j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2943,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104241n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2944,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34568j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2945,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56959470',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2946,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345347',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2947,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34548x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2948,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34592d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2949,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5788688s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2950,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34572s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2951,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34529n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2952,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56916610',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2953,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2954,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34722s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2955,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34553h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2956,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5690726k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2957,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104238z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2958,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34589h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2959,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34533w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2960,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104239b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2961,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345556',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2962,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34569w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2963,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34739h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2964,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5691593m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2965,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104243d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2966,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34719w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2967,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34593r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2968,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34601j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2969,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34574g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2970,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56933568',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2971,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346037',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2972,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345405',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2973,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34724g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2974,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34554v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2975,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345765',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2976,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347265',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2977,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34535k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2978,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345378',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2979,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34595f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2980,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34602w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2981,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5707346w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2982,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34575t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2983,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345614',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2984,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345974',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2985,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34725t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2986,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34520j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2987,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56906126',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2988,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34556j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2989,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5691327x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2990,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345227',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2991,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34536x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2992,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34580d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2993,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345587',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2994,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34560s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2995,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34730d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2996,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56944380',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2997,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34596s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2998,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345823',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (2999,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104739w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3000,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103856g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3001,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047675',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3002,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104763n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3003,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104770v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3004,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104759k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3005,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6316566j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3006,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104406s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3007,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103362r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3008,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34348163c/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3009,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104135h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3010,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63901r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3011,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63927f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3012,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63924d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3013,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63921c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3014,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63966b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3015,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639294',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3016,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639263',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3017,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639232',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3018,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639201',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3019,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63918g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3020,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63915f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3021,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63912d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3022,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63937r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3023,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63934q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3024,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63931p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3025,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639174',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3026,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639143',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3027,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639112',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3028,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63909h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3029,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63906g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3030,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63928s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3031,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63903f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3032,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63900d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3033,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63925r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3034,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63922q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3035,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63967p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3036,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639085',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3037,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639054',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3038,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639023',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3039,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63919t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3040,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63916s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3041,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63913r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3042,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63910q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3043,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63939f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3044,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63936d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3045,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63933c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3046,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63930b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3047,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639383',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3048,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639352',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3049,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34374610t/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3050,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63907t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3051,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639321',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3052,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103733b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3053,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34604k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3054,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347323',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3055,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34541h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3056,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34521w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3057,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56943006',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3058,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346068',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3059,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345436',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3060,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34557w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3061,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34727h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3062,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56933798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3063,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345796',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3064,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34581r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3065,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34538m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3066,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34731r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3067,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042332',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3068,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34562g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3069,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34598g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3070,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34605x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3071,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34542v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3072,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345645',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3073,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34578v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3074,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34523k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3075,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34728v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3076,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34559k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3077,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56913164',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3078,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34610h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3079,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345258',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3080,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34539z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3081,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5601346s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3082,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34583f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3083,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56933657',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3084,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346126',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3085,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34563t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3086,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34733f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3087,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34599t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3088,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345854',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3089,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k347354',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3090,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5691315q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3091,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34607m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3092,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34544j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3093,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34524x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3094,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k346099',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3095,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345467',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3096,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34611v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3097,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32860483w/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3098,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104234f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3099,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34584s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345703',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3101,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598097',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3102,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596299',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3103,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590972',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3104,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591322',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3105,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104765d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3106,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104766s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3107,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047628',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3108,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104772m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3109,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104769x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3110,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104768j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3111,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104775r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3112,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104774c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3113,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3114,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104761w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3115,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104760h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3116,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047717',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3117,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574421x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3118,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573850q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3119,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574418f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3120,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047115',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106608q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1066093',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106606z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3124,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759404s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3125,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759420w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3126,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594219',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3127,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759183c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3128,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759184s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3129,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592829',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3130,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593476',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3131,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759378r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6325188q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6325192m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6317527r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3135,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6316568c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63238539',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63315409',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3138,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6334618r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6322792r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63359828',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6322072k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6331636r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6335981v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63251916',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6331531b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63324082',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6321970j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63175307',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3149,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6325190s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6332407n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6323725n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6317525x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63251894',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63251931',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6321971z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6321968g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6331633h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63165335',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6331539n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3160,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63220715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3161,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759106k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31399j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3163,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31411k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31414m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31400x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31403z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k313986',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314138',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314107',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31405n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31402m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31408p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31407b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314049',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314018',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314091',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k314060',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3178,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34425263p/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k31412x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3180,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34425275p/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3181,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759089h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104889x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104456h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3184,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759113q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30796c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3186,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85317c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3188,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590742',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035466',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6316567z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6332404d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6321961k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104931g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3194,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759299k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104795f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104796t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047976',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060665',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104460k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104461z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573488s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574411j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687256w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687260s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744490',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574379s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586983',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225700',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55684066',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573345p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571029x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573453k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55733871',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572946v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573521z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122565p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573414g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572950r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738032',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104700f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573518g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568301s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3223,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3224,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710362',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573945r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574409g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3227,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047026',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574413c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567343t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661914j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574385h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744156',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573910j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738440',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739480',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568342q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573878s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104701t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573519w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743917',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573523s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122567h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573990k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658699h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574202w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734614',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573839p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574414s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573495x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573843k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572909k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573951g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3253,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744564',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734184',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55742054',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3256,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573456t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573908g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574387b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3259,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574028f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573564q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568344j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104703k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122568x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6140805c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574455q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573421m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739146',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122569b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572954d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5570997j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574204q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046776',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568624t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3276,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573952w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3277,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572914w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3278,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573393r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3279,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573497r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3280,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687265v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3281,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046818',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574388r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573458n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739554',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104704z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55729174',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572891b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104676t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104705b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61408484',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56872720',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573419j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3294,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104680w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568306v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568773n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661958q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3298,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047073',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6140886t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658685g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574196m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573825n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55683271',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573374d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225559',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586879',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104696h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586916',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3310,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574372w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574369d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573442s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568114q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573546s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046988',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744030',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56872527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574437s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3319,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574441p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743754',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573507p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572936g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744794',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573511k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572940c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710258',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735491',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573830z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5728013b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56587170',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573827g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574054x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687247x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104697w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573587q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225574',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687248b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738336',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5650142h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573548m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55733782',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739413',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55746206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122556q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572019v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5577542c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573509h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574199v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3349,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122560m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573513d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658692m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739020',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3353,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55726247',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710273',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104699n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574404d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738744',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55729441',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55709875',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574380f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574017n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734918',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739391',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571030k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55740590',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573869t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574444x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573406x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573873q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743828',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5578789s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122562f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734525',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658694f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574405t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573382z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573834m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567228s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744475',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225648',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586968',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744512',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574377z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574381v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567096x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3387,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55742002',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658719t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744082',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734896',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658268k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734933',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573408r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739057',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743843',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710347',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735580',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56872223',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573943x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574407n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6140893z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573853z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55741474',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046865',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738959',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573958c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046907',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735409',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225841',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573814v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3411,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5603568p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104709v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61408966',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744319',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3415,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568354x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571051r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104685s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55741882',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122579q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574466h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738173',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658703z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122583m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574003m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574470d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571012n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6137524k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738974',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568291v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687276n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046920',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687280j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55894136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573820k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573365f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55744334',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573473b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586827',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3440,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104687j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571053k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568360n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574471t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574260b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104691m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739309',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046899',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122585f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573541q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574220t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574428t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573857m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658677x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55743702',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572931d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5570974j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573818h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687238z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104688x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573926d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56584725',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55741956',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56872846',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56586842',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574365r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104693c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3468,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573435n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55733693',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573539n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572968f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658707m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658711h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046954',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658923d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574434j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687279w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573967b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574194s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687283s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573504f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573823t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55774317',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734028',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735068',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3486,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687244p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55685410',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122620f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55735105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104694r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568575s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55709823',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574367k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574475g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573441c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573545c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3497,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658713b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3498,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573968r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3499,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55734399',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3500,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572934n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3501,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63280140',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3502,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105839g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3503,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6398118x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3504,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63981200',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3505,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb344243809/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3506,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k166705b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3507,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49685t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3508,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759283q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3509,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574422b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3510,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568175d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3511,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55692396',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3512,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046831',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3513,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572680v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3514,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55742128',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3515,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573807q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3516,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573811m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3517,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104706q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3518,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573212z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3519,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104678k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3520,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122604b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3521,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55709660',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3522,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104710s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3523,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104682n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3524,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574459c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3525,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574207z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3526,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56872349',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3527,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574211v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3528,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5658700q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3529,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122580c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3530,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55728950',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3531,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574419v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3532,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574423r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3533,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6140892j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3534,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573397d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3535,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225789',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3536,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328696274/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3537,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573960f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3538,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572922f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3539,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5687269h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3540,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61225826',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3541,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55670802',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3542,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574184d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3543,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5573809j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3544,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104679z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3545,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104708g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3546,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55739628',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3547,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122577w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3548,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571050b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3549,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55738158',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3550,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5572962z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3551,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104684d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3552,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k6122581s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3553,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5571006x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3554,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55710488',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3555,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74169m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3556,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74837x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3557,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2005723',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3558,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55773752',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3559,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5604044v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3560,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471155h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3561,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56759943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3562,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55684407',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3563,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66791q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3564,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103067q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3565,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204334z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3566,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5436320f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3567,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5543912j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3568,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5542350v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3569,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k832675',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3570,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551138p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3571,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54701660',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3572,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k408420x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3573,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k480038s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3574,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55677310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3575,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56516859',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3576,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5523533s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3577,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5668213w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3578,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85655r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3579,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k740293',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3580,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k220561v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3581,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5473323v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3582,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5675966s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3583,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54447407',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3584,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200620x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3585,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55264304',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3586,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k433162g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3587,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54508960',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3588,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5449749h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3589,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67373x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3590,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2413555',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3591,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61677p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3592,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5452816k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3593,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32689464v/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3594,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54921895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3595,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5476817s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3596,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5516029t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3597,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551036h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3598,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5429300b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3599,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5489516j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3600,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k68041q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3601,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72282m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3602,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5830402z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3603,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200564h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3604,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455112f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3605,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71947s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3606,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56515263',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3607,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k111050d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3608,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k762410',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3609,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458221p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3610,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54555619',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3611,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582060',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3612,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458210w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3613,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458198w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3614,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54581947',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3615,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458186p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3616,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3617,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3618,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458223h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3619,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582097',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3620,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458212q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3621,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54581962',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3622,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582349',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3623,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458201x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3624,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458238z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3625,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328092880/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3626,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458225b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3627,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582223',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3628,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458214j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3629,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458239c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3630,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458203r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3631,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582364',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3632,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458216c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3633,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458217s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3634,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458205k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3635,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458241f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3636,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3637,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458207d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3638,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54581910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3639,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458183f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3640,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54582186',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3641,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54553532',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3642,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k29451j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3643,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5426848z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3644,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54604267',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3645,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651570h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3646,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71821t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3647,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83259j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3648,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83278t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3649,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62818z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3650,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55049j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3651,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56607453',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3652,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2005935',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3653,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55510568',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3654,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67366n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3655,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299620',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3656,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629279v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3657,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292756',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3658,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629969w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3659,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629280h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3660,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299657',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3661,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629264d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3662,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629970j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3663,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629954f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3664,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629973s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3665,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629267n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3666,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72472v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3667,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54475607',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3668,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629957p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3669,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292630',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3670,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299531',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3671,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292667',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3672,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299568',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3673,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629271j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3674,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629961k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3675,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb391783647/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3676,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629274s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3677,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629964t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3678,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292704',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3679,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56298209',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3680,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299605',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3681,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299761',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3682,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5541579q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3683,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5657431x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3684,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5558675v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3685,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56748434',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3686,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54018498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3687,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63506c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3688,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856892',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3689,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5448750v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3690,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5548731r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3691,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k27984d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3692,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k114776c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3693,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5546083f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3694,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5559014d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3695,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85711d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3696,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56517150',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3697,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74941f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3698,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54171512',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3699,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328071976/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3700,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54171408',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3701,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417148k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3702,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417143h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3703,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417150n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3704,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417144x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3705,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54171475',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3706,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54156923',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3707,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417146r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3708,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5417141p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3709,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63498k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3710,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5467743z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3711,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55129021',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3712,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1090558',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3713,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5526277v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3714,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k862416',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3715,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5489686j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3716,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k680829',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3717,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651578t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3718,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55512188',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3719,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54508641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3720,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72317f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3721,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104038b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3722,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568861s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3723,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5550309b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3724,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5549163z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3725,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k751137',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3726,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55750317',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3727,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327774096/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3728,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5424025k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3729,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k550068',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3730,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55007m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3731,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54007078',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3732,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55423518',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3733,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63499x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3734,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471124z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3735,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54405958',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3736,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72405q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3737,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k7698t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3738,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326850476/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3739,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5705344f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3740,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5705349h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3741,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5701419g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3742,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455339s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3743,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54550976',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3744,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85667r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3745,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856683',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3746,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k29841b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3747,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5464068f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3748,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55654565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3749,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55685855',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3750,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5550713m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3751,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54084729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3752,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32888671s/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3753,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5546004t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3754,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660780j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3755,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k81594d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3756,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k92232g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3757,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54918h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3758,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k724736',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3759,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56522783',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3760,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56521513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3761,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54697388',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3762,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105075v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3763,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k207008b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3764,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856621',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3765,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54522227',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3766,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471095p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3767,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66739m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3768,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k743037',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3769,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55038w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3770,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k64792k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3771,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54895473',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3772,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k99892p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3773,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5579952r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3774,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k998931',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3775,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455440s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3776,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5453570n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3777,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2005770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3778,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651381m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3779,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5427348j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3780,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458636h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3781,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k746915',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3782,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5403289b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3783,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32696906j/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3784,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k91173j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3785,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5445172f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3786,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567477z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3787,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856474',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3788,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61693x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3789,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5442812n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3790,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660693t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3791,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5546774w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3792,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5444761d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3793,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69658b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3794,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696559',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3795,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69681v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3796,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69687x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3797,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69680h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3798,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69686k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3799,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69675x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3800,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69672w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3801,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69678z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3802,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69674k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3803,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696857',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3804,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69677m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3805,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69663x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3806,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69660w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3807,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69666z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3808,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567604r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3809,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696768',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3810,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696737',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3811,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69662k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3812,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696799',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3813,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69668n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3814,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69665m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3815,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k696617',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3816,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69656n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3817,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69659p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3818,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5429286h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3819,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k619912',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3820,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74945t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3821,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k634915',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3822,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5543150g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3823,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71971n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3824,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k715183',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3825,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63501n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3826,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629262k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3827,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629278f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3828,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629952m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3829,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5628982f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3830,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629281x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3831,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459343x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3832,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629968g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3833,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56025795',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3834,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629265t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3835,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629971z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3836,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629955v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3837,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299516',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3838,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292771',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3839,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299672',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3840,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629972c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3841,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629269g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3842,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629975m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3843,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629959h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3844,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629272z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3845,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299746',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3846,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56292682',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3847,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629273c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3848,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56299583',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3849,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63658w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3850,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629963d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3851,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5780170w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3852,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629950s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3853,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629276m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3854,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5629966n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3855,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5818084c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3856,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54538038',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3857,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74250g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3858,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1081996',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3859,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62586m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3860,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5550240s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3861,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86640z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3862,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86638d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3863,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85726f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3864,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86639r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3865,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86635c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3866,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86636q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3867,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k866372',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3868,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54989535',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3869,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55682943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3870,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856412',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3871,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551426h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3872,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k76216s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3873,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568353h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3874,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55764590',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3875,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327836106/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3876,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54292853',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3877,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k856563',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3878,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55450337',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3879,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5473375k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3880,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5473346v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3881,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72549m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3882,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74151j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3883,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54446983',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3884,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55042642',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3885,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455647c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3886,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86597n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3887,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568193b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3888,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451583n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3889,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451577x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3890,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54515879',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3891,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54515827',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3892,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451585g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3893,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651676b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3894,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451578b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3895,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451586w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3896,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451579r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3897,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451580d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3898,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451581t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3899,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54508500',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3900,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32877284k/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3901,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54515842',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3902,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451588q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3903,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k109275k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3904,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72323c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3905,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30820d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3906,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54553302',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3907,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54403500',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3908,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2079249',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3909,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5576862v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3910,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104327j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3911,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83305w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3912,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5698574f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3913,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660471j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3914,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k634888',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3915,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661314g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3916,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5485957m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3917,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5442888s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3918,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567291j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3919,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5650673s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3920,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2006143',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3921,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2037283',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3922,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55674524',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3923,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5445658w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3924,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5487199t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3925,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2005757',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3926,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5707760j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3927,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k111711k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3928,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5533137b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3929,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5541522x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3930,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5407606p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3931,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5441859r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3932,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5526704p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3933,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k110052w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3934,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73972g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3935,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471375z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3936,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5694986s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3937,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54065810',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3938,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567481v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3939,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71887r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3940,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k754957',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3941,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5549245c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3942,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660791b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3943,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5460692x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3944,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72283z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3945,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k666725',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3946,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5656433f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3947,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54620163',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3948,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55635045',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3949,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55450604',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3950,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5548134x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3951,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67853p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3952,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55481553',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3953,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32807971q/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3954,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568202v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3955,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55552922',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3956,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200567n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3957,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k423595n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3958,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k76215f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3959,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569254',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3960,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456927z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3961,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32810097f/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3962,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456919d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3963,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455855m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3964,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569165',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3965,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569202',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3966,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5534928f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3967,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54507816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3968,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67949q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3969,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5562220x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3970,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55622784',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3971,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55630921',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3972,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54911196',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3973,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54911218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3974,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32865936z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3975,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5489797p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3976,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5491120v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3977,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49805w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3978,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5492747w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3979,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493222n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3980,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493161d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3981,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54931830',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3982,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54932195',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3983,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328611103/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3984,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54931548',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3985,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493157h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3986,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54931815',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3987,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493213p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3988,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54931741',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3989,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54931296',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3990,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493178p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3991,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493202w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3992,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459383f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3993,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660511m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3994,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551289b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3995,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k828218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3996,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85654d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3997,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k616363',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3998,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2093452',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (3999,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85691m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4000,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54871510',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4001,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2006177',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4002,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56517595',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4003,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82462r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4004,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651708v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4005,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5530958b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4006,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85664q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4007,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k725457',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4008,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k668345',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4009,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54325286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4010,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661060p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4011,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66862d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4012,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5579961q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4013,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660834n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4014,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k480041g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4015,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455387v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4016,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83828x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4017,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515557j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4018,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515564p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4019,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55155564',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4020,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515566h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4021,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515559c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4022,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515567x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4023,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55085843',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4024,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515561f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4025,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5515562v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4026,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459255s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4027,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55155653',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4028,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32877212q/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4029,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55155549',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4030,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55155601',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4031,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458523j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4032,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1039842',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4033,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k110700k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4034,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5458000t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4035,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1147093',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4036,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200622p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4037,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k206752p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4038,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66932r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4039,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54447296',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4040,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72471h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4041,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204369w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4042,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1149192',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4043,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5657086h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4044,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74126b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4045,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030861',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4046,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200562r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4047,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5544221d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4048,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k206780z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4049,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5679293h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4050,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56030664',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4051,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72320b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4052,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660846v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4053,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455285p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4054,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32844751n/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4055,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569662',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4056,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457038z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4057,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570349',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4058,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5406283s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4059,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327421729/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4060,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456974m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4061,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457023h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4062,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457039c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4063,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456993z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4064,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54560199',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4065,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457026r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4066,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569892',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4067,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570223',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4068,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5675037z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4069,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456994c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4070,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32707778d/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4071,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569610',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4072,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457033w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4073,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569966',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4074,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569647',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4075,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570134',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4076,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456985d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4077,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570290',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4078,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456988n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4079,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457021p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4080,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k220575q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4081,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54495136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4082,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86043b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4083,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32702471z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4084,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55630298',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4085,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5550812j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4086,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5495447s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4087,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55682676',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4088,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85712r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4089,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457533m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4090,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54560481',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4091,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54884943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4092,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5526743s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4093,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k832733',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4094,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k722593',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4095,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k832613',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4096,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k65143z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4097,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61681x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4098,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k202955b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4099,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661556h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5494523d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4101,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5460693b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4102,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567105f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4103,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55406078',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4104,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84135h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4105,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k745880',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4106,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74475c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4107,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56602409',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4108,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5659707x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4109,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k92316h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4110,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73176n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4111,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54732579',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4112,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5450702k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4113,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56846370',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4114,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5577780r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4115,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5426787q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4116,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56792604',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4117,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85730p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4118,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471861n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4119,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72171p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4120,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74492z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660464d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1081360',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108137c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4124,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74885s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4125,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5659127m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4126,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5661081v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4127,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5575018c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4128,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72120s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4129,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5568583b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4130,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k674887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4131,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k77708s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5401502t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66388q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k206527x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4135,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2065289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455046w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k80054j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4138,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5566696p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660360d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54680997',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54428043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54679672',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5692265k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56574434',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k282523',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5512582p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459415z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5489445x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4149,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5477289h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5545819q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73202c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55424469',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54010149',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55682142',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73772x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55510427',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200618m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54613978',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55008z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4160,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568125',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4161,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455897z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457347z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4163,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573439',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573276',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457332h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457348c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456855x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457335r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573313',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568355',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456840g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456824c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457323j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457342w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568429',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457326s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573224',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4178,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568266',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456847c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4180,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456850v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4181,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457330p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54556444',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457346j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4184,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568622',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457333x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4186,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457349s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54773218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4188,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455652p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573454',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568177',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573291',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457334b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456806f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4194,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326841117/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457321q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568214',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568370',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457324z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54558227',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573365',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457341g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457284w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457325c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456829f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456832x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54568607',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456800z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55658910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457344q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457328m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54573402',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55485290',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72123t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66908w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5475347w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k69394c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82459v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k776989',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62378f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651421p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54939044',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4223,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49799s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4224,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k91107r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71367r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54285081',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4227,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327415082/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5526547r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569840',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457024x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456959x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569877',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569558',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570364',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570045',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54498189',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457041f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457025b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456963t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569914',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456979p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457012q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457028k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570401',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54547371',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569751',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456983k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457016c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457003r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457019m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54569981',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4253,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54570312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5456971c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1104393',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4256,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1075558',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k57466548',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k57466563',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4259,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32771725t/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5746657h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5545115n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63838t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040500',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72027x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5653966m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72475w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54603546',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56795108',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56515990',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2205674',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521965h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521783r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5516231k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521845d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5516257t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4276,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521992d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4277,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521773c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4278,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55217704',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4279,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32700920z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4280,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55218833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4281,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521850q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521839p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521790w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521853z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521780h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521854c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55218514',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5521977q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37020w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54450938',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k110514t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k832764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5435362g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4294,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328087048/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54353612',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54353041',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54694409',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4298,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108588q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54430282',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5655660q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5652042s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5579948v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5652063z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56519786',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5492732f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71799g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k667895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108056c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5470747q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4310,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660848p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5423973f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5425717r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k634799',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5444825w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5457646k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55505751',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k743099',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651870j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4319,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54946601',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459034x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k96287q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5535100x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55405624',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5546033j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61900x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5469051q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55041832',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5438935k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204711c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551429r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5602795z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2030053',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73365j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k229189t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2059767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5534248s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k673717',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54310945',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85692z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5459401x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56606947',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k92284q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k922852',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71800v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56537769',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54548329',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k36210w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k362117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4349,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5575032n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63475x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54712338',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200781p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4353,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb400472414/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551756p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5444416j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k622723',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5469893t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54553035',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2006190',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5461220c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5650306b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200612b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74124n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63486k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54144908',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55765971',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204343x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2043462',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204342j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204339v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204338g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204345p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2043415',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2043449',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2043373',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204340s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5652053k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54553428',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5480187f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5567599w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5479050k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k751586',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1092712',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56820505',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5493610t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660710w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4387,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32739981z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54548418',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455296g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54685032',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744025',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k732460',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5696363b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5652414v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73366w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63478z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651820n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55649021',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1106746',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1050644',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5427089f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5546059s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1186943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5477106w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5657591j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5436247r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71809z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471156x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5468142s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5479161q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4411,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32820941h/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54816291',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54790102',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56515033',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4415,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2413589',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5559323d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k669097',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651705m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k717984',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66767v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5451691j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k71953q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83266t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55425064',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55588173',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5492309t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55430200',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1083624',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86602d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k86603r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108837j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56605069',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k669004',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55458189',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72469z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55267216',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74130k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5664641b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5446470z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4440,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108736v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1087343',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k108735g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5432030j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55441909',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55509473',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5467587f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63483j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k111857j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5685368t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54919337',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54586108',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72462j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84160q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55751943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56634257',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5450915w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5475341d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k762890',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55460465',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5544283h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84190n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k682209',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54594312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5653931d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67372k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55442697',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54918616',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4468,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32739980m/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85669f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1083370',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k111897x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5471024m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651769j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5673047q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5576571s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5532970d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5523484r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5574982b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55767079',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455390b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54855169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k65009h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k83271d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54906631',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5449535s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4486,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54564010',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k36429v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k113004r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k815603',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56604986',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61896h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56605299',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5565217c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56951210',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54771932',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k57059648',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4497,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k717953',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4498,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5455343p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4499,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5469193d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4500,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k37455n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4501,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5489755b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4502,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54923144',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4503,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5660741f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4504,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k204378v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4505,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54697069',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4506,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k724767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4507,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200615g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4508,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54571033',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4509,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k110480d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4510,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74308z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4511,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72555j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4512,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2005634',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4513,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k118836d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4514,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k552044',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4515,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5516489g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4516,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63495j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4517,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k207340m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4518,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5561376b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4519,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k4415289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4520,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k865938',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4521,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5692254s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4522,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5488125t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4523,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55028k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4524,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56606695',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4525,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k673790',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4526,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5442689h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4527,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54554468',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4528,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55329831',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4529,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56519237',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4530,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5651473d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4531,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5696738n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4532,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200570b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4533,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k77792h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4534,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5532823d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4535,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5473403f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4536,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72886n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4537,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54601444',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4538,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28155v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4539,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k281566',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4540,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74509v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4541,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k92750s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4542,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k72474j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4543,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k76391t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4544,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5543434d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4545,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5551337z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4546,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5473242v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4547,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k111107n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4548,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k55073665',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4549,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb32871637q/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4550,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5408750r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4551,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67408r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4552,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k57014434',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4553,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k731817',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4554,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54540047',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4555,'z3950 5 FRBNF316667660000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4556,'z3950 5 FRBNF320870040000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4557,'z3950 5 FRBNF330033010000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4558,'z3950 5 FRBNF339141010000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4559,'z3950 5 FRBNF343121600000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4560,'z3950 5 FRBNF350022390000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4561,'z3950 5 FRBNF350685170000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4562,'z3950 5 FRBNF350743490000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4563,'z3950 5 FRBNF351514460000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4564,'z3950 5 FRBNF354561940000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4565,'z3950 5 FRBNF355116690000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4566,'z3950 5 FRBNF357036170000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4567,'z3950 5 FRBNF370449150000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4568,'z3950 5 FRBNF376794750000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4569,'z3950 5 FRBNF377758160000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4570,'z3950 5 FRBNF377864990000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4571,'z3950 5 FRBNF385611080000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4572,'z3950 5 FRBNF390826000000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4573,'z3950 5 FRBNF394519290000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4574,'z3950 5 FRBNF397761040000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4575,'z3950 5 FRBNF407947150000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4576,'z3950 5 FRBNF407952240000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4577,'z3950 5 FRBNF408373950000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4578,'z3950 5 FRBNF408415610000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4579,'z3950 5 FRBNF408505270000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4580,'z3950 5 FRBNF416034670000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4581,'z3950 5 FRBNF420835720000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4582,'z3950 5 FRBNF427809970000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4583,'z3950 5 FRBNF300178480000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4584,'z3950 5 FRBNF300178510000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4585,'z3950 5 FRBNF300178520000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4586,'z3950 5 FRBNF300216770000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4587,'z3950 5 FRBNF301018330000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4588,'z3950 5 FRBNF301130990000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4589,'z3950 5 FRBNF301304670000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4590,'z3950 5 FRBNF301974400000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4591,'z3950 5 FRBNF301996210000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4592,'z3950 5 FRBNF30199622000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4593,'z3950 5 FRBNF303830110000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4594,'z3950 5 FRBNF303899080000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4595,'z3950 5 FRBNF303919410000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4596,'z3950 5 FRBNF30433391000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4597,'z3950 5 FRBNF304333920000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4598,'z3950 5 FRBNF304528670000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4599,'z3950 5 FRBNF304528680000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4600,'z3950 5 FRBNF304528690000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4601,'z3950 5 FRBNF304575800000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4602,'z3950 5 FRBNF304611800000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4603,'z3950 5 FRBNF304611810000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4604,'z3950 5 FRBNF305215680000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4605,'z3950 5 FRBNF30521569000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4606,'z3950 5 FRBNF305735350000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4607,'z3950 5 FRBNF305985200000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4608,'z3950 5 FRBNF306004460000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4609,'z3950 5 FRBNF306781670000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4610,'z3950 5 FRBNF307393150000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4611,'z3950 5 FRBNF307393160000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4612,'z3950 5 FRBNF308189520000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4613,'z3950 5 FRBNF308189530000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4614,'z3950 5 FRBNF308676910000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4615,'z3950 5 FRBNF309978830000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4616,'z3950 5 FRBNF309978840000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4617,'z3950 5 FRBNF309978850000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4618,'z3950 5 FRBNF309978860000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4619,'z3950 5 FRBNF309978870000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4620,'z3950 5 FRBNF309978880000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4621,'z3950 5 FRBNF309978890000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4622,'z3950 5 FRBNF309979740000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4623,'z3950 5 FRBNF310101440000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4624,'z3950 5 FRBNF310508850000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4625,'z3950 5 FRBNF310701800000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4626,'z3950 5 FRBNF311243900000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4627,'z3950 5 FRBNF311677710000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4628,'z3950 5 FRBNF311961020000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4629,'z3950 5 FRBNF312198840000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4630,'z3950 5 FRBNF312419480000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4631,'z3950 5 FRBNF313717230000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4632,'z3950 5 FRBNF313903250000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4633,'z3950 5 FRBNF316191210000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4634,'z3950 5 FRBNF317550360000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4635,'z3950 5 FRBNF318221600000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4636,'z3950 5 FRBNF319758360000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4637,'z3950 5 FRBNF320495930000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4638,'z3950 5 FRBNF321197280000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4639,'z3950 5 FRBNF321778790000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4640,'z3950 5 FRBNF32189191000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4641,'z3950 5 FRBNF324106750000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4642,'z3950 5 FRBNF32452360000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4643,'z3950 5 FRBNF325566950000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4644,'z3950 5 FRBNF326883070000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4645,'z3950 5 FRBNF32714732000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4646,'z3950 5 FRBNF327147330000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4647,'z3950 5 FRBNF327147340000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4648,'z3950 5 FRBNF327147350000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4649,'z3950 5 FRBNF327147360000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4650,'z3950 5 FRBNF327147370000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4651,'z3950 5 FRBNF327147380000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4652,'z3950 5 FRBNF327147390000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4653,'z3950 5 FRBNF327147400000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4654,'z3950 5 FRBNF327147410000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4655,'z3950 5 FRBNF327147420000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4656,'z3950 5 FRBNF327147430000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4657,'z3950 5 FRBNF327147440000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4658,'z3950 5 FRBNF327147450000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4659,'z3950 5 FRBNF327147460000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4660,'z3950 5 FRBNF327147470000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4661,'z3950 5 FRBNF32714748000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4662,'z3950 5 FRBNF327147490000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4663,'z3950 5 FRBNF327147500000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4664,'z3950 5 FRBNF327147510000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4665,'z3950 5 FRBNF327147520000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4666,'z3950 5 FRBNF32714753000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4667,'z3950 5 FRBNF327147540000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4668,'z3950 5 FRBNF327147550000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4669,'z3950 5 FRBNF327147560000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4670,'z3950 5 FRBNF327147570000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4671,'z3950 5 FRBNF327147590000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4672,'z3950 5 FRBNF327147600000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4673,'z3950 5 FRBNF327147610000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4674,'z3950 5 FRBNF327147620000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4675,'z3950 5 FRBNF327147630000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4676,'z3950 5 FRBNF327147640000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4677,'z3950 5 FRBNF327147650000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4678,'z3950 5 FRBNF327147660000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4679,'z3950 5 FRBNF327147670000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4680,'z3950 5 FRBNF327147680000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4681,'z3950 5 FRBNF32714769000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4682,'z3950 5 FRBNF327147700000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4683,'z3950 6 f6c18e5206723acf75f531589b18f61e',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4684,'z3950 6 4bddb78f4137c2d11d2698d751ef68a0',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4685,'z3950 6 82de7a59dd0ede3375415f9adda9c35d',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4686,'z3950 6 05511e57f65e9d4d2d9f92c734b31324',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4687,'z3950 6 8f1fb018f072bf864cd8fd5c24f4f8f2',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4688,'z3950 6 66b1ade86b152ac1f787e7b3672ef71f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4689,'z3950 6 b87b2375cccefdfe6175562f751ef9b7',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4690,'z3950 6 48474820b1cb386be737cd1ea3135c06',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4691,'z3950 6 4ce99bbf4373548277bd10c2a9b1a0f6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4692,'z3950 6 3744eefbd09cb50b65496bd22cd215f5',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4693,'z3950 6 cb88b3e79d065f30c8b216449df6df4f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4694,'z3950 6 b7005ff8d16e77ec4a7200d690b6fcda',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4695,'z3950 6 9bf3767815055b91763dcb2038bfe222',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4696,'z3950 6 395825860e505cc6beaa50660d6e7da8',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4697,'z3950 6 2a5525667cacf313d82c28ff88fede27',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4698,'z3950 6 0b8f9cbef64694be80ea4cf0f1937da6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4699,'z3950 6 e8eb7ab57db291bd8446bc9ffdef1a21',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4700,'z3950 6 34f37d645deb07dbbf20fc05956df2d3',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4701,'z3950 6 3d2ea802fe9bbbcb1d6f929be7c82579',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4702,'z3950 6 d216a94d785fe844e7f7357023d25de4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4703,'z3950 6 5ab07c5d491d063c0e9f6013ef2ddb80',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4704,'z3950 6 e8360850ed055df1ca6a55ad1438b329',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4705,'z3950 6 b273270b2b589d29011415566db99864',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4706,'z3950 6 6c0e36d915f9eaf09a251500db8bea82',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4707,'z3950 6 9c8df95b8ca4eaf5b1b9749075d43b18',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4708,'z3950 6 4ce2f7831da18165f91fc6c7bcf6ddbb',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4709,'z3950 6 a8e37565671197c6f8a9bec05e0d8c60',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4710,'z3950 6 f8f8fda09130b61109a65d369c23b5a4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4711,'z3950 6 4d8dd230d679da88b5949acd8176c9fe',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4712,'z3950 6 07f8a00a19552fbcd8fd0cbce64ab46c',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4713,'z3950 6 936f21947690056dee2a2f4d2947bbee',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4714,'z3950 6 bb368a8ca627b824fb15c93354701cb6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4715,'z3950 6 edc211915ca87fdeb12831f96196809f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4716,'z3950 6 4cf2c3a256814cfdd97df91e70ec4f24',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4717,'z3950 6 9e268857862f8af52e9e8efc98192139',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4718,'z3950 6 04556b62b24bf35091ef870bf5a69cd4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4719,'z3950 6 134224503fb12ac6a920d0fed4dade51',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4720,'z3950 6 5237f6dbad3e7331ffd20ad1fe8fcd29',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4721,'z3950 6 4cf73f29fd2a6b24ac3b5198c577f599',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4722,'z3950 6 b50e5172a5a5137ccfe48f5706bec210',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4723,'z3950 6 93aa4127ab578accdb1996f2c8f45629',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4724,'z3950 6 ed9d5fb3516920e38e5e8b2662d70c81',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4725,'z3950 6 8a0c75e9bdfa1551df75db76ddf6abb1',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4726,'z3950 6 425905a47c6967035d64d00892903b16',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4727,'z3950 6 02250f13209c5984cfdc0f20b970f717',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4728,'z3950 6 bf78629643f84feddabc51485de436af',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4729,'z3950 6 d13aee663413601eeb374c7ab8f152f8',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4730,'z3950 6 062358ea5708c39b5ba0765a9c1f5397',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4731,'z3950 6 539b3d19b481760ada09e6c4324f4e3c',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4732,'z3950 6 4b4d2e81bb4d32d0aa8065ab167826bc',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4733,'z3950 6 4bfc541a5f4e74f46ed8673389c87e00',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4734,'z3950 6 30c391e634f58d4395c26f5bdaf68d69',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4735,'z3950 6 1f0b47fc7511b5d1d37c495dd060dd3f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4736,'z3950 6 7712fa3c1f40e2b5446da1d8f52d76e9',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4737,'z3950 6 7b520cd9500ebdcd38447b964b83d3a2',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4738,'z3950 6 3d9964237a8bde68ce8485697a44340e',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4739,'z3950 6 fa50678aa6ef02c8076affa7df64f78f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4740,'z3950 6 b97ec1c8e3081c94212bc05daf1770e3',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4741,'z3950 6 c6158620948e9e493db160318506d694',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4742,'z3950 6 923bebc20be72a27274cdf8353e3d1e6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4743,'z3950 6 c86cc438d2c30969beee8b8c5bd0aac0',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4744,'z3950 6 ece69e958313da23ec244e5794787c3a',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4745,'z3950 6 808b18fa3fe5f56f67f930a14026fbb4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4746,'z3950 6 8bfa9012c406f3acb6d1c8dd8c2dd361',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4747,'z3950 6 ed504074b9ba0ed4739c9d29b1fb899b',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4748,'z3950 6 f5d11c710ce0d88b7d79a65b5fd3b0b2',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4749,'z3950 6 d66d0f3b86d0ccb6c8d51c41ae6df808',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4750,'z3950 6 c09344f2764667cfc89499d292cabe1a',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4751,'z3950 6 48bfa3097bf8ec267d78f8df90240019',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4752,'z3950 6 099d8919502b7dfc4b2dfd1927cff7d6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4753,'z3950 6 d6a769160d59e75fc7935a87a4808f05',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4754,'z3950 6 84a5e968a50d3e0d129bf1449948e32a',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4755,'z3950 6 68252e08e464855140003c99a710c870',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4756,'z3950 6 87a770e4645ee1ea564d03cac6ef797c',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4757,'z3950 6 d4d2fac33f192195202c0e769e7087ea',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4758,'z3950 6 b8fdd837c814484fa7e8437c96005187',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4759,'z3950 6 986cf23e913f80bbefc246f93939bbb4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4760,'z3950 6 4e503d61a16c0fb13cb9923cb446ea7c',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4761,'z3950 6 89a5063f6dfa266055a3173e5e055e56',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4762,'z3950 6 5c8890927aed0b488c8aefd4bfa55aea',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4763,'z3950 6 e32ac1a9c3d4a95423a96479f6d6b24e',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4764,'z3950 6 12136cbb38581061b1ebc7712954749c',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4765,'z3950 6 c6919a877aaceac60987acfc8c45425f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4766,'z3950 6 eb957443c697649b91b7c64919c06d7f',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4767,'z3950 6 a11bb3e5d1f43f211c201d8a617f9b33',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4768,'z3950 6 2a091362ff1071a951d324e20e9a920a',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4769,'z3950 6 d2b9c17c16c75a8807eb68defcc08d04',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4770,'z3950 6 2904df34aeda87378aaeb18a2bba7882',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4771,'z3950 6 ee90f69bac1fecee06371c952a2298e6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4772,'z3950 6 85b5716ecad83555b6cc0b0547205236',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4773,'z3950 6 37175092ae0cb68b48f8f77b8f4f6fb4',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4774,'z3950 6 12032229b56d7de171ce71fd722c47cf',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4775,'z3950 6 b1be9fae6ab85481769103e16d8f0ef1',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4776,'z3950 6 d73118a927c9e24ee9429f22caf26683',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4777,'z3950 6 89450f26ea706a730616e647a3c84cc7',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4778,'z3950 6 b594923641cb7432a7e96e3afe249365',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4779,'z3950 6 252ecf6a1a164ae492b919e5710c36c6',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4780,'z3950 6 e1423c04688dc8422a54da8231cf0295',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4781,'z3950 6 392f034705e56074639fb7029cca0b1e',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4782,'z3950 6 76c08300a3a9c0ec0d118c54f53b0163',6);
INSERT INTO external_count (rid, recid, source_id) VALUES (4783,'entrez 8 16060060',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4784,'entrez 8 11625217',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4785,'entrez 8 10401413',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4786,'entrez 8 10356040',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4787,'entrez 8 10342468',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4788,'entrez 8 8783434',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4789,'entrez 8 8790771',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4790,'entrez 8 7800031',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4791,'entrez 8 8067815',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4792,'entrez 8 8107832',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4793,'entrez 8 1959911',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4794,'entrez 8 3274744',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4795,'entrez 8 21267107',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4796,'entrez 8 5840806',8);
INSERT INTO external_count (rid, recid, source_id) VALUES (4797,'z3950 5 FRBNF30034929000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4798,'z3950 5 FRBNF300486730000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4799,'z3950 5 FRBNF300486740000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4800,'z3950 5 FRBNF300486750000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4801,'z3950 5 FRBNF300486760000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4802,'z3950 5 FRBNF300521700000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4803,'z3950 5 FRBNF300598460000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4804,'z3950 5 FRBNF300915700000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4805,'z3950 5 FRBNF301036970000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4806,'z3950 5 FRBNF301036980000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4807,'z3950 5 FRBNF301036990000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4808,'z3950 5 FRBNF301037000000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4809,'z3950 5 FRBNF301037010000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4810,'z3950 5 FRBNF30122119000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4811,'z3950 5 FRBNF301221200000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4812,'z3950 5 FRBNF301283200000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4813,'z3950 5 FRBNF301507110000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4814,'z3950 5 FRBNF301752130000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4815,'z3950 5 FRBNF301778030000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4816,'z3950 5 FRBNF301796960000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4817,'z3950 5 FRBNF301896380000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4818,'z3950 5 FRBNF302013410000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4819,'z3950 5 FRBNF302159110000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4820,'z3950 5 FRBNF302159120000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4821,'z3950 5 FRBNF302284520000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4822,'z3950 5 FRBNF302401620000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4823,'z3950 5 FRBNF302626650000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4824,'z3950 5 FRBNF302626660000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4825,'z3950 5 FRBNF302626670000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4826,'z3950 5 FRBNF302801080000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4827,'z3950 5 FRBNF303012130000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4828,'z3950 5 FRBNF30301215000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4829,'z3950 5 FRBNF303012160000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4830,'z3950 5 FRBNF303012170000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4831,'z3950 5 FRBNF303109530000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4832,'z3950 5 FRBNF303152770000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4833,'z3950 5 FRBNF303414460000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4834,'z3950 5 FRBNF303456890000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4835,'z3950 5 FRBNF303591880000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4836,'z3950 5 FRBNF303630920000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4837,'z3950 5 FRBNF303630970000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4838,'z3950 5 FRBNF303677450000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4839,'z3950 5 FRBNF303799190000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4840,'z3950 5 FRBNF303807310000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4841,'z3950 5 FRBNF304122930000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4842,'z3950 5 FRBNF304154810000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4843,'z3950 5 FRBNF304205400000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4844,'z3950 5 FRBNF304209660000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4845,'z3950 5 FRBNF304403480000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4846,'z3950 5 FRBNF304463700000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4847,'z3950 5 FRBNF304507690000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4848,'z3950 5 FRBNF304592760000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4849,'z3950 5 FRBNF30482746000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4850,'z3950 5 FRBNF304894920000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4851,'z3950 5 FRBNF304971750000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4852,'z3950 5 FRBNF304984200000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4853,'z3950 5 FRBNF304984210000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4854,'z3950 5 FRBNF305062130000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4855,'z3950 5 FRBNF305474620000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4856,'z3950 5 FRBNF305638940000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4857,'z3950 5 FRBNF305764790000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4858,'z3950 5 FRBNF305814580000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4859,'z3950 5 FRBNF305815630000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4860,'z3950 5 FRBNF305815650000002',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4861,'z3950 5 FRBNF306090950000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4862,'z3950 5 FRBNF306239120000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4863,'z3950 5 FRBNF306393720000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4864,'z3950 5 FRBNF306397530000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4865,'z3950 5 FRBNF306397540000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4866,'z3950 5 FRBNF306682350000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4867,'z3950 5 FRBNF306682360000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4868,'z3950 5 FRBNF306724150000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4869,'z3950 5 FRBNF306792870000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4870,'z3950 5 FRBNF307015060000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4871,'z3950 5 FRBNF307015070000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4872,'z3950 5 FRBNF307109100000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4873,'z3950 5 FRBNF307125760000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4874,'z3950 5 FRBNF307198770000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4875,'z3950 5 FRBNF307198780000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4876,'z3950 5 FRBNF307198820000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4877,'z3950 5 FRBNF307198830000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4878,'z3950 5 FRBNF307198840000000',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4879,'z3950 5 FRBNF307198850000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4880,'z3950 5 FRBNF307232420000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4881,'z3950 5 FRBNF307290730000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4882,'z3950 5 FRBNF307333820000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4883,'z3950 5 FRBNF30736401000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4884,'z3950 5 FRBNF307410480000005',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4885,'z3950 5 FRBNF307453200000009',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4886,'z3950 5 FRBNF307552500000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4887,'z3950 5 FRBNF307592400000008',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4888,'z3950 5 FRBNF307776720000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4889,'z3950 5 FRBNF307837530000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4890,'z3950 5 FRBNF307880050000004',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4891,'z3950 5 FRBNF307935560000001',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4892,'z3950 5 FRBNF30803114000000X',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4893,'z3950 5 FRBNF308268270000007',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4894,'z3950 5 FRBNF308339220000006',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4895,'z3950 5 FRBNF308339230000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4896,'z3950 5 FRBNF308497910000003',5);
INSERT INTO external_count (rid, recid, source_id) VALUES (4897,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb33409493k/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4898,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106270v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4899,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4900,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34515z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4901,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34514m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4902,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328566125/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4903,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345138',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4904,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34512x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4905,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326804969/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4906,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84220r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4907,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103770k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4908,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049596',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4909,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4910,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103767w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4911,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106287v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4912,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4913,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106260h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4914,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106286g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4915,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038731',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4916,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104940f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4917,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720521/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4918,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105690h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4919,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105689k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4920,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057450',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4921,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103586k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4922,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103587z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4923,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035856',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4924,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103588b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4925,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74436g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4926,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044520',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4927,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044855',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4928,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104907q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4929,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104905z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4930,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049083',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4931,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104909g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4932,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104906b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4933,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062730',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4934,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104487x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4935,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591537',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4936,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200851z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4937,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104662z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4938,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326950044/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4939,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046687',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4940,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047285',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4941,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104664q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4942,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104663b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4943,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104671x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4944,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104670j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4945,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104667v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4946,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104666g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4947,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104669m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4948,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046653',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4949,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4950,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104675f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4951,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4952,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042591',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4953,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104384g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4954,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104440w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4955,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103737v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4956,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4957,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104953x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4958,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104911s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4959,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105353b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4960,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104808s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4961,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106261w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4962,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104918f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4963,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4964,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104914x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4965,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049549',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4966,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49679w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4967,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043909',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4968,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106205b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4969,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84097s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4970,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048540',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4971,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105354q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4972,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104489p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4973,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044889',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4974,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95347h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4975,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k91437h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4976,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106209v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4977,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104381b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4978,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82435v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4979,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82434h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4980,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104442n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4981,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4982,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048048',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4983,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4984,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104805n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4985,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4986,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34461v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4987,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344746',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4988,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34460h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4989,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34467x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4990,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344599',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4991,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34470t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4992,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34469m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4993,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34473v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4994,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344626',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4995,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4996,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34458z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4997,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105762j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4998,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (4999,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104267m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5000,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105759v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5001,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67054t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5002,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85219s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5003,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85218f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5004,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104382q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5005,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5006,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104517t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5007,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037654',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5008,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39817p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5009,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398139',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5010,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056763',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5011,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056797',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5012,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105693n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5013,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105682x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5014,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105695d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5015,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105681j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5016,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105684p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5017,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105687t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5018,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056805',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5019,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056941',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5020,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105673z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5021,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105686f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5022,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056839',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5023,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105675q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5024,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720552/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5025,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105674b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5026,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105678v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5027,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105677g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5028,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056852',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5029,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106283b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5030,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037476',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5031,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056203',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5032,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105660g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5033,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056237',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5034,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105663m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5035,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105647f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5036,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105666r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5037,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105612h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5038,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105669w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5039,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105631t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5040,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105615n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5041,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056627',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5042,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105618s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5043,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105634z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5044,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056462',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5045,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056496',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5046,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056114',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5047,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105651h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5048,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056148',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5049,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105635b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5050,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105670t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5051,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105654n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5052,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105638g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5053,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105657s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5054,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056504',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5055,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105622v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5056,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328169156/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5057,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056538',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5058,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056373',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5059,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105626c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5060,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105642j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5061,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105629h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5062,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105661v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5063,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105645p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5064,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105648t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5065,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105613w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5066,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056415',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5067,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105665c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5068,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056449',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5069,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056250',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5070,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056284',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5071,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105668h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5072,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105630f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5073,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105633k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5074,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105617d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5075,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105652w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5076,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105636q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5077,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056640',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5078,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105639v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5079,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056674',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5080,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056326',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5081,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105672k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5082,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5083,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105656d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5084,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056195',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5085,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105691w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5086,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105659j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5087,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105621g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5088,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105640s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5089,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056716',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5090,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105643x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5091,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105627r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5092,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056551',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5093,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056585',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5094,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036030',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5095,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5096,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66361p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5097,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106158w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5098,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5099,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042489',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5101,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104969j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5102,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049685',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5103,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104970g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5104,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030937',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5105,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103780x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5106,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104994p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5107,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049952',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5108,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398181',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5109,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105866c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5110,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105870f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5111,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103551n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5112,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5113,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103549b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5114,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103572q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5115,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k3700445',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5116,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037387',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5117,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56886948',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5118,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104777h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5119,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34425274b/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5120,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047806',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104778w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5124,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63971x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5125,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63970k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5126,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639410',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5127,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639441',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5128,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639472',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5129,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63962z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5130,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5131,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63964n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63961m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63969c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63950z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5135,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639608',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63952n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5138,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63958q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63955p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63957c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63954b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639650',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639519',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63940n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63949r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63946q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63943p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5149,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34349269z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63948d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63945c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63942b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103634d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5608582h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036331',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104372c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5160,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104370m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5161,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744087',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037217',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5163,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82789m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82792h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82793v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82790t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k827915',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104408j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62076x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104264g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104529x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103575v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103574g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103718j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037531',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104098d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104110x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5178,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104847s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5180,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042455',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5181,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104246j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103720v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103719x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5184,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104412m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5186,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048137',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063438',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5188,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105867r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058684',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k823180',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82317n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104451m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5194,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044507',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053341',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103593s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104729j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103722m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39669c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035733',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104799z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39674z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103766h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104475t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39673m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k392051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035911',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105753k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106157h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k289312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104550j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82678p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84614x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104727s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104535r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103623p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104936c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038807',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496776',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5223,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104261b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5224,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105754z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30797q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5227,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104117k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104816c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053430',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104118z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048930',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104894c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104119b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84112v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104526s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105348w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049562',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104745q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104943k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104738h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045186',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104249p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104849j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047539',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104923w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104920r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049214',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104922h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106162z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k293638',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104850g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5253,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104800r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053375',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104115t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5256,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496803',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104498n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5259,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104507g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045063',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105885p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105844x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104853m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104472p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104478z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036017',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103602m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043880',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104422z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104423b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104421k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103369d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104985q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103754d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5276,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103755s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5277,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5278,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104521w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5279,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105750f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5280,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5281,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104996f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104997t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104731v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103883c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104525d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048574',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035555',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106441t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1064426',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39678b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5294,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043710',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104369p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043689',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5298,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044944',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105330h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49684g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103695v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104897h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104867g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103775g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103776v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103557x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103732z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103583f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048663',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5310,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104130m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044431',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036187',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048875',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104888j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034219',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105858s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105855n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5319,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058548',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105857d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103457m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104511j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104992x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049939',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104962w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104895r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048828',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105758g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036891',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105335d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105336s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104939h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104375h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39671x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2000804',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103595j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104872x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049515',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103579c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104367x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104516f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037620',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104751j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103763c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058425',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104090c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049384',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5349,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105892w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035610',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103772b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39679p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5353,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035521',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103571b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044690',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104103q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103895g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105699x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103757j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037607',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104101z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104255h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744056',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74404v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103559p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103635s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104479b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104274t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103725r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39805p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040801',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104462b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035644',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104085x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106344n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042633',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104244s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042667',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044342',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044329',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104541k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104492c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049303',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044719',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033634',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5387,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035691',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105876q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k26770x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104874p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104934m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104932v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049337',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200844r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5673310q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k824366',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104551x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103865f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104100k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841047',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84103w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496896',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104859w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82440f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104232p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048451',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30859f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103764r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049295',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041255',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5411,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058773',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058650',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398092',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037230',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5415,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396759',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103874d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105888t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104376w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037921',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398108',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030903',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5525439j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104260z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104466v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044677',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063930',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104871j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104950s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104387m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103752n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040793',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037429',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104807d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103420x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104519k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103773q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200850k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104431x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105339x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5440,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104846d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044643',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058815',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105331w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104424q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104430j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105344c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39676n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103584t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103739m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106154c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105751t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060618',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042680',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104439z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103592d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045542',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82386g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106060w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104500t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106203k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106200f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106201t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106199n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062026',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061988',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062162',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104087p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5468,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057615',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104730g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104514p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104958t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104448x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044130',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104983z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048739',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104945b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104447j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103091g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k75667j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k842275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047929',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49798f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k25566w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103416v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1034143',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5486,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106284q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062853',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103893q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038943',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062675',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106161k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048485',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95348v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103092v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103554s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103565h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5497,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104547v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5498,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104271p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5499,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042722',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5500,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038718',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5501,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104877t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5502,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105756q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5503,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103637j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5504,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058904',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5505,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105883x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5506,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103364h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5507,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043791',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5508,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103412b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5509,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041289',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5510,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104378n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5511,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103614q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5512,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200835s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5513,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103577m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5514,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104946q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5515,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104453c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5516,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104802h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5517,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104124s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5518,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104865q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5519,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103878x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5520,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103604c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5521,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036106',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5522,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037306',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5523,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103724c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5524,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053506',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5525,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104534c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5526,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057526',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5527,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045139',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5528,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036967',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5529,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103884r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5530,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200198t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5531,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103691b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5532,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053498',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5533,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104948g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5534,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k823049',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5535,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104252c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5536,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104399q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5537,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103892b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5538,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103891z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5539,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103749z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5540,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104987g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5541,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104988v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5542,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103138c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5543,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104459n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5544,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040924',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5545,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048841',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5546,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048998',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5547,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036229',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5548,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053464',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5549,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037298',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5550,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044978',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5551,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103785t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5552,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105891h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5553,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104493r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5554,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103741x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5555,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1050979',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5556,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041077',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5557,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104856r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5558,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104658w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5559,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104814m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5560,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2001996',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5561,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104444d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5562,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035809',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5563,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103769n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5564,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104892m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5565,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104089f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5566,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047416',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5567,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104496w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5568,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104121n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5569,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105763x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5570,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398150',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5571,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k2000838',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5572,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103630w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5573,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036318',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5574,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035432',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5575,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5576,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104952j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5577,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104253r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5578,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103748k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5579,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104391p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5580,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106602f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5581,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k73217d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5582,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1066826',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5583,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104373r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5584,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104858h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5585,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104876f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5586,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045241',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5587,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82005t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5588,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105351k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5589,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045398',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5590,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106534x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5591,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5592,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104486j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5593,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103413q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5594,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104102b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5595,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104082s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5596,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104916p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5597,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105333n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5598,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5675366q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5599,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053328',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5600,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105222m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5601,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049897',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5602,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105862v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5603,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049863',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5604,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044732',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5605,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044808',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5606,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104957f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5607,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103632n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5608,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104910d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5609,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041132',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5610,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104114f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5611,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k852429',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5612,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104258n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5613,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036276',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5614,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103628k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5615,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103629z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5616,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049172',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5617,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033846',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5618,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103385k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5619,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049159',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5620,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104991j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5621,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84129k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5622,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049002',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5623,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061564',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5624,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049350',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5625,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104863z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5626,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104883n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5627,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28488n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5628,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k284770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5629,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103581p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5630,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104445s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5631,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104129p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5632,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104256w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5633,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042544',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5634,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044465',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5635,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106210s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5636,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39811m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5637,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103611k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5638,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103771z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5639,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104902t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5640,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038854',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5641,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103886h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5642,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103568n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5643,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104405d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5644,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104961h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5645,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k279983',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5646,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28011z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5647,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5648,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28010m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5649,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28013n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5650,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28019q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5651,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28016p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5652,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28018c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5653,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28015b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5654,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280129',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5655,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28001n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5656,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28007q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5657,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28004p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5658,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28006c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5659,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28003b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5660,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28009d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5661,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280171',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5662,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280140',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5663,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280009',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5664,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280082',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5665,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5666,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k280020',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5667,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k27999f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5668,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28020x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5669,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28023z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5670,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28022m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5671,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106206q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5672,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104438k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5673,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104436t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5674,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044376',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5675,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045364',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5676,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k54367321',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5677,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048150',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5678,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048752',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5679,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104470x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5680,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104949v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5681,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104247x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5682,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104505q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5683,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048786',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5684,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106204z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5685,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104393f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5686,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106342w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5687,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103365w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5688,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104864b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5689,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105356g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5690,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041166',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5691,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106259k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5692,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104265v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5693,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036933',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5694,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103563r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5695,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104123d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5696,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103740j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5697,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045317',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5698,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104964n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5699,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049638',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5700,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105220v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5701,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104868v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5702,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k735742',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5703,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044075',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5704,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104523n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5705,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5668016f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5706,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048103',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5707,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048095',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5708,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103694g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5709,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49687h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5710,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043867',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5711,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104811g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5712,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058637',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5713,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200838x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5714,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037777',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5715,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104885d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5716,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033668',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5717,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104886s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5718,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61533s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5719,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61530r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5720,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327699551/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5721,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61532f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5722,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k78025p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5723,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k78024b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5724,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61521s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5725,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61524t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5726,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61527v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5727,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61526h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5728,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61523g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5729,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615313',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5730,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61529j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5731,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k780261',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5732,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k61518w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5733,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615286',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5734,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615255',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5735,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k615224',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5736,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048705',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5737,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103621x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5738,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28834t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5739,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28831s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5740,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28837v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5741,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28836h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5742,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28833g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5743,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28830f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5744,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28839j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5745,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288413',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5746,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28822t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5747,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28828w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5748,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28825v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5749,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28824h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5750,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28821g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5751,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040712',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5752,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038799',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5753,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103743p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5754,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105338j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5755,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048964',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5756,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104465g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5757,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103746t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5758,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048014',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5759,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049125',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5760,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035992',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5761,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106268j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5762,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1040882',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5763,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045152',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5764,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106208g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5765,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044418',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5766,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103589q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5767,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104851v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5768,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104463q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5769,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045406',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5770,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035979',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5771,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105760s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5772,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048917',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5773,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104410v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5774,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105878g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5775,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82020q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5776,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103875s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5777,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103570z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5778,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103758x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5779,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103745f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5780,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104913j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5781,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82441s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5782,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39670k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5783,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104740t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5784,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103617v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5785,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1060631',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5786,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396770',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5787,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106282z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5788,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104967s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5789,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85239d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5790,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105887f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5791,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042578',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5792,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103872n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5793,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044588',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5794,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037518',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5795,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049905',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5796,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045529',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5797,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103761m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5798,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103566w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5799,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042709',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5800,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037866',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5801,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k75938s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5802,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288386',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5803,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288355',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5804,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288324',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5805,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28827j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5806,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28816w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5807,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28819x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5808,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288204',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5809,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288235',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5810,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288266',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5811,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288297',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5812,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28815j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5813,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28818k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5814,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28843s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5815,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28840r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5816,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288177',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5817,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k288146',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5818,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k28842f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5819,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595363',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5820,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759530m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5821,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759537h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5822,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759538x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5823,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759539b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5824,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595400',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5825,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759541d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5826,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759542t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5827,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595311',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5828,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759532f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5829,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759533v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5830,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595348',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5831,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759535p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5832,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759138j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5833,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759139z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5834,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759140m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5835,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591411',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5836,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759142f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5837,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759143v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5838,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591448',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5839,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591463',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5840,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759147h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5841,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759148x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5842,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759250b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5843,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592525',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5844,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759253k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5845,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759251r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5846,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592540',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5847,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759255d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5848,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759256t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5849,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592577',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5850,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759258n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5851,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591144',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5852,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759118s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5853,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759115j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5854,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759116z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5855,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759117c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5856,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759779j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5857,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759380t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5858,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593817',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5859,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593832',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5860,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759382n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5861,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759645d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5862,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596440',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5863,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759376x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5864,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596388',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5865,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759375h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5866,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759639p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5867,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759640b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5868,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759641r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5869,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759377b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5870,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593795',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5871,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596425',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5872,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759643k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5873,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595756',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5874,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759576m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5875,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595771',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5876,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759578f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5877,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759579v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5878,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759574s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5879,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759814j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5880,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759815z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5881,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759816c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5882,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759691n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5883,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759671w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5884,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5885,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596796',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5886,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759673q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5887,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596744',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5888,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759675j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5889,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759676z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5890,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759677c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5891,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759678s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5892,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5893,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759585k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5894,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595845',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5895,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77590868',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5896,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77597554',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5897,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759242s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5898,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592436',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5899,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759244m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5900,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592451',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5901,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759246f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5902,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759247v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5903,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592488',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5904,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759249p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5905,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5906,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759260q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5907,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592614',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5908,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759262j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5909,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591307',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5910,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759131n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5911,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759134w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5912,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591359',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5913,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759136q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5914,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591374',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5915,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759149b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5916,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591856',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5917,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759177n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5918,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591782',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5919,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759179g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5920,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591804',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5921,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759181j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5922,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759182z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5923,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759241c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5924,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594160',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5925,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759418t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5926,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594197',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5927,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759417d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5928,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759849r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5929,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591233',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5930,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759124h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5931,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759125x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5932,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759126b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5933,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759127r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5934,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759493s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5935,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594946',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5936,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594998',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5937,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759500g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5938,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759501w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5939,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595029',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5940,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595044',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5941,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595860',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5942,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759587d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5943,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759588t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5944,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595897',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5945,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759590w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5946,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595919',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5947,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759592q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5948,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759853n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5949,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77598542',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5950,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759855g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5951,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591129',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5952,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594694',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5953,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759470s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5954,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5955,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759232d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5956,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759233t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5957,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592347',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5958,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759235n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5959,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592362',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5960,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759237g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5961,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759238w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5962,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592399',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5963,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759240z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5964,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759230k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5965,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592273',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5966,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759228h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5967,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759229x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5968,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594679',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5969,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759468q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5970,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5971,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759221m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5972,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592221',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5973,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759223f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5974,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759224v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5975,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592258',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5976,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759226p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5977,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759846h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5978,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759526q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5979,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595274',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5980,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759528j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5981,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759529z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5982,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595437',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5983,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759523g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5984,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759524w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5985,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77595259',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5986,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759625n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5987,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759623t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5988,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77596247',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5989,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759495m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5990,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77594961',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5991,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759497f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5992,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759498v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5993,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759510v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5994,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759122p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5995,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591196',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5996,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759120v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5997,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592703',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5998,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759271h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (5999,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759272x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6000,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759273b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6001,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759336d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6002,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759337t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6003,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593387',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6004,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759339n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6005,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593298',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6006,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759330x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6007,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759331b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6008,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759332r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6009,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593335',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6010,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759334k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6011,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593350',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6012,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759389j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6013,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593884',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6014,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759387q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6015,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6016,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759373p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6017,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593743',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6018,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759384g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6019,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759385w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6020,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593869',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6021,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759403c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6022,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6023,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759364q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6024,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77593654',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6025,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759366j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6026,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759402z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6027,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759401j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6028,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759367z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6029,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759368c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6030,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759369s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6031,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759370f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6032,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759371v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6033,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759263z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6034,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759264c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6035,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759265s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6036,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592666',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6037,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759267m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6038,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591285',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6039,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759129k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6040,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759186m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6041,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591871',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6042,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759188f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6043,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759189v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6044,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759190h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6045,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759191x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6046,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759192b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6047,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759193r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6048,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591945',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6049,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592095',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6050,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759210t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6051,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759212n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6052,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592132',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6053,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759214g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6054,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759215w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6055,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6056,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759217q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6057,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592184',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6058,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759219j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6059,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759195k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6060,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591960',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6061,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759197d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6062,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759198t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6063,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759201v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6064,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592028',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6065,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759203p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6066,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77592043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6067,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759205h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6068,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759206x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6069,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759207b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6070,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759208r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6071,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591626',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6072,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759163m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6073,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6074,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759166v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6075,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759168p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6076,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759170r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6077,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759172k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6078,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759174d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6079,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759175t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6080,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591767',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6081,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591730',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6082,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6083,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591693',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6084,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591678',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6085,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759165f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6086,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759161s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6087,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759160c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6088,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759159q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6089,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591589',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6090,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759152t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6091,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759154n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6092,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591552',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6093,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759156g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6094,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759157w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6095,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591500',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6096,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b7759151d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6097,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb33409493k/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6098,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106270v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6099,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345169',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6100,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34515z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6101,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34514m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6102,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328566125/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6103,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k345138',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6104,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34512x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6105,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326804969/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6106,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84220r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6107,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103770k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6108,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049596',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6109,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041310',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6110,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103767w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6111,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106287v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6112,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062887',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6113,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106260h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6114,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106286g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6115,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038731',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6116,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104940f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6117,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720521/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6118,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105690h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6119,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105689k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6120,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1057450',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6121,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103586k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6122,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103587z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6123,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035856',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6124,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103588b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6125,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k74436g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6126,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044520',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6127,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044855',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6128,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104907q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6129,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104905z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6130,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049083',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6131,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104909g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6132,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104906b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6133,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062730',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6134,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104487x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6135,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591537',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6136,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k200851z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6137,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104662z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6138,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb326950044/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6139,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046687',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6140,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047285',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6141,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104664q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6142,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104663b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6143,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104671x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6144,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104670j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6145,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104667v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6146,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104666g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6147,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104669m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6148,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046653',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6149,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1046729',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6150,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104675f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6151,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841016',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6152,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042591',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6153,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104384g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6154,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104440w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6155,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103737v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6156,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062641',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6157,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104953x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6158,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104911s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6159,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105353b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6160,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104808s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6161,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106261w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6162,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104918f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6163,'oai 7 oai:bnf.fr:gallica/ark:/12148/btv1b77591218',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6164,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104914x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6165,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049549',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6166,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k49679w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6167,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043909',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6168,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106205b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6169,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84097s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6170,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048540',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6171,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105354q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6172,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104489p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6173,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044889',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6174,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k95347h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6175,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k91437h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6176,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106209v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6177,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104381b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6178,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82435v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6179,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82434h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6180,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104442n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6181,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045275',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6182,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048048',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6183,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053417',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6184,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104805n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6185,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344715',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6186,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34461v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6187,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344746',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6188,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34460h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6189,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34467x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6190,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344599',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6191,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34470t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6192,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34469m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6193,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34473v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6194,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344626',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6195,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k344688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6196,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k34458z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6197,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105762j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6198,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044910',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6199,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104267m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6200,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105759v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6201,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k67054t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6202,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85219s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6203,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k85218f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6204,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104382q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6205,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043833',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6206,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104517t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6207,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037654',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6208,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39817p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6209,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398139',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6210,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056763',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6211,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056797',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6212,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105693n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6213,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105682x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6214,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105695d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6215,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105681j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6216,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105684p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6217,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105687t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6218,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056805',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6219,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056941',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6220,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105673z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6221,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105686f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6222,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056839',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6223,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105675q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6224,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb327720552/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6225,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105674b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6226,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105678v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6227,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105677g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6228,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056852',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6229,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106283b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6230,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037476',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6231,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056203',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6232,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105660g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6233,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056237',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6234,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105663m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6235,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105647f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6236,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105666r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6237,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105612h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6238,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105669w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6239,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105631t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6240,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105615n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6241,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056627',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6242,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105618s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6243,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105634z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6244,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056462',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6245,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056496',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6246,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056114',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6247,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105651h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6248,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056148',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6249,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105635b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6250,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105670t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6251,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105654n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6252,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105638g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6253,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105657s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6254,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056504',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6255,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105622v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6256,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb328169156/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6257,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056538',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6258,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056373',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6259,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105626c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6260,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105642j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6261,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105629h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6262,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105661v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6263,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105645p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6264,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105648t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6265,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105613w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6266,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056415',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6267,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105665c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6268,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056449',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6269,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056250',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6270,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056284',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6271,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105668h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6272,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105630f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6273,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105633k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6274,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105617d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6275,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105652w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6276,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105636q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6277,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056640',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6278,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105639v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6279,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056674',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6280,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056326',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6281,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105672k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6282,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056161',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6283,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105656d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6284,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056195',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6285,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105691w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6286,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105659j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6287,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105621g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6288,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105640s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6289,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056716',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6290,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105643x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6291,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105627r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6292,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056551',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6293,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1056585',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6294,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036030',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6295,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1062798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6296,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k66361p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6297,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106158w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6298,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1061530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6299,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042489',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6300,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045105',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6301,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104969j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6302,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049685',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6303,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104970g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6304,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030937',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6305,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103780x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6306,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104994p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6307,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049952',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6308,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398181',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6309,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105866c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6310,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105870f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6311,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103551n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6312,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1033681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6313,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103549b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6314,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103572q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6315,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k3700445',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6316,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037387',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6317,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k56886948',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6318,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104777h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6319,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34425274b/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6320,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047806',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6321,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104778w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6322,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047798',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6323,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047764',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6324,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63971x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6325,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63970k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6326,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639410',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6327,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639441',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6328,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639472',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6329,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63962z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6330,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639728',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6331,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63964n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6332,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63961m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6333,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63969c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6334,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63950z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6335,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639639',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6336,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639608',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6337,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63952n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6338,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63958q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6339,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63955p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6340,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63957c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6341,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63954b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6342,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6343,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639650',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6344,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639519',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6345,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63940n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6346,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63949r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6347,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63946q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6348,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63943p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6349,'oai 7 oai:bnf.fr:gallica/ark:/12148/cb34349269z/date',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6350,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63948d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6351,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63945c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6352,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k63942b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6353,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639592',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6354,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639561',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6355,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k639530',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6356,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103634d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6357,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k5608582h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6358,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036331',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6359,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104372c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6360,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104370m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6361,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k744087',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6362,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037217',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6363,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82789m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6364,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82792h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6365,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82793v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6366,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82790t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6367,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k827915',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6368,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104408j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6369,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k62076x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6370,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104264g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6371,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104529x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6372,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103575v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6373,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103574g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6374,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103718j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6375,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037531',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6376,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104098d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6377,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104110x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6378,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041119',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6379,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104847s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6380,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1042455',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6381,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104246j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6382,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103720v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6383,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103719x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6384,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104412m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6385,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044117',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6386,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048137',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6387,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1063438',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6388,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k396681',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6389,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105867r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6390,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1058684',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6391,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k823180',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6392,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82317n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6393,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104451m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6394,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044507',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6395,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053341',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6396,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103593s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6397,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104729j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6398,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048527',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6399,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103722m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6400,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39669c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6401,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035733',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6402,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037688',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6403,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104799z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6404,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39674z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6405,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103766h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6406,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104475t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6407,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39673m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6408,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k392051',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6409,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035911',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6410,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105753k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6411,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106157h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6412,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k398061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6413,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k289312',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6414,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104550j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6415,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k82678p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6416,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84614x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6417,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104727s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6418,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104535r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6419,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103623p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6420,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104936c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6421,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1038807',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6422,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496776',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6423,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104261b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6424,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049816',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6425,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105754z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6426,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k30797q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6427,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104117k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6428,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104816c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6429,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053430',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6430,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104118z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6431,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048930',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6432,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104894c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6433,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104119b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6434,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k841136',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6435,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k84112v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6436,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104526s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6437,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105348w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6438,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049562',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6439,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104745q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6440,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104943k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6441,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104738h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6442,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045186',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6443,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104249p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6444,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104849j',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6445,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1047539',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6446,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104923w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6447,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104920r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6448,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1049214',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6449,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104922h',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6450,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106162z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6451,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k293638',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6452,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104850g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6453,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104800r',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6454,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1053375',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6455,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104115t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6456,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k496803',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6457,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104498n',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6458,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048061',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6459,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104507g',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6460,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1045063',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6461,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105885p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6462,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105844x',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6463,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104853m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6464,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104472p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6465,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104478z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6466,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1036017',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6467,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103602m',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6468,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043880',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6469,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104422z',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6470,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1044206',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6471,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104423b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6472,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104421k',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6473,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103369d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6474,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104985q',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6475,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103754d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6476,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103755s',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6477,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1037565',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6478,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104521w',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6479,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k105750f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6480,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041208',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6481,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104996f',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6482,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104997t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6483,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104731v',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6484,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k103883c',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6485,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104525d',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6486,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1048574',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6487,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030513',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6488,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1035555',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6489,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k106441t',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6490,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1041043',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6491,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1064426',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6492,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1030895',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6493,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k39678b',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6494,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043710',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6495,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k104369p',7);
INSERT INTO external_count (rid, recid, source_id) VALUES (6496,'oai 7 oai:bnf.fr:gallica/ark:/12148/bpt6k1043689',7);
/*!40000 ALTER TABLE external_count ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `facettes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE facettes (
  id_facette int(10) unsigned NOT NULL AUTO_INCREMENT,
  facette_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  facette_critere int(5) NOT NULL DEFAULT '0',
  facette_ss_critere int(5) NOT NULL DEFAULT '0',
  facette_nb_result int(2) NOT NULL DEFAULT '0',
  facette_visible tinyint(1) NOT NULL DEFAULT '0',
  facette_type_sort int(1) NOT NULL DEFAULT '0',
  facette_order_sort int(1) NOT NULL DEFAULT '0',
  facette_order int(11) NOT NULL DEFAULT '1',
  facette_limit_plus int(11) NOT NULL DEFAULT '0',
  facette_opac_views_num text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_facette)
) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `facettes`
--

LOCK TABLES facettes WRITE;
/*!40000 ALTER TABLE facettes DISABLE KEYS */;
INSERT INTO facettes (id_facette, facette_name, facette_critere, facette_ss_critere, facette_nb_result, facette_visible, facette_type_sort, facette_order_sort, facette_order, facette_limit_plus, facette_opac_views_num) VALUES (1,'Sujets',25,1,5,1,0,1,1,0,'');
INSERT INTO facettes (id_facette, facette_name, facette_critere, facette_ss_critere, facette_nb_result, facette_visible, facette_type_sort, facette_order_sort, facette_order, facette_limit_plus, facette_opac_views_num) VALUES (2,'Section',90,3,0,1,1,0,1,0,'');
INSERT INTO facettes (id_facette, facette_name, facette_critere, facette_ss_critere, facette_nb_result, facette_visible, facette_type_sort, facette_order_sort, facette_order, facette_limit_plus, facette_opac_views_num) VALUES (3,'Type de document',31,0,0,1,1,0,1,0,'');
INSERT INTO facettes (id_facette, facette_name, facette_critere, facette_ss_critere, facette_nb_result, facette_visible, facette_type_sort, facette_order_sort, facette_order, facette_limit_plus, facette_opac_views_num) VALUES (4,'Auteur',27,1,5,1,0,1,1,0,'');
/*!40000 ALTER TABLE facettes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_questions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_questions (
  id_faq_question int(10) unsigned NOT NULL AUTO_INCREMENT,
  faq_question_num_type int(10) unsigned NOT NULL DEFAULT '0',
  faq_question_num_theme int(10) unsigned NOT NULL DEFAULT '0',
  faq_question_num_demande int(10) unsigned NOT NULL DEFAULT '0',
  faq_question_question text COLLATE utf8_unicode_ci NOT NULL,
  faq_question_question_userdate varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  faq_question_question_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  faq_question_answer text COLLATE utf8_unicode_ci NOT NULL,
  faq_question_answer_userdate varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  faq_question_answer_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  faq_question_statut int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_faq_question)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_questions`
--

LOCK TABLES faq_questions WRITE;
/*!40000 ALTER TABLE faq_questions DISABLE KEYS */;
/*!40000 ALTER TABLE faq_questions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_questions_categories`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_questions_categories (
  num_faq_question int(10) unsigned NOT NULL DEFAULT '0',
  num_categ int(10) unsigned NOT NULL DEFAULT '0',
  categ_order int(10) unsigned NOT NULL DEFAULT '0',
  KEY i_faq_categ (num_faq_question,num_categ)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_questions_categories`
--

LOCK TABLES faq_questions_categories WRITE;
/*!40000 ALTER TABLE faq_questions_categories DISABLE KEYS */;
/*!40000 ALTER TABLE faq_questions_categories ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_questions_fields_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_questions_fields_global_index (
  id_faq_question int(10) unsigned NOT NULL DEFAULT '0',
  code_champ int(3) unsigned NOT NULL DEFAULT '0',
  code_ss_champ int(3) unsigned NOT NULL DEFAULT '0',
  ordre int(4) unsigned NOT NULL DEFAULT '0',
  `value` text COLLATE utf8_unicode_ci NOT NULL,
  pond int(4) unsigned NOT NULL DEFAULT '100',
  lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  authority_num varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  PRIMARY KEY (id_faq_question,code_champ,code_ss_champ,lang,ordre),
  KEY i_value (`value`(300)),
  KEY i_code_champ_code_ss_champ (code_champ,code_ss_champ)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_questions_fields_global_index`
--

LOCK TABLES faq_questions_fields_global_index WRITE;
/*!40000 ALTER TABLE faq_questions_fields_global_index DISABLE KEYS */;
/*!40000 ALTER TABLE faq_questions_fields_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_questions_words_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_questions_words_global_index (
  id_faq_question int(10) unsigned NOT NULL DEFAULT '0',
  code_champ int(10) unsigned NOT NULL DEFAULT '0',
  code_ss_champ int(10) unsigned NOT NULL DEFAULT '0',
  num_word int(10) unsigned NOT NULL DEFAULT '0',
  pond int(10) unsigned NOT NULL DEFAULT '100',
  position int(10) unsigned NOT NULL DEFAULT '1',
  field_position int(10) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_faq_question,code_champ,num_word,position,code_ss_champ),
  KEY code_champ (code_champ),
  KEY i_id_mot (num_word,id_faq_question),
  KEY i_code_champ_code_ss_champ_num_word (code_champ,code_ss_champ,num_word)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_questions_words_global_index`
--

LOCK TABLES faq_questions_words_global_index WRITE;
/*!40000 ALTER TABLE faq_questions_words_global_index DISABLE KEYS */;
/*!40000 ALTER TABLE faq_questions_words_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_themes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_themes (
  id_theme int(10) unsigned NOT NULL AUTO_INCREMENT,
  libelle_theme varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_theme)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_themes`
--

LOCK TABLES faq_themes WRITE;
/*!40000 ALTER TABLE faq_themes DISABLE KEYS */;
/*!40000 ALTER TABLE faq_themes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faq_types`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE faq_types (
  id_type int(10) unsigned NOT NULL AUTO_INCREMENT,
  libelle_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_type)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faq_types`
--

LOCK TABLES faq_types WRITE;
/*!40000 ALTER TABLE faq_types DISABLE KEYS */;
/*!40000 ALTER TABLE faq_types ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `fiche`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE fiche (
  id_fiche int(10) unsigned NOT NULL AUTO_INCREMENT,
  infos_global mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_infos_global mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_fiche)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `fiche`
--

LOCK TABLES fiche WRITE;
/*!40000 ALTER TABLE fiche DISABLE KEYS */;
/*!40000 ALTER TABLE fiche ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `frais`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE frais (
  id_frais int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  condition_frais mediumtext COLLATE utf8_unicode_ci NOT NULL,
  montant double(12,2) unsigned NOT NULL DEFAULT '0.00',
  num_cp_compta varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_tva_achat varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  index_libelle text COLLATE utf8_unicode_ci,
  PRIMARY KEY (id_frais)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `frais`
--

LOCK TABLES frais WRITE;
/*!40000 ALTER TABLE frais DISABLE KEYS */;
/*!40000 ALTER TABLE frais ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `gestfic0_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE gestfic0_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `gestfic0_custom`
--

LOCK TABLES gestfic0_custom WRITE;
/*!40000 ALTER TABLE gestfic0_custom DISABLE KEYS */;
/*!40000 ALTER TABLE gestfic0_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `gestfic0_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE gestfic0_custom_lists (
  gestfic0_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  gestfic0_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  gestfic0_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY gestfic0_custom_champ (gestfic0_custom_champ),
  KEY gestfic0_champ_list_value (gestfic0_custom_champ,gestfic0_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `gestfic0_custom_lists`
--

LOCK TABLES gestfic0_custom_lists WRITE;
/*!40000 ALTER TABLE gestfic0_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE gestfic0_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `gestfic0_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE gestfic0_custom_values (
  gestfic0_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  gestfic0_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  gestfic0_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  gestfic0_custom_text mediumtext COLLATE utf8_unicode_ci,
  gestfic0_custom_integer int(11) DEFAULT NULL,
  gestfic0_custom_date date DEFAULT NULL,
  gestfic0_custom_float float DEFAULT NULL,
  KEY gestfic0_custom_champ (gestfic0_custom_champ),
  KEY gestfic0_custom_origine (gestfic0_custom_origine),
  KEY i_gcv_st (gestfic0_custom_small_text),
  KEY i_gcv_t (gestfic0_custom_text(255)),
  KEY i_gcv_i (gestfic0_custom_integer),
  KEY i_gcv_d (gestfic0_custom_date),
  KEY i_gcv_f (gestfic0_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `gestfic0_custom_values`
--

LOCK TABLES gestfic0_custom_values WRITE;
/*!40000 ALTER TABLE gestfic0_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE gestfic0_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `grilles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE grilles (
  grille_typdoc char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  grille_niveau_biblio char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'm',
  grille_localisation mediumint(8) NOT NULL DEFAULT '0',
  descr_format longtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (grille_typdoc,grille_niveau_biblio,grille_localisation)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `grilles`
--

LOCK TABLES grilles WRITE;
/*!40000 ALTER TABLE grilles DISABLE KEYS */;
/*!40000 ALTER TABLE grilles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groupe`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE groupe (
  id_groupe int(6) unsigned NOT NULL AUTO_INCREMENT,
  libelle_groupe varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  resp_groupe int(6) unsigned DEFAULT '0',
  lettre_rappel int(1) unsigned NOT NULL DEFAULT '0',
  mail_rappel int(1) unsigned NOT NULL DEFAULT '0',
  lettre_rappel_show_nomgroup int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_groupe),
  UNIQUE KEY libelle_groupe (libelle_groupe)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groupe`
--

LOCK TABLES groupe WRITE;
/*!40000 ALTER TABLE groupe DISABLE KEYS */;
/*!40000 ALTER TABLE groupe ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groupexpl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE groupexpl (
  id_groupexpl int(10) unsigned NOT NULL AUTO_INCREMENT,
  groupexpl_resp_expl_num int(10) unsigned NOT NULL DEFAULT '0',
  groupexpl_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  groupexpl_comment varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  groupexpl_location int(10) unsigned NOT NULL DEFAULT '0',
  groupexpl_statut_resp int(10) unsigned NOT NULL DEFAULT '0',
  groupexpl_statut_others int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_groupexpl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groupexpl`
--

LOCK TABLES groupexpl WRITE;
/*!40000 ALTER TABLE groupexpl DISABLE KEYS */;
/*!40000 ALTER TABLE groupexpl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groupexpl_expl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE groupexpl_expl (
  groupexpl_num int(10) unsigned NOT NULL DEFAULT '0',
  groupexpl_expl_num int(10) unsigned NOT NULL DEFAULT '0',
  groupexpl_checked int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (groupexpl_num,groupexpl_expl_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groupexpl_expl`
--

LOCK TABLES groupexpl_expl WRITE;
/*!40000 ALTER TABLE groupexpl_expl DISABLE KEYS */;
/*!40000 ALTER TABLE groupexpl_expl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_field`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_field (
  id_harvest_field int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_harvest_profil int(10) unsigned NOT NULL DEFAULT '0',
  harvest_field_xml_id int(10) unsigned NOT NULL DEFAULT '0',
  harvest_field_first_flag int(10) unsigned NOT NULL DEFAULT '0',
  harvest_field_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_harvest_field)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_field`
--

LOCK TABLES harvest_field WRITE;
/*!40000 ALTER TABLE harvest_field DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_field ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_profil`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_profil (
  id_harvest_profil int(10) unsigned NOT NULL AUTO_INCREMENT,
  harvest_profil_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_harvest_profil)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_profil`
--

LOCK TABLES harvest_profil WRITE;
/*!40000 ALTER TABLE harvest_profil DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_profil ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_profil_import`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_profil_import (
  id_harvest_profil_import int(10) unsigned NOT NULL AUTO_INCREMENT,
  harvest_profil_import_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_harvest_profil_import)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_profil_import`
--

LOCK TABLES harvest_profil_import WRITE;
/*!40000 ALTER TABLE harvest_profil_import DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_profil_import ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_profil_import_field`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_profil_import_field (
  num_harvest_profil_import int(10) unsigned NOT NULL DEFAULT '0',
  harvest_profil_import_field_xml_id int(10) unsigned NOT NULL DEFAULT '0',
  harvest_profil_import_field_flag int(10) unsigned NOT NULL DEFAULT '0',
  harvest_profil_import_field_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_harvest_profil_import,harvest_profil_import_field_xml_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_profil_import_field`
--

LOCK TABLES harvest_profil_import_field WRITE;
/*!40000 ALTER TABLE harvest_profil_import_field DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_profil_import_field ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_search_field`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_search_field (
  num_harvest_profil int(10) unsigned NOT NULL DEFAULT '0',
  num_source int(10) unsigned NOT NULL DEFAULT '0',
  num_field int(10) unsigned NOT NULL DEFAULT '0',
  num_ss_field int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_harvest_profil,num_source)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_search_field`
--

LOCK TABLES harvest_search_field WRITE;
/*!40000 ALTER TABLE harvest_search_field DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_search_field ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `harvest_src`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE harvest_src (
  id_harvest_src int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_harvest_field int(10) unsigned NOT NULL DEFAULT '0',
  num_source int(10) unsigned NOT NULL DEFAULT '0',
  harvest_src_unimacfield varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  harvest_src_unimacsubfield varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  harvest_src_pmb_unimacfield varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  harvest_src_pmb_unimacsubfield varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  harvest_src_prec_flag int(10) unsigned NOT NULL DEFAULT '0',
  harvest_src_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_harvest_src)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `harvest_src`
--

LOCK TABLES harvest_src WRITE;
/*!40000 ALTER TABLE harvest_src DISABLE KEYS */;
/*!40000 ALTER TABLE harvest_src ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `import_marc`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE import_marc (
  id_import bigint(5) unsigned NOT NULL AUTO_INCREMENT,
  notice longblob NOT NULL,
  origine varchar(50) COLLATE utf8_unicode_ci DEFAULT '',
  no_notice int(10) unsigned DEFAULT '0',
  encoding varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_import),
  KEY i_nonot_orig (no_notice,origine)
) ENGINE=MyISAM AUTO_INCREMENT=50 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `import_marc`
--

LOCK TABLES import_marc WRITE;
/*!40000 ALTER TABLE import_marc DISABLE KEYS */;
/*!40000 ALTER TABLE import_marc ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `index_concept`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE index_concept (
  num_object int(10) unsigned NOT NULL,
  type_object int(10) unsigned NOT NULL,
  num_concept int(10) unsigned NOT NULL,
  order_concept int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_object,type_object,num_concept)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `index_concept`
--

LOCK TABLES index_concept WRITE;
/*!40000 ALTER TABLE index_concept DISABLE KEYS */;
/*!40000 ALTER TABLE index_concept ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `indexint`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE indexint (
  indexint_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  indexint_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  indexint_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_indexint mediumtext COLLATE utf8_unicode_ci,
  num_pclass int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (indexint_id),
  UNIQUE KEY indexint_name (indexint_name,num_pclass)
) ENGINE=MyISAM AUTO_INCREMENT=119 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `indexint`
--

LOCK TABLES indexint WRITE;
/*!40000 ALTER TABLE indexint DISABLE KEYS */;
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (1,'000','Information Communication',' 000 information communication ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (2,'010','Bibliographies Catalogues',' 010 bibliographies catalogues ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (3,'020','Bibliothèques - et lecture, documentation',' 020 bibliotheques lecture documentation ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (4,'030','Encyclopédies générales',' 030 encyclopedies generales ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (6,'050','Périodiques généraux - annuaires',' 050 periodiques generaux annuaires ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (7,'060','Organisations générales - congrès',' 060 organisations generales congres ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (8,'070','Presse Edition',' 070 presse edition ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (9,'080','Recueils - mélanges, discours',' 080 recueils melanges discours ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (10,'090','Manuscrits Livres rares',' 090 manuscrits livres rares ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (11,'100','Philosophie',' 100 philosophie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (12,'110','Métaphysique',' 110 metaphysique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (13,'120','Connaissance',' 120 connaissance ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (14,'130','Parapsychologie - astrologie, graphologie',' 130 parapsychologie astrologie graphologie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (15,'140','Systèmes philosophiques',' 140 systemes philosophiques ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (16,'150','Psychologie',' 150 psychologie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (17,'160','Logique',' 160 logique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (18,'170','Morale - éthique',' 170 morale ethique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (19,'180','Philosophes anciens - et orientaux',' 180 philosophes anciens orientaux ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (20,'190','Philosophes modernes - (XVIe S. à nos jours)',' 190 philosophes modernes xvie s nos jours ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (21,'200','Religion',' 200 religion ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (22,'210','Religion naturelle',' 210 religion naturelle ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (23,'220','Bible Evangiles',' 220 bible evangiles ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (24,'230','Théologie doctrinale chrétienne - (dogme)',' 230 theologie doctrinale chretienne dogme ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (25,'240','Théologie spirituelle - vie religieuse',' 240 theologie spirituelle vie religieuse ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (26,'250','Théologie pastorale',' 250 theologie pastorale ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (27,'260','L\'Eglise chrétienne et la société',' 260 eglise chretienne societe ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (28,'270','Histoire de l\'Eglise chrétienne',' 270 histoire eglise chretienne ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (29,'280','Autres confessions chrétiennes',' 280 autres confessions chretiennes ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (30,'290','Autres religions et mythologies',' 290 autres religions mythologies ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (31,'300','Sciences sociales',' 300 sciences sociales ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (32,'310','Statistiques',' 310 statistiques ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (33,'320','Politique - l\'Etat',' 320 politique etat ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (34,'330','Economie - finances, production, consommation',' 330 economie finances production consommation ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (35,'340','Droit - justice',' 340 droit justice ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (36,'350','Administration de l\'Etat',' 350 administration etat ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (37,'360','Aide Assistance Secours',' 360 aide assistance secours ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (38,'370','Education - enseignement',' 370 education enseignement ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (39,'380','Commerce Transports Communication',' 380 commerce transports communication ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (40,'390','Costumes et folklore',' 390 costumes folklore ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (41,'400','Langage',' 400 langage ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (42,'410','Linguistique',' 410 linguistique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (43,'420','Langue anglaise',' 420 langue anglaise ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (44,'430','Langue allemande',' 430 langue allemande ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (45,'440','Langue française - (dictionnaires, grammaire)',' 440 langue francaise dictionnaires grammaire ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (46,'450','Langue italienne',' 450 langue italienne ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (47,'460','Langue espagnole et portugaise',' 460 langue espagnole portugaise ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (48,'470','Langue latine',' 470 langue latine ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (49,'480','Langue grecque',' 480 langue grecque ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (50,'490','Autres langues - russe, arabe',' 490 autres langues russe arabe ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (51,'500','Sciences',' 500 sciences ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (52,'510','Mathématiques',' 510 mathematiques ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (53,'520','Astronomie',' 520 astronomie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (54,'530','Physique',' 530 physique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (55,'540','Chimie - minéralogie',' 540 chimie mineralogie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (56,'550','Sciences de la Terre - géologie, météorologie',' 550 sciences terre geologie meteorologie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (57,'560','Paléontologie - (les fossiles)',' 560 paleontologie fossiles ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (58,'570','Sciences de la vie - biologie, génétique',' 570 sciences vie biologie genetique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (59,'580','Botanique - (les plantes)',' 580 botanique plantes ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (60,'590','Zoologie - (les animaux)',' 590 zoologie animaux ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (61,'600','Techniques',' 600 techniques ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (62,'610','Médecine - hygiène, santé',' 610 medecine hygiene sante ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (63,'620','Techniques industrielles - mécanique, électricité, radio, énergie',' 620 techniques industrielles mecanique electricite radio energie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (64,'630','Agriculture - forêt, élevage, pêche',' 630 agriculture foret elevage peche ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (65,'640','Arts ménagers - cuisine, couture, soins de beauté',' 640 arts menagers cuisine couture soins beaute ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (66,'650','Entreprise - travail de bureaux, vente, publicité',' 650 entreprise travail bureaux vente publicite ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (67,'660','Industries chimiques et alimentaires',' 660 industries chimiques alimentaires ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (68,'670','Fabrications industrielles - métallurgie, bois, textile',' 670 fabrications industrielles metallurgie bois textile ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (69,'680','Articles manufacturés',' 680 articles manufactures ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (70,'690','Bâtiment - construction',' 690 batiment construction ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (71,'700','Arts et loisirs',' 700 arts loisirs ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (72,'710','Urbanisme - art du paysage',' 710 urbanisme art paysage ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (73,'720','Architecture',' 720 architecture ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (74,'730','Sculpture',' 730 sculpture ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (75,'740','Dessin - arts décoratifs',' 740 dessin arts decoratifs ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (76,'750','Peinture',' 750 peinture ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (77,'760','Arts graphiques - graphisme',' 760 arts graphiques graphisme ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (78,'770','Photographie',' 770 photographie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (79,'780','Musique',' 780 musique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (80,'790','Loisirs - spectacles, jeux, sports',' 790 loisirs spectacles jeux sports ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (81,'800','Littérature',' 800 litterature ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (82,'810','Littérature américaine',' 810 litterature americaine ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (83,'820','Littérature anglaise',' 820 litterature anglaise ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (84,'830','Littérature allemande',' 830 litterature allemande ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (85,'840','Littérature française',' 840 litterature francaise ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (86,'850','Littérature italienne',' 850 litterature italienne ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (87,'860','Littérature espagnole et portugaise',' 860 litterature espagnole portugaise ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (88,'870','Littérature latine',' 870 litterature latine ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (89,'880','Littérature grecque',' 880 litterature grecque ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (90,'890','Autres littératures',' 890 autres litteratures ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (91,'900','Histoire géographie',' 900 histoire geographie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (92,'910','Géographie - voyages',' 910 geographie voyages ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (93,'920','Biographies - vie d\'un personnage, généalogie',' 920 biographies vie personnage genealogie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (94,'930','Histoire ancienne',' 930 histoire ancienne ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (95,'940','Histoire de l\'Europe',' 940 histoire europe ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (96,'950','Histoire de l\'Asie',' 950 histoire asie ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (97,'960','Histoire de l\'Afrique',' 960 histoire afrique ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (98,'970','Histoire de l\'Amérique du Nord',' 970 histoire amerique nord ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (99,'980','Histoire de l\'Amérique du Sud',' 980 histoire amerique sud ',1);
INSERT INTO indexint (indexint_id, indexint_name, indexint_comment, index_indexint, num_pclass) VALUES (100,'990','Histoire de l\'Océanie',' 990 histoire oceanie ',1);
/*!40000 ALTER TABLE indexint ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `indexint_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE indexint_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `indexint_custom`
--

LOCK TABLES indexint_custom WRITE;
/*!40000 ALTER TABLE indexint_custom DISABLE KEYS */;
/*!40000 ALTER TABLE indexint_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `indexint_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE indexint_custom_lists (
  indexint_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  indexint_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  indexint_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (indexint_custom_champ),
  KEY editorial_champ_list_value (indexint_custom_champ,indexint_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `indexint_custom_lists`
--

LOCK TABLES indexint_custom_lists WRITE;
/*!40000 ALTER TABLE indexint_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE indexint_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `indexint_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE indexint_custom_values (
  indexint_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  indexint_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  indexint_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  indexint_custom_text text COLLATE utf8_unicode_ci,
  indexint_custom_integer int(11) DEFAULT NULL,
  indexint_custom_date date DEFAULT NULL,
  indexint_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (indexint_custom_champ),
  KEY editorial_custom_origine (indexint_custom_origine),
  KEY i_icv_st (indexint_custom_small_text),
  KEY i_icv_t (indexint_custom_text(255)),
  KEY i_icv_i (indexint_custom_integer),
  KEY i_icv_d (indexint_custom_date),
  KEY i_icv_f (indexint_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `indexint_custom_values`
--

LOCK TABLES indexint_custom_values WRITE;
/*!40000 ALTER TABLE indexint_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE indexint_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `infopages`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE infopages (
  id_infopage int(10) unsigned NOT NULL AUTO_INCREMENT,
  content_infopage longblob NOT NULL,
  title_infopage varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  valid_infopage tinyint(1) NOT NULL DEFAULT '1',
  restrict_infopage int(11) NOT NULL DEFAULT '0',
  infopage_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_infopage)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `infopages`
--

LOCK TABLES infopages WRITE;
/*!40000 ALTER TABLE infopages DISABLE KEYS */;
/*!40000 ALTER TABLE infopages ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `lenders`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE lenders (
  idlender smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  lender_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (idlender)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `lenders`
--

LOCK TABLES lenders WRITE;
/*!40000 ALTER TABLE lenders DISABLE KEYS */;
INSERT INTO lenders (idlender, lender_libelle) VALUES (1,'BDP');
INSERT INTO lenders (idlender, lender_libelle) VALUES (2,'Fonds propre');
/*!40000 ALTER TABLE lenders ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `liens_actes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE liens_actes (
  num_acte int(8) unsigned NOT NULL DEFAULT '0',
  num_acte_lie int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_acte,num_acte_lie),
  KEY i_num_acte (num_acte),
  KEY i_num_acte_lie (num_acte_lie)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `liens_actes`
--

LOCK TABLES liens_actes WRITE;
/*!40000 ALTER TABLE liens_actes DISABLE KEYS */;
/*!40000 ALTER TABLE liens_actes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `lignes_actes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE lignes_actes (
  id_ligne int(15) unsigned NOT NULL AUTO_INCREMENT,
  type_ligne int(3) unsigned NOT NULL DEFAULT '0',
  num_acte int(8) unsigned NOT NULL DEFAULT '0',
  lig_ref int(15) unsigned NOT NULL DEFAULT '0',
  num_acquisition int(12) unsigned NOT NULL DEFAULT '0',
  num_rubrique int(8) unsigned NOT NULL DEFAULT '0',
  num_produit int(8) unsigned NOT NULL DEFAULT '0',
  num_type int(8) unsigned NOT NULL DEFAULT '0',
  libelle mediumtext COLLATE utf8_unicode_ci NOT NULL,
  `code` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  prix double(12,2) unsigned NOT NULL DEFAULT '0.00',
  tva float(8,2) unsigned NOT NULL DEFAULT '0.00',
  nb int(5) unsigned NOT NULL DEFAULT '1',
  date_ech date NOT NULL DEFAULT '0000-00-00',
  date_cre date NOT NULL DEFAULT '0000-00-00',
  statut int(3) unsigned NOT NULL DEFAULT '0',
  remise float(8,2) NOT NULL DEFAULT '0.00',
  index_ligne mediumtext COLLATE utf8_unicode_ci NOT NULL,
  ligne_ordre smallint(2) unsigned NOT NULL DEFAULT '0',
  debit_tva smallint(2) unsigned NOT NULL DEFAULT '0',
  commentaires_gestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  commentaires_opac mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_ligne),
  KEY num_acte (num_acte)
) ENGINE=MyISAM AUTO_INCREMENT=37 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `lignes_actes`
--

LOCK TABLES lignes_actes WRITE;
/*!40000 ALTER TABLE lignes_actes DISABLE KEYS */;
/*!40000 ALTER TABLE lignes_actes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `lignes_actes_relances`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE lignes_actes_relances (
  num_ligne int(10) unsigned NOT NULL,
  date_relance date NOT NULL DEFAULT '0000-00-00',
  type_ligne int(3) unsigned NOT NULL DEFAULT '0',
  num_acte int(8) unsigned NOT NULL DEFAULT '0',
  lig_ref int(15) unsigned NOT NULL DEFAULT '0',
  num_acquisition int(12) unsigned NOT NULL DEFAULT '0',
  num_rubrique int(8) unsigned NOT NULL DEFAULT '0',
  num_produit int(8) unsigned NOT NULL DEFAULT '0',
  num_type int(8) unsigned NOT NULL DEFAULT '0',
  libelle mediumtext COLLATE utf8_unicode_ci NOT NULL,
  `code` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  prix float(8,2) NOT NULL DEFAULT '0.00',
  tva float(8,2) unsigned NOT NULL DEFAULT '0.00',
  nb int(5) unsigned NOT NULL DEFAULT '1',
  date_ech date NOT NULL DEFAULT '0000-00-00',
  date_cre date NOT NULL DEFAULT '0000-00-00',
  statut int(3) unsigned NOT NULL DEFAULT '1',
  remise float(8,2) NOT NULL DEFAULT '0.00',
  index_ligne mediumtext COLLATE utf8_unicode_ci NOT NULL,
  ligne_ordre smallint(2) unsigned NOT NULL DEFAULT '0',
  debit_tva smallint(2) unsigned NOT NULL DEFAULT '0',
  commentaires_gestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  commentaires_opac mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_ligne,date_relance)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `lignes_actes_relances`
--

LOCK TABLES lignes_actes_relances WRITE;
/*!40000 ALTER TABLE lignes_actes_relances DISABLE KEYS */;
/*!40000 ALTER TABLE lignes_actes_relances ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `lignes_actes_statuts`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE lignes_actes_statuts (
  id_statut int(3) NOT NULL AUTO_INCREMENT,
  libelle mediumtext COLLATE utf8_unicode_ci NOT NULL,
  relance int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_statut)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `lignes_actes_statuts`
--

LOCK TABLES lignes_actes_statuts WRITE;
/*!40000 ALTER TABLE lignes_actes_statuts DISABLE KEYS */;
INSERT INTO lignes_actes_statuts (id_statut, libelle, relance) VALUES (1,'Traitement normal',1);
/*!40000 ALTER TABLE lignes_actes_statuts ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `linked_mots`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE linked_mots (
  num_mot mediumint(8) unsigned NOT NULL DEFAULT '0',
  num_linked_mot mediumint(8) unsigned NOT NULL DEFAULT '0',
  type_lien tinyint(1) NOT NULL DEFAULT '1',
  ponderation float NOT NULL DEFAULT '1',
  PRIMARY KEY (num_mot,num_linked_mot,type_lien)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `linked_mots`
--

LOCK TABLES linked_mots WRITE;
/*!40000 ALTER TABLE linked_mots DISABLE KEYS */;
/*!40000 ALTER TABLE linked_mots ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `log_expl_retard`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE log_expl_retard (
  id_log int(11) unsigned NOT NULL AUTO_INCREMENT,
  date_log timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  titre varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  expl_id int(11) NOT NULL DEFAULT '0',
  expl_cb varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_pret date NOT NULL DEFAULT '0000-00-00',
  date_retour date NOT NULL DEFAULT '0000-00-00',
  amende decimal(16,2) NOT NULL DEFAULT '0.00',
  num_log_retard int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_log)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `log_expl_retard`
--

LOCK TABLES log_expl_retard WRITE;
/*!40000 ALTER TABLE log_expl_retard DISABLE KEYS */;
/*!40000 ALTER TABLE log_expl_retard ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `log_retard`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE log_retard (
  id_log int(11) unsigned NOT NULL AUTO_INCREMENT,
  date_log timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  niveau_reel int(1) NOT NULL DEFAULT '0',
  niveau_suppose int(1) NOT NULL DEFAULT '0',
  amende_totale decimal(16,2) NOT NULL DEFAULT '0.00',
  frais decimal(16,2) NOT NULL DEFAULT '0.00',
  idempr int(11) NOT NULL DEFAULT '0',
  log_printed int(1) unsigned NOT NULL DEFAULT '0',
  log_mail int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_log)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `log_retard`
--

LOCK TABLES log_retard WRITE;
/*!40000 ALTER TABLE log_retard DISABLE KEYS */;
/*!40000 ALTER TABLE log_retard ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `logopac`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE logopac (
  id_log int(8) unsigned NOT NULL AUTO_INCREMENT,
  date_log timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  url_demandee varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  url_referente varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  get_log blob NOT NULL,
  post_log blob NOT NULL,
  num_session varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  server_log blob NOT NULL,
  empr_carac blob NOT NULL,
  empr_doc blob NOT NULL,
  empr_expl blob NOT NULL,
  nb_result blob NOT NULL,
  gen_stat blob NOT NULL,
  PRIMARY KEY (id_log),
  KEY lopac_date_log (date_log)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `logopac`
--

LOCK TABLES logopac WRITE;
/*!40000 ALTER TABLE logopac DISABLE KEYS */;
/*!40000 ALTER TABLE logopac ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `mailtpl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE mailtpl (
  id_mailtpl int(10) unsigned NOT NULL AUTO_INCREMENT,
  mailtpl_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  mailtpl_objet varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  mailtpl_tpl mediumtext COLLATE utf8_unicode_ci NOT NULL,
  mailtpl_users varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_mailtpl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `mailtpl`
--

LOCK TABLES mailtpl WRITE;
/*!40000 ALTER TABLE mailtpl DISABLE KEYS */;
/*!40000 ALTER TABLE mailtpl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `map_echelles`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE map_echelles (
  map_echelle_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  map_echelle_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (map_echelle_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `map_echelles`
--

LOCK TABLES map_echelles WRITE;
/*!40000 ALTER TABLE map_echelles DISABLE KEYS */;
/*!40000 ALTER TABLE map_echelles ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `map_emprises`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE map_emprises (
  map_emprise_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  map_emprise_type int(10) unsigned NOT NULL DEFAULT '0',
  map_emprise_obj_num int(10) unsigned NOT NULL DEFAULT '0',
  map_emprise_data geometry NOT NULL,
  map_emprise_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (map_emprise_id),
  KEY i_map_emprise_obj_num (map_emprise_obj_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `map_emprises`
--

LOCK TABLES map_emprises WRITE;
/*!40000 ALTER TABLE map_emprises DISABLE KEYS */;
/*!40000 ALTER TABLE map_emprises ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `map_hold_areas`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE map_hold_areas (
  id_obj int(10) unsigned NOT NULL DEFAULT '0',
  type_obj int(10) unsigned NOT NULL DEFAULT '0',
  area double DEFAULT NULL,
  bbox_area double DEFAULT NULL,
  center longtext CHARACTER SET latin1,
  PRIMARY KEY (id_obj)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `map_hold_areas`
--

LOCK TABLES map_hold_areas WRITE;
/*!40000 ALTER TABLE map_hold_areas DISABLE KEYS */;
/*!40000 ALTER TABLE map_hold_areas ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `map_projections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE map_projections (
  map_projection_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  map_projection_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (map_projection_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `map_projections`
--

LOCK TABLES map_projections WRITE;
/*!40000 ALTER TABLE map_projections DISABLE KEYS */;
/*!40000 ALTER TABLE map_projections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `map_refs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE map_refs (
  map_ref_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  map_ref_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (map_ref_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `map_refs`
--

LOCK TABLES map_refs WRITE;
/*!40000 ALTER TABLE map_refs DISABLE KEYS */;
/*!40000 ALTER TABLE map_refs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `mots`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE mots (
  id_mot mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  mot varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_mot),
  UNIQUE KEY mot (mot)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `mots`
--

LOCK TABLES mots WRITE;
/*!40000 ALTER TABLE mots DISABLE KEYS */;
/*!40000 ALTER TABLE mots ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `noeuds`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE noeuds (
  id_noeud int(9) unsigned NOT NULL AUTO_INCREMENT,
  autorite varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_parent int(9) unsigned NOT NULL DEFAULT '0',
  num_renvoi_voir int(9) unsigned NOT NULL DEFAULT '0',
  visible char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '1',
  num_thesaurus int(3) unsigned NOT NULL DEFAULT '0',
  path mediumtext COLLATE utf8_unicode_ci NOT NULL,
  authority_import_denied int(10) unsigned NOT NULL DEFAULT '0',
  not_use_in_indexation int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_noeud),
  KEY num_parent (num_parent),
  KEY num_thesaurus (num_thesaurus),
  KEY autorite (autorite),
  KEY key_path (path(333)),
  KEY i_num_renvoi_voir (num_renvoi_voir)
) ENGINE=MyISAM AUTO_INCREMENT=2513 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `noeuds`
--

LOCK TABLES noeuds WRITE;
/*!40000 ALTER TABLE noeuds DISABLE KEYS */;
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1,'TOP',0,0,'0',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1378,'1377',1,0,'1',1,'1378',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1379,'1378',1,0,'1',1,'1379',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1380,'1379',1,0,'1',1,'1380',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1381,'1380',1,0,'1',1,'1381',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1382,'1381',1,0,'1',1,'1382',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1383,'1382',1,0,'1',1,'1383',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1384,'1383',1,0,'1',1,'1384',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1385,'1384',1,0,'1',1,'1385',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1386,'1385',1,0,'1',1,'1386',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1387,'1386',1,0,'1',1,'1387',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1388,'1387',1378,0,'1',1,'1378/1388',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1389,'1388',1378,0,'1',1,'1378/1389',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1390,'1389',1378,0,'1',1,'1378/1390',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1391,'1390',1378,0,'1',1,'1378/1391',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1392,'1391',1378,0,'1',1,'1378/1392',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1393,'1392',1378,0,'1',1,'1378/1393',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1394,'1393',1378,0,'1',1,'1378/1394',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1395,'1394',1378,0,'1',1,'1378/1395',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1396,'1395',1378,0,'1',1,'1378/1396',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1397,'1396',1378,0,'1',1,'1378/1397',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1398,'1397',1378,0,'1',1,'1378/1398',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1399,'1398',1378,0,'1',1,'1378/1399',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1400,'1399',1378,0,'1',1,'1378/1400',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1401,'1400',1378,0,'1',1,'1378/1401',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1402,'1401',1390,0,'1',1,'1378/1390/1402',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1403,'1402',1408,0,'1',1,'1378/1390/1408/1403',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1404,'1403',1390,0,'1',1,'1378/1390/1404',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1405,'1404',1390,0,'1',1,'1378/1390/1405',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1406,'1405',1390,0,'1',1,'1378/1390/1406',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1407,'1406',1408,0,'1',1,'1378/1390/1408/1407',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1408,'1407',1390,0,'1',1,'1378/1390/1408',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1409,'1408',1408,0,'1',1,'1378/1390/1408/1409',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1410,'1409',1406,0,'1',1,'1378/1390/1406/1410',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1411,'1410',1391,0,'1',1,'1378/1391/1411',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1412,'1411',1391,0,'1',1,'1378/1391/1412',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1413,'1412',1391,0,'1',1,'1378/1391/1413',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1414,'1413',1391,0,'1',1,'1378/1391/1414',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1415,'1414',1391,0,'1',1,'1378/1391/1415',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1416,'1415',1391,0,'1',1,'1378/1391/1416',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1417,'1416',1391,0,'1',1,'1378/1391/1417',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1418,'1417',1391,0,'1',1,'1378/1391/1418',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1419,'1418',1391,0,'1',1,'1378/1391/1419',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1420,'1419',1394,0,'1',1,'1378/1394/1420',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1421,'1420',2046,0,'1',1,'1378/1394/2046/1421',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1422,'1421',2045,0,'1',1,'1378/1394/2045/1422',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1423,'1422',2045,0,'1',1,'1378/1394/2045/1423',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1424,'1423',2045,0,'1',1,'1378/1394/2045/1424',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1425,'1424',2045,0,'1',1,'1378/1394/2045/1425',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1426,'1425',2045,0,'1',1,'1378/1394/2045/1426',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1427,'1426',2045,0,'1',1,'1378/1394/2045/1427',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1428,'1427',2045,0,'1',1,'1378/1394/2045/1428',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1429,'1428',2045,0,'1',1,'1378/1394/2045/1429',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1430,'1429',2045,0,'1',1,'1378/1394/2045/1430',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1431,'1430',1420,0,'1',1,'1378/1394/1420/1431',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1432,'1431',1420,0,'1',1,'1378/1394/1420/1432',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1433,'1432',1420,0,'1',1,'1378/1394/1420/1433',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1434,'1433',1420,0,'1',1,'1378/1394/1420/1434',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1435,'1434',1420,0,'1',1,'1378/1394/1420/1435',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1436,'1435',1420,0,'1',1,'1378/1394/1420/1436',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1437,'1436',1420,0,'1',1,'1378/1394/1420/1437',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1438,'1437',1420,0,'1',1,'1378/1394/1420/1438',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1439,'1438',1420,0,'1',1,'1378/1394/1420/1439',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1440,'1439',1420,0,'1',1,'1378/1394/1420/1440',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1441,'1440',1420,0,'1',1,'1378/1394/1420/1441',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1442,'1441',2046,0,'1',1,'1378/1394/2046/1442',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1443,'1442',1420,0,'1',1,'1378/1394/1420/1443',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1444,'1443',1420,0,'1',1,'1378/1394/1420/1444',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1445,'1444',2046,0,'1',1,'1378/1394/2046/1445',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1446,'1445',1422,0,'1',1,'1378/1394/2045/1422/1446',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1447,'1446',1423,0,'1',1,'1378/1394/2045/1423/1447',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1448,'1447',1424,0,'1',1,'1378/1394/2045/1424/1448',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1449,'1448',1425,0,'1',1,'1378/1394/2045/1425/1449',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1450,'1449',1426,0,'1',1,'1378/1394/2045/1426/1450',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1451,'1450',1427,0,'1',1,'1378/1394/2045/1427/1451',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1452,'1451',1428,0,'1',1,'1378/1394/2045/1428/1452',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1453,'1452',1429,0,'1',1,'1378/1394/2045/1429/1453',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1454,'1453',1430,0,'1',1,'1378/1394/2045/1430/1454',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1455,'1454',2046,0,'1',1,'1378/1394/2046/1455',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1456,'1455',1422,0,'1',1,'1378/1394/2045/1422/1456',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1457,'1456',1423,0,'1',1,'1378/1394/2045/1423/1457',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1458,'1457',1424,0,'1',1,'1378/1394/2045/1424/1458',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1459,'1458',1425,0,'1',1,'1378/1394/2045/1425/1459',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1460,'1459',1426,0,'1',1,'1378/1394/2045/1426/1460',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1461,'1460',1427,0,'1',1,'1378/1394/2045/1427/1461',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1462,'1461',1428,0,'1',1,'1378/1394/2045/1428/1462',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1463,'1462',1428,0,'1',1,'1378/1394/2045/1428/1463',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1464,'1463',1429,0,'1',1,'1378/1394/2045/1429/1464',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1465,'1464',1430,0,'1',1,'1378/1394/2045/1430/1465',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1466,'1465',2046,0,'1',1,'1378/1394/2046/1466',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1467,'1466',1422,0,'1',1,'1378/1394/2045/1422/1467',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1468,'1467',1423,0,'1',1,'1378/1394/2045/1423/1468',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1469,'1468',1424,0,'1',1,'1378/1394/2045/1424/1469',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1470,'1469',1425,0,'1',1,'1378/1394/2045/1425/1470',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1471,'1470',1426,0,'1',1,'1378/1394/2045/1426/1471',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1472,'1471',1427,0,'1',1,'1378/1394/2045/1427/1472',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1473,'1472',1429,0,'1',1,'1378/1394/2045/1429/1473',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1474,'1473',1428,0,'1',1,'1378/1394/2045/1428/1474',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1475,'1474',1430,0,'1',1,'1378/1394/2045/1430/1475',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1476,'1475',1426,0,'1',1,'1378/1394/2045/1426/1476',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1477,'1476',1427,0,'1',1,'1378/1394/2045/1427/1477',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1478,'1477',1429,0,'1',1,'1378/1394/2045/1429/1478',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1479,'1478',1430,0,'1',1,'1378/1394/2045/1430/1479',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1480,'1479',1422,0,'1',1,'1378/1394/2045/1422/1480',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1481,'1480',1423,0,'1',1,'1378/1394/2045/1423/1481',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1482,'1481',1424,0,'1',1,'1378/1394/2045/1424/1482',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1483,'1482',1425,0,'1',1,'1378/1394/2045/1425/1483',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1484,'1483',2160,0,'1',1,'1378/1399/2160/1484',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1485,'1484',2160,0,'1',1,'1378/1399/2160/1485',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1486,'1485',2160,0,'1',1,'1378/1399/2160/1486',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1487,'1486',2160,0,'1',1,'1378/1399/2160/1487',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1488,'1487',2160,0,'1',1,'1378/1399/2160/1488',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1489,'1488',2160,0,'1',1,'1378/1399/2160/1489',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1490,'1489',2160,0,'1',1,'1378/1399/2160/1490',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1492,'1491',1399,0,'1',1,'1378/1399/1492',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1493,'1492',1379,0,'1',1,'1379/1493',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1494,'1493',1379,0,'1',1,'1379/1494',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1495,'1494',1379,0,'1',1,'1379/1495',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1496,'1495',1379,0,'1',1,'1379/1496',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1497,'1496',1379,0,'1',1,'1379/1497',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1498,'1497',1379,0,'1',1,'1379/1498',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1499,'1498',1495,0,'1',1,'1379/1495/1499',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1500,'1499',1495,0,'1',1,'1379/1495/1500',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1501,'1500',1495,0,'1',1,'1379/1495/1501',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1502,'1501',1495,0,'1',1,'1379/1495/1502',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1503,'1502',1495,0,'1',1,'1379/1495/1503',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1504,'1503',1495,0,'1',1,'1379/1495/1504',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1505,'1504',1495,0,'1',1,'1379/1495/1505',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1506,'1505',1382,0,'1',1,'1382/1506',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1507,'1506',1495,0,'1',1,'1379/1495/1507',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1508,'1507',1495,0,'1',1,'1379/1495/1508',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1509,'1508',1495,0,'1',1,'1379/1495/1509',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1510,'1509',1495,0,'1',1,'1379/1495/1510',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1511,'1510',1495,0,'1',1,'1379/1495/1511',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1512,'1511',1497,0,'1',1,'1379/1497/1512',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1513,'1512',1497,0,'1',1,'1379/1497/1513',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1514,'1513',1497,0,'1',1,'1379/1497/1514',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1515,'1514',1380,0,'1',1,'1380/1515',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1516,'1515',1380,0,'1',1,'1380/1516',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1517,'1516',1380,0,'1',1,'1380/1517',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1518,'1517',1380,0,'1',1,'1380/1518',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1519,'1518',1380,0,'1',1,'1380/1519',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1520,'1519',1380,0,'1',1,'1380/1520',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1521,'1520',1380,0,'1',1,'1380/1521',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1522,'1521',1380,0,'1',1,'1380/1522',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1523,'1522',1380,0,'1',1,'1380/1523',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1524,'1523',1525,1641,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1525,'1524',1515,0,'1',1,'1380/1515/1525',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1526,'1525',1515,0,'1',1,'1380/1515/1526',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1527,'1526',1526,0,'1',1,'1380/1515/1526/1527',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1528,'1527',1526,0,'1',1,'1380/1515/1526/1528',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1529,'1528',1526,0,'1',1,'1380/1515/1526/1529',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1530,'1529',1526,0,'1',1,'1380/1515/1526/1530',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1531,'1530',1515,0,'1',1,'1380/1515/1531',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1532,'1531',1515,0,'1',1,'1380/1515/1532',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1533,'1532',1515,0,'1',1,'1380/1515/1533',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1534,'1533',1515,0,'1',1,'1380/1515/1534',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1535,'1534',1515,0,'1',1,'1380/1515/1535',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1536,'1535',1516,0,'1',1,'1380/1516/1536',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1537,'1536',1516,0,'1',1,'1380/1516/1537',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1538,'1537',1516,0,'1',1,'1380/1516/1538',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1539,'1538',1516,0,'1',1,'1380/1516/1539',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1540,'1539',1516,0,'1',1,'1380/1516/1540',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1541,'1540',1516,0,'1',1,'1380/1516/1541',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1542,'1541',1516,0,'1',1,'1380/1516/1542',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1543,'1542',1516,0,'1',1,'1380/1516/1543',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1544,'1543',1516,0,'1',1,'1380/1516/1544',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1545,'1544',1517,0,'1',1,'1380/1517/1545',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1546,'1545',1517,0,'1',1,'1380/1517/1546',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1547,'1546',1523,0,'1',1,'1380/1523/1547',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1548,'1547',1517,0,'1',1,'1380/1517/1548',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1549,'1548',1517,0,'1',1,'1380/1517/1549',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1550,'1549',1551,0,'1',1,'1380/1517/1551/1550',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1551,'1550',1517,0,'1',1,'1380/1517/1551',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1552,'1551',1517,0,'1',1,'1380/1517/1552',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1553,'1552',1517,0,'1',1,'1380/1517/1553',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1554,'1553',1518,0,'1',1,'1380/1518/1554',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1555,'1554',1518,0,'1',1,'1380/1518/1555',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1556,'1555',1518,0,'1',1,'1380/1518/1556',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1557,'1556',1518,0,'1',1,'1380/1518/1557',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1558,'1557',1518,0,'1',1,'1380/1518/1558',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1559,'1558',1519,0,'1',1,'1380/1519/1559',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1560,'1559',1519,0,'1',1,'1380/1519/1560',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1561,'1560',1519,0,'1',1,'1380/1519/1561',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1562,'1561',1519,0,'1',1,'1380/1519/1562',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1563,'1562',1519,0,'1',1,'1380/1519/1563',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1564,'1563',1519,0,'1',1,'1380/1519/1564',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1565,'1564',1519,0,'1',1,'1380/1519/1565',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1566,'1565',1519,0,'1',1,'1380/1519/1566',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1567,'1566',1555,0,'1',1,'1380/1518/1555/1567',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1568,'1567',2167,0,'1',1,'1380/1520/2167/1568',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1569,'1568',2167,0,'1',1,'1380/1520/2167/1569',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1570,'1569',2167,0,'1',1,'1380/1520/2167/1570',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1571,'1570',2167,0,'1',1,'1380/1520/2167/1571',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1572,'1571',2167,0,'1',1,'1380/1520/2167/1572',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1573,'1572',2167,0,'1',1,'1380/1520/2167/1573',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1574,'1573',2168,0,'1',1,'1380/1520/2168/1574',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1575,'1574',2168,0,'1',1,'1380/1520/2168/1575',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1576,'1575',2168,0,'1',1,'1380/1520/2168/1576',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1577,'1576',1520,0,'1',1,'1380/1520/1577',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1578,'1577',1520,0,'1',1,'1380/1520/1578',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1579,'1578',1520,0,'1',1,'1380/1520/1579',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1580,'1579',1520,0,'1',1,'1380/1520/1580',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1581,'1580',1520,0,'1',1,'1380/1520/1581',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1583,'1582',1521,0,'1',1,'1380/1521/1583',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1584,'1583',1521,0,'1',1,'1380/1521/1584',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1585,'1584',1521,0,'1',1,'1380/1521/1585',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1586,'1585',1521,0,'1',1,'1380/1521/1586',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1587,'1586',1521,0,'1',1,'1380/1521/1587',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1588,'1587',1521,0,'1',1,'1380/1521/1588',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1589,'1588',1521,0,'1',1,'1380/1521/1589',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1590,'1589',1521,0,'1',1,'1380/1521/1590',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1591,'1590',1521,0,'1',1,'1380/1521/1591',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1592,'1591',1522,0,'1',1,'1380/1522/1592',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1593,'1592',2166,0,'1',1,'1380/1522/2166/1593',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1594,'1593',2166,0,'1',1,'1380/1522/2166/1594',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1595,'1594',2166,0,'1',1,'1380/1522/2166/1595',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1596,'1595',1522,0,'1',1,'1380/1522/1596',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1597,'1596',1522,0,'1',1,'1380/1522/1597',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1598,'1597',1522,0,'1',1,'1380/1522/1598',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1599,'1598',1522,0,'1',1,'1380/1522/1599',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1600,'1599',1522,0,'1',1,'1380/1522/1600',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1601,'1600',1522,0,'1',1,'1380/1522/1601',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1602,'1601',1522,0,'1',1,'1380/1522/1602',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1603,'1602',1523,0,'1',1,'1380/1523/1603',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1604,'1603',1523,0,'1',1,'1380/1523/1604',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1605,'1604',1523,0,'1',1,'1380/1523/1605',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1606,'1605',1523,0,'1',1,'1380/1523/1606',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1607,'1606',1523,0,'1',1,'1380/1523/1607',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1608,'1607',1523,0,'1',1,'1380/1523/1608',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1609,'1608',1523,0,'1',1,'1380/1523/1609',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1610,'1609',1523,0,'1',1,'1380/1523/1610',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1611,'1610',1523,0,'1',1,'1380/1523/1611',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1612,'1611',1381,0,'1',1,'1381/1612',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1613,'1612',2022,0,'1',1,'1381/2022/1613',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1614,'1613',1381,0,'1',1,'1381/1614',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1615,'1614',2022,0,'1',1,'1381/2022/1615',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1616,'1615',2022,0,'1',1,'1381/2022/1616',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1617,'1616',1381,0,'1',1,'1381/1617',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1618,'1617',1381,0,'1',1,'1381/1618',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1619,'1618',1381,0,'1',1,'1381/1619',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1620,'1619',1381,0,'1',1,'1381/1620',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1621,'1620',2022,0,'1',1,'1381/2022/1621',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1622,'1621',1620,0,'1',1,'1381/1620/1622',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1623,'1622',1620,0,'1',1,'1381/1620/1623',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1624,'1623',1620,0,'1',1,'1381/1620/1624',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1625,'1624',1620,0,'1',1,'1381/1620/1625',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1626,'1625',1620,0,'1',1,'1381/1620/1626',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1627,'1626',1620,0,'1',1,'1381/1620/1627',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1628,'1627',1620,0,'1',1,'1381/1620/1628',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1629,'1628',1621,0,'1',1,'1381/2022/1621/1629',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1630,'1629',1621,0,'1',1,'1381/2022/1621/1630',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1631,'1630',1621,0,'1',1,'1381/2022/1621/1631',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1632,'1631',1621,0,'1',1,'1381/2022/1621/1632',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1633,'1632',1621,0,'1',1,'1381/2022/1621/1633',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1634,'1633',1621,0,'1',1,'1381/2022/1621/1634',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1635,'1634',1621,0,'1',1,'1381/2022/1621/1635',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1636,'1635',1621,0,'1',1,'1381/2022/1621/1636',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1637,'1636',1621,0,'1',1,'1381/2022/1621/1637',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1638,'1637',1621,0,'1',1,'1381/2022/1621/1638',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1639,'1638',1621,0,'1',1,'1381/2022/1621/1639',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1640,'1639',1639,0,'1',1,'1381/2022/1621/1639/1640',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1641,'1640',1644,0,'1',1,'1381/2022/1621/1639/1644/1641',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1642,'1641',1639,0,'1',1,'1381/2022/1621/1639/1642',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1643,'1642',2141,0,'1',1,'1381/2022/1621/1639/2141/1643',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1644,'1643',1639,0,'1',1,'1381/2022/1621/1639/1644',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1645,'1644',1639,0,'1',1,'1381/2022/1621/1639/1645',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1646,'1645',1382,0,'1',1,'1382/1646',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1647,'1646',1382,0,'1',1,'1382/1647',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1648,'1647',1382,0,'1',1,'1382/1648',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1649,'1648',1382,0,'1',1,'1382/1649',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1650,'1649',1382,0,'1',1,'1382/1650',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1651,'1650',1382,0,'1',1,'1382/1651',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1652,'1651',1382,0,'1',1,'1382/1652',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1653,'1652',1382,0,'1',1,'1382/1653',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1654,'1653',1382,0,'1',1,'1382/1654',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1655,'1654',1382,0,'1',1,'1382/1655',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1656,'1655',1382,0,'1',1,'1382/1656',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1657,'1656',1382,0,'1',1,'1382/1657',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1658,'1657',1647,0,'1',1,'1382/1647/1658',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1659,'1658',1647,0,'1',1,'1382/1647/1659',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1660,'1659',1647,0,'1',1,'1382/1647/1660',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1661,'1660',1647,0,'1',1,'1382/1647/1661',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1662,'1661',1647,0,'1',1,'1382/1647/1662',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1663,'1662',1651,0,'1',1,'1382/1651/1663',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1664,'1663',1651,0,'1',1,'1382/1651/1664',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1665,'1664',1651,0,'1',1,'1382/1651/1665',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1666,'1665',1651,0,'1',1,'1382/1651/1666',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1667,'1666',1651,0,'1',1,'1382/1651/1667',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1668,'1667',1651,0,'1',1,'1382/1651/1668',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1669,'1668',1651,0,'1',1,'1382/1651/1669',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1670,'1669',1651,0,'1',1,'1382/1651/1670',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1671,'1670',1651,0,'1',1,'1382/1651/1671',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1672,'1671',1651,0,'1',1,'1382/1651/1672',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1673,'1672',1651,0,'1',1,'1382/1651/1673',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1674,'1673',1651,0,'1',1,'1382/1651/1674',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1675,'1674',1654,0,'1',1,'1382/1654/1675',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1676,'1675',1654,0,'1',1,'1382/1654/1676',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1677,'1676',1654,0,'1',1,'1382/1654/1677',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1678,'1677',1654,0,'1',1,'1382/1654/1678',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1679,'1678',1654,0,'1',1,'1382/1654/1679',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1680,'1679',1654,0,'1',1,'1382/1654/1680',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1681,'1680',1684,0,'1',1,'1383/1684/1681',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1682,'1681',1383,0,'1',1,'1383/1682',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1683,'1682',1383,0,'1',1,'1383/1683',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1684,'1683',1383,0,'1',1,'1383/1684',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1685,'1684',1683,0,'1',1,'1383/1683/1685',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1686,'1685',1383,0,'1',1,'1383/1686',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1687,'1686',1383,0,'1',1,'1383/1687',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1688,'1687',1684,0,'1',1,'1383/1684/1688',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1689,'1688',1684,0,'1',1,'1383/1684/1689',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1690,'1689',1383,0,'1',1,'1383/1690',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1691,'1690',1684,0,'1',1,'1383/1684/1691',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1692,'1691',1683,0,'1',1,'1383/1683/1692',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1693,'1692',1383,0,'1',1,'1383/1693',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1694,'1693',1383,0,'1',1,'1383/1694',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1695,'1694',1385,0,'1',1,'1385/1695',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1696,'1695',1383,0,'1',1,'1383/1696',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1697,'1696',1383,0,'1',1,'1383/1697',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1698,'1697',1684,0,'1',1,'1383/1684/1698',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1699,'1698',1684,0,'1',1,'1383/1684/1699',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1700,'1699',1383,0,'1',1,'1383/1700',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1701,'1700',1684,0,'1',1,'1383/1684/1701',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1702,'1701',1682,0,'1',1,'1383/1682/1702',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1703,'1702',1682,0,'1',1,'1383/1682/1703',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1704,'1703',1682,0,'1',1,'1383/1682/1704',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1705,'1704',1682,0,'1',1,'1383/1682/1705',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1706,'1705',1682,0,'1',1,'1383/1682/1706',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1707,'1706',1687,0,'1',1,'1383/1687/1707',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1708,'1707',1687,0,'1',1,'1383/1687/1708',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1709,'1708',1687,0,'1',1,'1383/1687/1709',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1710,'1709',1687,0,'1',1,'1383/1687/1710',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1711,'1710',1687,0,'1',1,'1383/1687/1711',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1712,'1711',1687,0,'1',1,'1383/1687/1712',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1713,'1712',1687,0,'1',1,'1383/1687/1713',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1714,'1713',1683,0,'1',1,'1383/1683/1714',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1715,'1714',1696,0,'1',1,'1383/1696/1715',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1716,'1715',1696,0,'1',1,'1383/1696/1716',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1717,'1716',1696,0,'1',1,'1383/1696/1717',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1718,'1717',1696,0,'1',1,'1383/1696/1718',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1719,'1718',1696,0,'1',1,'1383/1696/1719',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1720,'1719',1696,0,'1',1,'1383/1696/1720',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1721,'1720',1696,0,'1',1,'1383/1696/1721',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1722,'1721',1696,0,'1',1,'1383/1696/1722',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1723,'1722',1384,0,'1',1,'1384/1723',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1724,'1723',1384,0,'1',1,'1384/1724',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1725,'1724',1384,0,'1',1,'1384/1725',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1726,'1725',1384,0,'1',1,'1384/1726',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1727,'1726',2203,0,'1',1,'1386/2203/1727',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1728,'1727',1384,0,'1',1,'1384/1728',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1729,'1728',1384,0,'1',1,'1384/1729',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1730,'1729',1384,0,'1',1,'1384/1730',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1731,'1730',1384,0,'1',1,'1384/1731',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1733,'1732',1384,0,'1',1,'1384/1733',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1734,'1733',1917,0,'1',1,'1387/1792/1833/1917/1734',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1735,'1734',1734,0,'1',1,'1387/1792/1833/1917/1734/1735',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1736,'1735',1734,0,'1',1,'1387/1792/1833/1917/1734/1736',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1737,'1736',1734,0,'1',1,'1387/1792/1833/1917/1734/1737',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1738,'1737',1734,0,'1',1,'1387/1792/1833/1917/1734/1738',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1739,'1738',1734,0,'1',1,'1387/1792/1833/1917/1734/1739',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1740,'1739',1734,0,'1',1,'1387/1792/1833/1917/1734/1740',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1741,'1740',1734,0,'1',1,'1387/1792/1833/1917/1734/1741',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1742,'1741',1734,0,'1',1,'1387/1792/1833/1917/1734/1742',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1743,'1742',1734,0,'1',1,'1387/1792/1833/1917/1734/1743',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1744,'1743',1734,0,'1',1,'1387/1792/1833/1917/1734/1744',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1746,'1745',1734,0,'1',1,'1387/1792/1833/1917/1734/1746',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1747,'1746',1734,0,'1',1,'1387/1792/1833/1917/1734/1747',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1748,'1747',1734,0,'1',1,'1387/1792/1833/1917/1734/1748',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1749,'1748',1734,0,'1',1,'1387/1792/1833/1917/1734/1749',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1750,'1749',1734,0,'1',1,'1387/1792/1833/1917/1734/1750',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1751,'1750',1734,0,'1',1,'1387/1792/1833/1917/1734/1751',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1752,'1751',1734,0,'1',1,'1387/1792/1833/1917/1734/1752',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1753,'1752',1734,0,'1',1,'1387/1792/1833/1917/1734/1753',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1754,'1753',1734,0,'1',1,'1387/1792/1833/1917/1734/1754',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1755,'1754',1734,0,'1',1,'1387/1792/1833/1917/1734/1755',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1756,'1755',1734,0,'1',1,'1387/1792/1833/1917/1734/1756',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1757,'1756',1734,0,'1',1,'1387/1792/1833/1917/1734/1757',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1758,'1757',1385,0,'1',1,'1385/1758',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1759,'1758',1385,0,'1',1,'1385/1759',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1760,'1759',1385,0,'1',1,'1385/1760',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1761,'1760',1385,0,'1',1,'1385/1761',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1762,'1761',1385,0,'1',1,'1385/1762',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1763,'1762',1385,0,'1',1,'1385/1763',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1764,'1763',1385,0,'1',1,'1385/1764',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1765,'1764',1385,0,'1',1,'1385/1765',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1766,'1765',1385,0,'1',1,'1385/1766',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1767,'1766',1385,0,'1',1,'1385/1767',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1768,'1767',1385,0,'1',1,'1385/1768',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1769,'1768',1385,0,'1',1,'1385/1769',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1770,'1769',1385,0,'1',1,'1385/1770',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1771,'1770',1385,0,'1',1,'1385/1771',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1772,'1771',1385,0,'1',1,'1385/1772',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1773,'1772',1765,0,'1',1,'1385/1765/1773',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1774,'1773',1765,0,'1',1,'1385/1765/1774',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1775,'1774',1765,0,'1',1,'1385/1765/1775',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1776,'1775',1765,0,'1',1,'1385/1765/1776',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1777,'1776',1765,0,'1',1,'1385/1765/1777',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1778,'1777',1386,0,'1',1,'1386/1778',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1779,'1778',1386,0,'1',1,'1386/1779',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1780,'1779',1386,0,'1',1,'1386/1780',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1781,'1780',1386,0,'1',1,'1386/1781',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1782,'1781',1386,0,'1',1,'1386/1782',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1783,'1782',1386,0,'1',1,'1386/1783',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1784,'1783',1386,0,'1',1,'1386/1784',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1785,'1784',1386,0,'1',1,'1386/1785',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1786,'1785',1386,0,'1',1,'1386/1786',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1787,'1786',1386,0,'1',1,'1386/1787',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1788,'1787',1387,0,'1',1,'1387/1788',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1789,'1788',1387,0,'1',1,'1387/1789',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1790,'1789',1387,0,'1',1,'1387/1790',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1791,'1790',1387,0,'1',1,'1387/1791',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1792,'1791',1387,0,'1',1,'1387/1792',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1793,'1792',1387,0,'1',1,'1387/1793',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1794,'1793',1387,0,'1',1,'1387/1794',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1795,'1794',1387,0,'1',1,'1387/1795',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1796,'1795',1387,0,'1',1,'1387/1796',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1797,'1796',1788,0,'1',1,'1387/1788/1797',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1798,'1797',1788,0,'1',1,'1387/1788/1798',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1799,'1798',1788,0,'1',1,'1387/1788/1799',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1800,'1799',1788,0,'1',1,'1387/1788/1800',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1801,'1800',1788,0,'1',1,'1387/1788/1801',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1802,'1801',1788,0,'1',1,'1387/1788/1802',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1803,'1802',1788,0,'1',1,'1387/1788/1803',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1804,'1803',1789,0,'1',1,'1387/1789/1804',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1805,'1804',1789,0,'1',1,'1387/1789/1805',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1806,'1805',1789,0,'1',1,'1387/1789/1806',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1807,'1806',1789,0,'1',1,'1387/1789/1807',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1808,'1807',1789,0,'1',1,'1387/1789/1808',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1809,'1808',1789,0,'1',1,'1387/1789/1809',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1810,'1809',1789,0,'1',1,'1387/1789/1810',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1811,'1810',1790,0,'1',1,'1387/1790/1811',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1812,'1811',1790,0,'1',1,'1387/1790/1812',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1813,'1812',1790,0,'1',1,'1387/1790/1813',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1814,'1813',1790,0,'1',1,'1387/1790/1814',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1815,'1814',1790,0,'1',1,'1387/1790/1815',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1816,'1815',1790,0,'1',1,'1387/1790/1816',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1817,'1816',1790,0,'1',1,'1387/1790/1817',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1818,'1817',1790,0,'1',1,'1387/1790/1818',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1819,'1818',1791,0,'1',1,'1387/1791/1819',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1820,'1819',1791,0,'1',1,'1387/1791/1820',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1821,'1820',1791,0,'1',1,'1387/1791/1821',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1822,'1821',1791,0,'1',1,'1387/1791/1822',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1823,'1822',1791,0,'1',1,'1387/1791/1823',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1824,'1823',1791,0,'1',1,'1387/1791/1824',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1825,'1824',1791,0,'1',1,'1387/1791/1825',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1826,'1825',1791,0,'1',1,'1387/1791/1826',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1827,'1826',1791,0,'1',1,'1387/1791/1827',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1828,'1827',1791,0,'1',1,'1387/1791/1828',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1829,'1828',1791,0,'1',1,'1387/1791/1829',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1830,'1829',1791,0,'1',1,'1387/1791/1830',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1831,'1830',1791,0,'1',1,'1387/1791/1831',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1832,'1831',1792,0,'1',1,'1387/1792/1832',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1833,'1832',1792,0,'1',1,'1387/1792/1833',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1834,'1833',1792,0,'1',1,'1387/1792/1834',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1835,'1834',1792,0,'1',1,'1387/1792/1835',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1836,'1835',1792,0,'1',1,'1387/1792/1836',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1837,'1836',1792,0,'1',1,'1387/1792/1837',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1838,'1837',1793,0,'1',1,'1387/1793/1838',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1839,'1838',1793,0,'1',1,'1387/1793/1839',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1840,'1839',1793,0,'1',1,'1387/1793/1840',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1841,'1840',1793,0,'1',1,'1387/1793/1841',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1842,'1841',1793,0,'1',1,'1387/1793/1842',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1843,'1842',1793,0,'1',1,'1387/1793/1843',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1844,'1843',1794,0,'1',1,'1387/1794/1844',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1845,'1844',1794,0,'1',1,'1387/1794/1845',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1846,'1845',1794,0,'1',1,'1387/1794/1846',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1847,'1846',1794,0,'1',1,'1387/1794/1847',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1848,'1847',1797,0,'1',1,'1387/1788/1797/1848',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1849,'1848',1797,0,'1',1,'1387/1788/1797/1849',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1850,'1849',1797,0,'1',1,'1387/1788/1797/1850',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1851,'1850',1797,0,'1',1,'1387/1788/1797/1851',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1852,'1851',1798,0,'1',1,'1387/1788/1798/1852',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1853,'1852',1798,0,'1',1,'1387/1788/1798/1853',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1854,'1853',1798,0,'1',1,'1387/1788/1798/1854',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1855,'1854',1798,0,'1',1,'1387/1788/1798/1855',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1856,'1855',1798,0,'1',1,'1387/1788/1798/1856',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1857,'1856',1798,0,'1',1,'1387/1788/1798/1857',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1858,'1857',1798,0,'1',1,'1387/1788/1798/1858',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1859,'1858',1798,0,'1',1,'1387/1788/1798/1859',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1860,'1859',1798,0,'1',1,'1387/1788/1798/1860',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1861,'1860',1798,0,'1',1,'1387/1788/1798/1861',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1862,'1861',1798,0,'1',1,'1387/1788/1798/1862',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1863,'1862',1798,0,'1',1,'1387/1788/1798/1863',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1864,'1863',1798,0,'1',1,'1387/1788/1798/1864',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1865,'1864',1798,0,'1',1,'1387/1788/1798/1865',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1866,'1865',1799,0,'1',1,'1387/1788/1799/1866',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1867,'1866',1799,0,'1',1,'1387/1788/1799/1867',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1868,'1867',1799,0,'1',1,'1387/1788/1799/1868',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1869,'1868',1799,0,'1',1,'1387/1788/1799/1869',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1870,'1869',1799,0,'1',1,'1387/1788/1799/1870',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1871,'1870',1800,0,'1',1,'1387/1788/1800/1871',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1872,'1871',1800,0,'1',1,'1387/1788/1800/1872',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1873,'1872',1800,0,'1',1,'1387/1788/1800/1873',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1874,'1873',1800,0,'1',1,'1387/1788/1800/1874',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1875,'1874',1800,0,'1',1,'1387/1788/1800/1875',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1876,'1875',1800,0,'1',1,'1387/1788/1800/1876',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1877,'1876',1800,0,'1',1,'1387/1788/1800/1877',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1878,'1877',1800,0,'1',1,'1387/1788/1800/1878',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1879,'1878',1801,0,'1',1,'1387/1788/1801/1879',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1880,'1879',1801,0,'1',1,'1387/1788/1801/1880',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1881,'1880',1801,0,'1',1,'1387/1788/1801/1881',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1882,'1881',1801,0,'1',1,'1387/1788/1801/1882',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1883,'1882',1801,0,'1',1,'1387/1788/1801/1883',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1884,'1883',1801,0,'1',1,'1387/1788/1801/1884',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1885,'1884',1801,0,'1',1,'1387/1788/1801/1885',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1886,'1885',1802,0,'1',1,'1387/1788/1802/1886',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1887,'1886',1802,0,'1',1,'1387/1788/1802/1887',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1888,'1887',1802,0,'1',1,'1387/1788/1802/1888',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1889,'1888',1802,0,'1',1,'1387/1788/1802/1889',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1890,'1889',1802,0,'1',1,'1387/1788/1802/1890',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1891,'1890',1802,0,'1',1,'1387/1788/1802/1891',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1892,'1891',1802,0,'1',1,'1387/1788/1802/1892',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1893,'1892',1802,0,'1',1,'1387/1788/1802/1893',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1894,'1893',1802,0,'1',1,'1387/1788/1802/1894',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1895,'1894',1802,0,'1',1,'1387/1788/1802/1895',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1896,'1895',1803,0,'1',1,'1387/1788/1803/1896',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1897,'1896',1803,0,'1',1,'1387/1788/1803/1897',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1898,'1897',1803,0,'1',1,'1387/1788/1803/1898',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1899,'1898',1803,0,'1',1,'1387/1788/1803/1899',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1900,'1899',1803,0,'1',1,'1387/1788/1803/1900',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1901,'1900',1803,0,'1',1,'1387/1788/1803/1901',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1902,'1901',1818,0,'1',1,'1387/1790/1818/1902',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1903,'1902',1818,0,'1',1,'1387/1790/1818/1903',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1904,'1903',1818,0,'1',1,'1387/1790/1818/1904',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1905,'1904',1818,0,'1',1,'1387/1790/1818/1905',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1906,'1905',1818,0,'1',1,'1387/1790/1818/1906',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1907,'1906',1818,0,'1',1,'1387/1790/1818/1907',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1908,'1907',1818,0,'1',1,'1387/1790/1818/1908',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1909,'1908',1818,0,'1',1,'1387/1790/1818/1909',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1910,'1909',1832,0,'1',1,'1387/1792/1832/1910',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1911,'1910',1832,0,'1',1,'1387/1792/1832/1911',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1912,'1911',1832,0,'1',1,'1387/1792/1832/1912',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1913,'1912',1832,0,'1',1,'1387/1792/1832/1913',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1914,'1913',1832,0,'1',1,'1387/1792/1832/1914',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1915,'1914',1833,0,'1',1,'1387/1792/1833/1915',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1916,'1915',1833,0,'1',1,'1387/1792/1833/1916',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1917,'1916',1833,0,'1',1,'1387/1792/1833/1917',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1918,'1917',1833,0,'1',1,'1387/1792/1833/1918',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1919,'1918',1833,0,'1',1,'1387/1792/1833/1919',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1920,'1919',1833,0,'1',1,'1387/1792/1833/1920',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1921,'1920',1833,0,'1',1,'1387/1792/1833/1921',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1922,'1921',1834,0,'1',1,'1387/1792/1834/1922',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1923,'1922',1834,0,'1',1,'1387/1792/1834/1923',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1924,'1923',1834,0,'1',1,'1387/1792/1834/1924',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1925,'1924',1834,0,'1',1,'1387/1792/1834/1925',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1926,'1925',1834,0,'1',1,'1387/1792/1834/1926',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1927,'1926',1835,0,'1',1,'1387/1792/1835/1927',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1928,'1927',1835,0,'1',1,'1387/1792/1835/1928',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1929,'1928',1835,0,'1',1,'1387/1792/1835/1929',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1930,'1929',1835,0,'1',1,'1387/1792/1835/1930',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1931,'1930',1835,0,'1',1,'1387/1792/1835/1931',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1932,'1931',1835,0,'1',1,'1387/1792/1835/1932',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1933,'1932',1835,0,'1',1,'1387/1792/1835/1933',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1934,'1933',1835,0,'1',1,'1387/1792/1835/1934',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1935,'1934',1836,0,'1',1,'1387/1792/1836/1935',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1936,'1935',1836,0,'1',1,'1387/1792/1836/1936',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1937,'1936',1836,0,'1',1,'1387/1792/1836/1937',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1938,'1937',1836,0,'1',1,'1387/1792/1836/1938',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1939,'1938',1837,0,'1',1,'1387/1792/1837/1939',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1940,'1939',1837,0,'1',1,'1387/1792/1837/1940',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1941,'1940',1837,0,'1',1,'1387/1792/1837/1941',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1942,'1941',1837,0,'1',1,'1387/1792/1837/1942',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1943,'1942',1837,0,'1',1,'1387/1792/1837/1943',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1944,'1943',1837,0,'1',1,'1387/1792/1837/1944',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1945,'1944',1837,0,'1',1,'1387/1792/1837/1945',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1946,'1945',1837,0,'1',1,'1387/1792/1837/1946',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1947,'1946',1837,0,'1',1,'1387/1792/1837/1947',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1948,'1947',1838,0,'1',1,'1387/1793/1838/1948',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1949,'1948',1838,0,'1',1,'1387/1793/1838/1949',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1950,'1949',1838,0,'1',1,'1387/1793/1838/1950',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1951,'1950',1838,0,'1',1,'1387/1793/1838/1951',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1952,'1951',1948,0,'1',1,'1387/1793/1838/1948/1952',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1953,'1952',1948,0,'1',1,'1387/1793/1838/1948/1953',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1954,'1953',1948,0,'1',1,'1387/1793/1838/1948/1954',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1955,'1954',1948,0,'1',1,'1387/1793/1838/1948/1955',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1956,'1955',1948,0,'1',1,'1387/1793/1838/1948/1956',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1957,'1956',1948,0,'1',1,'1387/1793/1838/1948/1957',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1958,'1957',1948,0,'1',1,'1387/1793/1838/1948/1958',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1959,'1958',1951,0,'1',1,'1387/1793/1838/1951/1959',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1960,'1959',1951,0,'1',1,'1387/1793/1838/1951/1960',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1961,'1960',1951,0,'1',1,'1387/1793/1838/1951/1961',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1962,'1961',1951,0,'1',1,'1387/1793/1838/1951/1962',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1963,'1962',1951,0,'1',1,'1387/1793/1838/1951/1963',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1964,'1963',1951,0,'1',1,'1387/1793/1838/1951/1964',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1965,'1964',1951,0,'1',1,'1387/1793/1838/1951/1965',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1966,'1965',1839,0,'1',1,'1387/1793/1839/1966',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1967,'1966',1839,0,'1',1,'1387/1793/1839/1967',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1968,'1967',1839,0,'1',1,'1387/1793/1839/1968',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1969,'1968',1835,0,'1',1,'1387/1792/1835/1969',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1970,'1969',1840,0,'1',1,'1387/1793/1840/1970',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1971,'1970',1840,0,'1',1,'1387/1793/1840/1971',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1972,'1971',1840,0,'1',1,'1387/1793/1840/1972',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1973,'1972',1840,0,'1',1,'1387/1793/1840/1973',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1974,'1973',1840,0,'1',1,'1387/1793/1840/1974',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1975,'1974',1840,0,'1',1,'1387/1793/1840/1975',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1976,'1975',1840,0,'1',1,'1387/1793/1840/1976',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1977,'1976',1840,0,'1',1,'1387/1793/1840/1977',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1978,'1977',1841,0,'1',1,'1387/1793/1841/1978',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1979,'1978',1841,0,'1',1,'1387/1793/1841/1979',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1980,'1979',1841,0,'1',1,'1387/1793/1841/1980',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1981,'1980',1841,0,'1',1,'1387/1793/1841/1981',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1982,'1981',1841,0,'1',1,'1387/1793/1841/1982',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1983,'1982',1841,0,'1',1,'1387/1793/1841/1983',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1984,'1983',1842,0,'1',1,'1387/1793/1842/1984',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1985,'1984',1842,0,'1',1,'1387/1793/1842/1985',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1986,'1985',1842,0,'1',1,'1387/1793/1842/1986',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1987,'1986',1842,0,'1',1,'1387/1793/1842/1987',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1988,'1987',1842,0,'1',1,'1387/1793/1842/1988',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1989,'1988',1842,0,'1',1,'1387/1793/1842/1989',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1990,'1989',1843,0,'1',1,'1387/1793/1843/1990',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1991,'1990',1843,0,'1',1,'1387/1793/1843/1991',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1992,'1991',1843,0,'1',1,'1387/1793/1843/1992',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1993,'1992',1843,0,'1',1,'1387/1793/1843/1993',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1994,'1993',1843,0,'1',1,'1387/1793/1843/1994',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1995,'1994',1843,0,'1',1,'1387/1793/1843/1995',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1996,'1995',1843,0,'1',1,'1387/1793/1843/1996',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1997,'1996',1843,0,'1',1,'1387/1793/1843/1997',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1998,'1997',1843,0,'1',1,'1387/1793/1843/1998',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (1999,'1998',1843,0,'1',1,'1387/1793/1843/1999',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2000,'1999',1845,0,'1',1,'1387/1794/1845/2000',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2001,'2000',1845,0,'1',1,'1387/1794/1845/2001',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2002,'2001',1845,0,'1',1,'1387/1794/1845/2002',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2003,'2002',1845,0,'1',1,'1387/1794/1845/2003',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2004,'2003',1845,0,'1',1,'1387/1794/1845/2004',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2005,'2004',1845,0,'1',1,'1387/1794/1845/2005',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2006,'2005',1846,0,'1',1,'1387/1794/1846/2006',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2007,'2006',1846,0,'1',1,'1387/1794/1846/2007',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2008,'2007',1846,0,'1',1,'1387/1794/1846/2008',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2009,'2008',1846,0,'1',1,'1387/1794/1846/2009',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2010,'2009',1846,0,'1',1,'1387/1794/1846/2010',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2011,'2010',1847,0,'1',1,'1387/1794/1847/2011',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2012,'2011',1847,0,'1',1,'1387/1794/1847/2012',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2013,'2012',1847,0,'1',1,'1387/1794/1847/2013',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2014,'2013',1847,0,'1',1,'1387/1794/1847/2014',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2015,'2014',1847,0,'1',1,'1387/1794/1847/2015',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2016,'2015',1847,0,'1',1,'1387/1794/1847/2016',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2017,'2016',1847,0,'1',1,'1387/1794/1847/2017',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2018,'2017',1847,0,'1',1,'1387/1794/1847/2018',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2019,'2018',1847,0,'1',1,'1387/1794/1847/2019',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2020,'2019',1847,0,'1',1,'1387/1794/1847/2020',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2021,'2020',1847,0,'1',1,'1387/1794/1847/2021',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2022,'2021',1381,0,'1',1,'1381/2022',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2023,'2022',1698,0,'1',1,'1383/1684/1698/2023',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2024,'2023',1787,0,'1',1,'1386/1787/2024',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2025,'2024',1698,0,'1',1,'1383/1684/1698/2025',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2026,'2025',1787,0,'1',1,'1386/1787/2026',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2027,'2026',1698,0,'1',1,'1383/1684/1698/2027',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2028,'2027',1787,0,'1',1,'1386/1787/2028',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2029,'2028',1503,0,'1',1,'1379/1495/1503/2029',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2030,'2029',2032,0,'1',1,'1382/1653/2032/2030',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2031,'2030',2032,0,'1',1,'1382/1653/2032/2031',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2032,'2031',1653,0,'1',1,'1382/1653/2032',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2034,'2033',1554,0,'1',1,'1380/1518/1554/2034',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2035,'2034',2046,0,'1',1,'1378/1394/2046/2035',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2036,'2035',2046,0,'1',1,'1378/1394/2046/2036',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2037,'2036',1787,0,'1',1,'1386/1787/2037',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2040,'2039',1731,0,'1',1,'1384/1731/2040',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2043,'2042',1691,0,'1',1,'1383/1684/1691/2043',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2044,'2043',1424,0,'1',1,'1378/1394/2045/1424/2044',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2045,'2044',1394,0,'1',1,'1378/1394/2045',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2046,'2045',1394,0,'1',1,'1378/1394/2046',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2047,'2046',2046,0,'1',1,'1378/1394/2046/2047',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2048,'2047',2046,0,'1',1,'1378/1394/2046/2048',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2049,'2048',2046,0,'1',1,'1378/1394/2046/2049',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2050,'2049',2046,0,'1',1,'1378/1394/2046/2050',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2051,'2050',2046,0,'1',1,'1378/1394/2046/2051',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2052,'2051',2046,0,'1',1,'1378/1394/2046/2052',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2053,'2052',2046,0,'1',1,'1378/1394/2046/2053',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2054,'2053',2049,0,'1',1,'1378/1394/2046/2049/2054',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2057,'2056',1593,0,'1',1,'1380/1522/2166/1593/2057',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2058,'2057',1593,0,'1',1,'1380/1522/2166/1593/2058',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2059,'2058',1593,0,'1',1,'1380/1522/2166/1593/2059',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2060,'2059',1593,0,'1',1,'1380/1522/2166/1593/2060',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2061,'2060',1593,0,'1',1,'1380/1522/2166/1593/2061',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2062,'2061',1593,0,'1',1,'1380/1522/2166/1593/2062',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2063,'2062',1593,0,'1',1,'1380/1522/2166/1593/2063',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2064,'2063',1593,0,'1',1,'1380/1522/2166/1593/2064',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2065,'2064',1593,0,'1',1,'1380/1522/2166/1593/2065',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2068,'2067',1455,0,'1',1,'1378/1394/2046/1455/2068',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2071,'2070',1554,0,'1',1,'1380/1518/1554/2071',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2072,'2071',1554,0,'1',1,'1380/1518/1554/2072',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2074,'2073',2051,0,'1',1,'1378/1394/2046/2051/2074',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2075,'2074',1652,0,'1',1,'1382/1652/2075',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2076,'2075',2125,0,'1',1,'1386/1780/2125/2076',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2078,'2077',1442,0,'1',1,'1378/1394/2046/1442/2078',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2079,'2078',2082,0,'1',1,'1380/1517/1551/1550/2082/2079',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2080,'2079',2082,0,'1',1,'1380/1517/1551/1550/2082/2080',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2081,'2080',2082,0,'1',1,'1380/1517/1551/1550/2082/2081',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2082,'2081',1550,0,'1',1,'1380/1517/1551/1550/2082',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2084,'2083',2035,0,'1',1,'1378/1394/2046/2035/2084',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2085,'2084',1708,0,'1',1,'1383/1687/1708/2085',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2086,'2085',1503,0,'1',1,'1379/1495/1503/2086',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2087,'2086',2086,0,'1',1,'1379/1495/1503/2086/2087',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2089,'2088',2036,0,'1',1,'1378/1394/2046/2036/2089',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2090,'2089',2089,0,'1',1,'1378/1394/2046/2036/2089/2090',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2093,'2092',1944,0,'1',1,'1387/1792/1837/1944/2093',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2094,'2093',2125,0,'1',1,'1386/1780/2125/2094',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2095,'2094',1425,0,'1',1,'1378/1394/2045/1425/2095',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2096,'2095',1426,0,'1',1,'1378/1394/2045/1426/2096',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2097,'2096',1427,0,'1',1,'1378/1394/2045/1427/2097',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2098,'2097',1937,0,'1',1,'1387/1792/1836/1937/2098',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2099,'2098',1428,0,'1',1,'1378/1394/2045/1428/2099',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2101,'2100',1599,0,'1',1,'1380/1522/1599/2101',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2102,'2101',1599,0,'1',1,'1380/1522/1599/2102',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2103,'2102',1599,0,'1',1,'1380/1522/1599/2103',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2104,'2103',1599,0,'1',1,'1380/1522/1599/2104',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2105,'2104',1599,0,'1',1,'1380/1522/1599/2105',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2106,'2105',1599,0,'1',1,'1380/1522/1599/2106',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2107,'2106',1599,0,'1',1,'1380/1522/1599/2107',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2108,'2107',2036,0,'1',1,'1378/1394/2046/2036/2108',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2109,'2108',1606,0,'1',1,'1380/1523/1606/2109',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2110,'2109',1445,0,'1',1,'1378/1394/2046/1445/2110',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2111,'2110',2049,0,'1',1,'1378/1394/2046/2049/2111',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2112,'2111',1420,0,'1',1,'1378/1394/1420/2112',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2113,'2112',2051,0,'1',1,'1378/1394/2046/2051/2113',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2116,'2115',1777,0,'1',1,'1385/1765/1777/2116',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2120,'2119',1383,0,'1',1,'1383/2120',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2121,'2120',2120,0,'1',1,'1383/2120/2121',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2124,'2123',2048,0,'1',1,'1378/1394/2046/2048/2124',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2125,'2124',1780,0,'1',1,'1386/1780/2125',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2126,'2125',2128,0,'1',1,'1386/1780/2125/2128/2126',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2127,'2126',2128,0,'1',1,'1386/1780/2125/2128/2127',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2128,'2127',2125,0,'1',1,'1386/1780/2125/2128',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2129,'2128',1758,0,'1',1,'1385/1758/2129',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2130,'2129',2129,0,'1',1,'1385/1758/2129/2130',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2131,'2130',2129,0,'1',1,'1385/1758/2129/2131',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2132,'2131',1694,0,'1',1,'1383/1694/2132',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2135,'2134',1378,0,'1',1,'1378/2135',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2136,'2135',2135,0,'1',1,'1378/2135/2136',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2137,'2136',1608,0,'1',1,'1380/1523/1608/2137',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2139,'2138',2140,0,'1',1,'1381/2022/1621/1639/2140/2139',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2140,'2139',1639,0,'1',1,'1381/2022/1621/1639/2140',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2141,'2140',1639,0,'1',1,'1381/2022/1621/1639/2141',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2142,'2141',1397,0,'1',1,'1378/1397/2142',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2144,'2143',1917,0,'1',1,'1387/1792/1833/1917/2144',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2146,'2145',2158,0,'1',1,'1378/1394/2147/2158/2146',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2147,'2146',1394,0,'1',1,'1378/1394/2147',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2148,'2147',2158,0,'1',1,'1378/1394/2147/2158/2148',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2150,'2149',2157,0,'1',1,'1378/1394/2147/2157/2150',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2152,'2151',2147,0,'1',1,'1378/1394/2147/2152',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2153,'2152',2147,0,'1',1,'1378/1394/2147/2153',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2154,'2153',2147,0,'1',1,'1378/1394/2147/2154',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2155,'2154',2147,0,'1',1,'1378/1394/2147/2155',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2156,'2155',2147,0,'1',1,'1378/1394/2147/2156',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2157,'2156',2147,0,'1',1,'1378/1394/2147/2157',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2158,'2157',2147,0,'1',1,'1378/1394/2147/2158',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2159,'2158',1399,0,'1',1,'1378/1399/2159',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2160,'2159',1399,0,'1',1,'1378/1399/2160',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2161,'2160',1399,0,'1',1,'1378/1399/2161',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2162,'2161',1526,0,'1',1,'1380/1515/1526/2162',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2163,'2162',1526,0,'1',1,'1380/1515/1526/2163',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2164,'2163',1515,0,'1',1,'1380/1515/2164',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2165,'2164',1515,0,'1',1,'1380/1515/2165',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2166,'2165',1522,0,'1',1,'1380/1522/2166',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2167,'2166',1520,0,'1',1,'1380/1520/2167',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2168,'2167',1520,0,'1',1,'1380/1520/2168',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2169,'2168',1520,0,'1',1,'1380/1520/2169',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2170,'2169',1378,0,'1',1,'1378/2170',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2171,'2170',1522,0,'1',1,'1380/1522/2171',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2172,'2171',2170,0,'1',1,'1378/2170/2172',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2174,'2173',1993,0,'1',1,'1387/1793/1843/1993/2174',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2175,'2174',1401,0,'1',1,'1378/1401/2175',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2177,'2176',1389,0,'1',1,'1378/1389/2177',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2179,'2178',2359,0,'1',1,'1378/1399/2160/1490/2359/2179',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2180,'2179',1618,0,'1',1,'1381/1618/2180',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2181,'2180',2135,0,'1',1,'1378/2135/2181',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2182,'2181',1405,0,'1',1,'1378/1390/1405/2182',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2183,'2182',1621,0,'1',1,'1381/2022/1621/2183',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2184,'2183',1405,0,'1',1,'1378/1390/1405/2184',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2185,'2184',1400,0,'1',1,'1378/1400/2185',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2186,'2185',1400,0,'1',1,'1378/1400/2186',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2191,'2190',1612,0,'1',1,'1381/1612/2191',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2192,'2191',2185,0,'1',1,'1378/1400/2185/2192',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2193,'2192',2047,0,'1',1,'1378/1394/2046/2047/2193',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2194,'2193',2049,0,'1',1,'1378/1394/2046/2049/2194',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2196,'2195',1733,0,'1',1,'1384/1733/2196',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2197,'2196',2196,0,'1',1,'1384/1733/2196/2197',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2198,'2197',2197,0,'1',1,'1384/1733/2196/2197/2198',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2200,'2199',1378,0,'1',1,'1378/2200',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2201,'2200',2200,0,'1',1,'1378/2200/2201',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2203,'2202',1386,0,'1',1,'1386/2203',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2205,'2204',1780,0,'1',1,'1386/1780/2205',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2206,'2205',2205,0,'1',1,'1386/1780/2205/2206',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2207,'2206',2205,0,'1',1,'1386/1780/2205/2207',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2212,'2211',2205,0,'1',1,'1386/1780/2205/2212',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2214,'2213',1613,0,'1',1,'1381/2022/1613/2214',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2215,'2214',2214,0,'1',1,'1381/2022/1613/2214/2215',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2216,'2215',2214,0,'1',1,'1381/2022/1613/2214/2216',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2217,'2216',1635,0,'1',1,'1381/2022/1621/1635/2217',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2218,'2217',1638,0,'1',1,'1381/2022/1621/1638/2218',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2219,'2218',1621,0,'1',1,'1381/2022/1621/2219',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2220,'2219',2219,0,'1',1,'1381/2022/1621/2219/2220',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2221,'2220',2219,0,'1',1,'1381/2022/1621/2219/2221',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2222,'2221',1615,0,'1',1,'1381/2022/1615/2222',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2223,'2222',1631,0,'1',1,'1381/2022/1621/1631/2223',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2224,'2223',2125,0,'1',1,'1386/1780/2125/2224',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2225,'2224',2125,0,'1',1,'1386/1780/2125/2225',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2226,'2225',1408,0,'1',1,'1378/1390/1408/2226',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2227,'2226',1764,0,'1',1,'1385/1764/2227',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2228,'2227',2368,0,'1',1,'1378/1399/2160/1489/2368/2228',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2229,'2228',1489,0,'1',1,'1378/1399/2160/1489/2229',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2231,'2230',1486,0,'1',1,'1378/1399/2160/1486/2231',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2232,'2231',1401,0,'1',1,'1378/1401/2232',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2233,'2232',1490,0,'1',1,'1378/1399/2160/1490/2233',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2235,'2234',1396,0,'1',1,'1378/1396/2235',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2236,'2235',1613,0,'1',1,'1381/2022/1613/2236',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2237,'2236',1405,0,'1',1,'1378/1390/1405/2237',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2239,'2238',1405,0,'1',1,'1378/1390/1405/2239',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2240,'2239',1402,0,'1',1,'1378/1390/1402/2240',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2242,'2241',1490,0,'1',1,'1378/1399/2160/1490/2242',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2245,'2244',2359,0,'1',1,'1378/1399/2160/1490/2359/2245',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2246,'2245',1401,0,'1',1,'1378/1401/2246',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2248,'2247',1490,0,'1',1,'1378/1399/2160/1490/2248',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2250,'2249',1490,0,'1',1,'1378/1399/2160/1490/2250',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2252,'2251',1525,0,'1',1,'1380/1515/1525/2252',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2253,'2252',2252,0,'1',1,'1380/1515/1525/2252/2253',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2254,'2253',1545,0,'1',1,'1380/1517/1545/2254',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2255,'2254',1551,0,'1',1,'1380/1517/1551/2255',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2256,'2255',1605,0,'1',1,'1380/1523/1605/2256',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2257,'2256',1611,0,'1',1,'1380/1523/1611/2257',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2258,'2257',1611,0,'1',1,'1380/1523/1611/2258',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2259,'2258',1571,0,'1',1,'1380/1520/2167/1571/2259',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2260,'2259',1405,0,'1',1,'1378/1390/1405/2260',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2261,'2260',1683,0,'1',1,'1383/1683/2261',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2262,'2261',1766,0,'1',1,'1385/1766/2262',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2264,'2263',1731,0,'1',1,'1384/1731/2264',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2265,'2264',1551,0,'1',1,'1380/1517/1551/2265',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2266,'2265',2265,0,'1',1,'1380/1517/1551/2265/2266',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2267,'2266',2171,0,'1',1,'1380/1522/2171/2267',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2268,'2267',1525,1643,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2269,'2268',1525,0,'1',1,'1380/1515/1525/2269',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2270,'2269',1525,0,'1',1,'1380/1515/1525/2270',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2271,'2270',1551,0,'1',1,'1380/1517/1551/2271',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2272,'2271',2271,0,'1',1,'1380/1517/1551/2271/2272',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2273,'2272',2275,0,'1',1,'1380/1517/1551/2277/2275/2273',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2274,'2273',2275,0,'1',1,'1380/1517/1551/2277/2275/2274',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2275,'2274',2277,0,'1',1,'1380/1517/1551/2277/2275',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2276,'2275',1778,1643,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2277,'2276',1551,0,'1',1,'1380/1517/1551/2277',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2278,'2277',1549,0,'1',1,'1380/1517/1549/2278',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2279,'2278',1731,0,'1',1,'1384/1731/2279',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2280,'2279',1546,0,'1',1,'1380/1517/1546/2280',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2281,'2280',1546,0,'1',1,'1380/1517/1546/2281',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2282,'2281',1546,0,'1',1,'1380/1517/1546/2282',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2283,'2282',1571,0,'1',1,'1380/1520/2167/1571/2283',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2284,'2283',1555,0,'1',1,'1380/1518/1555/2284',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2285,'2284',1555,0,'1',1,'1380/1518/1555/2285',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2286,'2285',1555,0,'1',1,'1380/1518/1555/2286',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2287,'2286',1718,0,'1',1,'1383/1696/1718/2287',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2288,'2287',1982,0,'1',1,'1387/1793/1841/1982/2288',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2289,'2288',2203,0,'1',1,'1386/2203/2289',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2290,'2289',2172,0,'1',1,'1378/2170/2172/2290',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2291,'2290',1725,0,'1',1,'1384/1725/2291',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2294,'2293',1759,0,'1',1,'1385/1759/2294',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2295,'2294',1474,0,'1',1,'1378/1394/2045/1428/1474/2295',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2297,'2296',1648,0,'1',1,'1382/1648/2297',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2298,'2297',1656,0,'1',1,'1382/1656/2298',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2299,'2298',1731,0,'1',1,'1384/1731/2299',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2300,'2299',1471,0,'1',1,'1378/1394/2045/1426/1471/2300',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2302,'2301',1471,0,'1',1,'1378/1394/2045/1426/1471/2302',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2303,'2302',1764,0,'1',1,'1385/1764/2303',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2304,'2303',1916,0,'1',1,'1387/1792/1833/1916/2304',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2306,'2305',1396,0,'1',1,'1378/1396/2306',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2308,'2307',1780,0,'1',1,'1386/1780/2308',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2309,'2308',2308,0,'1',1,'1386/1780/2308/2309',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2310,'2309',1650,0,'1',1,'1382/1650/2310',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2311,'2310',1774,0,'1',1,'1385/1765/1774/2311',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2312,'2311',1805,0,'1',1,'1387/1789/1805/2312',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2313,'2312',2205,0,'1',1,'1386/1780/2205/2313',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2314,'2313',1711,0,'1',1,'1383/1687/1711/2314',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2315,'2314',1711,0,'1',1,'1383/1687/1711/2315',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2316,'2315',1711,0,'1',1,'1383/1687/1711/2316',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2317,'2316',1711,0,'1',1,'1383/1687/1711/2317',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2318,'2317',1621,0,'1',1,'1381/2022/1621/2318',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2320,'2319',1658,0,'1',1,'1382/1647/1658/2320',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2321,'2320',2320,0,'1',1,'1382/1647/1658/2320/2321',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2322,'2321',1658,0,'1',1,'1382/1647/1658/2322',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2326,'2325',1785,0,'1',1,'1386/1785/2326',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2327,'2326',1764,0,'1',1,'1385/1764/2327',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2328,'2327',1496,0,'1',1,'1379/1496/2328',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2329,'2328',1496,0,'1',1,'1379/1496/2329',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2330,'2329',2032,0,'1',1,'1382/1653/2032/2330',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2332,'2331',1513,0,'1',1,'1379/1497/1513/2332',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2335,'2334',1655,0,'1',1,'1382/1655/2335',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2336,'2335',1770,0,'1',1,'1385/1770/2336',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2337,'2336',2336,0,'1',1,'1385/1770/2336/2337',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2338,'2337',2185,0,'1',1,'1378/1400/2185/2338',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2339,'2338',2185,0,'1',1,'1378/1400/2185/2339',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2340,'2339',2185,0,'1',1,'1378/1400/2185/2340',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2341,'2340',1657,0,'1',1,'1382/1657/2341',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2342,'2341',1396,0,'1',1,'1378/1396/2342',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2343,'2342',1513,0,'1',1,'1379/1497/1513/2343',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2345,'2344',1495,0,'1',1,'1379/1495/2345',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2346,'2345',1388,0,'1',1,'1378/1388/2346',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2347,'2346',1656,0,'1',1,'1382/1656/2347',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2348,'2347',1686,0,'1',1,'1383/1686/2348',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2349,'2348',1648,0,'1',1,'1382/1648/2349',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2350,'2349',2308,0,'1',1,'1386/1780/2308/2350',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2352,'2351',1703,0,'1',1,'1383/1682/1703/2352',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2353,'2352',1490,0,'1',1,'1378/1399/2160/1490/2353',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2354,'2353',1780,0,'1',1,'1386/1780/2354',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2356,'2355',2359,0,'1',1,'1378/1399/2160/1490/2359/2356',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2358,'2357',1490,0,'1',1,'1378/1399/2160/1490/2358',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2359,'2358',1490,0,'1',1,'1378/1399/2160/1490/2359',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2361,'2360',2125,0,'1',1,'1386/1780/2125/2361',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2362,'2361',1490,0,'1',1,'1378/1399/2160/1490/2362',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2364,'2363',1490,0,'1',1,'1378/1399/2160/1490/2364',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2366,'2365',1490,0,'1',1,'1378/1399/2160/1490/2366',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2368,'2367',1489,0,'1',1,'1378/1399/2160/1489/2368',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2369,'2368',2308,0,'1',1,'1386/1780/2308/2369',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2371,'2370',1771,0,'1',1,'1385/1771/2371',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2372,'2371',1662,0,'1',1,'1382/1647/1662/2372',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2373,'2372',1648,0,'1',1,'1382/1648/2373',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2374,'2373',1656,0,'1',1,'1382/1656/2374',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2375,'2374',1688,0,'1',1,'1383/1684/1688/2375',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2376,'2375',1650,0,'1',1,'1382/1650/2376',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2377,'2376',2125,0,'1',1,'1386/1780/2125/2377',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2378,'2377',1758,0,'1',1,'1385/1758/2378',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2380,'2379',1633,0,'1',1,'1381/2022/1621/1633/2380',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2381,'2380',1400,0,'1',1,'1378/1400/2381',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2382,'2381',2185,0,'1',1,'1378/1400/2185/2382',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2383,'2382',1613,0,'1',1,'1381/2022/1613/2383',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2384,'2383',2205,0,'1',1,'1386/1780/2205/2384',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2385,'2384',2384,0,'1',1,'1386/1780/2205/2384/2385',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2386,'2385',2205,0,'1',1,'1386/1780/2205/2386',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2387,'2386',2386,0,'1',1,'1386/1780/2205/2386/2387',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2388,'2387',2386,0,'1',1,'1386/1780/2205/2386/2388',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2391,'2390',2205,0,'1',1,'1386/1780/2205/2391',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2394,'2393',1652,0,'1',1,'1382/1652/2394',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2395,'2394',1652,0,'1',1,'1382/1652/2395',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2396,'2395',2203,0,'1',1,'1386/2203/2396',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2397,'2396',1780,0,'1',1,'1386/1780/2397',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2399,'2398',1693,0,'1',1,'1383/1693/2399',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2400,'2399',2399,0,'1',1,'1383/1693/2399/2400',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2402,'2401',1721,0,'1',1,'1383/1696/1721/2402',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2403,'2402',1787,0,'1',1,'1386/1787/2403',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2404,'2403',2120,0,'1',1,'1383/2120/2404',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2405,'2404',1731,0,'1',1,'1384/1731/2405',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2406,'2405',1656,0,'1',1,'1382/1656/2406',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2407,'2406',1729,0,'1',1,'1384/1729/2407',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2408,'2407',2205,0,'1',1,'1386/1780/2205/2408',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2410,'2409',1392,0,'1',1,'1378/1392/2410',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2411,'2410',2205,0,'1',1,'1386/1780/2205/2411',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2412,'2411',2411,0,'1',1,'1386/1780/2205/2411/2412',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2413,'2412',1780,0,'1',1,'1386/1780/2413',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2414,'2413',2125,0,'1',1,'1386/1780/2125/2414',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2416,'2415',2373,0,'1',1,'1382/1648/2373/2416',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2418,'2417',2373,0,'1',1,'1382/1648/2373/2418',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2420,'2419',1616,0,'1',1,'1381/2022/1616/2420',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2422,'2421',1780,0,'1',1,'1386/1780/2422',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2423,'2422',2125,0,'1',1,'1386/1780/2125/2423',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2424,'2423',2125,0,'1',1,'1386/1780/2125/2424',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2425,'2424',2185,0,'1',1,'1378/1400/2185/2425',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2426,'2425',2185,0,'1',1,'1378/1400/2185/2426',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2427,'2426',2185,0,'1',1,'1378/1400/2185/2427',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2428,'2427',1657,0,'1',1,'1382/1657/2428',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2429,'2428',2428,0,'1',1,'1382/1657/2428/2429',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2430,'2429',2429,0,'1',1,'1382/1657/2428/2429/2430',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2431,'2430',1466,0,'1',1,'1378/1394/2046/1466/2431',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2432,'2431',1765,0,'1',1,'1385/1765/2432',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2442,'2441',1466,0,'1',1,'1378/1394/2046/1466/2442',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2444,'2443',1466,0,'1',1,'1378/1394/2046/1466/2444',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2446,'2445',1620,0,'1',1,'1381/1620/2446',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2447,'2446',1616,0,'1',1,'1381/2022/1616/2447',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2448,'2447',2447,0,'1',1,'1381/2022/1616/2447/2448',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2449,'2448',1616,0,'1',1,'1381/2022/1616/2449',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2451,'2450',2022,0,'1',1,'1381/2022/2451',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2452,'2451',2451,0,'1',1,'1381/2022/2451/2452',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2454,'2453',2451,0,'1',1,'1381/2022/2451/2454',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2456,'2455',1394,0,'1',1,'1378/1394/2456',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2457,'2456',1618,0,'1',1,'1381/1618/2457',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2458,'2457',2457,0,'1',1,'1381/1618/2457/2458',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2460,'2459',1618,0,'1',1,'1381/1618/2460',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2461,'2460',1612,0,'1',1,'1381/1612/2461',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2462,'2461',2036,0,'1',1,'1378/1394/2046/2036/2462',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2463,'2462',1455,0,'1',1,'1378/1394/2046/1455/2463',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2465,'2464',1765,0,'1',1,'1385/1765/2465',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2466,'2465',2465,0,'1',1,'1385/1765/2465/2466',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2467,'2466',2465,0,'1',1,'1385/1765/2465/2467',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2469,'2468',2457,0,'1',1,'1381/1618/2457/2469',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2471,'2470',2472,0,'1',1,'1381/1618/2472/2471',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2472,'2471',1618,0,'1',1,'1381/1618/2472',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2473,'2472',2457,0,'1',1,'1381/1618/2457/2473',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2475,'2474',1618,0,'1',1,'1381/1618/2475',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2476,'2475',1389,0,'1',1,'1378/1389/2476',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2477,'2476',1716,0,'1',1,'1383/1696/1716/2477',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2478,'2477',2086,0,'1',1,'1379/1495/1503/2086/2478',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2479,'2478',1420,0,'1',1,'1378/1394/1420/2479',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2480,'2479',1726,0,'1',1,'1384/1726/2480',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2481,'2480',1726,2480,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2482,'2481',1726,0,'1',1,'1384/1726/2482',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2483,'2482',1726,2482,'1',1,'1384/1726/2483',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2484,'ORPHELINS',1,0,'0',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2485,'2484',1764,0,'1',1,'1385/1764/2485',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2486,'2485',1764,2485,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2487,'2486',1764,0,'1',1,'1385/1764/2487',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2488,'2487',1379,0,'1',1,'1379/2488',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2489,'2488',2488,0,'1',1,'1379/2488/2489',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2490,'2489',2489,0,'1',1,'1379/2488/2489/2490',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2491,'2490',1686,0,'1',1,'1383/1686/2491',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2492,'2491',1684,0,'1',1,'1383/1684/2492',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2493,'2492',1729,0,'1',1,'1384/1729/2493',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2494,'2493',2488,0,'1',1,'1379/2488/2494',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2495,'2494',1729,0,'1',1,'1384/1729/2495',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2496,'2495',1686,0,'1',1,'1383/1686/2496',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2497,'2496',1686,0,'1',1,'1383/1686/2497',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2498,'2497',1684,0,'1',1,'1383/1684/2498',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2499,'2498',2498,0,'1',1,'1383/1684/2498/2499',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2500,'2499',2498,0,'1',1,'1383/1684/2498/2500',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2501,'2500',2492,2502,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2502,'2501',1787,0,'1',1,'1386/1787/2502',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2503,'2502',1787,0,'1',1,'1386/1787/2503',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2504,'2503',2502,0,'1',1,'1386/1787/2502/2504',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2505,'2504',2503,0,'1',1,'1386/1787/2503/2505',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2506,'2505',2503,0,'1',1,'1386/1787/2503/2506',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2507,'2506',2505,0,'1',1,'1386/1787/2503/2505/2507',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2508,'2507',1765,0,'1',1,'1385/1765/2508',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2509,'2508',2508,0,'1',1,'1385/1765/2508/2509',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2510,'2509',1767,0,'1',1,'1385/1767/2510',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2511,'2510',2484,1670,'1',1,'',0,0);
INSERT INTO noeuds (id_noeud, autorite, num_parent, num_renvoi_voir, visible, num_thesaurus, path, authority_import_denied, not_use_in_indexation) VALUES (2512,'NONCLASSES',1,0,'0',1,'',0,0);
/*!40000 ALTER TABLE noeuds ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_children_records`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_children_records (
  child_record_num_record int(10) unsigned NOT NULL DEFAULT '0',
  child_record_num_formation int(10) unsigned NOT NULL DEFAULT '0',
  child_record_num_type int(10) unsigned NOT NULL DEFAULT '0',
  child_record_num_musicstand int(10) unsigned NOT NULL DEFAULT '0',
  child_record_num_instrument int(10) unsigned NOT NULL DEFAULT '0',
  child_record_effective int(10) unsigned NOT NULL DEFAULT '0',
  child_record_order int(10) unsigned NOT NULL DEFAULT '0',
  child_record_other varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  child_record_num_voice int(10) unsigned NOT NULL DEFAULT '0',
  child_record_num_workshop int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (child_record_num_record)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_children_records`
--

LOCK TABLES nomenclature_children_records WRITE;
/*!40000 ALTER TABLE nomenclature_children_records DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_children_records ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_exotic_instruments`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_exotic_instruments (
  id_exotic_instrument int(10) unsigned NOT NULL AUTO_INCREMENT,
  exotic_instrument_num_nomenclature int(10) unsigned NOT NULL DEFAULT '0',
  exotic_instrument_num_instrument int(10) unsigned NOT NULL DEFAULT '0',
  exotic_instrument_number int(10) unsigned NOT NULL DEFAULT '0',
  exotic_instrument_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_exotic_instrument)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_exotic_instruments`
--

LOCK TABLES nomenclature_exotic_instruments WRITE;
/*!40000 ALTER TABLE nomenclature_exotic_instruments DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_exotic_instruments ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_exotic_other_instruments`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_exotic_other_instruments (
  id_exotic_other_instrument int(10) unsigned NOT NULL AUTO_INCREMENT,
  exotic_other_instrument_num_exotic_instrument int(10) unsigned NOT NULL DEFAULT '0',
  exotic_other_instrument_num_instrument int(10) unsigned NOT NULL DEFAULT '0',
  exotic_other_instrument_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_exotic_other_instrument)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_exotic_other_instruments`
--

LOCK TABLES nomenclature_exotic_other_instruments WRITE;
/*!40000 ALTER TABLE nomenclature_exotic_other_instruments DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_exotic_other_instruments ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_families`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_families (
  id_family int(10) unsigned NOT NULL AUTO_INCREMENT,
  family_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  family_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_family)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_families`
--

LOCK TABLES nomenclature_families WRITE;
/*!40000 ALTER TABLE nomenclature_families DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_families ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_formations`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_formations (
  id_formation int(10) unsigned NOT NULL AUTO_INCREMENT,
  formation_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  formation_nature int(10) unsigned NOT NULL DEFAULT '0',
  formation_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_formation)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_formations`
--

LOCK TABLES nomenclature_formations WRITE;
/*!40000 ALTER TABLE nomenclature_formations DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_formations ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_instruments`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_instruments (
  id_instrument int(10) unsigned NOT NULL AUTO_INCREMENT,
  instrument_code varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  instrument_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  instrument_musicstand_num int(10) unsigned NOT NULL DEFAULT '0',
  instrument_standard int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_instrument)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_instruments`
--

LOCK TABLES nomenclature_instruments WRITE;
/*!40000 ALTER TABLE nomenclature_instruments DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_instruments ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_musicstands`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_musicstands (
  id_musicstand int(10) unsigned NOT NULL AUTO_INCREMENT,
  musicstand_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  musicstand_famille_num int(10) unsigned NOT NULL DEFAULT '0',
  musicstand_division int(10) unsigned NOT NULL DEFAULT '0',
  musicstand_order int(10) unsigned NOT NULL DEFAULT '0',
  musicstand_workshop int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_musicstand)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_musicstands`
--

LOCK TABLES nomenclature_musicstands WRITE;
/*!40000 ALTER TABLE nomenclature_musicstands DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_musicstands ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_notices_nomenclatures`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_notices_nomenclatures (
  id_notice_nomenclature int(10) unsigned NOT NULL AUTO_INCREMENT,
  notice_nomenclature_num_notice int(10) unsigned NOT NULL DEFAULT '0',
  notice_nomenclature_num_formation int(10) unsigned NOT NULL DEFAULT '0',
  notice_nomenclature_num_type int(10) unsigned NOT NULL DEFAULT '0',
  notice_nomenclature_label varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notice_nomenclature_abbreviation text COLLATE utf8_unicode_ci NOT NULL,
  notice_nomenclature_notes text COLLATE utf8_unicode_ci NOT NULL,
  notice_nomenclature_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_notice_nomenclature)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_notices_nomenclatures`
--

LOCK TABLES nomenclature_notices_nomenclatures WRITE;
/*!40000 ALTER TABLE nomenclature_notices_nomenclatures DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_notices_nomenclatures ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_types`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_types (
  id_type int(10) unsigned NOT NULL AUTO_INCREMENT,
  type_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  type_formation_num int(10) unsigned NOT NULL DEFAULT '0',
  type_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_type)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_types`
--

LOCK TABLES nomenclature_types WRITE;
/*!40000 ALTER TABLE nomenclature_types DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_types ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_voices`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_voices (
  id_voice int(10) unsigned NOT NULL AUTO_INCREMENT,
  voice_code varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  voice_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  voice_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_voice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_voices`
--

LOCK TABLES nomenclature_voices WRITE;
/*!40000 ALTER TABLE nomenclature_voices DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_voices ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_workshops`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_workshops (
  id_workshop int(10) unsigned NOT NULL AUTO_INCREMENT,
  workshop_label varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  workshop_num_nomenclature int(10) unsigned NOT NULL DEFAULT '0',
  workshop_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_workshop)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_workshops`
--

LOCK TABLES nomenclature_workshops WRITE;
/*!40000 ALTER TABLE nomenclature_workshops DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_workshops ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `nomenclature_workshops_instruments`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE nomenclature_workshops_instruments (
  id_workshop_instrument int(10) unsigned NOT NULL AUTO_INCREMENT,
  workshop_instrument_num_workshop int(10) unsigned NOT NULL DEFAULT '0',
  workshop_instrument_num_instrument int(10) unsigned NOT NULL DEFAULT '0',
  workshop_instrument_number int(10) unsigned NOT NULL DEFAULT '0',
  workshop_instrument_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_workshop_instrument)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `nomenclature_workshops_instruments`
--

LOCK TABLES nomenclature_workshops_instruments WRITE;
/*!40000 ALTER TABLE nomenclature_workshops_instruments DISABLE KEYS */;
/*!40000 ALTER TABLE nomenclature_workshops_instruments ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notice_onglet`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notice_onglet (
  id_onglet int(10) unsigned NOT NULL AUTO_INCREMENT,
  onglet_name varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (id_onglet)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notice_onglet`
--

LOCK TABLES notice_onglet WRITE;
/*!40000 ALTER TABLE notice_onglet DISABLE KEYS */;
/*!40000 ALTER TABLE notice_onglet ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notice_statut`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notice_statut (
  id_notice_statut smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  gestion_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  opac_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  notice_visible_opac tinyint(1) NOT NULL DEFAULT '1',
  notice_visible_gestion tinyint(1) NOT NULL DEFAULT '1',
  expl_visible_opac tinyint(1) NOT NULL DEFAULT '1',
  class_html varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notice_visible_opac_abon tinyint(1) NOT NULL DEFAULT '0',
  expl_visible_opac_abon int(10) unsigned NOT NULL DEFAULT '0',
  explnum_visible_opac int(1) unsigned NOT NULL DEFAULT '1',
  explnum_visible_opac_abon int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_notice_statut)
) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notice_statut`
--

LOCK TABLES notice_statut WRITE;
/*!40000 ALTER TABLE notice_statut DISABLE KEYS */;
INSERT INTO notice_statut (id_notice_statut, gestion_libelle, opac_libelle, notice_visible_opac, notice_visible_gestion, expl_visible_opac, class_html, notice_visible_opac_abon, expl_visible_opac_abon, explnum_visible_opac, explnum_visible_opac_abon) VALUES (1,'Sans statut particulier','',1,1,1,'statutnot1',0,0,1,0);
INSERT INTO notice_statut (id_notice_statut, gestion_libelle, opac_libelle, notice_visible_opac, notice_visible_gestion, expl_visible_opac, class_html, notice_visible_opac_abon, expl_visible_opac_abon, explnum_visible_opac, explnum_visible_opac_abon) VALUES (2,'Prêt express','',0,1,0,'statutnot2',0,0,0,0);
INSERT INTO notice_statut (id_notice_statut, gestion_libelle, opac_libelle, notice_visible_opac, notice_visible_gestion, expl_visible_opac, class_html, notice_visible_opac_abon, expl_visible_opac_abon, explnum_visible_opac, explnum_visible_opac_abon) VALUES (3,'En commande','',0,1,0,'statutnot4',0,0,0,0);
INSERT INTO notice_statut (id_notice_statut, gestion_libelle, opac_libelle, notice_visible_opac, notice_visible_gestion, expl_visible_opac, class_html, notice_visible_opac_abon, expl_visible_opac_abon, explnum_visible_opac, explnum_visible_opac_abon) VALUES (4,'Documents numériques (réservés aux abonnés)','',1,1,0,'statutnot6',0,0,1,1);
INSERT INTO notice_statut (id_notice_statut, gestion_libelle, opac_libelle, notice_visible_opac, notice_visible_gestion, expl_visible_opac, class_html, notice_visible_opac_abon, expl_visible_opac_abon, explnum_visible_opac, explnum_visible_opac_abon) VALUES (5,'Invisible à l\'OPAC','',0,1,0,'statutnot20',0,0,0,0);
/*!40000 ALTER TABLE notice_statut ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notice_tpl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notice_tpl (
  notpl_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  notpl_name varchar(256) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notpl_code mediumtext COLLATE utf8_unicode_ci NOT NULL,
  notpl_comment varchar(256) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notpl_id_test int(10) unsigned NOT NULL DEFAULT '0',
  notpl_show_opac int(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (notpl_id)
) ENGINE=MyISAM AUTO_INCREMENT=10 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notice_tpl`
--

LOCK TABLES notice_tpl WRITE;
/*!40000 ALTER TABLE notice_tpl DISABLE KEYS */;
INSERT INTO notice_tpl (notpl_id, notpl_name, notpl_code, notpl_comment, notpl_id_test, notpl_show_opac) VALUES (1,'Portail - liste de notices','','',106,0);
INSERT INTO notice_tpl (notpl_id, notpl_name, notpl_code, notpl_comment, notpl_id_test, notpl_show_opac) VALUES (9,'permalink','','',130,0);
/*!40000 ALTER TABLE notice_tpl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notice_tplcode`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notice_tplcode (
  num_notpl int(10) unsigned NOT NULL DEFAULT '0',
  notplcode_localisation mediumint(8) NOT NULL DEFAULT '0',
  notplcode_typdoc char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  notplcode_niveau_biblio char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'm',
  notplcode_niveau_hierar char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  nottplcode_code mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_notpl,notplcode_localisation,notplcode_typdoc,notplcode_niveau_biblio)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notice_tplcode`
--

LOCK TABLES notice_tplcode WRITE;
/*!40000 ALTER TABLE notice_tplcode DISABLE KEYS */;
INSERT INTO notice_tplcode (num_notpl, notplcode_localisation, notplcode_typdoc, notplcode_niveau_biblio, notplcode_niveau_hierar, nottplcode_code) VALUES (9,0,'0','0','0','#permalink();');
INSERT INTO notice_tplcode (num_notpl, notplcode_localisation, notplcode_typdoc, notplcode_niveau_biblio, notplcode_niveau_hierar, nottplcode_code) VALUES (1,0,'0','m','0','<table border=\"0\" cellpadding=\"1\" cellspacing=\"5\">\r\n	<tbody>\r\n		<tr>\r\n			<td style=\"width:110px;text-align:center;\">\r\n\r\n<a href=\"#permalink();\">#if(#img_url();,<img src=\"#img_url();\" style=\"width:100px;\" />,<img src=\"./styles/pmb4/images/no_image.jpg\" style=\"width:100px;\" />);</a>\r\n\r\n                        </td>\r\n			<td style=\"text-align:left;\">\r\n\r\n\r\n<a href=\"#permalink();\"><font size=3>#title();#a_empty(#complement_title();, : );</font></a>\r\n\r\n#str_replace(  , ,#a_empty(#authors_by_type_with_tpl(1,3,\\, ,\\, ,0,0,70\\,71\\,72,{rejete} {name});,<br />de ););\r\n\r\n#a_empty(#resume();,<br /><br />);\r\n\r\n                        </td>\r\n		</tr>\r\n	</tbody>\r\n</table>');
INSERT INTO notice_tplcode (num_notpl, notplcode_localisation, notplcode_typdoc, notplcode_niveau_biblio, notplcode_niveau_hierar, nottplcode_code) VALUES (1,0,'0','a','0','<table border=\"0\" cellpadding=\"1\" cellspacing=\"5\">\r\n	<tbody>\r\n		<tr>\r\n			<td style=\"width:110px;text-align:center;\">\r\n\r\n<a href=\"#permalink();\">#if(#img_url();,<img src=\"#img_url();\" style=\"width:100px;\" />,<img src=\"./styles/pmb4/images/no_image.jpg\" style=\"width:100px;\" />);</a>\r\n\r\n                        </td>\r\n			<td style=\"text-align:left;\">\r\n\r\n<a href=\"#permalink();\"><font size=3>#title();#a_empty(#complement_title();, : );</font></a>\r\n\r\n#str_replace(  , ,#a_empty(#authors_by_type_with_tpl(1,3,\\, ,\\, ,0,0,70\\,71\\,72,{rejete} {name});,<br />de ););\r\n\r\n<br />\r\n\r\n<i>In #nom_revue();#a_empty(#numero_bulletin();,\\, ); (#if(#extract_path((.*) [(],#date_bulletin(););,#extract_path((.*) [(],#date_bulletin(););,#date_bulletin(););)</i>\r\n\r\n#a_empty(#resume();,<br /><br />);\r\n\r\n                        </td>\r\n		</tr>\r\n	</tbody>\r\n</table>');
INSERT INTO notice_tplcode (num_notpl, notplcode_localisation, notplcode_typdoc, notplcode_niveau_biblio, notplcode_niveau_hierar, nottplcode_code) VALUES (1,0,'0','s','0','<table border=\"0\" cellpadding=\"1\" cellspacing=\"5\">\r\n	<tbody>\r\n		<tr>\r\n			<td style=\"width:110px;text-align:center;\">\r\n\r\n<a href=\"#permalink();\">#if(#img_url();,<img src=\"#img_url();\" style=\"width:100px;\" />,<img src=\"./styles/pmb4/images/no_image.jpg\" style=\"width:100px;\" />);</a>\r\n\r\n                        </td>\r\n			<td style=\"text-align:left;\">\r\n\r\n<a href=\"#permalink();\"><font size=3>#title();#a_empty(#complement_title();, : );</font></a>\r\n\r\n#a_empty(#resume();,<br /><br />);\r\n\r\n                        </td>\r\n		</tr>\r\n	</tbody>\r\n</table>');
INSERT INTO notice_tplcode (num_notpl, notplcode_localisation, notplcode_typdoc, notplcode_niveau_biblio, notplcode_niveau_hierar, nottplcode_code) VALUES (1,0,'0','b','0','<table border=\"0\" cellpadding=\"1\" cellspacing=\"5\">\r\n	<tbody>\r\n		<tr>\r\n			<td style=\"width:110px;text-align:center;\">\r\n\r\n<a href=\"#permalink();\">#if(#img_url();,<img src=\"#img_url();\" style=\"width:100px;\" />,<img src=\"./styles/pmb4/images/no_image.jpg\" style=\"width:100px;\" />);</a>\r\n\r\n                        </td>\r\n			<td style=\"text-align:left;\">\r\n\r\n<a href=\"#permalink();\"><font size=3>#extract_path((.*) [(],#title(););#a_empty(#complement_title();, : );</font></a>\r\n\r\n#str_replace(  , ,#a_empty(#authors_by_type_with_tpl(1,3,\\, ,\\, ,0,0,70\\,71\\,72,{rejete} {name});,<br />de ););\r\n\r\n<br />\r\n\r\n<i>Bulletin de #nom_revue();</i>\r\n\r\n#a_empty(#resume();,<br /><br />);\r\n\r\n                        </td>\r\n		</tr>\r\n	</tbody>\r\n</table>');
/*!40000 ALTER TABLE notice_tplcode ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices (
  notice_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  typdoc char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  tit1 mediumtext COLLATE utf8_unicode_ci,
  tit2 mediumtext COLLATE utf8_unicode_ci,
  tit3 mediumtext COLLATE utf8_unicode_ci,
  tit4 mediumtext COLLATE utf8_unicode_ci,
  tparent_id mediumint(8) unsigned NOT NULL DEFAULT '0',
  tnvol varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed1_id mediumint(8) unsigned NOT NULL DEFAULT '0',
  ed2_id mediumint(8) unsigned NOT NULL DEFAULT '0',
  coll_id mediumint(8) unsigned NOT NULL DEFAULT '0',
  subcoll_id mediumint(8) unsigned NOT NULL DEFAULT '0',
  `year` varchar(50) COLLATE utf8_unicode_ci DEFAULT NULL,
  nocoll varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  mention_edition varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `code` varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  npages varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ill varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  size varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  accomp varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  n_gen mediumtext COLLATE utf8_unicode_ci NOT NULL,
  n_contenu mediumtext COLLATE utf8_unicode_ci NOT NULL,
  n_resume mediumtext COLLATE utf8_unicode_ci NOT NULL,
  lien mediumtext COLLATE utf8_unicode_ci NOT NULL,
  eformat varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_l mediumtext COLLATE utf8_unicode_ci NOT NULL,
  indexint int(8) unsigned NOT NULL DEFAULT '0',
  index_serie text COLLATE utf8_unicode_ci,
  index_matieres mediumtext COLLATE utf8_unicode_ci NOT NULL,
  niveau_biblio char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'm',
  niveau_hierar char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  origine_catalogage int(8) unsigned NOT NULL DEFAULT '1',
  prix varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_n_gen mediumtext COLLATE utf8_unicode_ci,
  index_n_contenu mediumtext COLLATE utf8_unicode_ci,
  index_n_resume mediumtext COLLATE utf8_unicode_ci,
  index_sew mediumtext COLLATE utf8_unicode_ci,
  index_wew mediumtext COLLATE utf8_unicode_ci,
  statut int(5) NOT NULL DEFAULT '1',
  commentaire_gestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  create_date datetime NOT NULL DEFAULT '2005-01-01 00:00:00',
  update_date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  signature varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  thumbnail_url mediumblob NOT NULL,
  date_parution date NOT NULL DEFAULT '0000-00-00',
  opac_visible_bulletinage tinyint(3) unsigned NOT NULL DEFAULT '1',
  indexation_lang varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  map_echelle_num int(10) unsigned NOT NULL DEFAULT '0',
  map_projection_num int(10) unsigned NOT NULL DEFAULT '0',
  map_ref_num int(10) unsigned NOT NULL DEFAULT '0',
  map_equinoxe varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notice_is_new int(10) unsigned NOT NULL DEFAULT '0',
  notice_date_is_new datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  opac_serialcirc_demande tinyint(3) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (notice_id),
  KEY typdoc (typdoc),
  KEY tparent_id (tparent_id),
  KEY ed1_id (ed1_id),
  KEY ed2_id (ed2_id),
  KEY coll_id (coll_id),
  KEY subcoll_id (subcoll_id),
  KEY cb (`code`),
  KEY indexint (indexint),
  KEY sig_index (signature),
  KEY i_notice_n_biblio (niveau_biblio),
  KEY i_notice_n_hierar (niveau_hierar),
  KEY notice_eformat (eformat),
  KEY i_date_parution (date_parution),
  KEY i_not_statut (statut)
) ENGINE=MyISAM AUTO_INCREMENT=139 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices`
--

LOCK TABLES notices WRITE;
/*!40000 ALTER TABLE notices DISABLE KEYS */;
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (68,'i','Les perles et autres contes','','','',0,'',13,0,4,0,'2012','','','978-2-07-013600-1','','','14 cm','','','','Le symbole mystérieux d\'un collier qui a une perle de trop. La réalité crue qui vient anéantir le rêve et le bonheur offerts à une jeune aristocrate insouciante. L\'aventure, dans le port d\'Anvers, d\'un écrivain malheureux, qui fuit sa propre vie... Tels sont les thèmes et les personnages de ces trois contes. Et à travers eux, Karen Blixen nous démontre que le conte est bien l\'instrument privilégié de l\'exploration des mystères de la personnalité. Le doux velours du timbre d\'Anne Brochet nous transporte dans l\'univers mystérieux des contes de Karen Blixen. Une lecture posée qui met en mouvement l\'imagination de l\'auditeur. L\'écoute en classe de ces CD est autorisée par l\'éditeur','','','Livres lus en format CD',0,'',' livres lus format cd ','m','0',6,'15,90 eur','','',' symbole mysterieux collier qui perle trop realite crue qui vient aneantir reve bonheur offerts jeune aristocrate insouciante aventure dans port anvers ecrivain malheureux qui fuit sa propre vie tels sont themes personnages ces trois contes travers eux karen blixen nous demontre que conte est bien instrument privilegie exploration mysteres personnalite doux velours timbre anne brochet nous transporte dans univers mysterieux contes karen blixen lecture posee qui met mouvement imagination auditeur ecoute classe ces cd est autorisee par editeur ',' perles autres contes ','  Les perles et autres contes   ',1,'','2012-10-24 14:42:49','2012-10-24 15:08:13','0','','2012-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (69,'a','Contes des sages d\'Afrique','','','',0,'',6,0,5,0,'2004','','','978-2-02-068730-0','179 p.','ill. en coul., couv. ill.','18 cm','','','','','','','',0,'','','m','0',7,'15 EUR','','','',' contes sages afrique ','  Contes des sages d\'Afrique   ',1,'','2012-10-24 14:42:49','2012-10-24 14:16:37','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F35314D543836444D34394C2E5F534C3530305F41413330305F2E6A7067,'2004-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (70,'a','Sagesse d\'Afrique','','','paysages et pensées',0,'',7,0,0,0,'2008','','','978-2-8100-0117-0','1 vol. (160 p.)','ill. en coul., couv. ill. en coul.','23 x 29 cm','','Contient diverses pensées, poèmes et proverbes de différents auteurs\r\nIndex','','Présentation de l\'éditeur\r\nL\'Afrique se dévoile, au fil de magnifiques photographies accompagnées de pensées, de poèmes et de proverbes emplis de philosophie, à l\'image de ce continent dont la beauté invite à la médiation. Un voyage en terre d\'émerveillement, guidé par le regard de nombreux écrivains et d\'hommes engagés, pour découvrir un espace fascinant, ses paysages, sa faune et ses habitants. ','','','Afrique;Photographies',97,'',' afrique photographies ','m','0',7,'19,90 EUR',' contient diverses pensees poemes proverbes differents auteurs index ','',' presentation editeur afrique se devoile fil magnifiques photographies accompagnees pensees poemes proverbes emplis philosophie image ce continent dont beaute invite mediation voyage terre emerveillement guide par regard nombreux ecrivains hommes engages pour decouvrir espace fascinant ses paysages sa faune ses habitants ',' sagesse afrique paysages pensees ','  Sagesse d\'Afrique   paysages et pensées',1,'','2012-10-24 14:42:49','2012-12-12 14:05:39','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (71,'a','Afriques','','','',0,'',8,0,0,0,'2012','','','978-2-7541-0611-5','1 vol. (non paginé [395] p.)','tout en ill., couv. ill.','28 cm','','','','Depuis plus de vingt ans Raymond Depardon a parcouru tout le continent africain auquel il a consacré plusieurs films. Il a réalisé ainsi une grande quantité de photographies dont 350 inédites sont présentées dans cet ouvrage. Ces photographies couvrent toute l\'Afrique, à travers une présentation non pas par pays mais par associations originales. Ces associations privilégient un rythme soutenu, sans temps d\'arrêt, des enchaînements qui montrent la vie au travers de sujets très variés : portraits, villes, paysages, religions, activités sociales et métiers mais aussi des conflits et la misère. A travers ses photographies, exemptes de toute volonté d\'esthétiser son propos, Raymond Depardon ne livre aucun jugement sur l\'Afrique, aucune thèse. Ce qui relie entre elles ces prises de vue, c\'est l\'impulsion de l\'?il, simplement un regard de photographe et de grand voyageur sur les paysages et les hommes qui peuplent ce continent. Pourquoi des Afriques ? Depuis 1960, année de ma première rencontre avec le continent africain à l\'âge de dix-huit ans, et jusqu\'à mon dernier voyage cet hiver au Horar, je n\'ai cessé de photographier l\'Afrique. Mais que de lieux, de temps différents ! Une vie toute entière ne suffirait pas à prétendre connaître cette Afrique. Aujourd\'hui, les prétextes, les raisons de ces voyages sont oubliés. C\'est pour cela que j\'avais envie de faire ce livre, pour rendre la liberté à toutes ces photographies et enfin réunir toutes ces Afriques, celles des pistes, des sourires, des famines et des guerres civiles. Je voulais oser ces quatre cents pages de photographies sous respiration. Je voulais étouffer devant l\'immense Afrique, me trouver comme au bord d\'une route où nous serions en panne pour plusieurs jours, envahis, à rester silencieux et à écouter. Je me souviens de chaque lieu, de chaque temps. J\'ose le désordre, il le faut. Je réunis ces photographies prises pendant quarante-cinq ans de voyages en Afrique. Raymond Depardon','','','Afrique;Photographies',97,'',' afrique photographies ','m','0',8,'25 EUR','','',' depuis plus vingt ans raymond depardon parcouru tout continent africain auquel il consacre plusieurs films il realise ainsi grande quantite photographies dont 350 inedites sont presentees dans cet ouvrage ces photographies couvrent toute afrique travers presentation non pas par pays mais par associations originales ces associations privilegient rythme soutenu sans temps arret enchainements qui montrent vie travers sujets tres varies portraits villes paysages religions activites sociales metiers mais aussi conflits misere travers ses photographies exemptes toute volonte esthetiser son propos raymond depardon ne livre aucun jugement sur afrique aucune these ce qui relie entre elles ces prises vue c est impulsion il simplement regard photographe grand voyageur sur paysages hommes qui peuplent ce continent pourquoi afriques depuis 1960 annee ma premiere rencontre avec continent africain age dix huit ans jusqu mon dernier voyage cet hiver horar je n ai cesse photographier afrique mais que lieux temps differents vie toute entiere ne suffirait pas pretendre connaitre cette afrique aujourd hui pretextes raisons ces voyages sont oublies c est pour cela que j avais envie faire ce livre pour rendre liberte toutes ces photographies enfin reunir toutes ces afriques celles pistes sourires famines guerres civiles je voulais oser ces quatre cents pages photographies sous respiration je voulais etouffer devant immense afrique me trouver comme bord route ou nous serions panne pour plusieurs jours envahis rester silencieux ecouter je me souviens chaque lieu chaque temps j ose desordre il faut je reunis ces photographies prises pendant quarante cinq ans voyages afrique raymond depardon ',' afriques ','  Afriques   ',1,'','2012-10-24 14:42:49','2012-10-24 14:11:40','0','','2012-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (72,'m','Comptines et berceuses du baobab','','','l\'Afrique noire en 30 comptines',0,'',9,0,6,0,'2002','','','978-2-278-05277-6','1 livre (57 p.) - 1 disque compact (48 min 36 s)','ill. en coul., couv. ill. en coul','27 x 27 cm','','Contient des comptines de différents pays en différentes langues : Congo (mingala), Mali (bambara), Cameroun (bamena), Côte d\'Ivoire (bambara), Mauritanie (peul), Togo (mina), Sénégal (wolof), Rwanda (kinyarwanda), Guinée (susu), Mali (soninke), Centrafrique (sängö), Guinée-Conakry (susu), Congo (kikongo)','','Pour la première fois, une sélection de comptines et berceuses les plus représentatives de l\'Afrique noire, de la Cote-d\'Ivoire au Rwanda, dans la diversité des langues (lingala, wolof, bambara, peul, sango...) Chaque comptine est transcrite dans sa langue d\'origine et traduite en français. Les commentaires culturels sont regroupés à la fin de l\'ouvrage.','','','Comptines;Afrique centrale',79,'',' comptines afrique centrale ','m','0',7,'23,50 EUR',' contient comptines differents pays differentes langues congo mingala mali bambara cameroun bamena cote ivoire bambara mauritanie peul togo mina senegal wolof rwanda kinyarwanda guinee susu mali soninke centrafrique sango guinee conakry susu congo kikongo ','',' pour premiere fois selection comptines berceuses plus representatives afrique noire cote ivoire rwanda dans diversite langues lingala wolof bambara peul sango chaque comptine est transcrite dans sa langue origine traduite francais commentaires culturels sont regroupes fin ouvrage ',' comptines berceuses baobab afrique noire 30 comptines ','  Comptines et berceuses du baobab   l\'Afrique noire en 30 comptines',1,'','2012-10-24 14:42:50','2012-10-24 14:09:59','0','','2002-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (73,'a','Yakouba','','','',0,'',6,0,7,0,'2007','','','978-2-02-096487-6','','','22 cm','','','','','','','Jeunesse;Jeunesse - Albums;Lecteurs en herbe : 6-8 ans',0,'',' jeunesse jeunesse albums lecteurs herbe 6 8 ans ','m','0',6,'6,90 eur','','','',' yakouba ','  Yakouba   ',1,'','2012-10-24 14:42:50','2012-10-25 07:32:04','0','','2007-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (120,'a','Géo',NULL,'','',0,'',47,0,0,0,'1979-',NULL,'','0220-8245',NULL,NULL,NULL,NULL,'','','','http://www.geo.fr/','','',0,'','','s','1',1,'','','','',' geo ','  Géo   ',1,'','2012-10-24 17:19:23','2012-11-20 08:29:44','0',0x687474703A2F2F7777772E67656F2E66722F657874656E73696F6E2F67656F2F64657369676E2F67656F2F696D616765732F6C6F676F5F67656F2E706E67,'1979-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (74,'a','Rafara','','','un conte populaire africain',0,'',11,12,0,0,'2000','','','978-2-211-05694-6','Non paginé [40] p.','ill. en coul., couv. ill. en coul.','22 x 25 cm','','','','','','','',0,'','','m','0',7,'79 F : 12,04 EUR','','','',' rafara conte populaire africain ','  Rafara   un conte populaire africain',1,'','2012-10-24 14:42:50','2012-10-24 14:07:19','0','','2000-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (75,'a','Aya de Yopougon','','','',1,'2',13,0,8,0,'2006','','','978-2-07-057588-6','1 vol. (106-[12] p.)','ill. en noir et en coul., couv. ill. en coul.','25 cm','','Contient un lexique ivoirien-français, recettes culinaires, conseils de vie pratique','','','','','',0,' aya yopougon ','','m','0',7,'15,50 EUR',' contient lexique ivoirien francais recettes culinaires conseils vie pratique ','','',' aya yopougon 2 aya yopougon ',' aya yopougon  2 Aya de Yopougon   ',1,'','2012-10-24 14:42:50','2012-10-24 14:06:09','0','','2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (76,'a','Aya de Yopougon','','','',1,'1',13,0,8,0,'2005','','','978-2-07-057311-0','1 vol. (96-[6] p.)','ill. en noir et en coul., couv. ill. en coul.','25 cm','','','','Côte d\'Ivoire, 1978. Aya, dix-neuf ans, vit à Yopougon, un quartier populaire d\'Abidjan. Ça sent le début des vacances mais très vite les choses vont commencer à se gâter…«Dans les années 1970, la vie était douce en Côte d’Ivoire. Il y avait du travail, les hôpitaux étaient équipés et l’école était obligatoire. J’ai eu la chance de connaître cette époque insouciante, où les jeunes n’avaient pas à choisir leur camp trop vite, et ne se préoccupaient que de la vie courante : les études, les parents, les amours… Et c’est cela que je veux raconter dans \"Aya\", cette Afrique qui subsiste malgré tout car, comme on dit chez nous, «la vie continue»…» (Marguerite Abouet)','','','',0,' aya yopougon ','','m','0',7,'15 EUR','','',' cote ivoire 1978 aya dix neuf ans vit yopougon quartier populaire abidjan ca sent debut vacances mais tres vite choses vont commencer se gater dans annees 1970 vie etait douce cote ivoire il y avait travail hopitaux etaient equipes ecole etait obligatoire j ai eu chance connaitre cette epoque insouciante ou jeunes n avaient pas choisir leur camp trop vite ne se preoccupaient que vie courante etudes parents amours c est cela que je veux raconter dans aya cette afrique qui subsiste malgre tout car comme on dit chez nous vie continue marguerite abouet ',' aya yopougon 1 aya yopougon ',' aya yopougon  1 Aya de Yopougon   ',1,'','2012-10-24 14:42:50','2012-12-12 14:12:28','0','','2005-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (77,'a','African psycho','','','roman',0,'',14,0,0,0,'2003','','','978-2-84261-438-6','190 p.','','21 cm','','','','Quatrième de couverture\r\n« Que les choses soient claires : je ne souhaite pas être plus grand que l’Angoualima, ni me greffer des petits doigts, je veux être apprécié en fonction du résultat de mon geste criminel. Ne pouvant égaler les prouesses du Grand Maître, j\'aimerais au moins être considéré comme son fils spirituel. Pour cela, j\'en suis conscient, je dois encore travailler : tuer Germaine ce 29 décembre, c\'est-à-dire dans deux jours, n\'est qu\'une étape vers ce couronnement. »\r\n\r\nGrégoire Nakobomayo, orphelin, a grandi dans une ville industrielle de l\'Afrique post-coloniale. Accueilli quelque temps chez un couple instruit, il reçoit une éducation bourgeoise jusqu\'au jour où il plante son crayon dans l\'oeil du fils unique qui cherche à le violer. Obligé de fuir, il se réfugie dans le quartier le plus délabré de la ville et prend pour modèle \"Angoualima\", le célèbre serial killer qui depuis des années défie le pays, ses juges, ses flics et ses journalistes. Mais n\'est pas serial killer qui veut\r\nAvec humour -et.ironie-Alain Mabanckou conte les déboires d\'un psychopathe velléitaire et sans talent qui cherche dans la perversité un sens à sa vie.','','','',0,'','','m','0',8,'','','',' quatrieme couverture que choses soient claires je ne souhaite pas etre plus grand que angoualima ni me greffer petits doigts je veux etre apprecie fonction resultat mon geste criminel ne pouvant egaler prouesses grand maitre j aimerais moins etre considere comme son fils spirituel pour cela j suis conscient je dois encore travailler tuer germaine ce 29 decembre c est dire dans deux jours n est qu etape vers ce couronnement gregoire nakobomayo orphelin grandi dans ville industrielle afrique post coloniale accueilli quelque temps chez couple instruit il recoit education bourgeoise jusqu jour ou il plante son crayon dans oeil fils unique qui cherche violer oblige fuir il se refugie dans quartier plus delabre ville prend pour modele angoualima celebre serial killer qui depuis annees defie pays ses juges ses flics ses journalistes mais n est pas serial killer qui veut avec humour ironie alain mabanckou conte deboires psychopathe velleitaire sans talent qui cherche dans perversite sens sa vie ',' african psycho roman ','  African psycho   roman',1,'','2012-10-24 14:42:50','2012-12-12 12:23:20','0','','2003-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (78,'a','Soleil noir','','','',0,'',15,0,9,0,'2012','','','978-2-36413-008-1','1 vol. (172 p.)','','21 cm','','','','Présentation de l\'éditeur\r\nIl y eut un long il était une fois…\r\nD’une écriture libre, anarchiste, de la même veine qu’un chant de Joyce où la structure vole en éclat…\r\nIl était une fois, un jeune narrateur, qu’importe son nom, pendu par les pieds par un chef aussi noir que les origines de l’homme, tiraillé par la faim et qui rêve de Blanche Goodfather en train de se baigner nue du côté des Chutes du Rocher. Fin…\r\nIl était une fois un amour magnifique, Marie, aveugle, comme seul personnage lucide parmi ceux qui sont pris au piège de la violence et de l’absurdité d’un pays sous apartheid… De jeunes gens dans l’émeute, émeute du langage, émeute de la pensée, émeute du regard sur le monde, sur la vie, contre un système…\r\nSoleil noir (écrit en 1980) est ce roman éclaté où l’auteur balaie d’un revers de la main la frontière entre le réel et l’irréel, entre le conte et le témoignage, entre le rêve et la pensée, nous propulsant littéralement sans un monde aveuglé que seul le dérèglement du langage peut appréhender. Roman de la révolte, Soleil noir, publié pour la première fois en français, est un roman mythique de Marechera, écrit entre la rue et de fréquents séjours en prison. ','','','',0,'','','m','0',8,'14,40 EUR','','',' presentation editeur il y eut long il etait fois ecriture libre anarchiste meme veine qu chant joyce ou structure vole eclat il etait fois jeune narrateur qu importe son nom pendu par pieds par chef aussi noir que origines homme tiraille par faim qui reve blanche goodfather train se baigner nue cote chutes rocher fin il etait fois amour magnifique marie aveugle comme seul personnage lucide parmi ceux qui sont pris piege violence absurdite pays sous apartheid jeunes gens dans emeute emeute langage emeute pensee emeute regard sur monde sur vie contre systeme soleil noir ecrit 1980 est ce roman eclate ou auteur balaie revers main frontiere entre reel irreel entre conte temoignage entre reve pensee nous propulsant litteralement sans monde aveugle que seul dereglement langage peut apprehender roman revolte soleil noir publie pour premiere fois francais est roman mythique marechera ecrit entre rue frequents sejours prison ',' soleil noir ','  Soleil noir   ',1,'','2012-10-24 14:42:50','2012-12-12 14:07:58','0','','2012-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (79,'a','Les loups','','','',0,'',16,0,0,0,'2006','','','978-2-87767-470-6','1 vol. (non paginé [31] p.)','ill. en noir et en coul., jaquette ill. en coul.','27 cm','','','','Présentation de l\'éditeur\r\nC\'est l\'histoire d\'un lapin qui emprunte un ouvrage à la bibliothèque de son quartier, et qui découvre l\'extraordinaire, l\'incroyable pouvoir qu\'ont certains livres sur leur lecteur, parfois... ','','','',0,'','','m','0',7,'15 EUR','','',' presentation editeur c est histoire lapin qui emprunte ouvrage bibliotheque son quartier qui decouvre extraordinaire incroyable pouvoir qu ont certains livres sur leur lecteur parfois ',' loups ','  Les loups   ',1,'','2012-10-24 14:42:50','2012-12-12 13:59:43','0','','2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (80,'a','La bibliothécaire','','','',0,'',17,0,10,0,'2007','','','978-2-01-322406-2','192 p.','','17 cm','','','','Pourquoi la vielle dame qui habite en face de chez Guillaume écrit-elle très tard la nuit? Quelle est cette jeune fille qui ne sort de chez elle qu\'à le nuit tombée? Pour résoudre ces mystères, Guillaume se lance dans un fantastique voyage au pays des livres et de l\'écriture','','','Romans;Jeunesse;Littérature jeunesse;Albums;Jeunesse en format poche',0,'',' romans jeunesse litterature jeunesse albums jeunesse format poche ','m','0',6,'4,90 eur','','',' pourquoi vielle dame qui habite face chez guillaume ecrit elle tres tard nuit quelle est cette jeune fille qui ne sort chez elle qu nuit tombee pour resoudre ces mysteres guillaume se lance dans fantastique voyage pays livres ecriture ',' bibliothecaire ','  La bibliothécaire   ',1,'','2012-10-24 14:42:50','2012-10-24 14:01:02','0','','2007-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (81,'a','Jojo et le secret de la bibliothécaire','','','',2,'',18,0,0,0,'2006','','','978-2-87833-390-9','1 vol. (non paginé [30] p.)','ill. en coul., couv. ill. en coul.','20 cm','','','','La bibliothécaire a confié un terrible secret à Jojo et depuis, il n\'est plus le même...\r\nUne fiction pleine d\'humour sur l\'apprentissage de la lecture. A lire dès le CP.','','','',0,' jojo ','','m','0',7,'5,50 EUR','','',' bibliothecaire confie terrible secret jojo depuis il n est plus meme fiction pleine humour sur apprentissage lecture lire cp ',' jojo jojo secret bibliothecaire ',' jojo   Jojo et le secret de la bibliothécaire   ',1,'','2012-10-24 14:42:50','2012-10-24 13:59:22','0','','2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (82,'a','La sagesse du bibliothécaire','','','',0,'',19,0,12,0,'2004','','','978-2-915543-03-2','109 p.','couv. ill.','20 cm','','','','Présentation de l\'éditeur\r\nLe bibliothécaire aime les livres comme le marin aime la mer. Il n\'est pas nécessairement bon nageur mais il sait naviguer. L\'océan du savoir qui grise tous les savants, rend modeste le bibliothécaire. La bibliothèque est ce lieu indispensable où le savoir décante. Regardez comme cet océan furieux se calme dans la bibliothèque ! Le bibliothécaire sait lire les livres sans les ouvrir. Son regard transperce\r\nles couvertures. Il visite la page de titre, l\'auteur, les éditeurs, va directement au colophon, relève la date, le format,\r\nle nombre de pages, s\'attarde sur la table des matières, vérifie s\'il y a des index. Il évalue enfin sa robustesse et la qualité de son papier, celle de sa mise en page et de son impression.\r\nTout est dit. Si les auteurs savaient cela, ils feraient de faux livres uniquement pour les bibliothèques. ','','','Bibliothécaires;Déontologie;Bibliothécaires;Travail',3,'',' bibliothecaires deontologie bibliothecaires travail ','m','0',7,'12 EUR','','',' presentation editeur bibliothecaire aime livres comme marin aime mer il n est pas necessairement bon nageur mais il sait naviguer ocean savoir qui grise tous savants rend modeste bibliothecaire bibliotheque est ce lieu indispensable ou savoir decante regardez comme cet ocean furieux se calme dans bibliotheque bibliothecaire sait lire livres sans ouvrir son regard transperce couvertures il visite page titre auteur editeurs va directement colophon releve date format nombre pages s attarde sur table matieres verifie s il y index il evalue enfin sa robustesse qualite son papier celle sa mise page son impression tout est dit si auteurs savaient cela ils feraient faux livres uniquement pour bibliotheques ',' sagesse bibliothecaire ','  La sagesse du bibliothécaire   ',1,'','2012-10-24 14:42:50','2012-12-12 14:06:23','0','','2004-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (83,'a','Le métier de bibliothécaire','','','',0,'',20,0,13,0,'2010','','12e éd.','978-2-7654-0977-9','1 vol. (565 p.)','ill., couv. ill.','24 cm','','','','','','','Bibliothéconomie;France',3,'',' bibliotheconomie france ','m','0',7,'42 EUR','','','',' metier bibliothecaire ','  Le métier de bibliothécaire   ',1,'','2012-10-24 14:42:50','2012-10-24 13:57:45','0','','2010-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (121,'a','N° 403 - septembre 2012 - Numéro spécial Afrique',NULL,'','le réveil d\'un continent',0,'',0,0,0,0,'2012',NULL,'','','','','','','','LE MONDE QUI CHANGE\r\nLa mortalité infantile amorce son déclin.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nMo Ibrahim, cinquante-trois pays dans son collimateur.\r\n\r\nLE GOÛT DE GEO\r\nLe yassa poulet, ou l’hospitalité sénégalaise.\r\n\r\nÉVASION - Namibie, la nouvelle arche de Noé\r\nDans des espaces gérés par les habitants, la faune sauvage s’est multipliée, les touristes affluent et les populations en tirent un revenu.\r\n\r\nMODES DE VIE\r\nAfrican Valley(s) - L’Afrique aussi voit naître ces lieux où les technologies boostent la croissance.\r\nCampus en ébullition - Démographie oblige, les étudiants se pressent dans les universités d’Afrique subsaharienne.\r\n\r\nENVIRONNEMENT\r\nCinq chantiers qui vont changer l’Afrique.\r\nDov Zerah - Les deux défis à relever.\r\n\r\nGÉOPOLITIQUE - Région des Grands Lacs : la poudrière magnifique\r\nC’est un territoire riche, mais marqué par des décennies de conflits. La paix et le développement y font aujourd’hui leur chemin.\r\n\r\nCARTE DÉTACHABLE - Le réveil de l\'Afrique\r\n\r\nLE BON PLAN - Le Cap des Capétoniens\r\n\r\nGÉOPOLITIQUE - L\'eldorado de l\'Afrique latine\r\nL’Angola vit un boom exceptionnel. Portugais, Brésiliens ou Chinois viennent y tenter leur chance.\r\n\r\nGRANDE SÉRIE \"LA FRANCE DES VILLAGES\" - La Bourgogne\r\nPanorama mensuel des pépites du terroir. ','','','','',0,'','','b','2',1,'','',' monde qui change mortalite infantile amorce son declin heros aujourd hui mo ibrahim cinquante trois pays dans son collimateur gout geo yassa poulet ou hospitalite senegalaise evasion namibie nouvelle arche noe dans espaces geres par habitants faune sauvage s est multipliee touristes affluent populations tirent revenu modes vie african valley s afrique aussi voit naitre ces lieux ou technologies boostent croissance campus ebullition demographie oblige etudiants se pressent dans universites afrique subsaharienne environnement cinq chantiers qui vont changer afrique dov zerah deux defis relever geopolitique region grands lacs poudriere magnifique c est territoire riche mais marque par decennies conflits paix developpement y font aujourd hui leur chemin carte detachable reveil afrique bon plan cap capetoniens geopolitique eldorado afrique latine angola vit boom exceptionnel portugais bresiliens ou chinois viennent y tenter leur chance grande serie france villages bourgogne panorama mensuel pepites terroir ','',' n 403 septembre 2012 numero special afrique reveil continent ','  N° 403 - septembre 2012 - Numéro spécial Afrique   le réveil d\'un continent',1,'','2012-10-24 17:23:16','2012-11-20 08:29:44','0',0x687474703A2F2F7777772E67656F2E66722F7661722F67656F2F73746F726167652F696D616765732F6D656469612F696D616765732F72756272697175652D67656F2D696E666F732F656E2D6B696F737175652F67656F2D6E2D3430332D7370656369616C2D616672697175652D73657074656D6272652D323031322F313134333338302D312D6672652D46522F67656F2D6E2D3430332D7370656369616C2D616672697175652D73657074656D6272652D323031325F363230783436352E6A7067,'2012-09-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (84,'a','Les bibliothèques','','','',0,'',21,0,14,0,'2010','n° 944','12e éd. mise à jour','978-2-13-057064-6','1 vol. (127 p.)','couv. ill. en coul.','18 cm','','','','À la fois lieux de travail pour des recherches contemporaines et lieux de conservation d\'un patrimoine, les bibliothèques ont un rôle charnière entre le passé et le présent. Mais si leur mission demeure identique, les moyens mis à leur disposition, ainsi que les modes de consultation et d\'usage des livres, sont aujourd?hui en pleine mutation.\r\n\r\nCet ouvrage s\'assigne donc une double tâche : présenter l\'histoire des bibliothèques dans le monde occidental afin de comprendre l\'ampleur des changements qu?elles connaissent depuis un siècle, et donc les nouveaux enjeux culturels et économiques engendrés par de telles évolutions.\r\n\r\nDocteur en histoire, Denis Pallier est inspecteur général honoraire des bibliothèques.','','','Bibliothèques',3,'',' bibliotheques ','m','0',7,'9,00 EUR','','',' fois lieux travail pour recherches contemporaines lieux conservation patrimoine bibliotheques ont role charniere entre passe present mais si leur mission demeure identique moyens mis leur disposition ainsi que modes consultation usage livres sont aujourd hui pleine mutation cet ouvrage s assigne donc double tache presenter histoire bibliotheques dans monde occidental afin comprendre ampleur changements qu elles connaissent depuis siecle donc nouveaux enjeux culturels economiques engendres par telles evolutions docteur histoire denis pallier est inspecteur general honoraire bibliotheques ',' bibliotheques ','  Les bibliothèques   ',1,'','2012-10-24 14:42:51','2012-10-24 13:57:04','0','','2010-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (85,'a','Le grand amour du bibliothécaire','','','',0,'',22,0,0,0,'2005','','','978-2-203-12937-5','','','19 cm','','','','Présentation de l\'éditeur\r\nLes livres, ça fait désordre et ça prend la poussière, c\'est tout. Voilà ce que pense Fulbert le bibliothécaire. D\'ailleurs, il n\'y a qu\'un seul livre dans sa bibliothèque ! Mais voici qu\'arrive la ravissante Rose-Marie, assoiffée de lecture. Fulbert, ébloui et troublé, est bien désemparé. Il va falloir qu\'il trouve des livres, et vite ! ','','','Littérature jeunesse;BD, Mangas, Humour',0,'',' litterature jeunesse bd mangas humour ','m','0',6,'6,00 eur','','',' presentation editeur livres ca fait desordre ca prend poussiere c est tout voila ce que pense fulbert bibliothecaire ailleurs il n y qu seul livre dans sa bibliotheque mais voici qu arrive ravissante rose marie assoiffee lecture fulbert ebloui trouble est bien desempare il va falloir qu il trouve livres vite ',' grand amour bibliothecaire ','  Le grand amour du bibliothécaire   ',1,'','2012-10-24 14:42:51','2012-12-12 13:56:17','0','','2005-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (86,'a','Le bibliothécaire','','','',0,'',13,0,16,0,'2005','','','978-2-07-077327-5','1 vol. (450 p.)','couv. ill.','23 cm','','','','Travaillant dans une université huppée de Washington D.C, David Golberg devient, par le plus grand des hasards, le bibliothécaire privé d\'Alan Stowe. Vieil acariâtre multimillionnaire, industriel cynique et sans scrupules, Stowe est surtout le plus grand bailleur de fonds du parti républicain. Or, nous sommes justement en pleine élection présidentielle et l\'équipe du candidat sortant, un gosse de riche va-t-en-guerre, ancien alcoolique reconverti en fou de Dieu, voit d\'un mauvais ?il l\'arrivée de cet inconnu auprès d\'un homme aussi influent que Stowe. À peine Golberg a-t-il le temps de commencer le classement des papiers de l\'homme d\'affaires qu\'il se retrouve pris en chasse par des barbouzes de la Sécurité intérieure. Tandis que la candidate démocrate grignote son retard sur le Président et que le grand jour du vote se rapproche, David, aidé d\'une bande d\'amis, se voit contraint de trouver dans les documents de Stowe l\'information pour laquelle on veut le tuer... Après Reality Show, adapté au cinéma sous le titre Des hommes d\'influence avec Dustin Hoffman et Robert De Niro, Larry Beinhart fait un retour fracassant sur la scène littéraire, démontant pièce par pièce l\'administration Bush, sa manière de manipuler le public américain et l\'opinion mondiale en jouant avec des peurs et des fantasmes archaïques. Comme quoi les critiques les plus virulentes ne viennent pas toujours de la « vieille Europe »...','','','',0,'','','m','0',7,'24 EUR','','',' travaillant dans universite huppee washington c david golberg devient par plus grand hasards bibliothecaire prive alan stowe vieil acariatre multimillionnaire industriel cynique sans scrupules stowe est surtout plus grand bailleur fonds parti republicain or nous sommes justement pleine election presidentielle equipe candidat sortant gosse riche va guerre ancien alcoolique reconverti fou dieu voit mauvais il arrivee cet inconnu aupres homme aussi influent que stowe peine golberg il temps commencer classement papiers homme affaires qu il se retrouve pris chasse par barbouzes securite interieure tandis que candidate democrate grignote son retard sur president que grand jour vote se rapproche david aide bande amis se voit contraint trouver dans documents stowe information pour laquelle on veut tuer apres reality show adapte cinema sous titre hommes influence avec dustin hoffman robert niro larry beinhart fait retour fracassant sur scene litteraire demontant piece par piece administration bush sa maniere manipuler public americain opinion mondiale jouant avec peurs fantasmes archaiques comme quoi critiques plus virulentes ne viennent pas toujours vieille europe ',' bibliothecaire ','  Le bibliothécaire   ',1,'','2012-10-24 14:42:51','2012-10-24 13:54:29','0','','2005-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (87,'a','L\'enlèvement de la bibliothécaire','','','',0,'',23,0,17,0,'2002','189','','978-2-07-053882-9','56 p.','ill. en coul., couv. ill. en coul.','18 cm','','','','En kidnappant Mlle Labourdette, la ravissante bibliothécaire, le chef des brigands et ses quatre complices croient pouvoir obtenir de la municipalité une rançon rondelette. Mais c\'est compter sans le courage de la jeune fille, son bon c?ur et ses talents de... bibliothécaire !','','','',0,'','','m','0',7,'5 EUR','','',' kidnappant mlle labourdette ravissante bibliothecaire chef brigands ses quatre complices croient pouvoir obtenir municipalite rancon rondelette mais c est compter sans courage jeune fille son bon c ur ses talents bibliothecaire ',' enlevement bibliothecaire ','  L\'enlèvement de la bibliothécaire   ',1,'','2012-10-24 14:42:51','2012-10-24 13:53:38','0','','2002-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (88,'a','Des bibliothèques pleines de fantômes','','','',0,'',24,0,0,0,'2008','','','978-2-207-26054-8','1 vol. (138 p.)','couv. ill. en coul.','18 cm','','','','Avez-vous peur de mourir dans votre sommeil, enseveli sous l\'écroulement de votre bibliothèque ? L\'accumulation de livres ne met-elle pas en danger l\'existence même de votre famille ? Classez-vous les volumes par thème, langue, auteur, date de parution, format ou selon un autre critère de vous seul connu ? Peut-on faire voisiner sur une étagère deux auteurs irrémédiablement brouillés dans la vie ? Autant de graves questions se posant à cette espèce en voie de disparition : les bibliomanes, qui, outre la passion de posséder les livres, ont celle de les lire. Les bibliothèques sont des êtres vivants à l\'image de notre complexité intérieure. Elles finissent par composer un labyrinthe dont pour notre plus grand, et dangereux, plaisir nous pouvons très bien ne plus sortir. Dans ce petit traité sur l\'art de vivre avec trop de livres apparaissent, parmi nombre d\'autres, Pessoa tentant de devenir bibliothécaire, Matisse postulant au poste de «contrôleur du droit des pauvres» ou encore le capitaine Achab et le mystère de sa jambe abandonnée à Moby Dick. En fait, ces milliers de pages qui occupent nos étagères sont peuplées de fantômes bien vivants qui, une fois rencontrés, ne nous quittent plus.','','','Bibliothèques;Livres et lecture',3,'',' bibliotheques livres lecture ','m','0',7,'12 EUR','','',' avez vous peur mourir dans votre sommeil enseveli sous ecroulement votre bibliotheque accumulation livres ne met elle pas danger existence meme votre famille classez vous volumes par theme langue auteur date parution format ou selon autre critere vous seul connu peut on faire voisiner sur etagere deux auteurs irremediablement brouilles dans vie autant graves questions se posant cette espece voie disparition bibliomanes qui outre passion posseder livres ont celle lire bibliotheques sont etres vivants image notre complexite interieure elles finissent par composer labyrinthe dont pour notre plus grand dangereux plaisir nous pouvons tres bien ne plus sortir dans ce petit traite sur art vivre avec trop livres apparaissent parmi nombre autres pessoa tentant devenir bibliothecaire matisse postulant poste controleur droit pauvres ou encore capitaine achab mystere sa jambe abandonnee moby dick fait ces milliers pages qui occupent nos etageres sont peuplees fantomes bien vivants qui fois rencontres ne nous quittent plus ',' bibliotheques pleines fantomes ','  Des bibliothèques pleines de fantômes   ',1,'','2012-10-24 14:42:51','2012-10-24 13:52:55','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (89,'a','Cuisine actuelle de l\'Afrique noire','','','plus de 60 recettes faciles à réaliser',0,'',25,0,0,0,'2003','','','978-2-87691-819-1','215 p.','ill. en noir et en coul., couv. ill. en coul.','23 cm','','','','Présentation de l\'éditeur\r\nSénégal, Mali, Cameroun, Congo, Côte d\'Ivoire, logo, Nigeria, Gabon... L\'Afrique Noire, dans son immense diversité, offre aux palais amateurs de bonne chère, des plats savoureux et délicats qui, contrairement aux idées reçues, peuvent être simples à réaliser dès lors que l\'on dispose des connaissances et du savoir-faire indispensables. Plus de 60 recettes faciles à réaliser : A travers un large choix de recettes, composé entre autres des grands classiques (Tiep, Yassa, Mafé, Saka-Saka, Mbongo...), les auteurs de cet ouvrage nous accompagnent pas à pas pour réaliser le meilleur de la cuisine africaine. Présentation des ingrédients spécifiques à la préparation des plats (arachide, manioc, graines de courge...), portraits légendés, trucs et astuces, recettes étape par étape... dans ce beau livre riche en photos, la cuisine africaine se met enfin à la portée de fous ! Un beau livre de cuisine pour goûter et apprécier toutes les saveurs de l\'Afrique Noire : Et pour qu\'au plaisir de la bouche se joigne celui de l\'esprit et de la vue, des proverbes, des textes, des photos viennent agrémenter de-ci de-là les recettes.','','','Cuisine africaine',65,'',' cuisine africaine ','m','0',7,'24,90 EUR','','',' presentation editeur senegal mali cameroun congo cote ivoire logo nigeria gabon afrique noire dans son immense diversite offre palais amateurs bonne chere plats savoureux delicats qui contrairement idees recues peuvent etre simples realiser lors que on dispose connaissances savoir faire indispensables plus 60 recettes faciles realiser travers large choix recettes compose entre autres grands classiques tiep yassa mafe saka saka mbongo auteurs cet ouvrage nous accompagnent pas pas pour realiser meilleur cuisine africaine presentation ingredients specifiques preparation plats arachide manioc graines courge portraits legendes trucs astuces recettes etape par etape dans ce beau livre riche photos cuisine africaine se met enfin portee fous beau livre cuisine pour gouter apprecier toutes saveurs afrique noire pour qu plaisir bouche se joigne celui esprit vue proverbes textes photos viennent agrementer ci recettes ',' cuisine actuelle afrique noire plus 60 recettes faciles realiser ','  Cuisine actuelle de l\'Afrique noire   plus de 60 recettes faciles à réaliser',1,'','2012-10-24 14:42:51','2012-12-12 12:37:10','0','','2003-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (90,'a','Au coeur de l\'Afrique','','','',0,'',26,0,18,0,'2012','','Nouvelle éd.','978-2-7459-5517-3','1 vol. (251 p.)','ill. en noir et en coul., couv. ill. en coul.','27 cm','','','','Présentation de l\'éditeur\r\nUne plongée au coeur de l\'Afrique, mère de l\'humanité et continent phare du IIIe millénaire. Face aux visions d\'une Afrique déchirée, voici de nouveaux éclairages. A travers des questions comme la désertification, la déforestation, l\'exode rural, la colonisation ou l\'explosion démographique, le continent se livre en profondeur. Sa géographie a été une donnée décisive, ses peuples se sont adaptés à une nature difficile. L\'Afrique, c\'est une histoire remplie d\'épisodes épiques d\'une richesse insoupçonnée, assombrie parla terrible période de l\'esclavage. C\'est aussi une leçon de courage et de solidarité inépuisables. ','','','Afrique noire;Géographie;Ouvrages pour la jeunesse;Afrique noire;Histoire;Ouvrages pour la jeunesse',92,'',' afrique noire geographie ouvrages pour jeunesse afrique noire histoire ouvrages pour jeunesse ','m','0',8,'14,50 EUR','','',' presentation editeur plongee coeur afrique mere humanite continent phare iiie millenaire face visions afrique dechiree voici nouveaux eclairages travers questions comme desertification deforestation exode rural colonisation ou explosion demographique continent se livre profondeur sa geographie ete donnee decisive ses peuples se sont adaptes nature difficile afrique c est histoire remplie episodes epiques richesse insoupconnee assombrie parla terrible periode esclavage c est aussi lecon courage solidarite inepuisables ',' coeur afrique ','  Au coeur de l\'Afrique   ',1,'','2012-10-24 14:42:51','2012-12-12 12:26:31','0','','2012-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (91,'a','Grosse légume','','','',0,'',27,0,0,0,'2007','','','978-2-84156-884-0','1 vol. (non paginé [26] p.)','ill. en coul., couv. ill. en coul.','18 cm','','','','','','','',0,'','','m','0',7,'10,50 EUR','','','',' grosse legume ','  Grosse légume   ',1,'','2012-10-24 14:42:51','2012-10-24 13:47:20','0','','2007-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (92,'a','Les enquêtes du potager','','','par l\'inspecteur Lapou',0,'',28,0,0,0,'2007','','','978-2-07-061220-8','1 vol. (non paginé [72] p.)','ill. en coul., couv. ill. en coul.','33 cm','','Réunit : \"L\'enterrement de la carotte\" ; \"Le pissenlit écrasé\" ; \"La disparition du jeune poireau\" ; \"L\'agression du champignon\" ; \"La chute de la tomate\" ; \"Le poseur de lapins\" ; \"Le voleur de courgettes\" ; \"Le cerisier dévalisé\" ; \"La bande de radis\" ; \"Le citron trop pressé\"','','','','','',0,'','','m','0',7,'15 EUR',' reunit enterrement carotte pissenlit ecrase disparition jeune poireau agression champignon chute tomate poseur lapins voleur courgettes cerisier devalise bande radis citron trop presse ','','',' enquetes potager par inspecteur lapou ','  Les enquêtes du potager   par l\'inspecteur Lapou',1,'','2012-10-24 14:42:51','2012-10-24 13:46:38','0','','2007-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (93,'a','Quel radis dis donc !','','','',0,'',9,0,19,0,'2008','','','978-2-278-06156-3','1 vol. (non paginé [22] p.)','ill. en coul., couv. ill. en coul.','17 cm','','','','','','','',0,'','','m','0',7,'4,90 EUR','','','',' quel radis dis donc ','  Quel radis dis donc !   ',1,'','2012-10-24 14:42:51','2012-10-24 13:45:43','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (94,'a','Le jardin potager','','','',0,'',29,0,20,0,'2011','','','978-2-09-253001-6','32 p','','20 cm','','','','Présentation de l\'éditeur\r\nSais-tu faire germer des graines ? Quel est l\'outil le plus précieux du jardinier ? Qu\'est-ce qui pousse au bout du monde ?','','','Jardinage;Albums;Jeunesse - Documentaires;Eveil, petite enfance, albums à colorier',59,'',' jardinage albums jeunesse documentaires eveil petite enfance albums colorier ','m','0',6,'10,95 eur','','',' presentation editeur sais tu faire germer graines quel est outil plus precieux jardinier qu est ce qui pousse bout monde ',' jardin potager ','  Le jardin potager   ',1,'','2012-10-24 14:42:52','2012-12-12 13:58:48','0','','2011-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (95,'a','Zigomar n\'aime pas les légumes','','','',0,'',12,0,0,0,'1992','','','978-2-211-04841-5','28 p.','ill. en coul., couv. ill. en coul.','23 x 29 cm','','A pour suite dans le même ouvrage : \"Zigomar n\'aime pas du tout les légumes et il a bien raison\"','','','','','',0,'','','m','0',7,'75 F',' pour suite dans meme ouvrage zigomar n aime pas tout legumes il bien raison ','','',' zigomar n aime pas legumes ','  Zigomar n\'aime pas les légumes   ',1,'','2012-10-24 14:42:52','2012-10-24 13:42:25','0','','1992-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (96,'a','Je cuisine avec les fruits et légumes du marché','','','',0,'',30,0,0,0,'2008','','[Nouvelle éd.]','978-2-244-46006-2','1 vol. (138 p.)','ill. en noir et en coul., couv. ill. en coul.','27 cm','','','','','','','Cuisine (légumes);Ouvrages pour la jeunesse;Cuisine (fruits);Ouvrages pour la jeunesse',65,'',' cuisine legumes ouvrages pour jeunesse cuisine fruits ouvrages pour jeunesse ','m','0',7,'17,90 EUR','','','',' je cuisine avec fruits legumes marche ','  Je cuisine avec les fruits et légumes du marché   ',1,'','2012-10-24 14:42:52','2012-10-24 13:41:48','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (97,'a','Une cuisine grande comme un jardin','','','60 recettes pour découvrir les fruits et les légumes du monde',0,'',31,0,0,0,'2004','','','978-2-915569-13-1','68 p.','ill. en coul., couv. ill. en coul.','36 cm','','','','Présentation de l\'éditeur\r\nVoici un voyage extraordinaire au pays des fruits et des légumes. Des recettes qui nous les font découvrir différemment, des informations sur leur culture ou leur étonnante histoire, des proverbes du monde entier qui les célèbrent et les peintures de Martin Jarrie qui nous disent tout de leur chair et de leur saveur. ','','','Cuisine (fruits);Cuisine (légumes)',65,'',' cuisine fruits cuisine legumes ','m','0',7,'23,50 EUR','','',' presentation editeur voici voyage extraordinaire pays fruits legumes recettes qui nous font decouvrir differemment informations sur leur culture ou leur etonnante histoire proverbes monde entier qui celebrent peintures martin jarrie qui nous disent tout leur chair leur saveur ',' cuisine grande comme jardin 60 recettes pour decouvrir fruits legumes monde ','  Une cuisine grande comme un jardin   60 recettes pour découvrir les fruits et les légumes du monde',1,'','2012-10-24 14:42:52','2012-12-12 12:37:47','0','','2004-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (98,'a','Trop bon ! les fruits et les légumes','','','22 recettes d\'enfants',0,'',32,0,0,0,'2009','','','978-2-84006-581-4','1 vol. (non paginé [26] p.)','ill. en coul., couv. ill. en coul','25 x 33 cm','','','','Présentation de l\'éditeur\r\nLes fruits et les légumes, c\'est trop bon ! Au fil de ces 22 recettes, découvre les fruits et les légumes comme tu ne les as encore jamais goûtés ! En glaces, en gratins, en pizzas ou même en gaufres ! Pas de doute, tes papilles adoreront tous ces petits plats concoctés spécialement par les enfants... pour les enfants ! Entre enfants, on se comprend ! ','','','',65,'','','m','0',7,'14,95 EUR','','',' presentation editeur fruits legumes c est trop bon fil ces 22 recettes decouvre fruits legumes comme tu ne as encore jamais goutes glaces gratins pizzas ou meme gaufres pas doute tes papilles adoreront tous ces petits plats concoctes specialement par enfants pour enfants entre enfants on se comprend ',' trop bon fruits legumes 22 recettes enfants ','  Trop bon ! les fruits et les légumes   22 recettes d\'enfants',1,'','2012-10-24 14:42:52','2012-12-12 14:09:35','0','','2009-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (99,'a','Rouge comme une tomate','','','et autres émotions naturelles',0,'',32,0,0,0,'2007','','','978-2-84006-501-2','1 vol. (non paginé [40] p.)','ill. en coul., couv. ill. en coul.','28 cm','','','','Présentation de l\'éditeur\r\nQuelle tête fais-tu lorsque tu es heureux ? Fatigué ? Fâché ? Ou que tu t\'es fait gronder ? Toutes les moues et expressions enfantines, des plus drôles aux plus tendres, sous la forme de fruits et légumes hilarants ! ','','','',0,'','','m','0',7,'13 EUR','','',' presentation editeur quelle tete fais tu lorsque tu es heureux fatigue fache ou que tu es fait gronder toutes moues expressions enfantines plus droles plus tendres sous forme fruits legumes hilarants ',' rouge comme tomate autres emotions naturelles ','  Rouge comme une tomate   et autres émotions naturelles',1,'','2012-10-24 14:42:52','2012-12-12 14:05:06','0','','2007-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (100,'a','Bébés à croquer','','','',0,'',32,0,0,0,'2006','','','978-2-84006-443-5','1 vol. (non paginé [24] p.)','tout en ill. en coul., couv. ill. en coul.','22 x 24 cm','','','','Présentation de l\'éditeur\r\nCaneton, mouton, pingouin ou jeune chien... Vous allez fondre pour ces délicieux bébés animaux... A croquer !','','','Artisanat de nature;Ouvrages illustrés',75,'',' artisanat nature ouvrages illustres ','m','0',7,'10 EUR','','',' presentation editeur caneton mouton pingouin ou jeune chien vous allez fondre pour ces delicieux bebes animaux croquer ',' bebes croquer ','  Bébés à croquer   ',1,'','2012-10-24 14:42:52','2012-12-12 12:22:44','0','','2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (101,'a','Fruits, légumes','','','',0,'',33,0,0,0,'2011','','','978-2-211-20487-3','1 vol. (non paginé [50] p.)','ill. en coul., couv. ill. en coul.','31 cm','','','','Présentation de l\'éditeur\r\nOh la belle verte! Si les légumes et les fruits étaient aussi beaux dans la réalité que dans cette « encyclopédie », les enfants les dévoreraient !','','','',0,'','','m','0',8,'13,50 EUR','','',' presentation editeur oh belle verte si legumes fruits etaient aussi beaux dans realite que dans cette encyclopedie enfants devoreraient ',' fruits legumes ','  Fruits, légumes   ',1,'','2012-10-24 14:42:52','2012-12-12 13:55:36','0','','2011-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (102,'a','Orange, pomme, poire','','','',0,'',16,0,0,0,'2009','','','978-2-87767-590-1','1 vol. (non paginé [20] p.)','ill. en coul., couv. ill. en coul.','18 cm','','','','Présentation de l\'éditeur\r\nUne orange, une pomme, une poire et un ours, Grégoire. Qui aurait imaginé que ces quatre mots puissent être conjugués en autant de façons ? Emily gravett, bien sûr ! ','','','',0,'','','m','0',7,'10 EUR','','',' presentation editeur orange pomme poire ours gregoire qui aurait imagine que ces quatre mots puissent etre conjugues autant facons emily gravett bien sur ',' orange pomme poire ','  Orange, pomme, poire   ',1,'','2012-10-24 14:42:52','2012-12-12 14:03:47','0','','2009-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (103,'a','Fahrenheit 451','','','',0,'',13,0,21,1,'2000','3','','978-2-07-041573-1','213 p.','couv. ill. en coul.','18 cm','','','','451 degrés Fahrenheit représentent la température à laquelle un livre s\'enflamme et se consume.Dans cette société future où la lecture, source de questionnement et de réflexion, est considérée comme un acte antisocial, un corps spécial de pompiers est chargé de brûler tous les livres, dont la détention est interdite pour le bien collectif.Montag, le pompier pyromane, se met pourtant à rêver d\'un monde différent, qui ne bannirait pas la littérature et l\'imaginaire au profit d\'un bonheur immédiatement consommable. Il devient dès lors un dangereux criminel, impitoyablement poursuivi par une société qui désavoue son passé.','','','',0,'','','m','0',7,'25 F : 3,81 EUR','','',' 451 degres fahrenheit representent temperature laquelle livre s enflamme se consume dans cette societe future ou lecture source questionnement reflexion est consideree comme acte antisocial corps special pompiers est charge bruler tous livres dont detention est interdite pour bien collectif montag pompier pyromane se met pourtant rever monde different qui ne bannirait pas litterature imaginaire profit bonheur immediatement consommable il devient lors dangereux criminel impitoyablement poursuivi par societe qui desavoue son passe ',' fahrenheit 451 ','  Fahrenheit 451   ',1,'','2012-10-24 14:42:52','2012-10-24 13:32:20','0','','2000-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (104,'a','La huitième couleur','','','',3,'1',34,0,0,0,'1996','','','978-2-84172-039-2','279 p.','couv. ill. en coul.','18 cm','','','','Quatrième de couverture\r\nDans une dimension lointaine et passablement farfelue, un monde se balade à dos de quatre éléphants, eux©mêmes juchés sur la carapace de la Grande Tortue... Oui, c\'est le Disque©monde... Les habitants de la cité d\'Ankh©Morpork croyaient avoir tout vu. Et Deuxfleurs avait l\'air tellement inoffensif, bonhomme chétif, fidèlement escorté par un Bagage de bois magique déambulant sur une myriade de petites jambes. Tellement inoffensif que le Patricien avait chargé le calamiteux sorcier Rincevent de sa sécurité dans la cité quadrillée par la Guilde des Voleurs et celle des Assassins ; mission périlleuse et qui devait les conduire loin : dans une caverne de dragons ; peut©être jusqu\'au Rebord du Disque. Car Deuxfleurs était d\'une espèce plus redoutable qu\'on ne l\'imaginait : c\'était un touriste... A la lumière de l\'octarine, la huitième couleur, celle de la magie, découvrez l\'univers fantastique et cocasse de Terry Pratchett.','','','',0,' annales disque monde ','','m','0',7,'80 F','','',' quatrieme couverture dans dimension lointaine passablement farfelue monde se balade dos quatre elephants eux memes juches sur carapace grande tortue oui c est disque monde habitants cite ankh morpork croyaient avoir tout vu deuxfleurs avait air tellement inoffensif bonhomme chetif fidelement escorte par bagage bois magique deambulant sur myriade petites jambes tellement inoffensif que patricien avait charge calamiteux sorcier rincevent sa securite dans cite quadrillee par guilde voleurs celle assassins mission perilleuse qui devait conduire loin dans caverne dragons peut etre jusqu rebord disque car deuxfleurs etait espece plus redoutable qu on ne imaginait c etait touriste lumiere octarine huitieme couleur celle magie decouvrez univers fantastique cocasse terry pratchett ',' annales disque monde 1 huitieme couleur ',' annales disque monde  1 La huitième couleur   ',1,'','2012-10-24 14:42:52','2012-12-12 14:11:02','0','','1996-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (105,'a','Le huitième sortilège','','','',3,'2',34,0,0,0,'1993','','','978-2-905158-75-8','270 p.','couv. ill. en coul.','18 cm','','','','Présentation de l\'éditeur\r\nOctogénaire, borgne, chauve et édenté, Cohen le Barbare, le plus grand héros de tous les temps, réussira-t-il à tirer Deuxfleurs et Rincevent des griffes de leurs poursuivants ? Question capitale, car le tissu même du temps et de l\'espace est sur le point de passer dans l\'essoreuse. Une étoile rouge menace de percuter le Disque-Monde et la survie de celui-ci est entre les mains du sorcier calamiteux : dans son esprit (très) brumeux se tapit en effet le... huitième sortilège ! La suite de l\'épopée la plus démente de la fantasy, avec, dans les seconds rôles, une distribution prestigieuse : le Bagage, l\'In-Octavo, Herrena la harpie, Kwartz le troll, Trymon l\'enchanteur maléfique et, naturellement, La Mort...','','','',0,' annales disque monde ','','m','0',7,'77 F','','',' presentation editeur octogenaire borgne chauve edente cohen barbare plus grand heros tous temps reussira il tirer deuxfleurs rincevent griffes leurs poursuivants question capitale car tissu meme temps espace est sur point passer dans essoreuse etoile rouge menace percuter disque monde survie celui ci est entre mains sorcier calamiteux dans son esprit tres brumeux se tapit effet huitieme sortilege suite epopee plus demente fantasy avec dans seconds roles distribution prestigieuse bagage in octavo herrena harpie kwartz troll trymon enchanteur malefique naturellement mort ',' annales disque monde 2 huitieme sortilege ',' annales disque monde  2 Le huitième sortilège   ',1,'','2012-10-24 14:42:52','2012-12-12 14:11:51','0','','1993-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (106,'a','La triste fin du petit enfant huître et autres histoires','','','',0,'',35,0,24,0,'2008','','','978-2-264-04873-8','128 p.','','17 cm','','','','Fidèle à son univers d\'une inventivité si  particulière, mêlant crauté et tendresse,  macabre et poésie, Tim Burton donne le jour à une  étonnante famille d\'enfants solitaires, étranges et  différents, qui ne tarderont pas à nous horrifier,  à nous émouvoir et à nous faire rire.  Un livre pour l\'enfant qui est en nous','','','Littérature;Romans contemporains;Littérature au format poche;Romans en Poche',82,'',' litterature romans contemporains litterature format poche romans poche ','m','0',6,'10,14 eur','','',' fidele son univers inventivite si particuliere melant craute tendresse macabre poesie tim burton donne jour etonnante famille enfants solitaires etranges differents qui ne tarderont pas nous horrifier nous emouvoir nous faire rire livre pour enfant qui est nous ',' triste fin petit enfant huitre autres histoires ','  La triste fin du petit enfant huître et autres histoires   ',1,'','2012-10-24 14:42:52','2012-10-24 13:27:36','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (107,'a','Tim Burton','','','',0,'',36,0,25,0,'','171','','978-2-35880-032-7','','','','','','','Présentation de l\'éditeur\r\nIl était une fois un garçon qui aimait inventer des histoires. Il se dit qu\'un homme déguisé en chauve-souris, ça ferait peur aux méchants. Il pense à la petite fille qui passe de l\'autre côté du miroir et découvre un monde merveilleux. A la femme qui se prend pour un chat et qui joue avec l\'homme pingouin. Il se dit qu\'une citrouille ne remplacera jamais le Père Noël, mais qu\'elle pourrait avoir envie d\'essayer. Il imagine ce qui se passerait si les habitants de Mars attaquaient la Terre... Son rêve, c\'était de rassembler toutes ces histoires et tous leurs personnages. Aujourd\'hui, le petit garçon est devenu grands et il fait du cinéma. Le tour du monde des musées en BD et en jeu .: le musée du Palais a Pékin.','','','Jeunesse;L\'Univers des Enfants',71,'',' jeunesse univers enfants ','m','0',6,'7,90 EUR','','',' presentation editeur il etait fois garcon qui aimait inventer histoires il se dit qu homme deguise chauve souris ca ferait peur mechants il pense petite fille qui passe autre cote miroir decouvre monde merveilleux femme qui se prend pour chat qui joue avec homme pingouin il se dit qu citrouille ne remplacera jamais pere noel mais qu elle pourrait avoir envie essayer il imagine ce qui se passerait si habitants mars attaquaient terre son reve c etait rassembler toutes ces histoires tous leurs personnages aujourd hui petit garcon est devenu grands il fait cinema tour monde musees bd jeu musee palais pekin ',' tim burton ','  Tim Burton   ',1,'','2012-10-24 14:42:52','2012-12-12 14:08:39','0','','0000-00-00',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (108,'a','Tim burton','','','',0,'',37,0,26,0,'2010','','','978-2-86642-597-5','224 p.','','22 cm','','','','','','','',71,'','','m','0',6,'24,95 eur','','','',' tim burton ','  Tim burton   ',1,'','2012-10-24 14:42:52','2012-10-24 13:22:44','0','','2010-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (109,'m','La musique africaine','','','Timbélélé et la reine Lune',0,'',38,0,27,0,'2008','','','978-2-07-062114-9','32 p.','','18 cm','','','','Laissez-vous envoûter par le son de la kora, du balafon, du khollé, des djembés, du tama, l\'accent du narrateur et les voix incomparables des frères Toure.Partez à la découverte des musiques d\'Afrique !','','','Jeunesse - Albums;Musique et instruments;Contes, comptines et poésie',79,'',' jeunesse albums musique instruments contes comptines poesie ','m','0',6,'13,50 EUR','','',' laissez vous envouter par son kora balafon kholle djembes tama accent narrateur voix incomparables freres toure partez decouverte musiques afrique ',' musique africaine timbelele reine lune ','  La musique africaine   Timbélélé et la reine Lune',1,'','2012-10-24 14:42:53','2012-10-28 17:30:36','0','','2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (110,'g','Edward aux mains d\'argent','','','',0,'',39,0,0,0,'2011','','','','1 DVD (1 h 45 min)','16/9, coul. (PAL), son., surround (Dolby)','','','','','Synopsis\r\nEdward est la création d\'un savant génial. Il ne possède pas de vrais mains, mais des lames très tranchantes à la place des doigts. Il peut réaliser avec ses instruments de véritables oeuvres d\'art, qui vont provoquer la curiosité et l\'enthousiasme de toute la ville. Mais il est capable de blesser et de faire mal quand il ne se contrôle plus... ','','','',0,'','','m','0',1,'','','',' synopsis edward est creation savant genial il ne possede pas vrais mains mais lames tres tranchantes place doigts il peut realiser avec ses instruments veritables oeuvres art qui vont provoquer curiosite enthousiasme toute ville mais il est capable blesser faire mal quand il ne se controle plus ',' edward mains argent ','  Edward aux mains d\'argent   ',1,'','2012-10-24 14:49:09','2012-12-12 13:43:08','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F35315A45626B4F53774F4C2E5F41413131355F2E6A7067,'2011-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (111,'g','Beetlejuice','','','',0,'',40,0,28,2,'2010','079','','','1 DVD vidéo zone 2 (1 h 32 min)','16/9, coul. (PAL), son., surround','','','','','Synopsis\r\nBarbara et Adam forment un adorable couple. Hélas survient un stupide accident de voiture et les voilà devenus fantômes obligés de hanter les murs de leur propre demeure ! Quelle n\'est pas leur déception lorsqu\'ils la voient livrée aux mains d\'une famille excentrique dont les membres évoluent entre hystérie et stupidité. Barbara et Adam tentent de les chasser. En vain. La seule solution : faire appel à Beetlejuice, un fantôme exorciseur de vivants... ','','','',0,'','','m','0',1,'','','',' synopsis barbara adam forment adorable couple helas survient stupide accident voiture voila devenus fantomes obliges hanter murs leur propre demeure quelle n est pas leur deception lorsqu ils voient livree mains famille excentrique dont membres evoluent entre hysterie stupidite barbara adam tentent chasser vain seule solution faire appel beetlejuice fantome exorciseur vivants ',' beetlejuice ','  Beetlejuice   ',1,'','2012-10-24 14:51:53','2012-12-12 12:24:30','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353132425A43315A39304C2E5F534C3530305F41413330305F2E6A7067,'2010-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (112,'g','Big Fish','','','',0,'',41,0,0,0,'2004','','','','1 DVD zone 2 (2 h 51 min)','coul. (PAL), sonore','','','','','Synopsis\r\nApprenant qu\'Edward, son père, est sur le point de mourir, Will décide de se rapprocher de lui pour enfin connaître cet homme qui a bercé son enfance avec des contes plus ou moins fantastiques dans lesquels il se mettait en scène aux côtés de personnages extravagants et extraordinaires...','','','',0,'','','m','0',1,'','','',' synopsis apprenant qu edward son pere est sur point mourir will decide se rapprocher lui pour enfin connaitre cet homme qui berce son enfance avec contes plus ou moins fantastiques dans lesquels il se mettait scene cotes personnages extravagants extraordinaires ',' big fish ','  Big Fish   ',1,'','2012-10-24 14:55:20','2012-12-12 12:25:06','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353130573251435357584C2E5F41413136305F2E6A7067,'2004-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (113,'g','Les noces funèbres','','','',0,'',40,0,0,0,'2008','','','','1 DVD zone 2 (1 h 17 min)','19/9, coul. (PAL), son., surround (Dolby)','','','','','Synopsis\r\nAu XIXe siècle, dans un village d\'Europe de l\'est, Victor, un jeune homme, découvre le monde des morts après avoir épousé, sans le vouloir, le cadavre d\'une mystérieuse mariée. Pendant son voyage, sa promise, Victoria l\'attend désespérément dans le monde des vivants. Bien que la vie au Royaume des Morts s\'avère beaucoup plus animée et joyeuse que sa véritable existence, Victor apprend que rien au monde, pas même la mort, ne pourra briser son amour pour sa femme... ','','','',0,'','','m','0',1,'','','',' synopsis xixe siecle dans village europe est victor jeune homme decouvre monde morts apres avoir epouse sans vouloir cadavre mysterieuse mariee pendant son voyage sa promise victoria attend desesperement dans monde vivants bien que vie royaume morts s avere beaucoup plus animee joyeuse que sa veritable existence victor apprend que rien monde pas meme mort ne pourra briser son amour pour sa femme ',' noces funebres ','  Les noces funèbres   ',1,'','2012-10-24 14:57:40','2012-12-12 14:03:11','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353172676F305930666F4C2E5F41413136305F2E6A7067,'2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (114,'g','Charlie et la chocolaterie','','','',0,'',40,0,0,0,'2006','','','','2 DVD zone 2 (1 h 50 min)','16/9, coul. (PAL), son., surround (Dolby)','','','','','Synopsis\r\nQuelles sont les merveilles qui t\'attendent dans l\'usine de Willy Wonka ? Pars à la découverte de vastes étendues d\'herbe sucrée au bon goût de menthe dans la Salle du Chocolat... Navigue sur la Rivière de Chocolat dans un grand bateau en sucre rose... Essaye le Gobestoppeur sans fin dans la Salle des Inventions... Observe les talentueux écureuils de la Salle de Tri des Noix et voyage en ascenseur de verre jusqu\'à la Salle de Télévision. Tu y trouveras une montagne d\'humour saupoudrée d\'un peu de mystère... et une aventure aussi savoureuse et agréable qu\'une tablette de Délice Fondant Wonka Guimauve-Caramel... ','','','',0,'','','m','0',1,'','','',' synopsis quelles sont merveilles qui attendent dans usine willy wonka pars decouverte vastes etendues herbe sucree bon gout menthe dans salle chocolat navigue sur riviere chocolat dans grand bateau sucre rose essaye gobestoppeur sans fin dans salle inventions observe talentueux ecureuils salle tri noix voyage ascenseur verre jusqu salle television tu y trouveras montagne humour saupoudree peu mystere aventure aussi savoureuse agreable qu tablette delice fondant wonka guimauve caramel ',' charlie chocolaterie ','  Charlie et la chocolaterie   ',1,'','2012-10-24 15:00:13','2012-12-12 12:25:56','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353145414E5A443052354C2E5F41413136305F2E6A7067,'2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (115,'j','Miriam Makeba','','','her essential recordings ; the empress of African song',0,'',42,0,0,0,'2006','','','','2 disques compacts (57 min, 1 h 01 min)','','','1 livret (8 p.) : ill. ; 12 cm','','','','','','',0,'','','m','0',1,'','','','',' miriam makeba her essential recordings the empress of african song ','  Miriam Makeba   her essential recordings ; the empress of African song',1,'','2012-10-24 15:04:39','2012-10-24 13:17:33','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353158527847315836424C2E5F534C3530305F41413330305F2E6A7067,'2006-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (116,'j','Jammu Africa','','','',0,'',43,0,0,0,'2003','','','','1 disque compact','','','','','','','','','',0,'','','m','0',8,'','','','',' jammu africa ','  Jammu Africa   ',1,'','2012-10-24 15:08:21','2012-10-24 13:17:22','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F353172636478315639454C2E5F41413131355F2E6A7067,'2003-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (117,'j','Tchamantché','','','',0,'',44,0,0,0,'2008','','','','1 disque compact','','','1 brochure ([20] p.) : ill. en coul. ; 12 cm','','','','','','',0,'','','m','0',8,'','','','',' tchamantche ','  Tchamantché   ',1,'','2012-10-24 15:10:11','2012-12-12 14:17:01','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F333173556F414A4C6B644C2E5F41413131355F2E6A7067,'2008-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (118,'j','M\'Bemba','','','',0,'',45,0,0,0,'2005','','','','1 disque compact (1 h)','','','1 livret (16 p.) : ill., 12 cm','','','','','','',0,'','','m','0',1,'','','','',' m bemba ','  M\'Bemba   ',1,'','2012-10-24 15:11:43','2012-10-24 13:16:57','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F34313658796653436C494C2E5F41413131355F2E6A7067,'2005-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (119,'j','Folila','','','',0,'',46,0,0,0,'2012','','','','1 disque compact (46 min 41 s)','','','1 brochure ([16] p.) : ill. en coul. ; 12 cm','','','','','','',0,'','','m','0',8,'','','','',' folila ','  Folila   ',1,'','2012-10-24 15:14:57','2012-10-24 13:16:44','0',0x687474703A2F2F6563782E696D616765732D616D617A6F6E2E636F6D2F696D616765732F492F363171616B53726C6A554C2E5F41413131355F2E6A7067,'2012-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (122,'a','N° 393 - novembre 2011 - L\'Île de Pâques',NULL,'','Le rêve ultime des voyageurs',0,'',0,0,0,0,'2011',NULL,'','','','','','','','ÉVASION - La dernière frontière du Pacifique\r\nÀ des milliers de kilomètres de toute terre émergée, l’île de Pâques et ses statues géantes fascinent toujours les voyageurs.\r\n\r\nMODES DE VIE - Le Grand Paris\r\nÀ quoi ressemblera le Grand Paris ? Un métro de 200 kilomètres, un port gigantesque à Achères, une Silicon Valley à Saclay… La future mégapole commence à dévoiler son nouveau visage.\r\n\r\nENVIRONNEMENT - L\'iPhone est-il écolo ?\r\nÉtape par étape, l’analyse de l’impact environnemental du petit bijou d’Apple.\r\n\r\nVOYAGE - La nouvelle vie de Cracovie\r\nLa cité polonaise est l’un des lieux les plus touristiques de l’ancien bloc de l’Est. Grâce à sa richesse culturelle et à sa jeunesse qui crée une ambiance de «movida».\r\n\r\nPARTIR - Quoi de neuf à Bruxelles ?\r\nMalgré la crise institutionnelle qui paralyse le pays, la capitale belge n’a pas perdu sa créativité. Tables, hôtels, shopping… Tour d’horizon des nouvelles adresses.\r\n\r\nGÉOPOLITIQUE - Comment la Chine redessine le monde\r\nEn Grèce, en Birmanie, en Zambie… Partout, les Chinois financent et bâtissent des ports, des routes, des hôpitaux. C’est la phase nouvelle du «zouchuqu», leur stratégie de conquête tous azimuts.\r\n\r\nLE MONDE EN CARTES - Pourquoi la Kapisa est dans l’oeil du cyclone ?\r\nProche de Kaboul, cette province est la zone de tous les dangers pour les militaires français.\r\n\r\nGRANDE SÉRIE : LE LITTORAL FRANÇAIS - LA NORMANDIE\r\nNotre photographe livre son coup d’oeil sur les hauts lieux de la côte normande. Et notre journaliste analyse les enjeux du moment sur le plan du tourisme et de l’environnement. ','','','','',0,'','','b','2',1,'','',' evasion derniere frontiere pacifique milliers kilometres toute terre emergee ile paques ses statues geantes fascinent toujours voyageurs modes vie grand paris quoi ressemblera grand paris metro 200 kilometres port gigantesque acheres silicon valley saclay future megapole commence devoiler son nouveau visage environnement iphone est il ecolo etape par etape analyse impact environnemental petit bijou apple voyage nouvelle vie cracovie cite polonaise est lieux plus touristiques ancien bloc est grace sa richesse culturelle sa jeunesse qui cree ambiance movida partir quoi neuf bruxelles malgre crise institutionnelle qui paralyse pays capitale belge n pas perdu sa creativite tables hotels shopping tour horizon nouvelles adresses geopolitique comment chine redessine monde grece birmanie zambie partout chinois financent batissent ports routes hopitaux c est phase nouvelle zouchuqu leur strategie conquete tous azimuts monde cartes pourquoi kapisa est dans oeil cyclone proche kaboul cette province est zone tous dangers pour militaires francais grande serie littoral francais normandie notre photographe livre son coup oeil sur hauts lieux cote normande notre journaliste analyse enjeux moment sur plan tourisme environnement ','',' n 393 novembre 2011 ile paques reve ultime voyageurs ','  N° 393 - novembre 2011 - L\'Île de Pâques   Le rêve ultime des voyageurs',1,'','2012-10-24 17:26:11','2012-11-20 08:29:44','0',0x687474703A2F2F7777772E67656F2E66722F7661722F67656F2F73746F726167652F696D616765732F6D656469612F696D616765732F72756272697175652D67656F2D696E666F732F656E2D6B696F737175652F6D6167617A696E652D67656F2D6E6F76656D6272652D323031312D3339332F313034303036302D312D6672652D46522F6D6167617A696E652D67656F2D6E6F76656D6272652D323031312D3339335F363230783436352E6A7067,'2011-11-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (123,'a','N° 402 - août 2012 - Compostelle, Shikoku, Lalibela... Les chemins de la sagesse',NULL,'','',0,'',0,0,0,0,'2012',NULL,'','','','','','','','LE MONDE QUI CHANGE\r\nLe patrimoine de la Syrie sous la menace.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nCe chirurgien indien qui prend à cœur la santé de son pays.\r\n\r\nLE GOÛT DE GEO\r\nLe «dim-sum», un microfestin à la chinoise.\r\n\r\nÉVASION - Dans le sillage d\'Ulysse\r\nHeureux qui comme le héros d\'Homère a fait un beau voyage... GEO a suivi ses pas en Méditerranée.\r\n\r\nESCALE - Jean Didier Urbain\r\nVite parcouru, mal lu.\r\n\r\nMODES DE VIE - A la vie, à la mer\r\nReportage sur ces marins pêcheurs qui écument les océans glacés et bravent les tempêtes.\r\n\r\nENVIRONNEMENT - Faut-il se préparer aux grandes sécheresses ?\r\nIl fait plus sec et plus chaud. Résultat, la terre a soif et les agriculteurs trinquent.\r\n\r\nVOYAGE - Le renouveau des chemins sacrés\r\nLes marcheurs affluent vers les routes spirituelles à la recherche du grand voyage intérieur.\r\n\r\nLE BON PLAN - Le Bilbao des Bilbotars\r\n\r\nGÉOPOLITIQUE - Terres fertiles à louer\r\nDe puissants investisseurs étrangers trustent les meilleurs champs des pays du Sud. Néocolonialisme ou développement agricole ?\r\n\r\nLE MONDE EN CARTES - Des îles très disputées\r\n\r\nGRANDE SÉRIE - La France des villages\r\nPérigord et Quercy : panorama mensuel des pépites du terroir.','','','','',0,'','','b','2',1,'','',' monde qui change patrimoine syrie sous menace heros aujourd hui ce chirurgien indien qui prend c ur sante son pays gout geo dim sum microfestin chinoise evasion dans sillage ulysse heureux qui comme heros homere fait beau voyage geo suivi ses pas mediterranee escale jean didier urbain vite parcouru mal lu modes vie vie mer reportage sur ces marins pecheurs qui ecument oceans glaces bravent tempetes environnement faut il se preparer grandes secheresses il fait plus sec plus chaud resultat terre soif agriculteurs trinquent voyage renouveau chemins sacres marcheurs affluent vers routes spirituelles recherche grand voyage interieur bon plan bilbao bilbotars geopolitique terres fertiles louer puissants investisseurs etrangers trustent meilleurs champs pays sud neocolonialisme ou developpement agricole monde cartes iles tres disputees grande serie france villages perigord quercy panorama mensuel pepites terroir ','',' n 402 aout 2012 compostelle shikoku lalibela chemins sagesse ','  N° 402 - août 2012 - Compostelle, Shikoku, Lalibela... Les chemins de la sagesse   ',1,'','2012-10-24 17:30:07','2012-11-20 08:29:44','0',0x687474703A2F2F7777772E67656F2E66722F7661722F67656F2F73746F726167652F696D616765732F6D656469612F636F75766572747572652D67656F2D6E2D3430322F313133353938332D312D6672652D46522F636F75766572747572652D67656F2D6E2D3430325F363230783436352E6A7067,'2012-08-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (124,'l','Bulletin des bibliothèques de France',NULL,'BBF','',0,'',48,0,0,0,'1995-',NULL,'','1292-8399',NULL,NULL,NULL,NULL,'','','','http://bbf.enssib.fr/','','',0,'','','s','1',1,'','','','',' bulletin bibliotheques france bbf ','  Bulletin des bibliothèques de France  BBF ',1,'','2012-10-24 17:35:46','2012-11-20 08:29:44','0',0x687474703A2F2F6262662E656E737369622E66722F73697465732F6262662E656E737369622E66722F7468656D65732F4242462F696D616765732F636F6D6D756E2F4242665F6C6F676F5F696D7072657373696F6E2E706E67,'1995-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (125,'l','Bibliothécaire de soi-même',NULL,'','',0,'',0,0,0,0,'2010',NULL,'','','',NULL,NULL,NULL,'','','Les bibliothèques publiques ont souvent pour origine des collections privées. Mais la fréquentation de ces bibliothèques n\'empêche pas, accompagne même, le goût pour constituer sa bibliothèque privée, « la reconstitution à son usage propre d\'une sorte de bibliothèque publique ». La gestion de ces bibliothèques privées se heurte aux mêmes problèmes que les bibliothèques institutionnelles, comme le classement, le rangement, mais aussi la politique d\'acquisition, même si le caractère privé de sa bibliothèque autorise de nombreuses licences au propriétaire des livres, « bibliothécaire de soi-même ». L\'obligation de conservation et d\'entretien est évidente, si celle de désherbage, désormais largement pratiqué dans les bibliothèques publiques, l\'est moins - tout comme le catalogage, et a fortiori le prêt.','','','',0,'','','a','2',1,'','','',' bibliotheques publiques ont souvent pour origine collections privees mais frequentation ces bibliotheques n empeche pas accompagne meme gout pour constituer sa bibliotheque privee reconstitution son usage propre sorte bibliotheque publique gestion ces bibliotheques privees se heurte memes problemes que bibliotheques institutionnelles comme classement rangement mais aussi politique acquisition meme si caractere prive sa bibliotheque autorise nombreuses licences proprietaire livres bibliothecaire soi meme obligation conservation entretien est evidente si celle desherbage desormais largement pratique dans bibliotheques publiques est moins tout comme catalogage fortiori pret ',' bibliothecaire soi meme ','  Bibliothécaire de soi-même   ',1,'','2012-10-24 17:41:02','2012-12-12 15:24:55','',0x687474703A2F2F6262662E656E737369622E66722F73697465732F6262662E656E737369622E66722F7468656D65732F4242462F696D616765732F636F6D6D756E2F4242665F6C6F676F5F696D7072657373696F6E2E706E67,'2010-11-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (126,'l','Voyages en BM',NULL,'','',0,'',0,0,0,0,'2010',NULL,'','','',NULL,NULL,NULL,'','','La trajectoire d\'un usager des bibliothèques publiques, de l\'enfance à aujourd\'hui : autodidacte, il fréquente assidûment la bibliothèque municipale de Montreuil-sous-Bois, « copropriétaire d\'une BM unique dans la commune... Ma première patrie fut cette bibliothèque » ; le contact permanent des livres, le passage difficile de l\'adolescence, puis le « boulot d\'auteur », toujours accompagné des bibliothèques. « Aujourd\'hui, je ne ressemble pas à mes gosses. À cause ou grâce à ces livres empruntés chaque semaine, j\'ai quitté une classe sociale... sans jamais en trouver une autre de rechange. »','','','',0,'','','a','2',1,'','','',' trajectoire usager bibliotheques publiques enfance aujourd hui autodidacte il frequente assidument bibliotheque municipale montreuil sous bois coproprietaire bm unique dans commune ma premiere patrie fut cette bibliotheque contact permanent livres passage difficile adolescence puis boulot auteur toujours accompagne bibliotheques aujourd hui je ne ressemble pas mes gosses cause ou grace ces livres empruntes chaque semaine j ai quitte classe sociale sans jamais trouver autre rechange ',' voyages bm ','  Voyages en BM   ',1,'','2012-10-24 17:44:30','2012-11-20 08:29:44','0',0x687474703A2F2F6262662E656E737369622E66722F73697465732F6262662E656E737369622E66722F7468656D65732F4242462F696D616765732F636F6D6D756E2F4242665F6C6F676F5F696D7072657373696F6E2E706E67,'2010-11-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (127,'l','L\'abeille et le bibliothécaire ou éthique du libre et lecture publique en zone rurale',NULL,'','',0,'',0,0,0,0,'2012',NULL,'','','',NULL,NULL,NULL,'','','Mariant évolution des techniques et analyse des territoires ruraux, cet article se veut une réflexion (et une incitation) sur le travail en commun, une « théorie de la pratique », la mise en oeuvre professionnelle et partagée de la société de la connaissance. L\'exemple du RISOM (Réseau intercommunal et solidaire des médiathèques de Tence, St-Jeures et Le Mazet-St-Voy, Haute-Loire), qui propose le partage d\'informations sur des projets d\'animation, leurs outils et leurs usages, vient à l\'appui et en illustration de cette analyse.','','','',0,'','','a','2',1,'','','',' mariant evolution techniques analyse territoires ruraux cet article se veut reflexion incitation sur travail commun theorie pratique mise oeuvre professionnelle partagee societe connaissance exemple risom reseau intercommunal solidaire mediatheques tence st jeures mazet st voy haute loire qui propose partage informations sur projets animation leurs outils leurs usages vient appui illustration cette analyse ',' abeille bibliothecaire ou ethique libre lecture publique zone rurale ','  L\'abeille et le bibliothécaire ou éthique du libre et lecture publique en zone rurale   ',1,'','2012-10-24 17:48:22','2012-12-12 12:21:10','',0x687474703A2F2F6262662E656E737369622E66722F73697465732F6262662E656E737369622E66722F7468656D65732F4242462F696D616765732F636F6D6D756E2F4242665F6C6F676F5F696D7072657373696F6E2E706E67,'2012-09-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (128,'l','Poisson rouge','','','',0,'',0,0,0,0,'','','','','','','','','','','','http://www.poissonrouge.com/','','',0,'','','m','0',1,'','','','',' poisson rouge ','  Poisson rouge   ',1,'','2012-10-24 17:55:27','2012-10-24 15:55:27','0',0x687474703A2F2F7777772E696E7465726163746963612E636F6D2F7069672E6A7067,'0000-00-00',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (129,'a','Georges',NULL,'','petit-petit-petit magazine',0,'',49,0,0,0,'2010-',NULL,'','2110-8749',NULL,NULL,NULL,NULL,'','','Le concept de Georges\r\n\r\nBienvenue dans l’univers de Georges, petit – petit – petit magazine, revue alternative trimestrielle créée par les Éditions Grains de Sel, pour les enfants ni trop petits ni trop grands (dès 7-8 ans et jusqu’à 12 ans). Mais aussi pour les plus grands qui s’intéressent au graphisme et à l’illustration.\r\n \r\nMais qui est Georges ?\r\nUn magazine décalé et exigeant qui stimule la curiosité et revisite les traitements traditionnels des magazines pour enfants.\r\n\r\nQuels sont ses atouts ?\r\nUn graphisme épuré  et un thème original pour chaque numéro, sur un beau papier offset et recyclé, avec des illustrateurs aux univers sensibles et un second degré qui séduit les enfants (et même leurs parents).\r\n\r\nComment se présente-t-il ?\r\nPartie 1 – des HISTOIRES vraies, courtes, longues ou à l’envers.\r\nPartie 2 – des JEUX à colorier, calculer ou déchiffrer autour du thème du numéro.\r\nPartie 3 – des RUBRIQUES-À-BRAC pour découvrir des métiers, langues étrangères, scènes de films ou expériences scientifiques, mais de façon toujours farfelue&#8201;!','http://www.magazinegeorges.com/','','',0,'','','s','1',1,'','','',' concept georges bienvenue dans univers georges petit petit petit magazine revue alternative trimestrielle creee par editions grains sel pour enfants ni trop petits ni trop grands 7 8 ans jusqu 12 ans mais aussi pour plus grands qui s interessent graphisme illustration mais qui est georges magazine decale exigeant qui stimule curiosite revisite traitements traditionnels magazines pour enfants quels sont ses atouts graphisme epure theme original pour chaque numero sur beau papier offset recycle avec illustrateurs univers sensibles second degre qui seduit enfants meme leurs parents comment se presente il partie 1 histoires vraies courtes longues ou envers partie 2 jeux colorier calculer ou dechiffrer autour theme numero partie 3 rubriques brac pour decouvrir metiers langues etrangeres scenes films ou experiences scientifiques mais facon toujours farfelue 8201 ',' georges petit petit petit magazine ','  Georges   petit-petit-petit magazine',1,'','2012-10-24 18:05:03','2012-11-20 08:29:44','0',0x687474703A2F2F7777772E6D6167617A696E6567656F726765732E636F6D2F66722F77702D636F6E74656E742F7468656D65732F626363742F696D616765732F6C6F676F5F666F6F7465722E676966,'2010-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (130,'a','Numéro Moustache',NULL,'','',0,'',0,0,0,0,'2012',NULL,'','','','','','','','','Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !','http://www.magazinegeorges.com/les-numeros/moustache/','','',0,'','','b','2',1,'','','',' pour ce numero georges vous propose partie 1 histoires partie 2 jeux partie 3 rubriques brac lexique geoges vous souhaite mesdames messieurs agreable lecture ',' numero moustache ','  Numéro Moustache   ',1,'','2012-10-24 18:09:18','2012-12-12 12:20:12','0',0x687474703A2F2F7777772E6D6167617A696E6567656F726765732E636F6D2F66722F77702D636F6E74656E742F75706C6F6164732F323031312F30342F6D6F757374616368652E6A7067,'2012-10-24',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (131,'a','Numéro Cupcake',NULL,'','',0,'',0,0,0,0,'2012',NULL,'','','','','','','','','Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !','http://www.magazinegeorges.com/les-numeros/cupcake/','','',0,'','','b','2',1,'','','',' pour ce numero georges vous propose partie 1 histoires partie 2 jeux partie 3 rubriques brac lexique geoges vous souhaite mesdames messieurs agreable lecture ',' numero cupcake ','  Numéro Cupcake   ',1,'','2012-10-24 18:14:29','2012-12-12 12:19:50','0',0x687474703A2F2F7777772E6D6167617A696E6567656F726765732E636F6D2F66722F77702D636F6E74656E742F75706C6F6164732F323031312F30342F4E554D45524F2D474154454155332E6A7067,'2012-10-24',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (132,'a','Studio ciné live magazine',NULL,'','',0,'',50,0,0,0,'2009-',NULL,'','1969-9441',NULL,NULL,NULL,NULL,'Magazine mensuel.\r\nFusion de : \"Studio magazine\", ISSN 0982-8354\r\net de : \"Ciné live\", ISSN 1253-4250','','','http://www.lexpress.fr/culture/cinema/','','',0,'','','s','1',1,'',' magazine mensuel fusion studio magazine issn 0982 8354 cine live issn 1253 4250 ','','',' studio cine live magazine ','  Studio ciné live magazine   ',1,'','2012-10-25 09:19:02','2012-11-20 08:29:44','0',0x687474703A2F2F70726F66696C652E616B2E666263646E2E6E65742F6870726F66696C652D616B2D70726E312F32373534345F37313831383632333239375F393634355F6E2E6A7067,'2009-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (133,'a','Dark Shadows',NULL,'','dossier Tim Burton',0,'',0,0,0,0,'2012',NULL,'','','',NULL,NULL,NULL,'','','Tim Burton : une famille mortelle\r\nEva Green : mon journal de tournage\r\nFrankenweenie : l\'autre Burton\r\nTim sur un plateau','','','',0,'','','a','2',1,'','','',' tim burton famille mortelle eva green mon journal tournage frankenweenie autre burton tim sur plateau ',' dark shadows dossier tim burton ','  Dark Shadows   dossier Tim Burton',1,'','2012-10-25 09:26:08','2012-12-12 12:19:02','',0x687474703A2F2F70726F66696C652E616B2E666263646E2E6E65742F6870726F66696C652D616B2D70726E312F32373534345F37313831383632333239375F393634355F6E2E6A7067,'2012-04-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (135,'l','Histoire de Don Quichotte','','','',0,'',51,0,0,0,'1887','','','','1 vol. (100 p.)','pl. en couleur et vignettes gravées sur bois','gr. in-4','','','','','','','',0,'','','m','0',1,'','','','',' histoire don quichotte ','  Histoire de Don Quichotte   ',1,'','2012-11-20 12:35:30','2012-12-11 18:26:01','0','','1887-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
INSERT INTO notices (notice_id, typdoc, tit1, tit2, tit3, tit4, tparent_id, tnvol, ed1_id, ed2_id, coll_id, subcoll_id, year, nocoll, mention_edition, code, npages, ill, size, accomp, n_gen, n_contenu, n_resume, lien, eformat, index_l, indexint, index_serie, index_matieres, niveau_biblio, niveau_hierar, origine_catalogage, prix, index_n_gen, index_n_contenu, index_n_resume, index_sew, index_wew, statut, commentaire_gestion, create_date, update_date, signature, thumbnail_url, date_parution, opac_visible_bulletinage, indexation_lang, map_echelle_num, map_projection_num, map_ref_num, map_equinoxe, notice_is_new, notice_date_is_new, opac_serialcirc_demande) VALUES (136,'l','Les fleurs du mal','','','',0,'',52,0,0,0,'1857','','','','1 vol. (248 p.)','','19 cm','','','','','','','',0,'','','m','0',1,'','','','',' fleurs mal ','  Les fleurs du mal   ',1,'','2012-11-20 13:14:46','2012-12-11 18:26:14','0','','1857-01-01',1,'',0,0,0,'',0,'0000-00-00 00:00:00',1);
/*!40000 ALTER TABLE notices ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_authorities_sources`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_authorities_sources (
  num_authority_source int(10) unsigned NOT NULL DEFAULT '0',
  num_notice int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_authority_source,num_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_authorities_sources`
--

LOCK TABLES notices_authorities_sources WRITE;
/*!40000 ALTER TABLE notices_authorities_sources DISABLE KEYS */;
/*!40000 ALTER TABLE notices_authorities_sources ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_authperso`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_authperso (
  notice_authperso_notice_num int(10) unsigned NOT NULL DEFAULT '0',
  notice_authperso_authority_num int(10) unsigned NOT NULL DEFAULT '0',
  notice_authperso_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (notice_authperso_notice_num,notice_authperso_authority_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_authperso`
--

LOCK TABLES notices_authperso WRITE;
/*!40000 ALTER TABLE notices_authperso DISABLE KEYS */;
/*!40000 ALTER TABLE notices_authperso ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_categories`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_categories (
  notcateg_notice int(9) unsigned NOT NULL DEFAULT '0',
  num_noeud int(9) unsigned NOT NULL DEFAULT '0',
  num_vedette int(3) unsigned NOT NULL DEFAULT '0',
  ordre_vedette int(3) unsigned NOT NULL DEFAULT '1',
  ordre_categorie smallint(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (notcateg_notice,num_noeud,num_vedette),
  KEY num_noeud (num_noeud)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_categories`
--

LOCK TABLES notices_categories WRITE;
/*!40000 ALTER TABLE notices_categories DISABLE KEYS */;
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (110,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (111,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (112,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (113,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (114,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (115,1788,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (115,1398,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (116,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (116,1398,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (117,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (117,1398,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (118,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (118,1398,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (119,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (119,1398,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (109,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (109,1597,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (108,1392,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (107,1600,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (107,1392,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (106,2479,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (105,1433,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (104,1433,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (103,1433,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (102,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (101,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (100,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (100,1724,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (99,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (99,1724,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (98,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (98,1560,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (97,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (97,1560,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (96,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (96,1560,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (95,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (94,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (94,1561,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (93,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (92,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (91,2225,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (90,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (89,1780,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (89,1788,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (88,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (87,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (86,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (85,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (84,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (83,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (82,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (81,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (80,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (79,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (78,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (78,2053,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (77,2053,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (77,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (76,2053,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (76,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (75,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (75,2053,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (74,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (73,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (72,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (72,1597,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (71,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (71,1657,0,1,1);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (70,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (69,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (68,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (120,1650,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (121,1788,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (122,2021,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (123,1696,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (124,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (125,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (126,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (127,1658,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (128,1563,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (129,1563,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (131,1560,0,1,0);
INSERT INTO notices_categories (notcateg_notice, num_noeud, num_vedette, ordre_vedette, ordre_categorie) VALUES (132,1392,0,1,0);
/*!40000 ALTER TABLE notices_categories ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` mediumtext COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_custom`
--

LOCK TABLES notices_custom WRITE;
/*!40000 ALTER TABLE notices_custom DISABLE KEYS */;
/*!40000 ALTER TABLE notices_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_custom_lists (
  notices_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  notices_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  notices_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY notices_custom_champ (notices_custom_champ),
  KEY i_ncl_lv (notices_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_custom_lists`
--

LOCK TABLES notices_custom_lists WRITE;
/*!40000 ALTER TABLE notices_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE notices_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_custom_values (
  notices_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  notices_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  notices_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  notices_custom_text mediumtext COLLATE utf8_unicode_ci,
  notices_custom_integer int(11) DEFAULT NULL,
  notices_custom_date date DEFAULT NULL,
  notices_custom_float float DEFAULT NULL,
  KEY notices_custom_champ (notices_custom_champ),
  KEY notices_custom_origine (notices_custom_origine),
  KEY i_ncv_st (notices_custom_small_text),
  KEY i_ncv_t (notices_custom_text(255)),
  KEY i_ncv_i (notices_custom_integer),
  KEY i_ncv_d (notices_custom_date),
  KEY i_ncv_f (notices_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_custom_values`
--

LOCK TABLES notices_custom_values WRITE;
/*!40000 ALTER TABLE notices_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE notices_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_externes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_externes (
  num_notice int(11) NOT NULL DEFAULT '0',
  recid varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (num_notice),
  KEY i_recid (recid),
  KEY i_notice_recid (num_notice,recid)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_externes`
--

LOCK TABLES notices_externes WRITE;
/*!40000 ALTER TABLE notices_externes DISABLE KEYS */;
/*!40000 ALTER TABLE notices_externes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_fields_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_fields_global_index (
  id_notice mediumint(8) NOT NULL DEFAULT '0',
  code_champ int(3) NOT NULL DEFAULT '0',
  code_ss_champ int(3) NOT NULL DEFAULT '0',
  ordre int(4) NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  pond int(4) NOT NULL DEFAULT '100',
  lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  authority_num varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  PRIMARY KEY (id_notice,code_champ,code_ss_champ,lang,ordre),
  KEY i_value (`value`(300)),
  KEY i_code_champ_code_ss_champ (code_champ,code_ss_champ)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci
/*!50100 PARTITION BY KEY (code_champ,code_ss_champ)
PARTITIONS 50 */;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_fields_global_index`
--

LOCK TABLES notices_fields_global_index WRITE;
/*!40000 ALTER TABLE notices_fields_global_index DISABLE KEYS */;
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,30,0,0,'978-2-87833-390-9',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,30,0,0,'978-2-207-26054-8',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,30,0,0,'978-2-13-057064-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,30,0,0,'978-2-07-057588-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,10,0,0,'ill. en noir et en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,30,0,0,'978-2-7541-0611-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,30,0,0,'978-2-211-05694-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,10,0,0,'ill. en coul., couv. ill. en coul',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,10,0,0,'tout en ill., couv. ill.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,30,0,0,'978-2-278-05277-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,10,0,0,'ill. en noir et en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,10,0,0,'couv. ill.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,30,0,0,'978-2-07-062114-9',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,30,0,0,'978-2-84156-884-0',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,30,0,0,'978-2-01-322406-2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,30,0,0,'978-2-07-061220-8',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,10,0,0,'tout en ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,30,0,0,'978-2-07-013600-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,10,0,0,'ill. en coul., couv. ill. en coul',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,30,0,0,'978-2-244-46006-2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,30,0,0,'978-2-211-04841-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,30,0,0,'978-2-07-077327-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,30,0,0,'978-2-7654-0977-9',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,10,0,0,'ill., couv. ill.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,30,0,0,'978-2-86642-597-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,30,0,0,'978-2-358-80032-7',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,30,0,0,'978-2-264-04873-8',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,10,0,0,'couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,10,0,0,'couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,30,0,0,'978-2-07-041573-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,10,0,0,'couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,10,0,0,'ill. en noir et en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,30,0,0,'978-2-09-253001-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,30,0,0,'978-2-278-06156-3',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,30,0,0,'978-2-87691-819-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,10,0,0,'couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,30,0,0,'978-2-07-053882-9',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,10,0,0,'couv. ill.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,30,0,0,'978-2-203-12937-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,10,0,0,'couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,30,0,0,'978-2-915543-03-2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,10,0,0,'ill. en noir et en coul., jaquette ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,30,0,0,'978-2-364-13008-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,30,0,0,'978-2-84261-438-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,10,0,0,'ill. en noir et en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,10,0,0,'ill. en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,30,0,0,'978-2-02-096487-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,30,0,0,'978-2-02-068730-0',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,10,0,0,'ill. en coul., couv. ill.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,10,0,0,'16/9, coul. (PAL), son., surround (Dolby)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,10,0,0,'19/9, coul. (PAL), son., surround (Dolby)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,10,0,0,'16/9, coul. (PAL), son., surround',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,10,0,0,'16/9, coul. (PAL), son., surround (Dolby)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,10,0,0,'coul. (PAL), sonore',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,30,0,0,'1292-8399',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,30,0,0,'2110-8749',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,30,0,0,'1969-9441',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,30,0,0,'0220-8245',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,10,0,0,'pl. en couleur et vignettes gravées sur bois',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,30,0,0,'978-2-84006-443-5',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,30,0,0,'978-2-7459-5517-3',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,10,0,0,'ill. en noir et en coul., couv. ill. en coul.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,30,0,0,'978-2-915569-13-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,30,0,0,'978-2-211-20487-3',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,30,0,0,'978-2-87767-470-6',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,30,0,0,'978-2-87767-590-1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,30,0,0,'978-2-84006-501-2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,30,0,0,'978-2-8100-0117-0',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,30,0,0,'978-2-84006-581-4',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,30,0,0,'978-2-84172-039-2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,30,0,0,'978-2-905158-75-8',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,30,0,0,'978-2-07-057311-0',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,8,1,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,8,1,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,8,1,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,8,1,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,8,1,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,8,2,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,8,0,'BDP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,8,1,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,8,0,'Fonds propre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,28,1,0,'De baecque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,28,1,0,'Oubrerie',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,27,1,0,'Abouet',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,27,1,0,'Pallier',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,27,1,0,'Association des bibliothécaires français',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,9,0,0,'1 vol. (106-[12] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,27,1,0,'De Boel',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,27,1,0,'Depardon',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,27,1,0,'Dedieu',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,9,0,0,'1 livre (57 p.) - 1 disque compact (48 min 36 s)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,48,'Lingala',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,47,'Lingala',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,41,'Lingala',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,42,'Lingala',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,43,'Lingala',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,44,'Lingala',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,45,'Lingala',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,46,'Lingala',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,34,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,35,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,36,'Lingala',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,37,'Lingala',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,38,'Lingala',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,39,'Lingala',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,40,'Lingala',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,33,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,21,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,20,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,19,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,18,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,17,'Bambara',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,16,'Bambara',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,15,'Bambara',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,14,'Bambara',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,13,'Bambara',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,12,'Bambara',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,11,'Bambara',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,10,'Bambara',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,9,'Bambara',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,8,'Bambara',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,7,'Bambara',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,6,'Bambara',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,5,'Bambara',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,4,'Bambara',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,3,'Bambara',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,2,'Bambara',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,1,'Bambara',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,0,'Bambara',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,32,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,31,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,30,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,29,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,28,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,27,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,26,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,25,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,24,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,23,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,22,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,9,0,0,'1 vol. (non paginé [395] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,9,0,0,'1 vol. (160 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,27,1,0,'Zaïd',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,27,1,0,'Bonnet',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,27,1,0,'Heitz',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,27,1,0,'Bradbury',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,27,1,0,'Gourounas',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,9,0,0,'1 vol. (251 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,27,1,0,'Nantet',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,27,1,0,'Bâ',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,27,1,0,'Freymann',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,9,0,0,'1 DVD vidéo zone 2 (1 h 32 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,9,0,0,'192 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,27,1,0,'Mahy',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,9,0,0,'1 vol. (96-[6] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,27,1,0,'Abouet',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,28,1,0,'Oubrerie',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,9,0,0,'32 p',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,28,1,0,'Guidoux',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,28,1,0,'Prigent',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,27,1,0,'Gay-Para',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,27,1,0,'Guettier',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,9,0,0,'68 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,27,1,0,'Serres',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,11,'Anglais',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,12,'Anglais',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,13,'Anglais',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,14,'Anglais',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,15,'Anglais',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,9,'Anglais',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,4,'Anglais',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,3,'Anglais',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,1,'Anglais',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,0,'Anglais',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,8,'Anglais',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,7,'Anglais',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,9,0,0,'1 DVD (1 h 45 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,9,0,0,'1 vol. (non paginé [72] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,9,0,0,'1 vol. (non paginé [50] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,27,1,0,'Mabanckou',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,27,1,0,'Bravi',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,27,1,0,'Loubier',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,27,1,0,'Corentin',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,27,1,0,'Beinhart',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,0,'Anglais',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,9,0,0,'1 vol. (565 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,9,0,0,'109 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,27,1,0,'Melot',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,9,0,0,'1 disque compact (46 min 41 s)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,9,0,0,'1 disque compact (1 h)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,9,0,0,'1 disque compact',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,9,0,0,'2 disques compacts (57 min, 1 h 01 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,9,0,0,'2 DVD zone 2 (1 h 50 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,9,0,0,'1 DVD zone 2 (1 h 17 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,9,0,0,'1 DVD zone 2 (2 h 51 min)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,27,1,0,'Burton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,9,0,0,'224 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,9,0,0,'128 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,27,1,0,'Blixen',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,9,0,0,'213 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,27,1,0,'Freymann',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,9,0,0,'1 vol. (non paginé [24] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,9,0,0,'1 vol. (non paginé [26] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,27,1,0,'Teyras',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,9,0,0,'1 vol. (138 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,9,0,0,'28 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,9,0,0,'1 vol. (non paginé [22] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,9,0,0,'1 vol. (non paginé [26] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,9,0,0,'1 vol. (138 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,9,0,0,'56 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,9,0,0,'1 vol. (450 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,9,0,0,'1 vol. (127 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,9,0,0,'1 vol. (non paginé [30] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,9,0,0,'Non paginé [40] p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,49,'Lingala',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,50,'Lingala',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,51,'Lingala',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,52,'Lingala',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,9,0,0,'179 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,27,1,0,'Akkouche',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,27,1,0,'Boulnois',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,34,1,53,'Lingala',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,9,0,0,'32 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,0,'???????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,1,'Inglês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,9,0,0,'1 vol. (non paginé [31] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,27,1,0,'Gravett',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,27,1,0,'Gudule',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,28,1,0,'Durual',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,27,1,0,'Brisou-pellen',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,1,'Anglais',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,3,'Anglais',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,4,'Anglais',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,7,'Anglais',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,8,'Anglais',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,9,'Anglais',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,11,'Anglais',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,12,'Anglais',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,13,'Anglais',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,14,'Anglais',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,15,'Anglais',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,16,'Anglais',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,35,1,17,'Anglais',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,0,'Anglais',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,1,'Anglais',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,3,'Anglais',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,4,'Anglais',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,7,'Anglais',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,8,'Anglais',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,9,'Anglais',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,11,'Anglais',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,12,'Anglais',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,13,'Anglais',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,14,'Anglais',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,15,'Anglais',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,16,'Anglais',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,35,1,17,'Anglais',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,9,0,0,'215 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,27,1,0,'Bella Ola',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,28,1,0,'Cuvilliez',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,9,0,0,'1 vol. (non paginé [40] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,9,0,0,'1 vol. (non paginé [20] p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,27,1,0,'Gravett',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,0,'Anglais',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,1,'Anglais',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,2,'Anglais',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,3,'Anglais',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,4,'Anglais',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,5,'Anglais',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,7,'Anglais',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,8,'Anglais',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,9,'Anglais',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,11,'Anglais',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,12,'Anglais',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,13,'Anglais',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,14,'Anglais',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,15,'Anglais',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,16,'Anglais',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,35,1,17,'Anglais',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,4,'Saozneg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,3,'English',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,9,0,0,'279 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,27,1,0,'Pratchett',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,9,0,0,'270 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,27,1,0,'Pratchett',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,16,'Anglais',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,17,'Anglais',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,18,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,19,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,20,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,21,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,22,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,23,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,24,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,25,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,26,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,27,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,28,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,29,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,30,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,31,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,32,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,33,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,34,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,34,1,35,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,27,1,0,'Makeba',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,27,1,0,'Lo',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,9,0,0,'1 disque compact',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,27,1,0,'Keita',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,27,1,0,'Amadou & Mariam',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,33,1,0,'Géo',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,33,1,0,'Géo',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,33,1,0,'Géo',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,27,1,0,'ENSSIB',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,27,1,0,'Bonnet',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,33,1,0,'Bulletin des bibliothèques de France',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,33,1,0,'Bulletin des bibliothèques de France',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,27,1,0,'Aïoutz',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,33,1,0,'Bulletin des bibliothèques de France',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,27,1,0,'Interactica',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,0,'Français',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,1,'Français',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,3,'Français',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,4,'Français',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,33,1,0,'Georges',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,33,1,0,'Georges',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,7,'Français',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,8,'Français',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,9,'Français',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,11,'Français',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,12,'Français',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,13,'Français',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,14,'Français',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,15,'Français',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,16,'Français',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,34,1,17,'Français',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,33,1,0,'Studio ciné live magazine',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,9,0,0,'1 vol. (100 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,27,1,0,'Cervantès Saavedra',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,8,'?????',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,4,'Galleg',0,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,9,0,0,'1 vol. (248 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,27,1,0,'Baudelaire',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,9,'Francese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,10,'Français',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,9,0,0,'190 p.',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,28,1,0,'Elffers',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,5,'Français',0,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,6,'Français',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,7,'francés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,6,'Anglais',0,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,7,'anglés',0,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,28,1,0,'Elffers',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,9,0,0,'1 vol. (172 p.)',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,27,1,0,'Marechera',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,0,'?????',0,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,1,'Francês',0,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,2,'Français',0,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,34,1,3,'French',0,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,8,'??',0,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,9,'Inglese',0,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,10,'Anglais',0,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,11,'Engels',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,12,'English',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,13,'Inglês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,14,'English',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,15,'Anglès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,16,'Inglés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,35,1,17,'??????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,27,1,0,'Traoré',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,11,'Frans',0,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,12,'French',0,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,13,'Francês',0,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,14,'French',0,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,15,'Francès',0,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,16,'Francés',0,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,34,1,17,'?????',0,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,6,0,'DVD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,6,0,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,6,1,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,6,0,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,6,1,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,6,0,'Livre-CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,6,0,'Livre audio',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,6,1,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,6,1,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,6,1,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,6,1,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,6,2,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,6,0,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,6,0,'Livre',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,6,0,'DVD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,6,0,'DVD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,6,0,'DVD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,6,0,'DVD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,6,0,'CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,6,0,'CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,6,0,'CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,6,0,'CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,6,0,'CD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,6,0,'Revue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,8,0,0,'[Nouvelle éd.]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,8,0,0,'Nouvelle éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,8,0,0,'12e éd. mise à jour',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,8,0,0,'12e éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,19,5,0,'Boulogne-Billancourt',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,17,0,0,'Bibliothèques;Livres et lecture',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,19,5,1,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,19,5,0,'[Bruxelles]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,17,0,0,'Afrique;Photographies',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,19,5,0,'[Vanves]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,7,0,0,'2002',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,17,0,0,'Comptines;Afrique centrale',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,19,5,0,'[Issy-les-Moulineaux]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,17,0,0,'Afrique;Photographies',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,17,0,0,'Jeunesse - Albums;Musique et instruments;Contes, comptines et poésie',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,19,5,0,'Rodez',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,17,0,0,'Afrique noire;Géographie;Ouvrages pour la jeunesse;Afrique noire;Histoire;Ouvrages pour la jeunesse',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,7,0,0,'2007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,17,0,0,'Romans;Jeunesse;Littérature jeunesse;Albums;Jeunesse en format poche',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,19,5,0,'Nantes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,17,0,0,'Cuisine (fruits);Cuisine (légumes)',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,19,5,0,'Nantes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,7,0,0,'2007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,19,5,0,'La Roque-d\'Anthéron',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,17,0,0,'Bibliothèques',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,17,0,0,'Livres lus en format CD',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,19,5,0,'Champigny-sur-Marne',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,19,5,0,'Neuilly-sur-Seine',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,17,0,0,'Cuisine (légumes);Ouvrages pour la jeunesse;Cuisine (fruits);Ouvrages pour la jeunesse',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,17,0,0,'Bibliothéconomie;France',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,17,0,0,'Bibliothécaires;Déontologie;Bibliothécaires;Travail',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,19,5,0,'Neuilly-sur-Seine',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,19,5,0,'Neuilly-sur-Seine',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,7,0,0,'2005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,7,0,0,'2003',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,17,0,0,'Littérature;Romans contemporains;Littérature au format poche;Romans en Poche',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,7,0,0,'2000',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,19,5,0,'[Paris]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,17,0,0,'Artisanat de nature;Ouvrages illustrés',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,19,5,0,'[Voisins-le-Bretonneux]',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,7,0,0,'1992',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,17,0,0,'Jardinage;Albums;Jeunesse - Documentaires;Eveil, petite enfance, albums à colorier',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,7,0,0,'2007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,19,5,0,'Toulouse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,7,0,0,'2002',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,7,0,0,'2005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,17,0,0,'Littérature jeunesse;BD, Mangas, Humour',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,7,0,0,'2000',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,17,0,0,'Jeunesse;Jeunesse - Albums;Lecteurs en herbe : 6-8 ans',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,7,0,0,'2007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,7,0,0,'2004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,7,0,0,'2011',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,7,0,0,'1995-',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,7,0,0,'2010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,19,5,0,'Lyon',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,7,0,0,'2009-',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,7,1,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,7,0,0,'1979-',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,7,0,0,'2010-',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,7,1,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,7,0,0,'2005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,7,0,0,'2003',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,7,0,0,'2004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,7,1,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,7,0,0,'2005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,7,1,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,7,0,0,'2011',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,7,1,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,7,2,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,7,0,0,'2004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,7,0,0,'2009',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,7,0,0,'2007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,7,0,0,'2011',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,7,0,0,'2009',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,7,0,0,'1996',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,7,0,0,'1993',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,17,0,0,'Jeunesse;L\'Univers des Enfants',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,7,0,0,'2011',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,7,0,0,'2004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,7,0,0,'2006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,7,0,0,'2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,19,5,0,'Villeurbanne',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,7,1,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,7,0,0,'1887',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,7,0,0,'1857',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,17,0,0,'Cuisine africaine',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,7,0,0,'2003',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,19,5,0,'Paris',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,7,0,'Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,7,0,0,'2012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,7,0,'Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,19,1,0,'Columbia Tristar home video',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,19,1,0,'Cah cinema',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,19,1,0,'Arola',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,19,1,0,'Gallimard',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,19,1,0,'Gallimard',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,19,1,0,'Hachette Jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,19,1,0,'Éd. du Cercle de la librairie',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,19,1,1,'l\'école des loisirs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,19,1,0,'Pastel',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,19,1,0,'Hazan',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,19,1,0,'Seuil',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,19,1,0,'Didier jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,19,1,0,'les Éd. du Toucan',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,19,1,0,'Denoël',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,19,1,0,'Éd. First',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,19,1,0,'Circonflexe',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,19,1,0,'Twentieth century Fox',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,19,1,0,'Gallimard Jeunesse Musique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,19,1,0,'Gallimard',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,19,1,0,'Éd. du Rouergue',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,19,1,0,'Seuil',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,19,1,0,'Kaléidoscope',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,19,1,0,'Milan',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,19,1,0,'l\'Atalante',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,19,1,0,'Gallimard jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,19,1,0,'Casterman',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,19,1,0,'Rue du monde',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,19,1,0,'Didier jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,19,1,0,'Mila éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,19,1,0,'10-18',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,19,1,0,'l\'Atalante',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,19,1,0,'Gallimard jeunesse - Giboulées',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,19,1,0,'Vents d\'ailleurs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,19,1,0,'Serpent à plumes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,19,1,0,'Kaléidoscope',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,19,1,0,'l\'École des loisirs-Loulou & Cie',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,19,1,0,'Presses universitaires de France',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,19,1,0,'Gallimard',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,19,1,0,'Éd. Lito',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,19,1,0,'Warner home video',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,19,1,0,'Warner home video',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,19,1,0,'l\'école des loisirs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,19,1,0,'Nathan',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,19,1,0,'Gallimard',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,19,1,0,'l\'Oeil neuf éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,19,1,0,'Warner home video',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,19,1,0,'Mila éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,19,1,0,'Mila éd.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,19,1,0,'Participations éditions presse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,19,1,0,'Éd. Grains de sel',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,19,1,0,'Studio magazine',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,19,1,0,'Manteca',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,19,1,0,'AZ',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,19,1,0,'Universal music jazz France',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,19,1,0,'Universal Polydor',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,19,1,0,'Because music',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,19,1,0,'ENSSIB',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,19,1,0,'Garnier frères',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,19,1,0,'Poulet-Malassis et De Broise',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,29,3,0,'1953-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,3,1,'1970-...',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,3,0,'1952-...',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,29,3,0,'1942-2003',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,3,2,'1932-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,3,1,'1944-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,3,0,'1941-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,29,3,0,'1953-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,29,3,0,'1964-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,29,3,0,'1953-....',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,29,3,0,'1971-...',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,3,2,'1755-1794',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,3,1,'1817-1882',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,3,0,'1808-1892',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,28,3,0,'1966-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,28,3,0,'1963-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,28,3,0,'1966-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,5,1,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,5,2,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,5,0,'Empruntable',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,6,0,0,'2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,6,0,0,'1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,4,1,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,4,2,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,6,0,0,'1',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,6,0,0,'2',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,4,0,'Bibliothèque PMB Services',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,27,3,0,'1971-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,27,3,0,'1971-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,27,3,0,'1944-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,27,3,0,'1975-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,27,3,0,'1942-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,27,3,0,'1949-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,27,3,0,'1938-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,27,3,0,'1957-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,27,3,0,'1920-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,27,3,0,'1901-1991',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,27,3,0,'1936-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,27,3,0,'1956-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,27,3,0,'1962-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,27,3,0,'1956-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,27,3,0,'1948-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,27,3,0,'1948-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,27,3,0,'1965-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,27,3,0,'1952-1987',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,27,3,0,'1966-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,27,3,0,'1965-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,27,3,0,'1936-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,27,3,0,'1947-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,27,3,0,'1943-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,27,3,0,'1885-1962',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,27,3,0,'1932-2008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,27,3,0,'1956-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,27,3,0,'1974-....',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,27,3,0,'1547-1616',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,27,3,0,'1821-1867',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,15,0,0,'http://bbf.enssib.fr/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,15,0,0,'http://www.poissonrouge.com/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,15,0,0,'http://www.magazinegeorges.com/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,15,0,0,'http://www.magazinegeorges.com/les-numeros/moustache/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,15,0,0,'http://www.magazinegeorges.com/les-numeros/cupcake/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,15,0,0,'http://www.lexpress.fr/culture/cinema/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,15,0,0,'http://www.geo.fr/',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,20,2,0,'Arts et loisirs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,20,2,0,'Bibliothèques - et lecture, documentation',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,20,2,0,'Histoire de l\'Afrique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,2,0,'960 DEP',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,20,2,0,'Musique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,20,2,0,'Bibliothèques - et lecture, documentation',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,20,2,0,'Musique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,2,0,'DVD BEE',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,2,0,'DVD EDW',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,20,2,0,'Littérature américaine',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,20,2,0,'Bibliothèques - et lecture, documentation',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,20,2,0,'Arts ménagers - cuisine, couture, soins de beauté',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,2,0,'DVD BIG',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,2,0,'020 PAL',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,2,0,'C BAA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,2,0,'780 J SIL',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,2,0,'RA BLI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,2,0,'PER J GEO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,2,1,'PER J GEO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,2,0,'PER GEO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,2,1,'PER GEO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,2,0,'780 J GRO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,20,2,0,'Histoire de l\'Afrique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,2,0,'A DED',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,2,0,'A DEB',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,2,1,'A DEB',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,2,0,'BD ABO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,2,0,'BD ABO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,2,0,'R MAB',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,2,0,'R MAR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,2,0,'A GRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,2,0,'RJ GUD',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,2,0,'RJP HEI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,20,2,0,'Bibliothèques - et lecture, documentation',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,2,0,'020 ASS',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,2,1,'020 ASS',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,2,0,'JR BRI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,2,0,'RP BEI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,2,0,'RJ MAH',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,2,0,'020 BON',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,2,0,'640 BEL',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,20,2,0,'Géographie - voyages',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,2,0,'A GOU',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,2,0,'BD J GUE',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,2,0,'A GAY',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,2,1,'A GAY',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,20,2,0,'Botanique - (les plantes)',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,2,0,'A COR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,2,1,'A COR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,2,2,'A COR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,2,0,'640 J LOU',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,20,2,0,'Arts ménagers - cuisine, couture, soins de beauté',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,20,2,0,'Arts ménagers - cuisine, couture, soins de beauté',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,2,0,'740 FRE',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,20,2,0,'Dessin - arts décoratifs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,2,0,'A BRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,2,0,'A GRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,2,0,'RX BRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,2,0,'RX PRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,2,0,'RX PRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,2,0,'P BUR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,20,2,0,'Arts et loisirs',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,2,0,'700 DEB',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,2,0,'DVDJ NOC',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,2,0,'DVDJ CHAR',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,2,0,'9.1 MAK',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,2,0,'9.1 LO',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,2,0,'9.1 TRA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,2,0,'9.1 KEI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,2,0,'9.1 AMA',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,2,0,'PER STU',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,2,0,'740 J FRE',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,2,0,'910 J NAN',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,20,2,0,'Arts ménagers - cuisine, couture, soins de beauté',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,2,0,'640 J SER',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,2,0,'580 J GUI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,2,0,'960 ZAI',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,2,0,'020 MEL',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,2,0,'700 J TIM',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,2,0,'640 J TEY',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,21,1,0,'Album',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,20,1,0,'700',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,20,1,0,'700',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,21,1,0,'Bayou',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,21,1,0,'Bayou',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,21,1,0,'L.d.p.jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,21,1,0,'Que sais-je ?',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,21,1,0,'Le métier de',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,20,1,0,'020',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,20,1,0,'960',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,21,1,0,'Crea.jeunesse',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,21,1,0,'Un Livre, un cd',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,20,1,0,'780',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,20,1,0,'960',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,20,1,0,'020',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,20,1,0,'640',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,21,1,0,'Mes Premières Découvertes de la Musique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,20,1,0,'780',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,21,1,0,'Folio',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,20,1,0,'910',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,21,1,0,'Collection dirigée par Henri Gougaud',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,21,1,0,'Folio cadet',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,20,1,0,'640',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,21,1,0,'À petits petons',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,20,1,0,'640',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,21,1,0,'Littérature étrangère',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,20,1,0,'810',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,20,1,0,'740',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,21,1,0,'Fragments',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,20,1,0,'020',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,21,1,0,'Écoutez lire',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,20,1,0,'640',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,21,1,0,'Collection Warner',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,20,1,0,'580',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,21,1,0,'Collection Série noire',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,20,1,0,'020',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,21,1,0,'Sagesse d\'un métier',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,21,1,0,'Les encyclopes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,21,1,0,'Kididoc',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,21,1,0,'Revue dada',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,29,2,0,'Ewan',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,29,2,0,'Yves',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,2,2,'Chantal',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,2,1,'Elodie',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,2,0,'Paul',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,29,2,0,'Jean-Luc',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,29,2,1,'Johnny',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,29,2,0,'Winona',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,29,2,1,'Jacques',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,29,2,0,'Henri',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,2,2,'Quentin',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,2,1,'Marie',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,2,0,'Raymond',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,29,2,0,'Marie-Christine',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,29,2,0,'Martin',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,29,2,0,'Patrick',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,29,2,0,'Patrick',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,29,2,1,'Xavier',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,29,2,0,'Mickael',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,29,2,0,'Patrice',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,29,2,0,'Johnny',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,29,2,0,'Florent',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,29,2,0,'Marthe',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,2,2,'Jean-Pierre Claris de',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,2,1,'Gustave',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,2,0,'Jules',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,29,2,0,'Jean-Baptiste',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,14,0,0,'La bibliothécaire a confié un terrible secret à Jojo et depuis, il n\'est plus le même...\r\nUne fiction pleine d\'humour sur l\'apprentissage de la lecture. A lire dès le CP.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,4,0,0,'l\'Afrique noire en 30 comptines',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,14,0,0,'Depuis plus de vingt ans Raymond Depardon a parcouru tout le continent africain auquel il a consacré plusieurs films. Il a réalisé ainsi une grande quantité de photographies dont 350 inédites sont présentées dans cet ouvrage. Ces photographies couvrent toute l\'Afrique, à travers une présentation non pas par pays mais par associations originales. Ces associations privilégient un rythme soutenu, sans temps d\'arrêt, des enchaînements qui montrent la vie au travers de sujets très variés : portraits, villes, paysages, religions, activités sociales et métiers mais aussi des conflits et la misère. A travers ses photographies, exemptes de toute volonté d\'esthétiser son propos, Raymond Depardon ne livre aucun jugement sur l\'Afrique, aucune thèse. Ce qui relie entre elles ces prises de vue, c\'est l\'impulsion de l\'?il, simplement un regard de photographe et de grand voyageur sur les paysages et les hommes qui peuplent ce continent. Pourquoi des Afriques ? Depuis 1960, année de ma première rencontre avec le continent africain à l\'âge de dix-huit ans, et jusqu\'à mon dernier voyage cet hiver au Horar, je n\'ai cessé de photographier l\'Afrique. Mais que de lieux, de temps différents ! Une vie toute entière ne suffirait pas à prétendre connaître cette Afrique. Aujourd\'hui, les prétextes, les raisons de ces voyages sont oubliés. C\'est pour cela que j\'avais envie de faire ce livre, pour rendre la liberté à toutes ces photographies et enfin réunir toutes ces Afriques, celles des pistes, des sourires, des famines et des guerres civiles. Je voulais oser ces quatre cents pages de photographies sous respiration. Je voulais étouffer devant l\'immense Afrique, me trouver comme au bord d\'une route où nous serions en panne pour plusieurs jours, envahis, à rester silencieux et à écouter. Je me souviens de chaque lieu, de chaque temps. J\'ose le désordre, il le faut. Je réunis ces photographies prises pendant quarante-cinq ans de voyages en Afrique. Raymond Depardon',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,14,0,0,'Pour la première fois, une sélection de comptines et berceuses les plus représentatives de l\'Afrique noire, de la Cote-d\'Ivoire au Rwanda, dans la diversité des langues (lingala, wolof, bambara, peul, sango...) Chaque comptine est transcrite dans sa langue d\'origine et traduite en français. Les commentaires culturels sont regroupés à la fin de l\'ouvrage.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,4,0,0,'paysages et pensées',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,14,0,0,'Laissez-vous envoûter par le son de la kora, du balafon, du khollé, des djembés, du tama, l\'accent du narrateur et les voix incomparables des frères Toure.Partez à la découverte des musiques d\'Afrique !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,4,0,0,'et autres émotions naturelles',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,14,0,0,'Pourquoi la vielle dame qui habite en face de chez Guillaume écrit-elle très tard la nuit? Quelle est cette jeune fille qui ne sort de chez elle qu\'à le nuit tombée? Pour résoudre ces mystères, Guillaume se lance dans un fantastique voyage au pays des livres et de l\'écriture',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,4,0,0,'her essential recordings ; the empress of African song',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,14,0,0,'Fidèle à son univers d\'une inventivité si  particulière, mêlant crauté et tendresse,  macabre et poésie, Tim Burton donne le jour à une  étonnante famille d\'enfants solitaires, étranges et  différents, qui ne tarderont pas à nous horrifier,  à nous émouvoir et à nous faire rire.  Un livre pour l\'enfant qui est en nous',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,14,0,0,'451 degrés Fahrenheit représentent la température à laquelle un livre s\'enflamme et se consume.Dans cette société future où la lecture, source de questionnement et de réflexion, est considérée comme un acte antisocial, un corps spécial de pompiers est chargé de brûler tous les livres, dont la détention est interdite pour le bien collectif.Montag, le pompier pyromane, se met pourtant à rêver d\'un monde différent, qui ne bannirait pas la littérature et l\'imaginaire au profit d\'un bonheur immédiatement consommable. Il devient dès lors un dangereux criminel, impitoyablement poursuivi par une société qui désavoue son passé.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,4,0,0,'22 recettes d\'enfants',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,4,0,0,'60 recettes pour découvrir les fruits et les légumes du monde',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,4,0,0,'par l\'inspecteur Lapou',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,14,0,0,'Avez-vous peur de mourir dans votre sommeil, enseveli sous l\'écroulement de votre bibliothèque ? L\'accumulation de livres ne met-elle pas en danger l\'existence même de votre famille ? Classez-vous les volumes par thème, langue, auteur, date de parution, format ou selon un autre critère de vous seul connu ? Peut-on faire voisiner sur une étagère deux auteurs irrémédiablement brouillés dans la vie ? Autant de graves questions se posant à cette espèce en voie de disparition : les bibliomanes, qui, outre la passion de posséder les livres, ont celle de les lire. Les bibliothèques sont des êtres vivants à l\'image de notre complexité intérieure. Elles finissent par composer un labyrinthe dont pour notre plus grand, et dangereux, plaisir nous pouvons très bien ne plus sortir. Dans ce petit traité sur l\'art de vivre avec trop de livres apparaissent, parmi nombre d\'autres, Pessoa tentant de devenir bibliothécaire, Matisse postulant au poste de «contrôleur du droit des pauvres» ou encore le capitaine Achab et le mystère de sa jambe abandonnée à Moby Dick. En fait, ces milliers de pages qui occupent nos étagères sont peuplées de fantômes bien vivants qui, une fois rencontrés, ne nous quittent plus.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,14,0,0,'En kidnappant Mlle Labourdette, la ravissante bibliothécaire, le chef des brigands et ses quatre complices croient pouvoir obtenir de la municipalité une rançon rondelette. Mais c\'est compter sans le courage de la jeune fille, son bon c?ur et ses talents de... bibliothécaire !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,14,0,0,'Travaillant dans une université huppée de Washington D.C, David Golberg devient, par le plus grand des hasards, le bibliothécaire privé d\'Alan Stowe. Vieil acariâtre multimillionnaire, industriel cynique et sans scrupules, Stowe est surtout le plus grand bailleur de fonds du parti républicain. Or, nous sommes justement en pleine élection présidentielle et l\'équipe du candidat sortant, un gosse de riche va-t-en-guerre, ancien alcoolique reconverti en fou de Dieu, voit d\'un mauvais ?il l\'arrivée de cet inconnu auprès d\'un homme aussi influent que Stowe. À peine Golberg a-t-il le temps de commencer le classement des papiers de l\'homme d\'affaires qu\'il se retrouve pris en chasse par des barbouzes de la Sécurité intérieure. Tandis que la candidate démocrate grignote son retard sur le Président et que le grand jour du vote se rapproche, David, aidé d\'une bande d\'amis, se voit contraint de trouver dans les documents de Stowe l\'information pour laquelle on veut le tuer... Après Reality Show, adapté au cinéma sous le titre Des hommes d\'influence avec Dustin Hoffman et Robert De Niro, Larry Beinhart fait un retour fracassant sur la scène littéraire, démontant pièce par pièce l\'administration Bush, sa manière de manipuler le public américain et l\'opinion mondiale en jouant avec des peurs et des fantasmes archaïques. Comme quoi les critiques les plus virulentes ne viennent pas toujours de la « vieille Europe »...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,14,0,0,'À la fois lieux de travail pour des recherches contemporaines et lieux de conservation d\'un patrimoine, les bibliothèques ont un rôle charnière entre le passé et le présent. Mais si leur mission demeure identique, les moyens mis à leur disposition, ainsi que les modes de consultation et d\'usage des livres, sont aujourd?hui en pleine mutation.\r\n\r\nCet ouvrage s\'assigne donc une double tâche : présenter l\'histoire des bibliothèques dans le monde occidental afin de comprendre l\'ampleur des changements qu?elles connaissent depuis un siècle, et donc les nouveaux enjeux culturels et économiques engendrés par de telles évolutions.\r\n\r\nDocteur en histoire, Denis Pallier est inspecteur général honoraire des bibliothèques.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,14,0,0,'Quatrième de couverture\r\n« Que les choses soient claires : je ne souhaite pas être plus grand que l’Angoualima, ni me greffer des petits doigts, je veux être apprécié en fonction du résultat de mon geste criminel. Ne pouvant égaler les prouesses du Grand Maître, j\'aimerais au moins être considéré comme son fils spirituel. Pour cela, j\'en suis conscient, je dois encore travailler : tuer Germaine ce 29 décembre, c\'est-à-dire dans deux jours, n\'est qu\'une étape vers ce couronnement. »\r\n\r\nGrégoire Nakobomayo, orphelin, a grandi dans une ville industrielle de l\'Afrique post-coloniale. Accueilli quelque temps chez un couple instruit, il reçoit une éducation bourgeoise jusqu\'au jour où il plante son crayon dans l\'oeil du fils unique qui cherche à le violer. Obligé de fuir, il se réfugie dans le quartier le plus délabré de la ville et prend pour modèle \"Angoualima\", le célèbre serial killer qui depuis des années défie le pays, ses juges, ses flics et ses journalistes. Mais n\'est pas serial killer qui veut\r\nAvec humour -et.ironie-Alain Mabanckou conte les déboires d\'un psychopathe velléitaire et sans talent qui cherche dans la perversité un sens à sa vie.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,4,0,0,'un conte populaire africain',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,14,0,0,'Le symbole mystérieux d\'un collier qui a une perle de trop. La réalité crue qui vient anéantir le rêve et le bonheur offerts à une jeune aristocrate insouciante. L\'aventure, dans le port d\'Anvers, d\'un écrivain malheureux, qui fuit sa propre vie... Tels sont les thèmes et les personnages de ces trois contes. Et à travers eux, Karen Blixen nous démontre que le conte est bien l\'instrument privilégié de l\'exploration des mystères de la personnalité. Le doux velours du timbre d\'Anne Brochet nous transporte dans l\'univers mystérieux des contes de Karen Blixen. Une lecture posée qui met en mouvement l\'imagination de l\'auditeur. L\'écoute en classe de ces CD est autorisée par l\'éditeur',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,4,0,0,'le réveil d\'un continent',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,4,0,0,'Le rêve ultime des voyageurs',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,14,0,0,'Les bibliothèques publiques ont souvent pour origine des collections privées. Mais la fréquentation de ces bibliothèques n\'empêche pas, accompagne même, le goût pour constituer sa bibliothèque privée, « la reconstitution à son usage propre d\'une sorte de bibliothèque publique ». La gestion de ces bibliothèques privées se heurte aux mêmes problèmes que les bibliothèques institutionnelles, comme le classement, le rangement, mais aussi la politique d\'acquisition, même si le caractère privé de sa bibliothèque autorise de nombreuses licences au propriétaire des livres, « bibliothécaire de soi-même ». L\'obligation de conservation et d\'entretien est évidente, si celle de désherbage, désormais largement pratiqué dans les bibliothèques publiques, l\'est moins - tout comme le catalogage, et a fortiori le prêt.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,14,0,0,'La trajectoire d\'un usager des bibliothèques publiques, de l\'enfance à aujourd\'hui : autodidacte, il fréquente assidûment la bibliothèque municipale de Montreuil-sous-Bois, « copropriétaire d\'une BM unique dans la commune... Ma première patrie fut cette bibliothèque » ; le contact permanent des livres, le passage difficile de l\'adolescence, puis le « boulot d\'auteur », toujours accompagné des bibliothèques. « Aujourd\'hui, je ne ressemble pas à mes gosses. À cause ou grâce à ces livres empruntés chaque semaine, j\'ai quitté une classe sociale... sans jamais en trouver une autre de rechange. »',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,4,0,0,'dossier Tim Burton',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,14,0,0,'Le concept de Georges\r\n\r\nBienvenue dans l’univers de Georges, petit – petit – petit magazine, revue alternative trimestrielle créée par les Éditions Grains de Sel, pour les enfants ni trop petits ni trop grands (dès 7-8 ans et jusqu’à 12 ans). Mais aussi pour les plus grands qui s’intéressent au graphisme et à l’illustration.\r\n \r\nMais qui est Georges ?\r\nUn magazine décalé et exigeant qui stimule la curiosité et revisite les traitements traditionnels des magazines pour enfants.\r\n\r\nQuels sont ses atouts ?\r\nUn graphisme épuré  et un thème original pour chaque numéro, sur un beau papier offset et recyclé, avec des illustrateurs aux univers sensibles et un second degré qui séduit les enfants (et même leurs parents).\r\n\r\nComment se présente-t-il ?\r\nPartie 1 – des HISTOIRES vraies, courtes, longues ou à l’envers.\r\nPartie 2 – des JEUX à colorier, calculer ou déchiffrer autour du thème du numéro.\r\nPartie 3 – des RUBRIQUES-À-BRAC pour découvrir des métiers, langues étrangères, scènes de films ou expériences scientifiques, mais de façon toujours farfelue&#8201;!',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,4,0,0,'petit-petit-petit magazine',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,4,0,0,'Timbélélé et la reine Lune',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,14,0,0,'Tim Burton : une famille mortelle\r\nEva Green : mon journal de tournage\r\nFrankenweenie : l\'autre Burton\r\nTim sur un plateau',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,14,0,0,'Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,14,0,0,'Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,14,0,0,'Mariant évolution des techniques et analyse des territoires ruraux, cet article se veut une réflexion (et une incitation) sur le travail en commun, une « théorie de la pratique », la mise en oeuvre professionnelle et partagée de la société de la connaissance. L\'exemple du RISOM (Réseau intercommunal et solidaire des médiathèques de Tence, St-Jeures et Le Mazet-St-Voy, Haute-Loire), qui propose le partage d\'informations sur des projets d\'animation, leurs outils et leurs usages, vient à l\'appui et en illustration de cette analyse.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,14,0,0,'Présentation de l\'éditeur\r\nCaneton, mouton, pingouin ou jeune chien... Vous allez fondre pour ces délicieux bébés animaux... A croquer !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,4,0,0,'roman',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,14,0,0,'Synopsis\r\nBarbara et Adam forment un adorable couple. Hélas survient un stupide accident de voiture et les voilà devenus fantômes obligés de hanter les murs de leur propre demeure ! Quelle n\'est pas leur déception lorsqu\'ils la voient livrée aux mains d\'une famille excentrique dont les membres évoluent entre hystérie et stupidité. Barbara et Adam tentent de les chasser. En vain. La seule solution : faire appel à Beetlejuice, un fantôme exorciseur de vivants...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,14,0,0,'Synopsis\r\nApprenant qu\'Edward, son père, est sur le point de mourir, Will décide de se rapprocher de lui pour enfin connaître cet homme qui a bercé son enfance avec des contes plus ou moins fantastiques dans lesquels il se mettait en scène aux côtés de personnages extravagants et extraordinaires...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,14,0,0,'Synopsis\r\nQuelles sont les merveilles qui t\'attendent dans l\'usine de Willy Wonka ? Pars à la découverte de vastes étendues d\'herbe sucrée au bon goût de menthe dans la Salle du Chocolat... Navigue sur la Rivière de Chocolat dans un grand bateau en sucre rose... Essaye le Gobestoppeur sans fin dans la Salle des Inventions... Observe les talentueux écureuils de la Salle de Tri des Noix et voyage en ascenseur de verre jusqu\'à la Salle de Télévision. Tu y trouveras une montagne d\'humour saupoudrée d\'un peu de mystère... et une aventure aussi savoureuse et agréable qu\'une tablette de Délice Fondant Wonka Guimauve-Caramel...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,14,0,0,'Présentation de l\'éditeur\r\nUne plongée au coeur de l\'Afrique, mère de l\'humanité et continent phare du IIIe millénaire. Face aux visions d\'une Afrique déchirée, voici de nouveaux éclairages. A travers des questions comme la désertification, la déforestation, l\'exode rural, la colonisation ou l\'explosion démographique, le continent se livre en profondeur. Sa géographie a été une donnée décisive, ses peuples se sont adaptés à une nature difficile. L\'Afrique, c\'est une histoire remplie d\'épisodes épiques d\'une richesse insoupçonnée, assombrie parla terrible période de l\'esclavage. C\'est aussi une leçon de courage et de solidarité inépuisables.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,4,0,0,'plus de 60 recettes faciles à réaliser',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,14,0,0,'Présentation de l\'éditeur\r\nSénégal, Mali, Cameroun, Congo, Côte d\'Ivoire, logo, Nigeria, Gabon... L\'Afrique Noire, dans son immense diversité, offre aux palais amateurs de bonne chère, des plats savoureux et délicats qui, contrairement aux idées reçues, peuvent être simples à réaliser dès lors que l\'on dispose des connaissances et du savoir-faire indispensables. Plus de 60 recettes faciles à réaliser : A travers un large choix de recettes, composé entre autres des grands classiques (Tiep, Yassa, Mafé, Saka-Saka, Mbongo...), les auteurs de cet ouvrage nous accompagnent pas à pas pour réaliser le meilleur de la cuisine africaine. Présentation des ingrédients spécifiques à la préparation des plats (arachide, manioc, graines de courge...), portraits légendés, trucs et astuces, recettes étape par étape... dans ce beau livre riche en photos, la cuisine africaine se met enfin à la portée de fous ! Un beau livre de cuisine pour goûter et apprécier toutes les saveurs de l\'Afrique Noire : Et pour qu\'au plaisir de la bouche se joigne celui de l\'esprit et de la vue, des proverbes, des textes, des photos viennent agrémenter de-ci de-là les recettes.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,14,0,0,'Présentation de l\'éditeur\r\nVoici un voyage extraordinaire au pays des fruits et des légumes. Des recettes qui nous les font découvrir différemment, des informations sur leur culture ou leur étonnante histoire, des proverbes du monde entier qui les célèbrent et les peintures de Martin Jarrie qui nous disent tout de leur chair et de leur saveur.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,14,0,0,'Synopsis\r\nEdward est la création d\'un savant génial. Il ne possède pas de vrais mains, mais des lames très tranchantes à la place des doigts. Il peut réaliser avec ses instruments de véritables oeuvres d\'art, qui vont provoquer la curiosité et l\'enthousiasme de toute la ville. Mais il est capable de blesser et de faire mal quand il ne se contrôle plus...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,14,0,0,'Présentation de l\'éditeur\r\nOh la belle verte! Si les légumes et les fruits étaient aussi beaux dans la réalité que dans cette « encyclopédie », les enfants les dévoreraient !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,14,0,0,'Présentation de l\'éditeur\r\nLes livres, ça fait désordre et ça prend la poussière, c\'est tout. Voilà ce que pense Fulbert le bibliothécaire. D\'ailleurs, il n\'y a qu\'un seul livre dans sa bibliothèque ! Mais voici qu\'arrive la ravissante Rose-Marie, assoiffée de lecture. Fulbert, ébloui et troublé, est bien désemparé. Il va falloir qu\'il trouve des livres, et vite !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,14,0,0,'Présentation de l\'éditeur\r\nSais-tu faire germer des graines ? Quel est l\'outil le plus précieux du jardinier ? Qu\'est-ce qui pousse au bout du monde ?',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,14,0,0,'Présentation de l\'éditeur\r\nC\'est l\'histoire d\'un lapin qui emprunte un ouvrage à la bibliothèque de son quartier, et qui découvre l\'extraordinaire, l\'incroyable pouvoir qu\'ont certains livres sur leur lecteur, parfois...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,14,0,0,'Synopsis\r\nAu XIXe siècle, dans un village d\'Europe de l\'est, Victor, un jeune homme, découvre le monde des morts après avoir épousé, sans le vouloir, le cadavre d\'une mystérieuse mariée. Pendant son voyage, sa promise, Victoria l\'attend désespérément dans le monde des vivants. Bien que la vie au Royaume des Morts s\'avère beaucoup plus animée et joyeuse que sa véritable existence, Victor apprend que rien au monde, pas même la mort, ne pourra briser son amour pour sa femme...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,14,0,0,'Présentation de l\'éditeur\r\nUne orange, une pomme, une poire et un ours, Grégoire. Qui aurait imaginé que ces quatre mots puissent être conjugués en autant de façons ? Emily gravett, bien sûr !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,14,0,0,'Présentation de l\'éditeur\r\nQuelle tête fais-tu lorsque tu es heureux ? Fatigué ? Fâché ? Ou que tu t\'es fait gronder ? Toutes les moues et expressions enfantines, des plus drôles aux plus tendres, sous la forme de fruits et légumes hilarants !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,14,0,0,'Présentation de l\'éditeur\r\nL\'Afrique se dévoile, au fil de magnifiques photographies accompagnées de pensées, de poèmes et de proverbes emplis de philosophie, à l\'image de ce continent dont la beauté invite à la médiation. Un voyage en terre d\'émerveillement, guidé par le regard de nombreux écrivains et d\'hommes engagés, pour découvrir un espace fascinant, ses paysages, sa faune et ses habitants.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,14,0,0,'Présentation de l\'éditeur\r\nLe bibliothécaire aime les livres comme le marin aime la mer. Il n\'est pas nécessairement bon nageur mais il sait naviguer. L\'océan du savoir qui grise tous les savants, rend modeste le bibliothécaire. La bibliothèque est ce lieu indispensable où le savoir décante. Regardez comme cet océan furieux se calme dans la bibliothèque ! Le bibliothécaire sait lire les livres sans les ouvrir. Son regard transperce\r\nles couvertures. Il visite la page de titre, l\'auteur, les éditeurs, va directement au colophon, relève la date, le format,\r\nle nombre de pages, s\'attarde sur la table des matières, vérifie s\'il y a des index. Il évalue enfin sa robustesse et la qualité de son papier, celle de sa mise en page et de son impression.\r\nTout est dit. Si les auteurs savaient cela, ils feraient de faux livres uniquement pour les bibliothèques.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,14,0,0,'Présentation de l\'éditeur\r\nIl y eut un long il était une fois…\r\nD’une écriture libre, anarchiste, de la même veine qu’un chant de Joyce où la structure vole en éclat…\r\nIl était une fois, un jeune narrateur, qu’importe son nom, pendu par les pieds par un chef aussi noir que les origines de l’homme, tiraillé par la faim et qui rêve de Blanche Goodfather en train de se baigner nue du côté des Chutes du Rocher. Fin…\r\nIl était une fois un amour magnifique, Marie, aveugle, comme seul personnage lucide parmi ceux qui sont pris au piège de la violence et de l’absurdité d’un pays sous apartheid… De jeunes gens dans l’émeute, émeute du langage, émeute de la pensée, émeute du regard sur le monde, sur la vie, contre un système…\r\nSoleil noir (écrit en 1980) est ce roman éclaté où l’auteur balaie d’un revers de la main la frontière entre le réel et l’irréel, entre le conte et le témoignage, entre le rêve et la pensée, nous propulsant littéralement sans un monde aveuglé que seul le dérèglement du langage peut appréhender. Roman de la révolte, Soleil noir, publié pour la première fois en français, est un roman mythique de Marechera, écrit entre la rue et de fréquents séjours en prison.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,14,0,0,'Présentation de l\'éditeur\r\nIl était une fois un garçon qui aimait inventer des histoires. Il se dit qu\'un homme déguisé en chauve-souris, ça ferait peur aux méchants. Il pense à la petite fille qui passe de l\'autre côté du miroir et découvre un monde merveilleux. A la femme qui se prend pour un chat et qui joue avec l\'homme pingouin. Il se dit qu\'une citrouille ne remplacera jamais le Père Noël, mais qu\'elle pourrait avoir envie d\'essayer. Il imagine ce qui se passerait si les habitants de Mars attaquaient la Terre... Son rêve, c\'était de rassembler toutes ces histoires et tous leurs personnages. Aujourd\'hui, le petit garçon est devenu grands et il fait du cinéma. Le tour du monde des musées en BD et en jeu .: le musée du Palais a Pékin.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,14,0,0,'Présentation de l\'éditeur\r\nLes fruits et les légumes, c\'est trop bon ! Au fil de ces 22 recettes, découvre les fruits et les légumes comme tu ne les as encore jamais goûtés ! En glaces, en gratins, en pizzas ou même en gaufres ! Pas de doute, tes papilles adoreront tous ces petits plats concoctés spécialement par les enfants... pour les enfants ! Entre enfants, on se comprend !',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,14,0,0,'Quatrième de couverture\r\nDans une dimension lointaine et passablement farfelue, un monde se balade à dos de quatre éléphants, eux©mêmes juchés sur la carapace de la Grande Tortue... Oui, c\'est le Disque©monde... Les habitants de la cité d\'Ankh©Morpork croyaient avoir tout vu. Et Deuxfleurs avait l\'air tellement inoffensif, bonhomme chétif, fidèlement escorté par un Bagage de bois magique déambulant sur une myriade de petites jambes. Tellement inoffensif que le Patricien avait chargé le calamiteux sorcier Rincevent de sa sécurité dans la cité quadrillée par la Guilde des Voleurs et celle des Assassins ; mission périlleuse et qui devait les conduire loin : dans une caverne de dragons ; peut©être jusqu\'au Rebord du Disque. Car Deuxfleurs était d\'une espèce plus redoutable qu\'on ne l\'imaginait : c\'était un touriste... A la lumière de l\'octarine, la huitième couleur, celle de la magie, découvrez l\'univers fantastique et cocasse de Terry Pratchett.',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,14,0,0,'Présentation de l\'éditeur\r\nOctogénaire, borgne, chauve et édenté, Cohen le Barbare, le plus grand héros de tous les temps, réussira-t-il à tirer Deuxfleurs et Rincevent des griffes de leurs poursuivants ? Question capitale, car le tissu même du temps et de l\'espace est sur le point de passer dans l\'essoreuse. Une étoile rouge menace de percuter le Disque-Monde et la survie de celui-ci est entre les mains du sorcier calamiteux : dans son esprit (très) brumeux se tapit en effet le... huitième sortilège ! La suite de l\'épopée la plus démente de la fantasy, avec, dans les seconds rôles, une distribution prestigieuse : le Bagage, l\'In-Octavo, Herrena la harpie, Kwartz le troll, Trymon l\'enchanteur maléfique et, naturellement, La Mort...',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,14,0,0,'Côte d\'Ivoire, 1978. Aya, dix-neuf ans, vit à Yopougon, un quartier populaire d\'Abidjan. Ça sent le début des vacances mais très vite les choses vont commencer à se gâter…«Dans les années 1970, la vie était douce en Côte d’Ivoire. Il y avait du travail, les hôpitaux étaient équipés et l’école était obligatoire. J’ai eu la chance de connaître cette époque insouciante, où les jeunes n’avaient pas à choisir leur camp trop vite, et ne se préoccupaient que de la vie courante : les études, les parents, les amours… Et c’est cela que je veux raconter dans \"Aya\", cette Afrique qui subsiste malgré tout car, comme on dit chez nous, «la vie continue»…» (Marguerite Abouet)',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,3,0,'Vidéothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,3,0,'Vidéothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,13,0,0,'LE MONDE QUI CHANGE\r\nLa mortalité infantile amorce son déclin.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nMo Ibrahim, cinquante-trois pays dans son collimateur.\r\n\r\nLE GOÛT DE GEO\r\nLe yassa poulet, ou l’hospitalité sénégalaise.\r\n\r\nÉVASION - Namibie, la nouvelle arche de Noé\r\nDans des espaces gérés par les habitants, la faune sauvage s’est multipliée, les touristes affluent et les populations en tirent un revenu.\r\n\r\nMODES DE VIE\r\nAfrican Valley(s) - L’Afrique aussi voit naître ces lieux où les technologies boostent la croissance.\r\nCampus en ébullition - Démographie oblige, les étudiants se pressent dans les universités d’Afrique subsaharienne.\r\n\r\nENVIRONNEMENT\r\nCinq chantiers qui vont changer l’Afrique.\r\nDov Zerah - Les deux défis à relever.\r\n\r\nGÉOPOLITIQUE - Région des Grands Lacs : la poudrière magnifique\r\nC’est un territoire riche, mais marqué par des décennies de conflits. La paix et le développement y font aujourd’hui leur chemin.\r\n\r\nCARTE DÉTACHABLE - Le réveil de l\'Afrique\r\n\r\nLE BON PLAN - Le Cap des Capétoniens\r\n\r\nGÉOPOLITIQUE - L\'eldorado de l\'Afrique latine\r\nL’Angola vit un boom exceptionnel. Portugais, Brésiliens ou Chinois viennent y tenter leur chance.\r\n\r\nGRANDE SÉRIE \"LA FRANCE DES VILLAGES\" - La Bourgogne\r\nPanorama mensuel des pépites du terroir.',120,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,13,0,0,'ÉVASION - La dernière frontière du Pacifique\r\nÀ des milliers de kilomètres de toute terre émergée, l’île de Pâques et ses statues géantes fascinent toujours les voyageurs.\r\n\r\nMODES DE VIE - Le Grand Paris\r\nÀ quoi ressemblera le Grand Paris ? Un métro de 200 kilomètres, un port gigantesque à Achères, une Silicon Valley à Saclay… La future mégapole commence à dévoiler son nouveau visage.\r\n\r\nENVIRONNEMENT - L\'iPhone est-il écolo ?\r\nÉtape par étape, l’analyse de l’impact environnemental du petit bijou d’Apple.\r\n\r\nVOYAGE - La nouvelle vie de Cracovie\r\nLa cité polonaise est l’un des lieux les plus touristiques de l’ancien bloc de l’Est. Grâce à sa richesse culturelle et à sa jeunesse qui crée une ambiance de «movida».\r\n\r\nPARTIR - Quoi de neuf à Bruxelles ?\r\nMalgré la crise institutionnelle qui paralyse le pays, la capitale belge n’a pas perdu sa créativité. Tables, hôtels, shopping… Tour d’horizon des nouvelles adresses.\r\n\r\nGÉOPOLITIQUE - Comment la Chine redessine le monde\r\nEn Grèce, en Birmanie, en Zambie… Partout, les Chinois financent et bâtissent des ports, des routes, des hôpitaux. C’est la phase nouvelle du «zouchuqu», leur stratégie de conquête tous azimuts.\r\n\r\nLE MONDE EN CARTES - Pourquoi la Kapisa est dans l’oeil du cyclone ?\r\nProche de Kaboul, cette province est la zone de tous les dangers pour les militaires français.\r\n\r\nGRANDE SÉRIE : LE LITTORAL FRANÇAIS - LA NORMANDIE\r\nNotre photographe livre son coup d’oeil sur les hauts lieux de la côte normande. Et notre journaliste analyse les enjeux du moment sur le plan du tourisme et de l’environnement.',120,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,13,0,0,'LE MONDE QUI CHANGE\r\nLe patrimoine de la Syrie sous la menace.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nCe chirurgien indien qui prend à cœur la santé de son pays.\r\n\r\nLE GOÛT DE GEO\r\nLe «dim-sum», un microfestin à la chinoise.\r\n\r\nÉVASION - Dans le sillage d\'Ulysse\r\nHeureux qui comme le héros d\'Homère a fait un beau voyage... GEO a suivi ses pas en Méditerranée.\r\n\r\nESCALE - Jean Didier Urbain\r\nVite parcouru, mal lu.\r\n\r\nMODES DE VIE - A la vie, à la mer\r\nReportage sur ces marins pêcheurs qui écument les océans glacés et bravent les tempêtes.\r\n\r\nENVIRONNEMENT - Faut-il se préparer aux grandes sécheresses ?\r\nIl fait plus sec et plus chaud. Résultat, la terre a soif et les agriculteurs trinquent.\r\n\r\nVOYAGE - Le renouveau des chemins sacrés\r\nLes marcheurs affluent vers les routes spirituelles à la recherche du grand voyage intérieur.\r\n\r\nLE BON PLAN - Le Bilbao des Bilbotars\r\n\r\nGÉOPOLITIQUE - Terres fertiles à louer\r\nDe puissants investisseurs étrangers trustent les meilleurs champs des pays du Sud. Néocolonialisme ou développement agricole ?\r\n\r\nLE MONDE EN CARTES - Des îles très disputées\r\n\r\nGRANDE SÉRIE - La France des villages\r\nPérigord et Quercy : panorama mensuel des pépites du terroir.',120,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,3,0,0,'BBF',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,3,0,'Revues',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,3,1,'Revues',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,3,0,'Revues',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,3,1,'Revues',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,3,1,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,3,0,'Bandes-dessinées Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,3,0,'Bandes-dessinées Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,3,0,'Romans Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,3,0,'Romans Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,3,1,'Réserve',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,3,0,'Romans Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,3,0,'Romans Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,3,0,'Bandes-dessinées Jeunes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,3,1,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,3,1,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,3,2,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,3,0,'Albums',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,3,0,'Romans Adultes',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,3,0,'Documentaires',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,3,0,'Vidéothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,3,0,'Vidéothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,3,0,'Vidéothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,3,0,'Discothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,3,0,'Discothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,3,0,'Discothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,3,0,'Discothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,3,0,'Discothèque',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,3,0,'Revues',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,90,1,0,'000002',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,27,2,0,'Marguerite',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,90,1,0,'000036',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,27,2,0,'Denis',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,27,2,0,'Anne-Catherine',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,27,2,0,'Raymond',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,27,2,0,'Thierry',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,90,1,0,'000057',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,27,2,0,'Jacques',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,27,2,0,'Bruno',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,90,1,0,'000001',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,27,2,0,'Ray',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,27,2,0,'Amadou Hampâté',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,90,1,0,'000047',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,27,2,0,'Margaret',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,90,1,0,'000039',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,27,2,0,'Praline',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,27,2,0,'Bénédicte',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,90,1,0,'000023',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,90,1,0,'000016',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,90,1,0,'000015',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,27,2,0,'Jean',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,90,1,0,'000049',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,90,1,0,'000018',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,90,1,0,'000040',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,27,2,0,'Virginie',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,90,1,0,'000003',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,27,2,0,'Philippe',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,27,2,0,'Larry',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,90,1,0,'000044',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,90,1,0,'000004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,90,1,0,'000005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,90,1,0,'000020',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,90,1,0,'000059',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,90,1,0,'000011',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,90,1,0,'000060',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,27,2,0,'Karen',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,27,2,0,'Jacques',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,1,0,'P000004',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,90,1,1,'P000005',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,27,2,0,'Philippe',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,1,0,'P000002',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,90,1,1,'P000003',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,90,1,0,'000054',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,90,1,0,'000056',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,27,2,0,'Nassera',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,1,0,'000052',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,90,1,1,'000053',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,90,1,0,'000051',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,27,2,0,'Marguerite',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,27,2,0,'Alain',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,90,1,0,'000048',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,27,2,0,'Emily',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,90,1,0,'000046',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,90,1,0,'000045',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,27,2,0,'Michel',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,1,0,'000041',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,90,1,1,'000042',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,27,2,0,'Evelyn',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,90,1,0,'000038',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,90,1,0,'000037',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,90,1,0,'000034',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,27,2,0,'Bernard',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,90,1,0,'000030',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,90,1,0,'000029',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,1,0,'000028',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,90,1,1,'000027',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,90,1,0,'000026',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,1,0,'000032',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,1,1,'000031',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,90,1,2,'000025',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,90,1,0,'000024',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,27,2,0,'Alain',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,27,2,0,'Emmanuelle',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,90,1,0,'000021',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,27,2,0,'Saxton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,27,2,0,'Saxton',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,27,2,0,'Soledad',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,27,2,0,'Emily',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,90,1,0,'000017',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,27,2,0,'Terry',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,27,2,0,'Terry',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,90,1,0,'000014',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,90,1,0,'000013',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,90,1,0,'000012',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,27,2,0,'Tim',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,27,2,0,'Miriam',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,90,1,0,'000006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,27,2,0,'Ismaël',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,90,1,0,'000007',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,90,1,0,'000008',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,27,2,0,'Rokia',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,27,2,0,'Salif',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,90,1,0,'000009',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,90,1,0,'000010',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,27,2,0,'Mouloud',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,27,2,0,'Renaud',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,90,1,0,'P000006',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,27,2,0,'Charles',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,27,2,0,'Miguel de',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,90,1,0,'000033',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,27,2,0,'Alexandre',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,90,1,0,'000019',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,90,1,0,'000058',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,27,2,0,'Dambudzo',110,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,90,1,0,'000022',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,90,1,0,'000050',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,28,2,0,'Anto',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,28,2,0,'Clément',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,28,2,0,'Joëlle',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,28,2,0,'Clément',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,28,2,0,'Andrée',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,28,2,0,'Valerie',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,28,2,0,'Joost',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,28,2,0,'Christophe',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,28,2,0,'Joost',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,25,1,1,'Cinéma - Télévision',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,25,1,1,'Littérature d\'Afrique noire',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,23,1,0,'Aya de Yopougon',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,25,1,1,'Littérature d\'Afrique noire',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,23,1,0,'Aya de Yopougon',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,25,1,0,'Ethnologie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,23,1,0,'Jojo',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,25,1,0,'Fantastique et merveilleux',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,24,1,0,'Science-fiction',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,23,1,0,'Les annales du disque-monde',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,25,1,0,'Fantastique et merveilleux',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,25,1,0,'Cuisine',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,25,1,0,'Cuisine',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,25,1,0,'Poésie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,25,1,0,'Fantastique et merveilleux',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,23,1,0,'Les annales du disque-monde',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,25,1,1,'Littérature d\'Afrique noire',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,25,1,1,'Littérature d\'Afrique noire',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,25,1,0,'Cuisine',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,24,1,0,'Fantastique',75,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,25,1,0,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,25,1,0,'Jardinage',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,25,1,0,'Arts plastiques',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,25,1,0,'Géographie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,25,1,0,'Jeux et jouets',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,25,1,0,'Jeux et jouets',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,25,1,0,'Cinéma',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,25,1,0,'Arts plastiques',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,25,1,0,'Musique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,25,1,1,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,25,1,0,'Ile de Pâques',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,25,1,0,'Religion',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,25,1,0,'Bibliothéconomie',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,25,1,0,'Cuisine',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,25,1,0,'Cuisine',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,25,1,1,'Légumes',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,25,1,0,'Afrique',110,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,12,0,0,'Contient un lexique ivoirien-français, recettes culinaires, conseils de vie pratique',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,12,0,0,'Contient des comptines de différents pays en différentes langues : Congo (mingala), Mali (bambara), Cameroun (bamena), Côte d\'Ivoire (bambara), Mauritanie (peul), Togo (mina), Sénégal (wolof), Rwanda (kinyarwanda), Guinée (susu), Mali (soninke), Centrafrique (sängö), Guinée-Conakry (susu), Congo (kikongo)',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,12,0,0,'Contient diverses pensées, poèmes et proverbes de différents auteurs\r\nIndex',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,12,0,0,'Réunit : \"L\'enterrement de la carotte\" ; \"Le pissenlit écrasé\" ; \"La disparition du jeune poireau\" ; \"L\'agression du champignon\" ; \"La chute de la tomate\" ; \"Le poseur de lapins\" ; \"Le voleur de courgettes\" ; \"Le cerisier dévalisé\" ; \"La bande de radis\" ; \"Le citron trop pressé\"',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,12,0,0,'A pour suite dans le même ouvrage : \"Zigomar n\'aime pas du tout les légumes et il a bien raison\"',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,0,'Périodique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,1,'Périodique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,2,'Périodique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,3,'Périodique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,4,'Périodique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,5,'Périodique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,6,'Périodique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,7,'Périodique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,8,'Périodique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,9,'Périodique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,10,'Périodique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,11,'Périodique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,12,'Périodique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,13,'Périodique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,14,'Périodique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,15,'Périodique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,16,'Périodique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,32,0,17,'Périodique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,7,'Bulletin',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,6,'Bulletin',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,0,'Bulletin',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,1,'Bulletin',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,2,'Bulletin',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,3,'Bulletin',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,4,'Bulletin',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,5,'Bulletin',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,7,'Bulletin',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,6,'Bulletin',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,0,'Bulletin',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,1,'Bulletin',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,2,'Bulletin',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,3,'Bulletin',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,4,'Bulletin',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,5,'Bulletin',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,9,'Bulletin',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,8,'Bulletin',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,0,'Bulletin',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,1,'Bulletin',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,2,'Bulletin',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,3,'Bulletin',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,4,'Bulletin',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,5,'Bulletin',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,6,'Bulletin',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,7,'Bulletin',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,17,'Périodique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,14,'Périodique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,13,'Périodique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,12,'Périodique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,11,'Périodique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,10,'Périodique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,9,'Périodique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,8,'Périodique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,7,'Périodique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,6,'Périodique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,5,'Périodique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,4,'Périodique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,3,'Périodique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,2,'Périodique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,1,'Périodique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,0,'Périodique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,16,'Périodique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,32,0,15,'Périodique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,13,'Article',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,9,'Article',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,10,'Article',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,11,'Article',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,12,'Article',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,6,'Article',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,7,'Article',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,8,'??',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,0,'Article',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,1,'Article',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,2,'Article',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,3,'Article',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,4,'Article',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,5,'Article',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,7,'Article',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,8,'Article',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,9,'Article',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,10,'Article',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,11,'Article',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,12,'Article',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,13,'Article',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,14,'Article',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,15,'Article',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,16,'Article',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,17,'Article',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,5,'Article',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,4,'Article',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,3,'Article',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,2,'Article',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,1,'Article',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,0,'Article',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,32,0,6,'Article',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,10,'Article',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,12,'Article',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,7,'Article',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,9,'Article',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,0,'Article',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,11,'Article',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,8,'??',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,1,'Article',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,2,'Article',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,3,'Article',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,4,'Article',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,5,'Article',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,6,'Article',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,12,'Document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,11,'Document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,10,'Document',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,9,'Document',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,8,'Document',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,7,'Document',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,5,'Document',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,4,'Document',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,3,'Document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,1,'Document',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,32,0,0,'Document',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,17,'Périodique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,16,'Périodique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,15,'Périodique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,14,'Périodique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,13,'Périodique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,12,'Périodique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,11,'Périodique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,10,'Périodique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,9,'Périodique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,8,'Périodique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,7,'Périodique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,6,'Périodique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,5,'Périodique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,4,'Périodique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,3,'Périodique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,2,'Périodique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,1,'Périodique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,32,0,0,'Périodique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,8,'???? check-in',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,9,'Serial check-in',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,10,'Serial check-in',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,5,'Serial check-in',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,6,'Bulletin',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,7,'Serial check-in',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,0,'Serial check-in',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,1,'Serial check-in',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,2,'Bulletin',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,3,'Serial check-in',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,4,'Serial check-in',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,15,'Sèrie check-in',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,16,'Serial check-in',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,7,'Serial check-in',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,8,'???? check-in',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,9,'Serial check-in',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,10,'Serial check-in',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,6,'Bulletin',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,11,'Serial check-in',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,12,'Serial check-in',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,13,'Serial check-in',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,14,'Serial check-in',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,17,'Périodique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,16,'Périodique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,15,'Périodique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,14,'Périodique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,13,'Périodique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,12,'Périodique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,11,'Périodique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,10,'Périodique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,9,'Périodique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,8,'Périodique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,7,'Périodique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,6,'Périodique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,5,'Périodique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,4,'Périodique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,3,'Périodique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,2,'Périodique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,1,'Périodique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,32,0,0,'Périodique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,12,0,0,'Magazine mensuel.\r\nFusion de : \"Studio magazine\", ISSN 0982-8354\r\net de : \"Ciné live\", ISSN 1253-4250',100,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,12,'Article',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,11,'Article',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,9,'Article',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,6,'Article',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,8,'??',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,0,'Article',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,10,'Article',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,7,'Article',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,1,'Article',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,2,'Article',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,3,'Article',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,4,'Article',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,5,'Article',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,8,'Bulletin',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,9,'Bulletin',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,13,'Document',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,14,'Document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,15,'Document',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,16,'Document',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,32,0,17,'Document',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,10,'Bulletin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,11,'Bulletin',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,12,'Bulletin',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,13,'Bulletin',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,14,'Bulletin',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,15,'Bulletin',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,16,'Bulletin',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,32,0,17,'Bulletin',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,8,'Bulletin',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,9,'Bulletin',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,10,'Bulletin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,11,'Bulletin',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,12,'Bulletin',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,13,'Bulletin',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,14,'Bulletin',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,15,'Bulletin',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,16,'Bulletin',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,32,0,17,'Bulletin',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,10,'Bulletin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,11,'Bulletin',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,12,'Bulletin',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,13,'Bulletin',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,14,'Bulletin',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,15,'Bulletin',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,16,'Bulletin',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,32,0,17,'Bulletin',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,0,'Monograph',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,1,'Monograph',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,2,'Document',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,3,'Monograph',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,4,'Monograph',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,5,'Monograph',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,6,'Document',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,7,'Monograph',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,8,'?',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,13,'Article',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,14,'Article',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,15,'Article',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,16,'Article',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,32,0,17,'Article',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,0,'Serial check-in',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,1,'Serial check-in',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,2,'Bulletin',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,3,'Serial check-in',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,4,'Serial check-in',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,5,'Serial check-in',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,32,0,17,'Serial check-in',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,11,'Serial check-in',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,12,'Serial check-in',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,13,'Serial check-in',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,14,'Serial check-in',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,15,'Sèrie check-in',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,16,'Serial check-in',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,32,0,17,'Serial check-in',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,13,'Article',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,14,'Article',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,15,'Article',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,16,'Article',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,32,0,17,'Article',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,9,'Monograph',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,10,'Monograph',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,11,'Monograph',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,12,'Monograph',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,13,'Monograph',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,14,'Monograph',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,15,'Monografia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,16,'Monograph',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,32,0,17,'Monograph',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,14,'Article',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,15,'Article',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,16,'Article',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,32,0,17,'Article',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,29,1,0,'McGregor',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,29,1,0,'Alix',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,1,2,'Grosléziat',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,1,1,'Nouhen',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,29,1,0,'Mindy',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,29,1,0,'Tabuteau',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,29,1,1,'Depp',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,29,1,0,'Ryder',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,29,1,0,'Robillot',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,29,1,1,'Chambon',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,1,2,'Blake',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,1,1,'Saint-Dizier',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,29,1,0,'Farré',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,29,1,0,'Clément',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,29,1,0,'Jarrie',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,29,1,0,'Couton',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,29,1,0,'Couton',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,29,1,1,'Garnier',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,29,1,0,'Keaton',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,29,1,0,'Carrer',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,29,1,0,'Depp',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,29,1,0,'Silloray',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,29,1,0,'Metzger',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,1,2,'Florian',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,1,1,'Staal',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,29,1,0,'David',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,29,1,0,'Evette',80,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,11,'projectie of video',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,0,'document projeté ou vidéo',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,1,'documento de projecção ou vídeo',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,2,'document projeté ou vidéo',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,1,0,0,'Aya de Yopougon',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,17,'document multimédia',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,16,'document multimédia',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,15,'document multimédia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,14,'document multimédia',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,13,'document multimédia',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,12,'document multimédia',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,11,'document multimédia',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,10,'document multimédia',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,9,'document multimédia',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,8,'document multimédia',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,7,'document multimédia',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,6,'document multimédia',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,5,'document multimédia',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,4,'document multimédia',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,3,'document multimédia',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,2,'document multimédia',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,1,'document multimédia',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,31,0,0,'document multimédia',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (71,1,0,0,'Afriques',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,1,0,0,'Cuisine actuelle de l\'Afrique noire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,1,0,0,'La sagesse du bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,0,'document multimédia',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,1,'document multimédia',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,2,'document multimédia',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,3,'document multimédia',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,4,'document multimédia',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,5,'document multimédia',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,6,'document multimédia',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,7,'document multimédia',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,8,'document multimédia',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,9,'document multimédia',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,10,'document multimédia',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,11,'document multimédia',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,12,'document multimédia',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,13,'document multimédia',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,14,'document multimédia',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,15,'document multimédia',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,16,'document multimédia',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,31,0,17,'document multimédia',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,1,0,0,'Sagesse d\'Afrique',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,1,0,0,'Rouge comme une tomate',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,11,'projectie of video',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,6,'document projet?? ou vid??o',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,7,'document projectat o vidèo',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,8,'???,????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,1,0,0,'Big Fish',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,0,'document projeté ou vidéo',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,1,'documento de projecção ou vídeo',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,2,'document projeté ou vidéo',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,3,'video, projectable document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,4,'teul klewelet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,5,'document projeté ou vidéo',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,2,'enregistrement sonore musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,1,0,0,'La bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (80,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,1,0,0,'Au coeur de l\'Afrique',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,1,0,0,'Le grand amour du bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,1,0,0,'Une cuisine grande comme un jardin',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,1,0,0,'Tim Burton',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,1,0,0,'Fruits, légumes',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,1,0,0,'Bébés à croquer',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,12,'video, projectable document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,13,'vídeo, documento projetável',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,6,'document projet?? ou vid??o',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,7,'document projectat o vidèo',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,1,0,0,'Edward aux mains d\'argent',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,0,'document projeté ou vidéo',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,1,'documento de projecção ou vídeo',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,2,'document projeté ou vidéo',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,3,'video, projectable document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,4,'teul klewelet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,5,'document projeté ou vidéo',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,0,'enregistrement sonore non musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,1,'enregistrement sonore non musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,2,'enregistrement sonore non musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,3,'enregistrement sonore non musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,4,'enregistrement sonore non musical',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,5,'enregistrement sonore non musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,6,'enregistrement sonore non musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,7,'enregistrement sonore non musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,8,'enregistrement sonore non musical',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,9,'enregistrement sonore non musical',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,10,'enregistrement sonore non musical',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,11,'enregistrement sonore non musical',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,12,'enregistrement sonore non musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,13,'enregistrement sonore non musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,14,'enregistrement sonore non musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,15,'enregistrement sonore non musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,16,'enregistrement sonore non musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,31,0,17,'enregistrement sonore non musical',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,1,0,0,'Trop bon ! les fruits et les légumes',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,12,'video, projectable document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,13,'vídeo, documento projetável',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,1,0,0,'Les noces funèbres',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,0,'document projeté ou vidéo',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,1,'documento de projecção ou vídeo',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,2,'document projeté ou vidéo',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,3,'video, projectable document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,4,'teul klewelet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,5,'document projeté ou vidéo',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,13,'vídeo, documento projetável',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,9,'materiale visuale',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,10,'görüntü veya video',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,5,'document projeté ou vidéo',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,6,'document projet?? ou vid??o',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,7,'document projectat o vidèo',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,8,'???,????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,1,0,0,'Beetlejuice',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,10,'görüntü veya video',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,11,'projectie of video',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,12,'video, projectable document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,7,'document projectat o vidèo',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,8,'???,????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,9,'materiale visuale',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,1,0,0,'Charlie et la chocolaterie',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,0,'document projeté ou vidéo',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,1,'documento de projecção ou vídeo',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,2,'enregistrement sonore musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,3,'enregistrement sonore musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,4,'enregistrement sonore musical',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,5,'enregistrement sonore musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,6,'enregistrement sonore musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,7,'enregistrement sonore musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,8,'enregistrement sonore musical',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,9,'enregistrement sonore musical',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,10,'enregistrement sonore musical',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,11,'enregistrement sonore musical',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,12,'enregistrement sonore musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,13,'enregistrement sonore musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,14,'enregistrement sonore musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,15,'enregistrement sonore musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,16,'enregistrement sonore musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,17,'enregistrement sonore musical',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,4,'enregistrement sonore musical',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,5,'enregistrement sonore musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,6,'enregistrement sonore musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,7,'enregistrement sonore musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,8,'enregistrement sonore musical',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,9,'enregistrement sonore musical',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,10,'enregistrement sonore musical',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,11,'enregistrement sonore musical',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,12,'enregistrement sonore musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,13,'enregistrement sonore musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,14,'enregistrement sonore musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,15,'enregistrement sonore musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,16,'enregistrement sonore musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,17,'enregistrement sonore musical',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,7,'registrament sonòr musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,9,'registrazioni sonore musicali',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,10,'müzik kayd?',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,5,'enregistrement sonore musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,6,'enregistrement sonore musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,1,0,0,'Tchamantché',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,11,0,0,'1 brochure ([20] p.) : ill. en coul. ; 12 cm',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,0,'enregistrement sonore musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,17,'enregistrement sonore musical',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,16,'enregistrement sonore musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,15,'enregistrement sonore musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,14,'enregistrement sonore musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,11,'enregistrement sonore musical',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,12,'enregistrement sonore musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,13,'enregistrement sonore musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,5,'enregistrement sonore musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,6,'enregistrement sonore musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,7,'enregistrement sonore musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,8,'enregistrement sonore musical',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,9,'enregistrement sonore musical',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,10,'enregistrement sonore musical',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,0,'enregistrement sonore musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,1,'enregistrement sonore musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,2,'enregistrement sonore musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,3,'enregistrement sonore musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,31,0,4,'enregistrement sonore musical',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,3,'enregistrement sonore musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,4,'enregistrement sonore musical',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,5,'enregistrement sonore musical',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,6,'enregistrement sonore musical',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,7,'enregistrement sonore musical',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,8,'enregistrement sonore musical',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,9,'enregistrement sonore musical',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,10,'enregistrement sonore musical',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,11,'enregistrement sonore musical',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,12,'enregistrement sonore musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,13,'enregistrement sonore musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,14,'enregistrement sonore musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,15,'enregistrement sonore musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,16,'enregistrement sonore musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,17,'enregistrement sonore musical',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,1,'enregistrement sonore musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,31,0,0,'enregistrement sonore musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,11,0,0,'1 brochure ([16] p.) : ill. en coul. ; 12 cm',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (119,1,0,0,'Folila',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,11,0,0,'1 livret (16 p.) : ill., 12 cm',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (118,1,0,0,'M\'Bemba',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,12,'sound recording - musical',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,13,'som - musical',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,1,'registo sonoro musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,3,'enregistrement sonore musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,2,'enregistrement sonore musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,1,'enregistrement sonore musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,31,0,0,'enregistrement sonore musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (116,1,0,0,'Jammu Africa',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,1,'enregistrement sonore musical',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,31,0,0,'enregistrement sonore musical',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,11,0,0,'1 livret (8 p.) : ill. ; 12 cm',20,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (115,1,0,0,'Miriam Makeba',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (108,1,0,0,'Tim burton',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (106,1,0,0,'La triste fin du petit enfant huître et autres histoires',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,1,0,0,'Le huitième sortilège',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,1,0,0,'La huitième couleur',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (103,1,0,0,'Fahrenheit 451',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,1,0,0,'Orange, pomme, poire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (96,1,0,0,'Je cuisine avec les fruits et légumes du marché',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (95,1,0,0,'Zigomar n\'aime pas les légumes',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,1,0,0,'Le jardin potager',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (93,1,0,0,'Quel radis dis donc !',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (92,1,0,0,'Les enquêtes du potager',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (91,1,0,0,'Grosse légume',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (88,1,0,0,'Des bibliothèques pleines de fantômes',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (87,1,0,0,'L\'enlèvement de la bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (86,1,0,0,'Le bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (84,1,0,0,'Les bibliothèques',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (83,1,0,0,'Le métier de bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (81,1,0,0,'Jojo et le secret de la bibliothécaire',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,1,0,0,'Les loups',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,1,0,0,'Soleil noir',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (75,1,0,0,'Aya de Yopougon',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (74,1,0,0,'Rafara',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (73,1,0,0,'Yakouba',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (72,1,0,0,'Comptines et berceuses du baobab',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (69,1,0,0,'Contes des sages d\'Afrique',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,2,'document projeté ou vidéo',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,3,'video, projectable document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,4,'teul klewelet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,5,'document projeté ou vidéo',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,6,'document projet?? ou vid??o',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,6,'document projet?? ou vid??o',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,7,'document projectat o vidèo',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,8,'???,????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,9,'materiale visuale',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,10,'görüntü veya video',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,11,'projectie of video',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,12,'video, projectable document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,11,'projectie of video',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,3,'video, projectable document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,4,'teul klewelet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,8,'???,????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,9,'materiale visuale',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,10,'görüntü veya video',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,12,'video, projectable document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,9,'materiale visuale',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,10,'görüntü veya video',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (68,1,0,0,'Les perles et autres contes',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (121,1,0,0,'N° 403 - septembre 2012 - Numéro spécial Afrique',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (122,1,0,0,'N° 393 - novembre 2011 - L\'Île de Pâques',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (123,1,0,0,'N° 402 - août 2012 - Compostelle, Shikoku, Lalibela... Les chemins de la sagesse',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,17,'document électronique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,16,'document électronique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,15,'document électronique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,14,'document électronique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,13,'document électronique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,12,'document électronique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,11,'document électronique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,10,'document électronique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,9,'document électronique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,8,'document électronique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,7,'document électronique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,6,'document électronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,4,'document électronique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,3,'document électronique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,1,'document électronique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (124,1,0,0,'Bulletin des bibliothèques de France',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,11,'elektronisch document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,9,'archivi di elaboratore',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,10,'elektronik belge',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,6,'document ??lectronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,7,'document electronic',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,1,0,0,'Bibliothécaire de soi-même',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,1,'documento electrónico',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,3,'electronic document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,4,'teul elektronek',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,17,'document électronique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,16,'document électronique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,15,'document électronique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,14,'document électronique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,13,'document électronique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,12,'document électronique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,11,'document électronique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,10,'document électronique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,9,'document électronique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,8,'document électronique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,7,'document électronique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,6,'document électronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,4,'document électronique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,3,'document électronique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,1,'document électronique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (126,1,0,0,'Voyages en BM',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,10,'elektronik belge',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,11,'elektronisch document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,12,'electronic document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,7,'document electronic',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,1,0,0,'L\'abeille et le bibliothécaire ou éthique du libre et lecture publique en zone rurale',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,9,'archivi di elaboratore',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,1,'documento electrónico',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,3,'electronic document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,4,'teul elektronek',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,6,'document ??lectronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,17,'document électronique',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,16,'document électronique',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,15,'document électronique',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,14,'document électronique',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,13,'document électronique',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,12,'document électronique',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,11,'document électronique',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,10,'document électronique',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,9,'document électronique',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,8,'document électronique',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,7,'document électronique',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,6,'document électronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,4,'document électronique',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,3,'document électronique',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,1,'document électronique',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (128,1,0,0,'Poisson rouge',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,1,0,0,'Numéro Moustache',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,1,0,0,'Numéro Cupcake',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,17,'texte imprimé',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,16,'texte imprimé',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,15,'texte imprimé',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,14,'texte imprimé',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,13,'texte imprimé',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,12,'texte imprimé',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,11,'texte imprimé',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,10,'texte imprimé',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,9,'texte imprimé',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,8,'texte imprimé',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,7,'texte imprimé',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,6,'texte imprimé',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,4,'texte imprimé',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (132,1,0,0,'Studio ciné live magazine',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,7,'tèxt imprimit',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,1,0,0,'Dark Shadows',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,3,'printed text',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,4,'testenn voulet',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,5,'texte imprimé',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,6,'texte imprim??',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,3,'texte imprimé',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,1,'texte imprimé',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,31,0,0,'texte imprimé',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (120,1,0,0,'Géo',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,11,'geluidsopname (muziek)',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,2,'enregistrement sonore musical',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,3,'sound recording - musical',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,4,'enrolladenn da selaou (sonerezh)',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (129,1,0,0,'Georges',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (109,1,0,0,'La musique africaine',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,10,'elektronik belge',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,7,'document electronic',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,9,'archivi di elaboratore',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,4,'teul elektronek',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,6,'document ??lectronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,1,0,0,'Histoire de Don Quichotte',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,1,'documento electrónico',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,3,'electronic document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,15,'document electrònic',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,12,'electronic document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,13,'documento eletrônico',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,14,'electronic document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,9,'archivi di elaboratore',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,10,'elektronik belge',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,11,'elektronisch document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,1,0,0,'Les fleurs du mal',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,0,'document électronique',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,1,'documento electrónico',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,2,'document électronique',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,3,'electronic document',100,'en_US','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,4,'teul elektronek',100,'br_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,5,'document électronique',100,'hu_HU','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,6,'document ??lectronique',100,'ro_RO','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,7,'document electronic',100,'oc_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,8,'????',100,'ja_JP','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,17,'??????????????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,16,'documento electrónico',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (136,31,0,17,'??????????????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,14,'electronic document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,15,'document electrònic',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,16,'documento electrónico',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,11,'elektronisch document',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,12,'electronic document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (135,31,0,13,'documento eletrônico',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (133,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (131,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (130,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,13,'documento eletrônico',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,14,'electronic document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,15,'document electrònic',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,16,'documento electrónico',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (127,31,0,17,'??????????????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,1,0,0,'African psycho',130,'','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,0,'?? ?????',100,'ar','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,1,'texto impresso',100,'pt_PT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,2,'texte imprimé',100,'fr_FR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (100,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (77,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,13,'vídeo, documento projetável',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,14,'video, projectable document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,15,'document projectable o vídeo',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,16,'documento proyectable o vídeo',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (111,31,0,17,'??????? ??????? vidéo ??? ?????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,14,'video, projectable document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,15,'document projectable o vídeo',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,16,'documento proyectable o vídeo',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (112,31,0,17,'??????? ??????? vidéo ??? ?????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,13,'vídeo, documento projetável',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,14,'video, projectable document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,15,'document projectable o vídeo',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,16,'documento proyectable o vídeo',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (114,31,0,17,'??????? ??????? vidéo ??? ?????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (90,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,9,'materiale a stampa',100,'it_IT','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,10,'bas?l? metin',100,'tr_TR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,11,'gedrukte tekst',100,'nl_NL','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (89,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (97,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,14,'video, projectable document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,15,'document projectable o vídeo',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,16,'documento proyectable o vídeo',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (110,31,0,17,'??????? ??????? vidéo ??? ?????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (101,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (85,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (94,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (79,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,14,'video, projectable document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,15,'document projectable o vídeo',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,16,'documento proyectable o vídeo',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (113,31,0,17,'??????? ??????? vidéo ??? ?????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (102,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (99,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (70,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (82,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (78,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (107,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (98,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (104,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,12,'printed text',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (105,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,13,'texto impresso',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,14,'printed text',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,15,'text imprès',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,16,'texto impreso',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (76,31,0,17,'??????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,14,'sound recording - musical',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,15,'enregistrament sonor musical',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,16,'grabación musical',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (117,31,0,17,'?????????????',100,'la_LA','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,12,'electronic document',100,'en_UK','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,13,'documento eletrônico',100,'pt_BR','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,14,'electronic document',100,'de_DE','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,15,'document electrònic',100,'ca_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,16,'documento electrónico',100,'es_ES','0');
INSERT INTO notices_fields_global_index (id_notice, code_champ, code_ss_champ, ordre, value, pond, lang, authority_num) VALUES (125,31,0,17,'??????????????????',100,'la_LA','0');
/*!40000 ALTER TABLE notices_fields_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_global_index (
  num_notice mediumint(8) NOT NULL DEFAULT '0',
  no_index mediumint(8) NOT NULL DEFAULT '0',
  infos_global mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_infos_global mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_notice,no_index)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_global_index`
--

LOCK TABLES notices_global_index WRITE;
/*!40000 ALTER TABLE notices_global_index DISABLE KEYS */;
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (121,1,'    N° 403 - septembre 2012 - Numéro spécial Afrique   le réveil d\'un continent   LE MONDE QUI CHANGE\r\nLa mortalité infantile amorce son déclin.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nMo Ibrahim, cinquante-trois pays dans son collimateur.\r\n\r\nLE GOÛT DE GEO\r\nLe yassa poulet, ou l’hospitalité sénégalaise.\r\n\r\nÉVASION - Namibie, la nouvelle arche de Noé\r\nDans des espaces gérés par les habitants, la faune sauvage s’est multipliée, les touristes affluent et les populations en tirent un revenu.\r\n\r\nMODES DE VIE\r\nAfrican Valley(s) - L’Afrique aussi voit naître ces lieux où les technologies boostent la croissance.\r\nCampus en ébullition - Démographie oblige, les étudiants se pressent dans les universités d’Afrique subsaharienne.\r\n\r\nENVIRONNEMENT\r\nCinq chantiers qui vont changer l’Afrique.\r\nDov Zerah - Les deux défis à relever.\r\n\r\nGÉOPOLITIQUE - Région des Grands Lacs : la poudrière magnifique\r\nC’est un territoire riche, mais marqué par des décennies de conflits. La paix et le développement y font aujourd’hui leur chemin.\r\n\r\nCARTE DÉTACHABLE - Le réveil de l\'Afrique\r\n\r\nLE BON PLAN - Le Cap des Capétoniens\r\n\r\nGÉOPOLITIQUE - L\'eldorado de l\'Afrique latine\r\nL’Angola vit un boom exceptionnel. Portugais, Brésiliens ou Chinois viennent y tenter leur chance.\r\n\r\nGRANDE SÉRIE \"LA FRANCE DES VILLAGES\" - La Bourgogne\r\nPanorama mensuel des pépites du terroir.     Géo     Afrique ','   n 403 septembre 2012 numero special afrique reveil continent     monde qui change mortalite infantile amorce son declin heros aujourd hui mo ibrahim cinquante trois pays dans son collimateur gout geo yassa poulet ou hospitalite senegalaise evasion namibie nouvelle arche noe dans espaces geres par habitants faune sauvage s est multipliee touristes affluent populations tirent revenu modes vie african valley s afrique aussi voit naitre ces lieux ou technologies boostent croissance campus ebullition demographie oblige etudiants se pressent dans universites afrique subsaharienne environnement cinq chantiers qui vont changer afrique dov zerah deux defis relever geopolitique region grands lacs poudriere magnifique c est territoire riche mais marque par decennies conflits paix developpement y font aujourd hui leur chemin carte detachable reveil afrique bon plan cap capetoniens geopolitique eldorado afrique latine angola vit boom exceptionnel portugais bresiliens ou chinois viennent y tenter leur chance grande serie france villages bourgogne panorama mensuel pepites terroir   geo afrique ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (103,1,'    Fahrenheit 451    451 degrés Fahrenheit représentent la température à laquelle un livre s\'enflamme et se consume.Dans cette société future où la lecture, source de questionnement et de réflexion, est considérée comme un acte antisocial, un corps spécial de pompiers est chargé de brûler tous les livres, dont la détention est interdite pour le bien collectif.Montag, le pompier pyromane, se met pourtant à rêver d\'un monde différent, qui ne bannirait pas la littérature et l\'imaginaire au profit d\'un bonheur immédiatement consommable. Il devient dès lors un dangereux criminel, impitoyablement poursuivi par une société qui désavoue son passé.    Robillot Henri      Chambon Jacques      Bradbury Ray       Fantastique et merveilleux  science fiction  Science-fiction Folio  Gallimard ','   fahrenheit 451   451 degres fahrenheit representent temperature laquelle livre s enflamme se consume dans cette societe future ou lecture source questionnement reflexion est consideree comme acte antisocial corps special pompiers est charge bruler tous livres dont detention est interdite pour bien collectif montag pompier pyromane se met pourtant rever monde different qui ne bannirait pas litterature imaginaire profit bonheur immediatement consommable il devient lors dangereux criminel impitoyablement poursuivi par societe qui desavoue son passe     robillot henri chambon jacques bradbury ray  fantastique merveilleux science fiction science fiction folio  gallimard ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (73,1,'    Yakouba       Jeunesse;Jeunesse - Albums;Lecteurs en herbe : 6-8 ans Dedieu Thierry       Afrique Crea.jeunesse  Seuil ','   yakouba      jeunesse jeunesse albums lecteurs herbe 6 8 ans  dedieu thierry  afrique crea jeunesse  seuil ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (74,1,'    Rafara   un conte populaire africain     De Boel Anne-Catherine       Afrique Pastel l\'école des loisirs ','   rafara conte populaire africain      de boel anne catherine  afrique pastel l ecole des loisirs ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (76,1,' 1  aya yopougon  1 Aya de Yopougon    Côte d\'Ivoire, 1978. Aya, dix-neuf ans, vit à Yopougon, un quartier populaire d\'Abidjan. Ça sent le début des vacances mais très vite les choses vont commencer à se gâter…«Dans les années 1970, la vie était douce en Côte d’Ivoire. Il y avait du travail, les hôpitaux étaient équipés et l’école était obligatoire. J’ai eu la chance de connaître cette époque insouciante, où les jeunes n’avaient pas à choisir leur camp trop vite, et ne se préoccupaient que de la vie courante : les études, les parents, les amours… Et c’est cela que je veux raconter dans \"Aya\", cette Afrique qui subsiste malgré tout car, comme on dit chez nous, «la vie continue»…» (Marguerite Abouet)    Oubrerie Clément      Abouet Marguerite       Afrique Littérature d\'Afrique noire Bayou  Gallimard ','  aya yopougon   aya yopougon 1 aya yopougon   cote ivoire 1978 aya dix neuf ans vit yopougon quartier populaire abidjan ca sent debut vacances mais tres vite choses vont commencer se gater dans annees 1970 vie etait douce cote ivoire il y avait travail hopitaux etaient equipes ecole etait obligatoire j ai eu chance connaitre cette epoque insouciante ou jeunes n avaient pas choisir leur camp trop vite ne se preoccupaient que vie courante etudes parents amours c est cela que je veux raconter dans aya cette afrique qui subsiste malgre tout car comme on dit chez nous vie continue marguerite abouet     oubrerie clement abouet marguerite  afrique litterature afrique noire bayou  gallimard ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (79,1,'    Les loups    Présentation de l\'éditeur\r\nC\'est l\'histoire d\'un lapin qui emprunte un ouvrage à la bibliothèque de son quartier, et qui découvre l\'extraordinaire, l\'incroyable pouvoir qu\'ont certains livres sur leur lecteur, parfois...     Gravett Emily       Bibliothéconomie Kaléidoscope ','   loups   presentation editeur c est histoire lapin qui emprunte ouvrage bibliotheque son quartier qui decouvre extraordinaire incroyable pouvoir qu ont certains livres sur leur lecteur parfois     gravett emily  bibliotheconomie kaleidoscope ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (82,1,'    La sagesse du bibliothécaire    Présentation de l\'éditeur\r\nLe bibliothécaire aime les livres comme le marin aime la mer. Il n\'est pas nécessairement bon nageur mais il sait naviguer. L\'océan du savoir qui grise tous les savants, rend modeste le bibliothécaire. La bibliothèque est ce lieu indispensable où le savoir décante. Regardez comme cet océan furieux se calme dans la bibliothèque ! Le bibliothécaire sait lire les livres sans les ouvrir. Son regard transperce\r\nles couvertures. Il visite la page de titre, l\'auteur, les éditeurs, va directement au colophon, relève la date, le format,\r\nle nombre de pages, s\'attarde sur la table des matières, vérifie s\'il y a des index. Il évalue enfin sa robustesse et la qualité de son papier, celle de sa mise en page et de son impression.\r\nTout est dit. Si les auteurs savaient cela, ils feraient de faux livres uniquement pour les bibliothèques.    Bibliothécaires;Déontologie;Bibliothécaires;Travail Melot Michel       Bibliothéconomie 020 Bibliothèques - et lecture, documentation Sagesse d\'un métier  l\'Oeil neuf éd. ','   sagesse bibliothecaire   presentation editeur bibliothecaire aime livres comme marin aime mer il n est pas necessairement bon nageur mais il sait naviguer ocean savoir qui grise tous savants rend modeste bibliothecaire bibliotheque est ce lieu indispensable ou savoir decante regardez comme cet ocean furieux se calme dans bibliotheque bibliothecaire sait lire livres sans ouvrir son regard transperce couvertures il visite page titre auteur editeurs va directement colophon releve date format nombre pages s attarde sur table matieres verifie s il y index il evalue enfin sa robustesse qualite son papier celle sa mise page son impression tout est dit si auteurs savaient cela ils feraient faux livres uniquement pour bibliotheques     bibliothecaires deontologie bibliothecaires travail  melot michel  bibliotheconomie 020 bibliotheques lecture documentation sagesse metier  l oeil neuf ed ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (83,1,'    Le métier de bibliothécaire       Bibliothéconomie;France Alix Yves      Association des bibliothécaires français        Bibliothéconomie 020 Bibliothèques - et lecture, documentation Le métier de  Éd. du Cercle de la librairie ','   metier bibliothecaire      bibliotheconomie france  alix yves association des bibliothecaires francais  bibliotheconomie 020 bibliotheques lecture documentation metier  ed du cercle de la librairie ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (81,1,'   jojo   Jojo et le secret de la bibliothécaire    La bibliothécaire a confié un terrible secret à Jojo et depuis, il n\'est plus le même...\r\nUne fiction pleine d\'humour sur l\'apprentissage de la lecture. A lire dès le CP.    Heitz Bruno       Bibliothéconomie Circonflexe ','  jojo   jojo jojo secret bibliothecaire   bibliothecaire confie terrible secret jojo depuis il n est plus meme fiction pleine humour sur apprentissage lecture lire cp     heitz bruno  bibliotheconomie circonflexe ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (80,1,'    La bibliothécaire    Pourquoi la vielle dame qui habite en face de chez Guillaume écrit-elle très tard la nuit? Quelle est cette jeune fille qui ne sort de chez elle qu\'à le nuit tombée? Pour résoudre ces mystères, Guillaume se lance dans un fantastique voyage au pays des livres et de l\'écriture   Romans;Jeunesse;Littérature jeunesse;Albums;Jeunesse en format poche Durual Christophe      Gudule        Bibliothéconomie L.d.p.jeunesse  Hachette Jeunesse ','   bibliothecaire   pourquoi vielle dame qui habite face chez guillaume ecrit elle tres tard nuit quelle est cette jeune fille qui ne sort chez elle qu nuit tombee pour resoudre ces mysteres guillaume se lance dans fantastique voyage pays livres ecriture     romans jeunesse litterature jeunesse albums jeunesse format poche  durual christophe gudule  bibliotheconomie p jeunesse  hachette jeunesse ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (75,1,' 2  aya yopougon  2 Aya de Yopougon     Contient un lexique ivoirien-français, recettes culinaires, conseils de vie pratique   Oubrerie Clément      Abouet Marguerite       Afrique Littérature d\'Afrique noire Bayou  Gallimard ','  aya yopougon   aya yopougon 2 aya yopougon    contient lexique ivoirien francais recettes culinaires conseils vie pratique    oubrerie clement abouet marguerite  afrique litterature afrique noire bayou  gallimard ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (85,1,'    Le grand amour du bibliothécaire    Présentation de l\'éditeur\r\nLes livres, ça fait désordre et ça prend la poussière, c\'est tout. Voilà ce que pense Fulbert le bibliothécaire. D\'ailleurs, il n\'y a qu\'un seul livre dans sa bibliothèque ! Mais voici qu\'arrive la ravissante Rose-Marie, assoiffée de lecture. Fulbert, ébloui et troublé, est bien désemparé. Il va falloir qu\'il trouve des livres, et vite !    Littérature jeunesse;BD, Mangas, Humour Brisou-pellen Evelyn       Bibliothéconomie Casterman ','   grand amour bibliothecaire   presentation editeur livres ca fait desordre ca prend poussiere c est tout voila ce que pense fulbert bibliothecaire ailleurs il n y qu seul livre dans sa bibliotheque mais voici qu arrive ravissante rose marie assoiffee lecture fulbert ebloui trouble est bien desempare il va falloir qu il trouve livres vite     litterature jeunesse bd mangas humour  brisou pellen evelyn  bibliotheconomie casterman ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (69,1,'    Contes des sages d\'Afrique        Bâ Amadou Hampâté       Afrique Collection dirigée par Henri Gougaud  Seuil ','   contes sages afrique      ba amadou hampate  afrique collection dirigee par henri gougaud  seuil ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (70,1,'    Sagesse d\'Afrique   paysages et pensées Présentation de l\'éditeur\r\nL\'Afrique se dévoile, au fil de magnifiques photographies accompagnées de pensées, de poèmes et de proverbes emplis de philosophie, à l\'image de ce continent dont la beauté invite à la médiation. Un voyage en terre d\'émerveillement, guidé par le regard de nombreux écrivains et d\'hommes engagés, pour découvrir un espace fascinant, ses paysages, sa faune et ses habitants.  Contient diverses pensées, poèmes et proverbes de différents auteurs\r\nIndex  Afrique;Photographies Zaïd Nassera       Afrique 960 Histoire de l\'Afrique les Éd. du Toucan ','   sagesse afrique paysages pensees   presentation editeur afrique se devoile fil magnifiques photographies accompagnees pensees poemes proverbes emplis philosophie image ce continent dont beaute invite mediation voyage terre emerveillement guide par regard nombreux ecrivains hommes engages pour decouvrir espace fascinant ses paysages sa faune ses habitants   contient diverses pensees poemes proverbes differents auteurs index    afrique photographies  zaid nassera  afrique 960 histoire afrique les ed du toucan ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (72,1,'    Comptines et berceuses du baobab   l\'Afrique noire en 30 comptines Pour la première fois, une sélection de comptines et berceuses les plus représentatives de l\'Afrique noire, de la Cote-d\'Ivoire au Rwanda, dans la diversité des langues (lingala, wolof, bambara, peul, sango...) Chaque comptine est transcrite dans sa langue d\'origine et traduite en français. Les commentaires culturels sont regroupés à la fin de l\'ouvrage. Contient des comptines de différents pays en différentes langues : Congo (mingala), Mali (bambara), Cameroun (bamena), Côte d\'Ivoire (bambara), Mauritanie (peul), Togo (mina), Sénégal (wolof), Rwanda (kinyarwanda), Guinée (susu), Mali (soninke), Centrafrique (sängö), Guinée-Conakry (susu), Congo (kikongo)  Comptines;Afrique centrale Mindy Paul      Nouhen Elodie      Grosléziat Chantal       Afrique Musique 780 Musique Un Livre, un cd 1766-148X Didier jeunesse ','   comptines berceuses baobab afrique noire 30 comptines   pour premiere fois selection comptines berceuses plus representatives afrique noire cote ivoire rwanda dans diversite langues lingala wolof bambara peul sango chaque comptine est transcrite dans sa langue origine traduite francais commentaires culturels sont regroupes fin ouvrage   contient comptines differents pays differentes langues congo mingala mali bambara cameroun bamena cote ivoire bambara mauritanie peul togo mina senegal wolof rwanda kinyarwanda guinee susu mali soninke centrafrique sango guinee conakry susu congo kikongo    comptines afrique centrale  mindy paul nouhen elodie grosleziat chantal  afrique musique 780 musique livre cd 1766 148x didier jeunesse ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (71,1,'    Afriques    Depuis plus de vingt ans Raymond Depardon a parcouru tout le continent africain auquel il a consacré plusieurs films. Il a réalisé ainsi une grande quantité de photographies dont 350 inédites sont présentées dans cet ouvrage. Ces photographies couvrent toute l\'Afrique, à travers une présentation non pas par pays mais par associations originales. Ces associations privilégient un rythme soutenu, sans temps d\'arrêt, des enchaînements qui montrent la vie au travers de sujets très variés : portraits, villes, paysages, religions, activités sociales et métiers mais aussi des conflits et la misère. A travers ses photographies, exemptes de toute volonté d\'esthétiser son propos, Raymond Depardon ne livre aucun jugement sur l\'Afrique, aucune thèse. Ce qui relie entre elles ces prises de vue, c\'est l\'impulsion de l\'?il, simplement un regard de photographe et de grand voyageur sur les paysages et les hommes qui peuplent ce continent. Pourquoi des Afriques ? Depuis 1960, année de ma première rencontre avec le continent africain à l\'âge de dix-huit ans, et jusqu\'à mon dernier voyage cet hiver au Horar, je n\'ai cessé de photographier l\'Afrique. Mais que de lieux, de temps différents ! Une vie toute entière ne suffirait pas à prétendre connaître cette Afrique. Aujourd\'hui, les prétextes, les raisons de ces voyages sont oubliés. C\'est pour cela que j\'avais envie de faire ce livre, pour rendre la liberté à toutes ces photographies et enfin réunir toutes ces Afriques, celles des pistes, des sourires, des famines et des guerres civiles. Je voulais oser ces quatre cents pages de photographies sous respiration. Je voulais étouffer devant l\'immense Afrique, me trouver comme au bord d\'une route où nous serions en panne pour plusieurs jours, envahis, à rester silencieux et à écouter. Je me souviens de chaque lieu, de chaque temps. J\'ose le désordre, il le faut. Je réunis ces photographies prises pendant quarante-cinq ans de voyages en Afrique. Raymond Depardon   Afrique;Photographies Depardon Raymond       Afrique Ethnologie 960 Histoire de l\'Afrique Hazan ','   afriques   depuis plus vingt ans raymond depardon parcouru tout continent africain auquel il consacre plusieurs films il realise ainsi grande quantite photographies dont 350 inedites sont presentees dans cet ouvrage ces photographies couvrent toute afrique travers presentation non pas par pays mais par associations originales ces associations privilegient rythme soutenu sans temps arret enchainements qui montrent vie travers sujets tres varies portraits villes paysages religions activites sociales metiers mais aussi conflits misere travers ses photographies exemptes toute volonte esthetiser son propos raymond depardon ne livre aucun jugement sur afrique aucune these ce qui relie entre elles ces prises vue c est impulsion il simplement regard photographe grand voyageur sur paysages hommes qui peuplent ce continent pourquoi afriques depuis 1960 annee ma premiere rencontre avec continent africain age dix huit ans jusqu mon dernier voyage cet hiver horar je n ai cesse photographier afrique mais que lieux temps differents vie toute entiere ne suffirait pas pretendre connaitre cette afrique aujourd hui pretextes raisons ces voyages sont oublies c est pour cela que j avais envie faire ce livre pour rendre liberte toutes ces photographies enfin reunir toutes ces afriques celles pistes sourires famines guerres civiles je voulais oser ces quatre cents pages photographies sous respiration je voulais etouffer devant immense afrique me trouver comme bord route ou nous serions panne pour plusieurs jours envahis rester silencieux ecouter je me souviens chaque lieu chaque temps j ose desordre il faut je reunis ces photographies prises pendant quarante cinq ans voyages afrique raymond depardon     afrique photographies  depardon raymond  afrique ethnologie 960 histoire afrique hazan ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (120,1,'    Géo        Géographie Participations éditions presse ','   geo      geographie participations editions presse ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (68,1,'    Les perles et autres contes    Le symbole mystérieux d\'un collier qui a une perle de trop. La réalité crue qui vient anéantir le rêve et le bonheur offerts à une jeune aristocrate insouciante. L\'aventure, dans le port d\'Anvers, d\'un écrivain malheureux, qui fuit sa propre vie... Tels sont les thèmes et les personnages de ces trois contes. Et à travers eux, Karen Blixen nous démontre que le conte est bien l\'instrument privilégié de l\'exploration des mystères de la personnalité. Le doux velours du timbre d\'Anne Brochet nous transporte dans l\'univers mystérieux des contes de Karen Blixen. Une lecture posée qui met en mouvement l\'imagination de l\'auditeur. L\'écoute en classe de ces CD est autorisée par l\'éditeur   Livres lus en format CD Metzger Marthe      Blixen Karen       Afrique Écoutez lire  Gallimard ','   perles autres contes   symbole mysterieux collier qui perle trop realite crue qui vient aneantir reve bonheur offerts jeune aristocrate insouciante aventure dans port anvers ecrivain malheureux qui fuit sa propre vie tels sont themes personnages ces trois contes travers eux karen blixen nous demontre que conte est bien instrument privilegie exploration mysteres personnalite doux velours timbre anne brochet nous transporte dans univers mysterieux contes karen blixen lecture posee qui met mouvement imagination auditeur ecoute classe ces cd est autorisee par editeur     livres lus format cd  metzger marthe blixen karen  afrique ecoutez lire  gallimard ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (93,1,'    Quel radis dis donc !        Prigent Andrée      Gay-Para Praline       Légumes À petits petons  Didier jeunesse ','   quel radis dis donc      prigent andree gay para praline  legumes petits petons  didier jeunesse ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (95,1,'    Zigomar n\'aime pas les légumes     A pour suite dans le même ouvrage : \"Zigomar n\'aime pas du tout les légumes et il a bien raison\"   Corentin Philippe       Légumes l\'école des loisirs ','   zigomar n aime pas legumes    pour suite dans meme ouvrage zigomar n aime pas tout legumes il bien raison    corentin philippe  legumes l ecole des loisirs ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (96,1,'    Je cuisine avec les fruits et légumes du marché       Cuisine (légumes);Ouvrages pour la jeunesse;Cuisine (fruits);Ouvrages pour la jeunesse Loubier Virginie       Légumes Cuisine 640 Arts ménagers - cuisine, couture, soins de beauté Éd. Lito ','   je cuisine avec fruits legumes marche      cuisine legumes ouvrages pour jeunesse cuisine fruits ouvrages pour jeunesse  loubier virginie  legumes cuisine 640 arts menagers cuisine couture soins beaute ed lito ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (94,1,'    Le jardin potager    Présentation de l\'éditeur\r\nSais-tu faire germer des graines ? Quel est l\'outil le plus précieux du jardinier ? Qu\'est-ce qui pousse au bout du monde ?   Jardinage;Albums;Jeunesse - Documentaires;Eveil, petite enfance, albums à colorier Guidoux Valerie       Légumes Jardinage 580 Botanique - (les plantes) Kididoc  Nathan ','   jardin potager   presentation editeur sais tu faire germer graines quel est outil plus precieux jardinier qu est ce qui pousse bout monde     jardinage albums jeunesse documentaires eveil petite enfance albums colorier  guidoux valerie  legumes jardinage 580 botanique plantes kididoc  nathan ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (110,1,'    Edward aux mains d\'argent    Synopsis\r\nEdward est la création d\'un savant génial. Il ne possède pas de vrais mains, mais des lames très tranchantes à la place des doigts. Il peut réaliser avec ses instruments de véritables oeuvres d\'art, qui vont provoquer la curiosité et l\'enthousiasme de toute la ville. Mais il est capable de blesser et de faire mal quand il ne se contrôle plus...     Ryder Winona      Depp Johnny      Burton Tim       Cinéma Twentieth century Fox ','   edward mains argent   synopsis edward est creation savant genial il ne possede pas vrais mains mais lames tres tranchantes place doigts il peut realiser avec ses instruments veritables oeuvres art qui vont provoquer curiosite enthousiasme toute ville mais il est capable blesser faire mal quand il ne se controle plus     ryder winona depp johnny burton tim  cinema twentieth century fox ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (111,1,'    Beetlejuice    Synopsis\r\nBarbara et Adam forment un adorable couple. Hélas survient un stupide accident de voiture et les voilà devenus fantômes obligés de hanter les murs de leur propre demeure ! Quelle n\'est pas leur déception lorsqu\'ils la voient livrée aux mains d\'une famille excentrique dont les membres évoluent entre hystérie et stupidité. Barbara et Adam tentent de les chasser. En vain. La seule solution : faire appel à Beetlejuice, un fantôme exorciseur de vivants...     Keaton Mickael      Burton Tim       Cinéma  fantastique  Fantastique Collection Warner  Warner home video ','   beetlejuice   synopsis barbara adam forment adorable couple helas survient stupide accident voiture voila devenus fantomes obliges hanter murs leur propre demeure quelle n est pas leur deception lorsqu ils voient livree mains famille excentrique dont membres evoluent entre hysterie stupidite barbara adam tentent chasser vain seule solution faire appel beetlejuice fantome exorciseur vivants     keaton mickael burton tim  cinema fantastique fantastique collection warner  warner home video ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (112,1,'    Big Fish    Synopsis\r\nApprenant qu\'Edward, son père, est sur le point de mourir, Will décide de se rapprocher de lui pour enfin connaître cet homme qui a bercé son enfance avec des contes plus ou moins fantastiques dans lesquels il se mettait en scène aux côtés de personnages extravagants et extraordinaires...    McGregor Ewan      Burton Tim       Cinéma Columbia Tristar home video ','   big fish   synopsis apprenant qu edward son pere est sur point mourir will decide se rapprocher lui pour enfin connaitre cet homme qui berce son enfance avec contes plus ou moins fantastiques dans lesquels il se mettait scene cotes personnages extravagants extraordinaires     mcgregor ewan burton tim  cinema columbia tristar home video ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (113,1,'    Les noces funèbres    Synopsis\r\nAu XIXe siècle, dans un village d\'Europe de l\'est, Victor, un jeune homme, découvre le monde des morts après avoir épousé, sans le vouloir, le cadavre d\'une mystérieuse mariée. Pendant son voyage, sa promise, Victoria l\'attend désespérément dans le monde des vivants. Bien que la vie au Royaume des Morts s\'avère beaucoup plus animée et joyeuse que sa véritable existence, Victor apprend que rien au monde, pas même la mort, ne pourra briser son amour pour sa femme...     Burton Tim       Cinéma Warner home video ','   noces funebres   synopsis xixe siecle dans village europe est victor jeune homme decouvre monde morts apres avoir epouse sans vouloir cadavre mysterieuse mariee pendant son voyage sa promise victoria attend desesperement dans monde vivants bien que vie royaume morts s avere beaucoup plus animee joyeuse que sa veritable existence victor apprend que rien monde pas meme mort ne pourra briser son amour pour sa femme     burton tim  cinema warner home video ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (114,1,'    Charlie et la chocolaterie    Synopsis\r\nQuelles sont les merveilles qui t\'attendent dans l\'usine de Willy Wonka ? Pars à la découverte de vastes étendues d\'herbe sucrée au bon goût de menthe dans la Salle du Chocolat... Navigue sur la Rivière de Chocolat dans un grand bateau en sucre rose... Essaye le Gobestoppeur sans fin dans la Salle des Inventions... Observe les talentueux écureuils de la Salle de Tri des Noix et voyage en ascenseur de verre jusqu\'à la Salle de Télévision. Tu y trouveras une montagne d\'humour saupoudrée d\'un peu de mystère... et une aventure aussi savoureuse et agréable qu\'une tablette de Délice Fondant Wonka Guimauve-Caramel...     Depp Johnny      Burton Tim       Cinéma Warner home video ','   charlie chocolaterie   synopsis quelles sont merveilles qui attendent dans usine willy wonka pars decouverte vastes etendues herbe sucree bon gout menthe dans salle chocolat navigue sur riviere chocolat dans grand bateau sucre rose essaye gobestoppeur sans fin dans salle inventions observe talentueux ecureuils salle tri noix voyage ascenseur verre jusqu salle television tu y trouveras montagne humour saupoudree peu mystere aventure aussi savoureuse agreable qu tablette delice fondant wonka guimauve caramel     depp johnny burton tim  cinema warner home video ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (88,1,'    Des bibliothèques pleines de fantômes    Avez-vous peur de mourir dans votre sommeil, enseveli sous l\'écroulement de votre bibliothèque ? L\'accumulation de livres ne met-elle pas en danger l\'existence même de votre famille ? Classez-vous les volumes par thème, langue, auteur, date de parution, format ou selon un autre critère de vous seul connu ? Peut-on faire voisiner sur une étagère deux auteurs irrémédiablement brouillés dans la vie ? Autant de graves questions se posant à cette espèce en voie de disparition : les bibliomanes, qui, outre la passion de posséder les livres, ont celle de les lire. Les bibliothèques sont des êtres vivants à l\'image de notre complexité intérieure. Elles finissent par composer un labyrinthe dont pour notre plus grand, et dangereux, plaisir nous pouvons très bien ne plus sortir. Dans ce petit traité sur l\'art de vivre avec trop de livres apparaissent, parmi nombre d\'autres, Pessoa tentant de devenir bibliothécaire, Matisse postulant au poste de «contrôleur du droit des pauvres» ou encore le capitaine Achab et le mystère de sa jambe abandonnée à Moby Dick. En fait, ces milliers de pages qui occupent nos étagères sont peuplées de fantômes bien vivants qui, une fois rencontrés, ne nous quittent plus.   Bibliothèques;Livres et lecture Bonnet Jacques       Bibliothéconomie 020 Bibliothèques - et lecture, documentation Denoël ','   bibliotheques pleines fantomes   avez vous peur mourir dans votre sommeil enseveli sous ecroulement votre bibliotheque accumulation livres ne met elle pas danger existence meme votre famille classez vous volumes par theme langue auteur date parution format ou selon autre critere vous seul connu peut on faire voisiner sur etagere deux auteurs irremediablement brouilles dans vie autant graves questions se posant cette espece voie disparition bibliomanes qui outre passion posseder livres ont celle lire bibliotheques sont etres vivants image notre complexite interieure elles finissent par composer labyrinthe dont pour notre plus grand dangereux plaisir nous pouvons tres bien ne plus sortir dans ce petit traite sur art vivre avec trop livres apparaissent parmi nombre autres pessoa tentant devenir bibliothecaire matisse postulant poste controleur droit pauvres ou encore capitaine achab mystere sa jambe abandonnee moby dick fait ces milliers pages qui occupent nos etageres sont peuplees fantomes bien vivants qui fois rencontres ne nous quittent plus     bibliotheques livres lecture  bonnet jacques  bibliotheconomie 020 bibliotheques lecture documentation denoel ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (115,1,'    Miriam Makeba   her essential recordings ; the empress of African song     Makeba Miriam      Musique  Afrique Manteca ','   miriam makeba her essential recordings the empress of african song      makeba miriam musique  afrique manteca ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (106,1,'    La triste fin du petit enfant huître et autres histoires    Fidèle à son univers d\'une inventivité si  particulière, mêlant crauté et tendresse,  macabre et poésie, Tim Burton donne le jour à une  étonnante famille d\'enfants solitaires, étranges et  différents, qui ne tarderont pas à nous horrifier,  à nous émouvoir et à nous faire rire.  Un livre pour l\'enfant qui est en nous   Littérature;Romans contemporains;Littérature au format poche;Romans en Poche Burton Tim      Poésie 810 Littérature américaine Littérature étrangère  10-18 ','   triste fin petit enfant huitre autres histoires   fidele son univers inventivite si particuliere melant craute tendresse macabre poesie tim burton donne jour etonnante famille enfants solitaires etranges differents qui ne tarderont pas nous horrifier nous emouvoir nous faire rire livre pour enfant qui est nous     litterature romans contemporains litterature format poche romans poche  burton tim poesie 810 litterature americaine litterature etrangere  10 18 ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (107,1,'    Tim Burton    Présentation de l\'éditeur\r\nIl était une fois un garçon qui aimait inventer des histoires. Il se dit qu\'un homme déguisé en chauve-souris, ça ferait peur aux méchants. Il pense à la petite fille qui passe de l\'autre côté du miroir et découvre un monde merveilleux. A la femme qui se prend pour un chat et qui joue avec l\'homme pingouin. Il se dit qu\'une citrouille ne remplacera jamais le Père Noël, mais qu\'elle pourrait avoir envie d\'essayer. Il imagine ce qui se passerait si les habitants de Mars attaquaient la Terre... Son rêve, c\'était de rassembler toutes ces histoires et tous leurs personnages. Aujourd\'hui, le petit garçon est devenu grands et il fait du cinéma. Le tour du monde des musées en BD et en jeu .: le musée du Palais a Pékin.   Jeunesse;L\'Univers des Enfants Cinéma - Télévision  Cinéma 700 Arts et loisirs Revue dada  Arola ','   tim burton   presentation editeur il etait fois garcon qui aimait inventer histoires il se dit qu homme deguise chauve souris ca ferait peur mechants il pense petite fille qui passe autre cote miroir decouvre monde merveilleux femme qui se prend pour chat qui joue avec homme pingouin il se dit qu citrouille ne remplacera jamais pere noel mais qu elle pourrait avoir envie essayer il imagine ce qui se passerait si habitants mars attaquaient terre son reve c etait rassembler toutes ces histoires tous leurs personnages aujourd hui petit garcon est devenu grands il fait cinema tour monde musees bd jeu musee palais pekin     jeunesse univers enfants  cinema television  cinema 700 arts loisirs revue dada  arola ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (108,1,'    Tim burton        De baecque Anto       Cinéma 700 Arts et loisirs Album  Cah cinema ','   tim burton      de baecque anto  cinema 700 arts loisirs album  cah cinema ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (90,1,'    Au coeur de l\'Afrique    Présentation de l\'éditeur\r\nUne plongée au coeur de l\'Afrique, mère de l\'humanité et continent phare du IIIe millénaire. Face aux visions d\'une Afrique déchirée, voici de nouveaux éclairages. A travers des questions comme la désertification, la déforestation, l\'exode rural, la colonisation ou l\'explosion démographique, le continent se livre en profondeur. Sa géographie a été une donnée décisive, ses peuples se sont adaptés à une nature difficile. L\'Afrique, c\'est une histoire remplie d\'épisodes épiques d\'une richesse insoupçonnée, assombrie parla terrible période de l\'esclavage. C\'est aussi une leçon de courage et de solidarité inépuisables.    Afrique noire;Géographie;Ouvrages pour la jeunesse;Afrique noire;Histoire;Ouvrages pour la jeunesse Nantet Bernard       Afrique 910 Géographie - voyages Les encyclopes  Milan ','   coeur afrique   presentation editeur plongee coeur afrique mere humanite continent phare iiie millenaire face visions afrique dechiree voici nouveaux eclairages travers questions comme desertification deforestation exode rural colonisation ou explosion demographique continent se livre profondeur sa geographie ete donnee decisive ses peuples se sont adaptes nature difficile afrique c est histoire remplie episodes epiques richesse insoupconnee assombrie parla terrible periode esclavage c est aussi lecon courage solidarite inepuisables     afrique noire geographie ouvrages pour jeunesse afrique noire histoire ouvrages pour jeunesse  nantet bernard  afrique 910 geographie voyages encyclopes  milan ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (91,1,'    Grosse légume        Gourounas Jean       Légumes Éd. du Rouergue ','   grosse legume      gourounas jean  legumes ed du rouergue ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (92,1,'    Les enquêtes du potager   par l\'inspecteur Lapou  Réunit : \"L\'enterrement de la carotte\" ; \"Le pissenlit écrasé\" ; \"La disparition du jeune poireau\" ; \"L\'agression du champignon\" ; \"La chute de la tomate\" ; \"Le poseur de lapins\" ; \"Le voleur de courgettes\" ; \"Le cerisier dévalisé\" ; \"La bande de radis\" ; \"Le citron trop pressé\"   Guettier Bénédicte       Légumes Gallimard jeunesse - Giboulées ','   enquetes potager par inspecteur lapou    reunit enterrement carotte pissenlit ecrase disparition jeune poireau agression champignon chute tomate poseur lapins voleur courgettes cerisier devalise bande radis citron trop presse    guettier benedicte  legumes gallimard jeunesse giboulees ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (116,1,'    Jammu Africa        Lo Ismaël       Afrique Musique AZ ','   jammu africa      lo ismael  afrique musique az ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (117,1,'    Tchamantché        Traoré Rokia       Afrique Musique Universal music jazz France ','   tchamantche      traore rokia  afrique musique universal music jazz france ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (118,1,'    M\'Bemba        Keita Salif       Afrique Musique Universal Polydor ','   m bemba      keita salif  afrique musique universal polydor ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (119,1,'    Folila        Amadou & Mariam        Afrique Musique Because music ','   folila      amadou mariam  afrique musique because music ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (87,1,'    L\'enlèvement de la bibliothécaire    En kidnappant Mlle Labourdette, la ravissante bibliothécaire, le chef des brigands et ses quatre complices croient pouvoir obtenir de la municipalité une rançon rondelette. Mais c\'est compter sans le courage de la jeune fille, son bon c?ur et ses talents de... bibliothécaire !    Farré Raymond      Saint-Dizier Marie      Blake Quentin      Mahy Margaret       Bibliothéconomie Folio cadet  Gallimard jeunesse ','   enlevement bibliothecaire   kidnappant mlle labourdette ravissante bibliothecaire chef brigands ses quatre complices croient pouvoir obtenir municipalite rancon rondelette mais c est compter sans courage jeune fille son bon c ur ses talents bibliothecaire     farre raymond saint dizier marie blake quentin mahy margaret  bibliotheconomie folio cadet  gallimard jeunesse ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (86,1,'    Le bibliothécaire    Travaillant dans une université huppée de Washington D.C, David Golberg devient, par le plus grand des hasards, le bibliothécaire privé d\'Alan Stowe. Vieil acariâtre multimillionnaire, industriel cynique et sans scrupules, Stowe est surtout le plus grand bailleur de fonds du parti républicain. Or, nous sommes justement en pleine élection présidentielle et l\'équipe du candidat sortant, un gosse de riche va-t-en-guerre, ancien alcoolique reconverti en fou de Dieu, voit d\'un mauvais ?il l\'arrivée de cet inconnu auprès d\'un homme aussi influent que Stowe. À peine Golberg a-t-il le temps de commencer le classement des papiers de l\'homme d\'affaires qu\'il se retrouve pris en chasse par des barbouzes de la Sécurité intérieure. Tandis que la candidate démocrate grignote son retard sur le Président et que le grand jour du vote se rapproche, David, aidé d\'une bande d\'amis, se voit contraint de trouver dans les documents de Stowe l\'information pour laquelle on veut le tuer... Après Reality Show, adapté au cinéma sous le titre Des hommes d\'influence avec Dustin Hoffman et Robert De Niro, Larry Beinhart fait un retour fracassant sur la scène littéraire, démontant pièce par pièce l\'administration Bush, sa manière de manipuler le public américain et l\'opinion mondiale en jouant avec des peurs et des fantasmes archaïques. Comme quoi les critiques les plus virulentes ne viennent pas toujours de la « vieille Europe »...    Carrer Patrice      Beinhart Larry       Bibliothéconomie Collection Série noire  Gallimard ','   bibliothecaire   travaillant dans universite huppee washington c david golberg devient par plus grand hasards bibliothecaire prive alan stowe vieil acariatre multimillionnaire industriel cynique sans scrupules stowe est surtout plus grand bailleur fonds parti republicain or nous sommes justement pleine election presidentielle equipe candidat sortant gosse riche va guerre ancien alcoolique reconverti fou dieu voit mauvais il arrivee cet inconnu aupres homme aussi influent que stowe peine golberg il temps commencer classement papiers homme affaires qu il se retrouve pris chasse par barbouzes securite interieure tandis que candidate democrate grignote son retard sur president que grand jour vote se rapproche david aide bande amis se voit contraint trouver dans documents stowe information pour laquelle on veut tuer apres reality show adapte cinema sous titre hommes influence avec dustin hoffman robert niro larry beinhart fait retour fracassant sur scene litteraire demontant piece par piece administration bush sa maniere manipuler public americain opinion mondiale jouant avec peurs fantasmes archaiques comme quoi critiques plus virulentes ne viennent pas toujours vieille europe     carrer patrice beinhart larry  bibliotheconomie collection serie noire  gallimard ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (84,1,'    Les bibliothèques    À la fois lieux de travail pour des recherches contemporaines et lieux de conservation d\'un patrimoine, les bibliothèques ont un rôle charnière entre le passé et le présent. Mais si leur mission demeure identique, les moyens mis à leur disposition, ainsi que les modes de consultation et d\'usage des livres, sont aujourd?hui en pleine mutation.\r\n\r\nCet ouvrage s\'assigne donc une double tâche : présenter l\'histoire des bibliothèques dans le monde occidental afin de comprendre l\'ampleur des changements qu?elles connaissent depuis un siècle, et donc les nouveaux enjeux culturels et économiques engendrés par de telles évolutions.\r\n\r\nDocteur en histoire, Denis Pallier est inspecteur général honoraire des bibliothèques.   Bibliothèques Pallier Denis       Bibliothéconomie 020 Bibliothèques - et lecture, documentation Que sais-je ?  Presses universitaires de France ','   bibliotheques   fois lieux travail pour recherches contemporaines lieux conservation patrimoine bibliotheques ont role charniere entre passe present mais si leur mission demeure identique moyens mis leur disposition ainsi que modes consultation usage livres sont aujourd hui pleine mutation cet ouvrage s assigne donc double tache presenter histoire bibliotheques dans monde occidental afin comprendre ampleur changements qu elles connaissent depuis siecle donc nouveaux enjeux culturels economiques engendres par telles evolutions docteur histoire denis pallier est inspecteur general honoraire bibliotheques     bibliotheques  pallier denis  bibliotheconomie 020 bibliotheques lecture documentation que sais je  presses universitaires de france ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (97,1,'    Une cuisine grande comme un jardin   60 recettes pour découvrir les fruits et les légumes du monde Présentation de l\'éditeur\r\nVoici un voyage extraordinaire au pays des fruits et des légumes. Des recettes qui nous les font découvrir différemment, des informations sur leur culture ou leur étonnante histoire, des proverbes du monde entier qui les célèbrent et les peintures de Martin Jarrie qui nous disent tout de leur chair et de leur saveur.    Cuisine (fruits);Cuisine (légumes) Jarrie Martin      Serres Alain       Légumes Cuisine 640 Arts ménagers - cuisine, couture, soins de beauté Rue du monde ','   cuisine grande comme jardin 60 recettes pour decouvrir fruits legumes monde   presentation editeur voici voyage extraordinaire pays fruits legumes recettes qui nous font decouvrir differemment informations sur leur culture ou leur etonnante histoire proverbes monde entier qui celebrent peintures martin jarrie qui nous disent tout leur chair leur saveur     cuisine fruits cuisine legumes  jarrie martin serres alain  legumes cuisine 640 arts menagers cuisine couture soins beaute rue du monde ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (102,1,'    Orange, pomme, poire    Présentation de l\'éditeur\r\nUne orange, une pomme, une poire et un ours, Grégoire. Qui aurait imaginé que ces quatre mots puissent être conjugués en autant de façons ? Emily gravett, bien sûr !     Gravett Emily       Légumes Kaléidoscope ','   orange pomme poire   presentation editeur orange pomme poire ours gregoire qui aurait imagine que ces quatre mots puissent etre conjugues autant facons emily gravett bien sur     gravett emily  legumes kaleidoscope ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (98,1,'    Trop bon ! les fruits et les légumes   22 recettes d\'enfants Présentation de l\'éditeur\r\nLes fruits et les légumes, c\'est trop bon ! Au fil de ces 22 recettes, découvre les fruits et les légumes comme tu ne les as encore jamais goûtés ! En glaces, en gratins, en pizzas ou même en gaufres ! Pas de doute, tes papilles adoreront tous ces petits plats concoctés spécialement par les enfants... pour les enfants ! Entre enfants, on se comprend !     Clément Marie-Christine      Teyras Emmanuelle       Légumes Cuisine 640 Arts ménagers - cuisine, couture, soins de beauté Mila éd. ','   trop bon fruits legumes 22 recettes enfants   presentation editeur fruits legumes c est trop bon fil ces 22 recettes decouvre fruits legumes comme tu ne as encore jamais goutes glaces gratins pizzas ou meme gaufres pas doute tes papilles adoreront tous ces petits plats concoctes specialement par enfants pour enfants entre enfants on se comprend     clement marie christine teyras emmanuelle  legumes cuisine 640 arts menagers cuisine couture soins beaute mila ed ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (99,1,'    Rouge comme une tomate   et autres émotions naturelles Présentation de l\'éditeur\r\nQuelle tête fais-tu lorsque tu es heureux ? Fatigué ? Fâché ? Ou que tu t\'es fait gronder ? Toutes les moues et expressions enfantines, des plus drôles aux plus tendres, sous la forme de fruits et légumes hilarants !     Elffers Joost      Freymann Saxton       Légumes Arts plastiques Mila éd. ','   rouge comme tomate autres emotions naturelles   presentation editeur quelle tete fais tu lorsque tu es heureux fatigue fache ou que tu es fait gronder toutes moues expressions enfantines plus droles plus tendres sous forme fruits legumes hilarants     elffers joost freymann saxton  legumes arts plastiques mila ed ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (100,1,'    Bébés à croquer    Présentation de l\'éditeur\r\nCaneton, mouton, pingouin ou jeune chien... Vous allez fondre pour ces délicieux bébés animaux... A croquer !   Artisanat de nature;Ouvrages illustrés Elffers Joost      Freymann Saxton       Légumes Arts plastiques 740 Dessin - arts décoratifs Mila éd. ','   bebes croquer   presentation editeur caneton mouton pingouin ou jeune chien vous allez fondre pour ces delicieux bebes animaux croquer     artisanat nature ouvrages illustres  elffers joost freymann saxton  legumes arts plastiques 740 dessin arts decoratifs mila ed ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (101,1,'    Fruits, légumes    Présentation de l\'éditeur\r\nOh la belle verte! Si les légumes et les fruits étaient aussi beaux dans la réalité que dans cette « encyclopédie », les enfants les dévoreraient !    Bravi Soledad       Légumes l\'École des loisirs-Loulou & Cie ','   fruits legumes   presentation editeur oh belle verte si legumes fruits etaient aussi beaux dans realite que dans cette encyclopedie enfants devoreraient     bravi soledad  legumes l ecole des loisirs loulou cie ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (104,1,' 1  annales disque monde  1 La huitième couleur    Quatrième de couverture\r\nDans une dimension lointaine et passablement farfelue, un monde se balade à dos de quatre éléphants, eux©mêmes juchés sur la carapace de la Grande Tortue... Oui, c\'est le Disque©monde... Les habitants de la cité d\'Ankh©Morpork croyaient avoir tout vu. Et Deuxfleurs avait l\'air tellement inoffensif, bonhomme chétif, fidèlement escorté par un Bagage de bois magique déambulant sur une myriade de petites jambes. Tellement inoffensif que le Patricien avait chargé le calamiteux sorcier Rincevent de sa sécurité dans la cité quadrillée par la Guilde des Voleurs et celle des Assassins ; mission périlleuse et qui devait les conduire loin : dans une caverne de dragons ; peut©être jusqu\'au Rebord du Disque. Car Deuxfleurs était d\'une espèce plus redoutable qu\'on ne l\'imaginait : c\'était un touriste... A la lumière de l\'octarine, la huitième couleur, celle de la magie, découvrez l\'univers fantastique et cocasse de Terry Pratchett.    Couton Patrick      Pratchett Terry       Fantastique et merveilleux l\'Atalante ','  annales disque monde   annales disque monde 1 huitieme couleur   quatrieme couverture dans dimension lointaine passablement farfelue monde se balade dos quatre elephants eux memes juches sur carapace grande tortue oui c est disque monde habitants cite ankh morpork croyaient avoir tout vu deuxfleurs avait air tellement inoffensif bonhomme chetif fidelement escorte par bagage bois magique deambulant sur myriade petites jambes tellement inoffensif que patricien avait charge calamiteux sorcier rincevent sa securite dans cite quadrillee par guilde voleurs celle assassins mission perilleuse qui devait conduire loin dans caverne dragons peut etre jusqu rebord disque car deuxfleurs etait espece plus redoutable qu on ne imaginait c etait touriste lumiere octarine huitieme couleur celle magie decouvrez univers fantastique cocasse terry pratchett     couton patrick pratchett terry  fantastique merveilleux l atalante ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (105,1,' 2  annales disque monde  2 Le huitième sortilège    Présentation de l\'éditeur\r\nOctogénaire, borgne, chauve et édenté, Cohen le Barbare, le plus grand héros de tous les temps, réussira-t-il à tirer Deuxfleurs et Rincevent des griffes de leurs poursuivants ? Question capitale, car le tissu même du temps et de l\'espace est sur le point de passer dans l\'essoreuse. Une étoile rouge menace de percuter le Disque-Monde et la survie de celui-ci est entre les mains du sorcier calamiteux : dans son esprit (très) brumeux se tapit en effet le... huitième sortilège ! La suite de l\'épopée la plus démente de la fantasy, avec, dans les seconds rôles, une distribution prestigieuse : le Bagage, l\'In-Octavo, Herrena la harpie, Kwartz le troll, Trymon l\'enchanteur maléfique et, naturellement, La Mort...    Couton Patrick      Pratchett Terry       Fantastique et merveilleux l\'Atalante ','  annales disque monde   annales disque monde 2 huitieme sortilege   presentation editeur octogenaire borgne chauve edente cohen barbare plus grand heros tous temps reussira il tirer deuxfleurs rincevent griffes leurs poursuivants question capitale car tissu meme temps espace est sur point passer dans essoreuse etoile rouge menace percuter disque monde survie celui ci est entre mains sorcier calamiteux dans son esprit tres brumeux se tapit effet huitieme sortilege suite epopee plus demente fantasy avec dans seconds roles distribution prestigieuse bagage in octavo herrena harpie kwartz troll trymon enchanteur malefique naturellement mort     couton patrick pratchett terry  fantastique merveilleux l atalante ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (122,1,'    N° 393 - novembre 2011 - L\'Île de Pâques   Le rêve ultime des voyageurs   ÉVASION - La dernière frontière du Pacifique\r\nÀ des milliers de kilomètres de toute terre émergée, l’île de Pâques et ses statues géantes fascinent toujours les voyageurs.\r\n\r\nMODES DE VIE - Le Grand Paris\r\nÀ quoi ressemblera le Grand Paris ? Un métro de 200 kilomètres, un port gigantesque à Achères, une Silicon Valley à Saclay… La future mégapole commence à dévoiler son nouveau visage.\r\n\r\nENVIRONNEMENT - L\'iPhone est-il écolo ?\r\nÉtape par étape, l’analyse de l’impact environnemental du petit bijou d’Apple.\r\n\r\nVOYAGE - La nouvelle vie de Cracovie\r\nLa cité polonaise est l’un des lieux les plus touristiques de l’ancien bloc de l’Est. Grâce à sa richesse culturelle et à sa jeunesse qui crée une ambiance de «movida».\r\n\r\nPARTIR - Quoi de neuf à Bruxelles ?\r\nMalgré la crise institutionnelle qui paralyse le pays, la capitale belge n’a pas perdu sa créativité. Tables, hôtels, shopping… Tour d’horizon des nouvelles adresses.\r\n\r\nGÉOPOLITIQUE - Comment la Chine redessine le monde\r\nEn Grèce, en Birmanie, en Zambie… Partout, les Chinois financent et bâtissent des ports, des routes, des hôpitaux. C’est la phase nouvelle du «zouchuqu», leur stratégie de conquête tous azimuts.\r\n\r\nLE MONDE EN CARTES - Pourquoi la Kapisa est dans l’oeil du cyclone ?\r\nProche de Kaboul, cette province est la zone de tous les dangers pour les militaires français.\r\n\r\nGRANDE SÉRIE : LE LITTORAL FRANÇAIS - LA NORMANDIE\r\nNotre photographe livre son coup d’oeil sur les hauts lieux de la côte normande. Et notre journaliste analyse les enjeux du moment sur le plan du tourisme et de l’environnement.     Géo    Ile de Pâques ','   n 393 novembre 2011 ile paques reve ultime voyageurs     evasion derniere frontiere pacifique milliers kilometres toute terre emergee ile paques ses statues geantes fascinent toujours voyageurs modes vie grand paris quoi ressemblera grand paris metro 200 kilometres port gigantesque acheres silicon valley saclay future megapole commence devoiler son nouveau visage environnement iphone est il ecolo etape par etape analyse impact environnemental petit bijou apple voyage nouvelle vie cracovie cite polonaise est lieux plus touristiques ancien bloc est grace sa richesse culturelle sa jeunesse qui cree ambiance movida partir quoi neuf bruxelles malgre crise institutionnelle qui paralyse pays capitale belge n pas perdu sa creativite tables hotels shopping tour horizon nouvelles adresses geopolitique comment chine redessine monde grece birmanie zambie partout chinois financent batissent ports routes hopitaux c est phase nouvelle zouchuqu leur strategie conquete tous azimuts monde cartes pourquoi kapisa est dans oeil cyclone proche kaboul cette province est zone tous dangers pour militaires francais grande serie littoral francais normandie notre photographe livre son coup oeil sur hauts lieux cote normande notre journaliste analyse enjeux moment sur plan tourisme environnement   geoile paques ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (123,1,'    N° 402 - août 2012 - Compostelle, Shikoku, Lalibela... Les chemins de la sagesse      LE MONDE QUI CHANGE\r\nLe patrimoine de la Syrie sous la menace.\r\n\r\nLES HÉROS D\'AUJOURD\'HUI\r\nCe chirurgien indien qui prend à cœur la santé de son pays.\r\n\r\nLE GOÛT DE GEO\r\nLe «dim-sum», un microfestin à la chinoise.\r\n\r\nÉVASION - Dans le sillage d\'Ulysse\r\nHeureux qui comme le héros d\'Homère a fait un beau voyage... GEO a suivi ses pas en Méditerranée.\r\n\r\nESCALE - Jean Didier Urbain\r\nVite parcouru, mal lu.\r\n\r\nMODES DE VIE - A la vie, à la mer\r\nReportage sur ces marins pêcheurs qui écument les océans glacés et bravent les tempêtes.\r\n\r\nENVIRONNEMENT - Faut-il se préparer aux grandes sécheresses ?\r\nIl fait plus sec et plus chaud. Résultat, la terre a soif et les agriculteurs trinquent.\r\n\r\nVOYAGE - Le renouveau des chemins sacrés\r\nLes marcheurs affluent vers les routes spirituelles à la recherche du grand voyage intérieur.\r\n\r\nLE BON PLAN - Le Bilbao des Bilbotars\r\n\r\nGÉOPOLITIQUE - Terres fertiles à louer\r\nDe puissants investisseurs étrangers trustent les meilleurs champs des pays du Sud. Néocolonialisme ou développement agricole ?\r\n\r\nLE MONDE EN CARTES - Des îles très disputées\r\n\r\nGRANDE SÉRIE - La France des villages\r\nPérigord et Quercy : panorama mensuel des pépites du terroir.    Géo    Religion ','   n 402 aout 2012 compostelle shikoku lalibela chemins sagesse     monde qui change patrimoine syrie sous menace heros aujourd hui ce chirurgien indien qui prend c ur sante son pays gout geo dim sum microfestin chinoise evasion dans sillage ulysse heureux qui comme heros homere fait beau voyage geo suivi ses pas mediterranee escale jean didier urbain vite parcouru mal lu modes vie vie mer reportage sur ces marins pecheurs qui ecument oceans glaces bravent tempetes environnement faut il se preparer grandes secheresses il fait plus sec plus chaud resultat terre soif agriculteurs trinquent voyage renouveau chemins sacres marcheurs affluent vers routes spirituelles recherche grand voyage interieur bon plan bilbao bilbotars geopolitique terres fertiles louer puissants investisseurs etrangers trustent meilleurs champs pays sud neocolonialisme ou developpement agricole monde cartes iles tres disputees grande serie france villages perigord quercy panorama mensuel pepites terroir   georeligion ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (124,1,'    Bulletin des bibliothèques de France  BBF      ENSSIB        Bibliothéconomie ENSSIB ','   bulletin bibliotheques france bbf      enssib  bibliotheconomie enssib ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (125,1,'    Bibliothécaire de soi-même    Les bibliothèques publiques ont souvent pour origine des collections privées. Mais la fréquentation de ces bibliothèques n\'empêche pas, accompagne même, le goût pour constituer sa bibliothèque privée, « la reconstitution à son usage propre d\'une sorte de bibliothèque publique ». La gestion de ces bibliothèques privées se heurte aux mêmes problèmes que les bibliothèques institutionnelles, comme le classement, le rangement, mais aussi la politique d\'acquisition, même si le caractère privé de sa bibliothèque autorise de nombreuses licences au propriétaire des livres, « bibliothécaire de soi-même ». L\'obligation de conservation et d\'entretien est évidente, si celle de désherbage, désormais largement pratiqué dans les bibliothèques publiques, l\'est moins - tout comme le catalogage, et a fortiori le prêt.    Bonnet Jacques        Bulletin des bibliothèques de France  BBF  La bibliothèque vue par ses usagers, même  bibliotheque vue par ses usagers meme   Bibliothéconomie ','   bibliothecaire soi meme   bibliotheques publiques ont souvent pour origine collections privees mais frequentation ces bibliotheques n empeche pas accompagne meme gout pour constituer sa bibliotheque privee reconstitution son usage propre sorte bibliotheque publique gestion ces bibliotheques privees se heurte memes problemes que bibliotheques institutionnelles comme classement rangement mais aussi politique acquisition meme si caractere prive sa bibliotheque autorise nombreuses licences proprietaire livres bibliothecaire soi meme obligation conservation entretien est evidente si celle desherbage desormais largement pratique dans bibliotheques publiques est moins tout comme catalogage fortiori pret     bonnet jacques bulletin bibliotheques france bbf bibliotheque vue par ses usagers meme bibliotheque vue par ses usagers meme  bibliotheconomie ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (126,1,'    Voyages en BM    La trajectoire d\'un usager des bibliothèques publiques, de l\'enfance à aujourd\'hui : autodidacte, il fréquente assidûment la bibliothèque municipale de Montreuil-sous-Bois, « copropriétaire d\'une BM unique dans la commune... Ma première patrie fut cette bibliothèque » ; le contact permanent des livres, le passage difficile de l\'adolescence, puis le « boulot d\'auteur », toujours accompagné des bibliothèques. « Aujourd\'hui, je ne ressemble pas à mes gosses. À cause ou grâce à ces livres empruntés chaque semaine, j\'ai quitté une classe sociale... sans jamais en trouver une autre de rechange. »    Akkouche Mouloud        Bulletin des bibliothèques de France  BBF  La bibliothèque vue par ses usagers, même  bibliotheque vue par ses usagers meme   Bibliothéconomie ','   voyages bm   trajectoire usager bibliotheques publiques enfance aujourd hui autodidacte il frequente assidument bibliotheque municipale montreuil sous bois coproprietaire bm unique dans commune ma premiere patrie fut cette bibliotheque contact permanent livres passage difficile adolescence puis boulot auteur toujours accompagne bibliotheques aujourd hui je ne ressemble pas mes gosses cause ou grace ces livres empruntes chaque semaine j ai quitte classe sociale sans jamais trouver autre rechange     akkouche mouloud bulletin bibliotheques france bbf bibliotheque vue par ses usagers meme bibliotheque vue par ses usagers meme  bibliotheconomie ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (128,1,'    Poisson rouge        Interactica        Jeux et jouets ','   poisson rouge      interactica  jeux jouets ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (129,1,'    Georges   petit-petit-petit magazine Le concept de Georges\r\n\r\nBienvenue dans l’univers de Georges, petit – petit – petit magazine, revue alternative trimestrielle créée par les Éditions Grains de Sel, pour les enfants ni trop petits ni trop grands (dès 7-8 ans et jusqu’à 12 ans). Mais aussi pour les plus grands qui s’intéressent au graphisme et à l’illustration.\r\n \r\nMais qui est Georges ?\r\nUn magazine décalé et exigeant qui stimule la curiosité et revisite les traitements traditionnels des magazines pour enfants.\r\n\r\nQuels sont ses atouts ?\r\nUn graphisme épuré  et un thème original pour chaque numéro, sur un beau papier offset et recyclé, avec des illustrateurs aux univers sensibles et un second degré qui séduit les enfants (et même leurs parents).\r\n\r\nComment se présente-t-il ?\r\nPartie 1 – des HISTOIRES vraies, courtes, longues ou à l’envers.\r\nPartie 2 – des JEUX à colorier, calculer ou déchiffrer autour du thème du numéro.\r\nPartie 3 – des RUBRIQUES-À-BRAC pour découvrir des métiers, langues étrangères, scènes de films ou expériences scientifiques, mais de façon toujours farfelue&#8201;!     Jeux et jouets Éd. Grains de sel ','   georges petit petit petit magazine   concept georges bienvenue dans univers georges petit petit petit magazine revue alternative trimestrielle creee par editions grains sel pour enfants ni trop petits ni trop grands 7 8 ans jusqu 12 ans mais aussi pour plus grands qui s interessent graphisme illustration mais qui est georges magazine decale exigeant qui stimule curiosite revisite traitements traditionnels magazines pour enfants quels sont ses atouts graphisme epure theme original pour chaque numero sur beau papier offset recycle avec illustrateurs univers sensibles second degre qui seduit enfants meme leurs parents comment se presente il partie 1 histoires vraies courtes longues ou envers partie 2 jeux colorier calculer ou dechiffrer autour theme numero partie 3 rubriques brac pour decouvrir metiers langues etrangeres scenes films ou experiences scientifiques mais facon toujours farfelue 8201      jeux jouets ed grains de sel ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (109,1,'    La musique africaine   Timbélélé et la reine Lune Laissez-vous envoûter par le son de la kora, du balafon, du khollé, des djembés, du tama, l\'accent du narrateur et les voix incomparables des frères Toure.Partez à la découverte des musiques d\'Afrique !   Jeunesse - Albums;Musique et instruments;Contes, comptines et poésie Silloray Florent       Afrique Musique 780 Musique Mes Premières Découvertes de la Musique  Gallimard Jeunesse Musique ','   musique africaine timbelele reine lune   laissez vous envouter par son kora balafon kholle djembes tama accent narrateur voix incomparables freres toure partez decouverte musiques afrique     jeunesse albums musique instruments contes comptines poesie  silloray florent  afrique musique 780 musique mes premieres decouvertes musique  gallimard jeunesse musique ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (130,1,'    Numéro Moustache    Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !      Georges   petit-petit-petit magazine ','   numero moustache   pour ce numero georges vous propose partie 1 histoires partie 2 jeux partie 3 rubriques brac lexique geoges vous souhaite mesdames messieurs agreable lecture     georges petit petit petit magazine');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (131,1,'    Numéro Cupcake    Pour ce numéro, Georges vous propose :\r\nPartie 1 : des histoires\r\nPartie 2 : des jeux\r\nPartie 3 : des rubriques-à-brac\r\n+ un lexique\r\nGeoges vous souhaite, Mesdames et Messieurs, une agréable lecture !      Georges   petit-petit-petit magazine Cuisine ','   numero cupcake   pour ce numero georges vous propose partie 1 histoires partie 2 jeux partie 3 rubriques brac lexique geoges vous souhaite mesdames messieurs agreable lecture     georges petit petit petit magazinecuisine ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (132,1,'    Studio ciné live magazine     Magazine mensuel.\r\nFusion de : \"Studio magazine\", ISSN 0982-8354\r\net de : \"Ciné live\", ISSN 1253-4250   Boulnois Philippe       Cinéma Studio magazine ','   studio cine live magazine    magazine mensuel fusion studio magazine issn 0982 8354 cine live issn 1253 4250    boulnois philippe  cinema studio magazine ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (133,1,'    Dark Shadows   dossier Tim Burton Tim Burton : une famille mortelle\r\nEva Green : mon journal de tournage\r\nFrankenweenie : l\'autre Burton\r\nTim sur un plateau      Studio ciné live magazine        ','   dark shadows dossier tim burton   tim burton famille mortelle eva green mon journal tournage frankenweenie autre burton tim sur plateau     studio cine live magazine ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (127,1,'    L\'abeille et le bibliothécaire ou éthique du libre et lecture publique en zone rurale    Mariant évolution des techniques et analyse des territoires ruraux, cet article se veut une réflexion (et une incitation) sur le travail en commun, une « théorie de la pratique », la mise en oeuvre professionnelle et partagée de la société de la connaissance. L\'exemple du RISOM (Réseau intercommunal et solidaire des médiathèques de Tence, St-Jeures et Le Mazet-St-Voy, Haute-Loire), qui propose le partage d\'informations sur des projets d\'animation, leurs outils et leurs usages, vient à l\'appui et en illustration de cette analyse.    Aïoutz Renaud        Bulletin des bibliothèques de France  BBF  Bibliothèques et techniques  bibliotheques techniques   Bibliothéconomie ','   abeille bibliothecaire ou ethique libre lecture publique zone rurale   mariant evolution techniques analyse territoires ruraux cet article se veut reflexion incitation sur travail commun theorie pratique mise oeuvre professionnelle partagee societe connaissance exemple risom reseau intercommunal solidaire mediatheques tence st jeures mazet st voy haute loire qui propose partage informations sur projets animation leurs outils leurs usages vient appui illustration cette analyse     aioutz renaud bulletin bibliotheques france bbf bibliotheques techniques bibliotheques techniques  bibliotheconomie ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (135,1,'    Histoire de Don Quichotte        David Jules      Staal Gustave      Florian Jean-Pierre Claris de      Cervantès Saavedra Miguel de      Garnier frères ','   histoire don quichotte      david jules staal gustave florian jean pierre claris de cervantes saavedra miguel de garnier freres ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (136,1,'    Les fleurs du mal        Baudelaire Charles      Poulet-Malassis et De Broise ','   fleurs mal      baudelaire charles poulet malassis et de broise ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (77,1,'    African psycho   roman Quatrième de couverture\r\n« Que les choses soient claires : je ne souhaite pas être plus grand que l’Angoualima, ni me greffer des petits doigts, je veux être apprécié en fonction du résultat de mon geste criminel. Ne pouvant égaler les prouesses du Grand Maître, j\'aimerais au moins être considéré comme son fils spirituel. Pour cela, j\'en suis conscient, je dois encore travailler : tuer Germaine ce 29 décembre, c\'est-à-dire dans deux jours, n\'est qu\'une étape vers ce couronnement. »\r\n\r\nGrégoire Nakobomayo, orphelin, a grandi dans une ville industrielle de l\'Afrique post-coloniale. Accueilli quelque temps chez un couple instruit, il reçoit une éducation bourgeoise jusqu\'au jour où il plante son crayon dans l\'oeil du fils unique qui cherche à le violer. Obligé de fuir, il se réfugie dans le quartier le plus délabré de la ville et prend pour modèle \"Angoualima\", le célèbre serial killer qui depuis des années défie le pays, ses juges, ses flics et ses journalistes. Mais n\'est pas serial killer qui veut\r\nAvec humour -et.ironie-Alain Mabanckou conte les déboires d\'un psychopathe velléitaire et sans talent qui cherche dans la perversité un sens à sa vie.    Mabanckou Alain       Afrique Littérature d\'Afrique noire Serpent à plumes ','   african psycho roman   quatrieme couverture que choses soient claires je ne souhaite pas etre plus grand que angoualima ni me greffer petits doigts je veux etre apprecie fonction resultat mon geste criminel ne pouvant egaler prouesses grand maitre j aimerais moins etre considere comme son fils spirituel pour cela j suis conscient je dois encore travailler tuer germaine ce 29 decembre c est dire dans deux jours n est qu etape vers ce couronnement gregoire nakobomayo orphelin grandi dans ville industrielle afrique post coloniale accueilli quelque temps chez couple instruit il recoit education bourgeoise jusqu jour ou il plante son crayon dans oeil fils unique qui cherche violer oblige fuir il se refugie dans quartier plus delabre ville prend pour modele angoualima celebre serial killer qui depuis annees defie pays ses juges ses flics ses journalistes mais n est pas serial killer qui veut avec humour ironie alain mabanckou conte deboires psychopathe velleitaire sans talent qui cherche dans perversite sens sa vie     mabanckou alain  afrique litterature afrique noire serpent a plumes ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (89,1,'    Cuisine actuelle de l\'Afrique noire   plus de 60 recettes faciles à réaliser Présentation de l\'éditeur\r\nSénégal, Mali, Cameroun, Congo, Côte d\'Ivoire, logo, Nigeria, Gabon... L\'Afrique Noire, dans son immense diversité, offre aux palais amateurs de bonne chère, des plats savoureux et délicats qui, contrairement aux idées reçues, peuvent être simples à réaliser dès lors que l\'on dispose des connaissances et du savoir-faire indispensables. Plus de 60 recettes faciles à réaliser : A travers un large choix de recettes, composé entre autres des grands classiques (Tiep, Yassa, Mafé, Saka-Saka, Mbongo...), les auteurs de cet ouvrage nous accompagnent pas à pas pour réaliser le meilleur de la cuisine africaine. Présentation des ingrédients spécifiques à la préparation des plats (arachide, manioc, graines de courge...), portraits légendés, trucs et astuces, recettes étape par étape... dans ce beau livre riche en photos, la cuisine africaine se met enfin à la portée de fous ! Un beau livre de cuisine pour goûter et apprécier toutes les saveurs de l\'Afrique Noire : Et pour qu\'au plaisir de la bouche se joigne celui de l\'esprit et de la vue, des proverbes, des textes, des photos viennent agrémenter de-ci de-là les recettes.   Cuisine africaine Tabuteau Jean-Luc      Cuvilliez Joëlle      Bella Ola Alexandre      Cuisine  Afrique 640 Arts ménagers - cuisine, couture, soins de beauté Éd. First ','   cuisine actuelle afrique noire plus 60 recettes faciles realiser   presentation editeur senegal mali cameroun congo cote ivoire logo nigeria gabon afrique noire dans son immense diversite offre palais amateurs bonne chere plats savoureux delicats qui contrairement idees recues peuvent etre simples realiser lors que on dispose connaissances savoir faire indispensables plus 60 recettes faciles realiser travers large choix recettes compose entre autres grands classiques tiep yassa mafe saka saka mbongo auteurs cet ouvrage nous accompagnent pas pas pour realiser meilleur cuisine africaine presentation ingredients specifiques preparation plats arachide manioc graines courge portraits legendes trucs astuces recettes etape par etape dans ce beau livre riche photos cuisine africaine se met enfin portee fous beau livre cuisine pour gouter apprecier toutes saveurs afrique noire pour qu plaisir bouche se joigne celui esprit vue proverbes textes photos viennent agrementer ci recettes     cuisine africaine  tabuteau jean luc cuvilliez joelle bella ola alexandre cuisine  afrique 640 arts menagers cuisine couture soins beaute ed first ');
INSERT INTO notices_global_index (num_notice, no_index, infos_global, index_infos_global) VALUES (78,1,'    Soleil noir    Présentation de l\'éditeur\r\nIl y eut un long il était une fois…\r\nD’une écriture libre, anarchiste, de la même veine qu’un chant de Joyce où la structure vole en éclat…\r\nIl était une fois, un jeune narrateur, qu’importe son nom, pendu par les pieds par un chef aussi noir que les origines de l’homme, tiraillé par la faim et qui rêve de Blanche Goodfather en train de se baigner nue du côté des Chutes du Rocher. Fin…\r\nIl était une fois un amour magnifique, Marie, aveugle, comme seul personnage lucide parmi ceux qui sont pris au piège de la violence et de l’absurdité d’un pays sous apartheid… De jeunes gens dans l’émeute, émeute du langage, émeute de la pensée, émeute du regard sur le monde, sur la vie, contre un système…\r\nSoleil noir (écrit en 1980) est ce roman éclaté où l’auteur balaie d’un revers de la main la frontière entre le réel et l’irréel, entre le conte et le témoignage, entre le rêve et la pensée, nous propulsant littéralement sans un monde aveuglé que seul le dérèglement du langage peut appréhender. Roman de la révolte, Soleil noir, publié pour la première fois en français, est un roman mythique de Marechera, écrit entre la rue et de fréquents séjours en prison.     Evette Jean-Baptiste      Garnier Xavier      Marechera Dambudzo       Afrique Littérature d\'Afrique noire Fragments  Vents d\'ailleurs ','   soleil noir   presentation editeur il y eut long il etait fois ecriture libre anarchiste meme veine qu chant joyce ou structure vole eclat il etait fois jeune narrateur qu importe son nom pendu par pieds par chef aussi noir que origines homme tiraille par faim qui reve blanche goodfather train se baigner nue cote chutes rocher fin il etait fois amour magnifique marie aveugle comme seul personnage lucide parmi ceux qui sont pris piege violence absurdite pays sous apartheid jeunes gens dans emeute emeute langage emeute pensee emeute regard sur monde sur vie contre systeme soleil noir ecrit 1980 est ce roman eclate ou auteur balaie revers main frontiere entre reel irreel entre conte temoignage entre reve pensee nous propulsant litteralement sans monde aveugle que seul dereglement langage peut apprehender roman revolte soleil noir publie pour premiere fois francais est roman mythique marechera ecrit entre rue frequents sejours prison     evette jean baptiste garnier xavier marechera dambudzo  afrique litterature afrique noire fragments  vents d ailleurs ');
/*!40000 ALTER TABLE notices_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_langues`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_langues (
  num_notice int(8) unsigned NOT NULL DEFAULT '0',
  type_langue int(1) unsigned NOT NULL DEFAULT '0',
  code_langue char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ordre_langue smallint(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_notice,type_langue,code_langue)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_langues`
--

LOCK TABLES notices_langues WRITE;
/*!40000 ALTER TABLE notices_langues DISABLE KEYS */;
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (87,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (103,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (74,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (113,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (81,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (93,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (84,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (88,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (72,0,'bam',2);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (72,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (72,0,'lin',1);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (105,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (106,0,'eng',1);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (71,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (92,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (95,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (82,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (102,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (105,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (97,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (70,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (113,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (86,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (94,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (77,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (96,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (104,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (91,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (90,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (75,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (111,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (110,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (101,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (112,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (104,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (103,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (98,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (114,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (76,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (114,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (108,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (106,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (107,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (89,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (69,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (112,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (111,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (86,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (87,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (110,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (102,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (83,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (85,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (79,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (79,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (78,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (78,1,'eng',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (73,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (120,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (121,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (122,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (123,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (124,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (125,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (126,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (127,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (128,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (129,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (130,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (131,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (132,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (133,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (135,0,'fre',0);
INSERT INTO notices_langues (num_notice, type_langue, code_langue, ordre_langue) VALUES (136,0,'fre',0);
/*!40000 ALTER TABLE notices_langues ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_mots_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_mots_global_index (
  id_notice mediumint(8) NOT NULL DEFAULT '0',
  code_champ int(3) NOT NULL DEFAULT '0',
  code_ss_champ int(3) NOT NULL DEFAULT '0',
  num_word int(10) unsigned NOT NULL DEFAULT '0',
  pond int(4) NOT NULL DEFAULT '100',
  position int(11) NOT NULL DEFAULT '1',
  field_position int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (id_notice,code_champ,code_ss_champ,num_word,position,field_position),
  KEY code_champ (code_champ),
  KEY i_id_mot (num_word,id_notice),
  KEY i_code_champ_code_ss_champ_num_word (code_champ,code_ss_champ,num_word)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci
/*!50100 PARTITION BY KEY (code_champ,code_ss_champ)
PARTITIONS 50 */;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_mots_global_index`
--

LOCK TABLES notices_mots_global_index WRITE;
/*!40000 ALTER TABLE notices_mots_global_index DISABLE KEYS */;
/*!40000 ALTER TABLE notices_mots_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_relations`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_relations (
  num_notice bigint(20) unsigned NOT NULL DEFAULT '0',
  linked_notice bigint(20) unsigned NOT NULL DEFAULT '0',
  relation_type char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  rank int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (num_notice,linked_notice),
  KEY linked_notice (linked_notice),
  KEY relation_type (relation_type)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_relations`
--

LOCK TABLES notices_relations WRITE;
/*!40000 ALTER TABLE notices_relations DISABLE KEYS */;
INSERT INTO notices_relations (num_notice, linked_notice, relation_type, rank) VALUES (121,120,'b',1);
INSERT INTO notices_relations (num_notice, linked_notice, relation_type, rank) VALUES (122,120,'b',1);
INSERT INTO notices_relations (num_notice, linked_notice, relation_type, rank) VALUES (123,120,'b',1);
INSERT INTO notices_relations (num_notice, linked_notice, relation_type, rank) VALUES (130,129,'b',1);
INSERT INTO notices_relations (num_notice, linked_notice, relation_type, rank) VALUES (131,129,'b',1);
/*!40000 ALTER TABLE notices_relations ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `notices_titres_uniformes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE notices_titres_uniformes (
  ntu_num_notice int(9) unsigned NOT NULL DEFAULT '0',
  ntu_num_tu int(9) unsigned NOT NULL DEFAULT '0',
  ntu_titre varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_date varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_sous_vedette varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_langue varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_version varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_mention varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntu_ordre smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (ntu_num_notice,ntu_num_tu)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `notices_titres_uniformes`
--

LOCK TABLES notices_titres_uniformes WRITE;
/*!40000 ALTER TABLE notices_titres_uniformes DISABLE KEYS */;
/*!40000 ALTER TABLE notices_titres_uniformes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `offres_remises`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE offres_remises (
  num_fournisseur int(5) unsigned NOT NULL DEFAULT '0',
  num_produit int(8) unsigned NOT NULL DEFAULT '0',
  remise float(4,2) unsigned NOT NULL DEFAULT '0.00',
  condition_remise mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (num_fournisseur,num_produit)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `offres_remises`
--

LOCK TABLES offres_remises WRITE;
/*!40000 ALTER TABLE offres_remises DISABLE KEYS */;
/*!40000 ALTER TABLE offres_remises ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `onto_uri`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE onto_uri (
  uri_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  uri varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (uri_id),
  UNIQUE KEY uri (uri)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `onto_uri`
--

LOCK TABLES onto_uri WRITE;
/*!40000 ALTER TABLE onto_uri DISABLE KEYS */;
/*!40000 ALTER TABLE onto_uri ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_filters`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_filters (
  opac_filter_view_num int(10) unsigned NOT NULL DEFAULT '0',
  opac_filter_path varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  opac_filter_param mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (opac_filter_view_num,opac_filter_path)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_filters`
--

LOCK TABLES opac_filters WRITE;
/*!40000 ALTER TABLE opac_filters DISABLE KEYS */;
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'etageres','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'search_perso','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'infopages','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'nav_sections','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'nav_collections','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'flux_rss','a:1:{s:8:\"selected\";a:0:{}}');
INSERT INTO opac_filters (opac_filter_view_num, opac_filter_path, opac_filter_param) VALUES (1,'facettes','a:1:{s:8:\"selected\";a:4:{i:0;s:1:\"1\";i:1;s:1:\"2\";i:2;s:1:\"3\";i:3;s:1:\"4\";}}');
/*!40000 ALTER TABLE opac_filters ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_liste_lecture`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_liste_lecture (
  id_liste int(8) unsigned NOT NULL AUTO_INCREMENT,
  nom_liste varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  description text COLLATE utf8_unicode_ci,
  notices_associees blob NOT NULL,
  public int(1) NOT NULL DEFAULT '0',
  num_empr int(8) unsigned NOT NULL DEFAULT '0',
  `read_only` int(1) NOT NULL DEFAULT '0',
  confidential int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_liste)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_liste_lecture`
--

LOCK TABLES opac_liste_lecture WRITE;
/*!40000 ALTER TABLE opac_liste_lecture DISABLE KEYS */;
/*!40000 ALTER TABLE opac_liste_lecture ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_sessions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_sessions (
  empr_id int(10) unsigned NOT NULL DEFAULT '0',
  `session` mediumblob,
  date_rec timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (empr_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_sessions`
--

LOCK TABLES opac_sessions WRITE;
/*!40000 ALTER TABLE opac_sessions DISABLE KEYS */;
/*!40000 ALTER TABLE opac_sessions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_view_notices_1`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_view_notices_1 (
  opac_view_num_notice int(20) NOT NULL DEFAULT '0',
  PRIMARY KEY (opac_view_num_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_view_notices_1`
--

LOCK TABLES opac_view_notices_1 WRITE;
/*!40000 ALTER TABLE opac_view_notices_1 DISABLE KEYS */;
/*!40000 ALTER TABLE opac_view_notices_1 ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_views`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_views (
  opac_view_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  opac_view_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  opac_view_query mediumtext COLLATE utf8_unicode_ci NOT NULL,
  opac_view_human_query mediumtext COLLATE utf8_unicode_ci NOT NULL,
  opac_view_param mediumtext COLLATE utf8_unicode_ci NOT NULL,
  opac_view_visible int(1) unsigned NOT NULL DEFAULT '0',
  opac_view_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  opac_view_last_gen datetime DEFAULT NULL,
  opac_view_ttl int(11) NOT NULL DEFAULT '86400',
  PRIMARY KEY (opac_view_id)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_views`
--

LOCK TABLES opac_views WRITE;
/*!40000 ALTER TABLE opac_views DISABLE KEYS */;
INSERT INTO opac_views (opac_view_id, opac_view_name, opac_view_query, opac_view_human_query, opac_view_param, opac_view_visible, opac_view_comment, opac_view_last_gen, opac_view_ttl) VALUES (1,'Vue test','a:2:{s:6:\"SEARCH\";a:1:{i:0;s:3:\"f_2\";}i:0;a:5:{s:6:\"SEARCH\";s:3:\"f_2\";s:2:\"OP\";s:9:\"AUTHORITY\";s:5:\"FIELD\";a:1:{i:0;s:1:\"1\";}s:5:\"INTER\";N;s:8:\"FIELDVAR\";a:1:{s:12:\"authority_id\";a:1:{i:0;s:1:\"1\";}}}}','','',2,'','2012-09-05 10:24:15',0);
/*!40000 ALTER TABLE opac_views ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `opac_views_empr`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE opac_views_empr (
  emprview_view_num int(10) unsigned NOT NULL DEFAULT '0',
  emprview_empr_num int(10) unsigned NOT NULL DEFAULT '0',
  emprview_default int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (emprview_view_num,emprview_empr_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `opac_views_empr`
--

LOCK TABLES opac_views_empr WRITE;
/*!40000 ALTER TABLE opac_views_empr DISABLE KEYS */;
/*!40000 ALTER TABLE opac_views_empr ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `origin_authorities`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE origin_authorities (
  id_origin_authorities int(10) unsigned NOT NULL AUTO_INCREMENT,
  origin_authorities_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  origin_authorities_country varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  origin_authorities_diffusible int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_origin_authorities)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `origin_authorities`
--

LOCK TABLES origin_authorities WRITE;
/*!40000 ALTER TABLE origin_authorities DISABLE KEYS */;
INSERT INTO origin_authorities (id_origin_authorities, origin_authorities_name, origin_authorities_country, origin_authorities_diffusible) VALUES (1,'Catalogue Interne','FR',1);
INSERT INTO origin_authorities (id_origin_authorities, origin_authorities_name, origin_authorities_country, origin_authorities_diffusible) VALUES (2,'BnF','FR',1);
/*!40000 ALTER TABLE origin_authorities ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `origine_notice`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE origine_notice (
  orinot_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  orinot_nom varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  orinot_pays varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'FR',
  orinot_diffusion int(1) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (orinot_id),
  KEY orinot_nom (orinot_nom)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `origine_notice`
--

LOCK TABLES origine_notice WRITE;
/*!40000 ALTER TABLE origine_notice DISABLE KEYS */;
INSERT INTO origine_notice (orinot_id, orinot_nom, orinot_pays, orinot_diffusion) VALUES (1,'INTERNE','FR',1);
INSERT INTO origine_notice (orinot_id, orinot_nom, orinot_pays, orinot_diffusion) VALUES (6,'Librairie Dialogues','Fr',1);
INSERT INTO origine_notice (orinot_id, orinot_nom, orinot_pays, orinot_diffusion) VALUES (7,'BNF','FR',1);
INSERT INTO origine_notice (orinot_id, orinot_nom, orinot_pays, orinot_diffusion) VALUES (8,'FR-751131015','FR',1);
/*!40000 ALTER TABLE origine_notice ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ouvertures`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE ouvertures (
  date_ouverture date NOT NULL DEFAULT '0000-00-00',
  ouvert int(1) NOT NULL DEFAULT '1',
  commentaire varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_location int(3) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (date_ouverture,num_location)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ouvertures`
--

LOCK TABLES ouvertures WRITE;
/*!40000 ALTER TABLE ouvertures DISABLE KEYS */;
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-02-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2012-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2013-12-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-09-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2014-12-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-09-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2015-12-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-09-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2016-12-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-04-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-07-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-09-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2017-12-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2018-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-03-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-05-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-06-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-08-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-09-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-11-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2019-12-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-01-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-02-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-03-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-04-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-05-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-06-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-07-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-08-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-09-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-10-31',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-06',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-07',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-13',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-14',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-20',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-21',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-27',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-11-28',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-01',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-02',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-03',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-04',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-05',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-08',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-09',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-10',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-11',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-12',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-15',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-16',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-17',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-18',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-19',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-22',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-23',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-24',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-25',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-26',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-29',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-30',1,'',1);
INSERT INTO ouvertures (date_ouverture, ouvert, commentaire, num_location) VALUES ('2020-12-31',1,'',1);
/*!40000 ALTER TABLE ouvertures ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paiements`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE paiements (
  id_paiement int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaire mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_paiement)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paiements`
--

LOCK TABLES paiements WRITE;
/*!40000 ALTER TABLE paiements DISABLE KEYS */;
/*!40000 ALTER TABLE paiements ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `param_subst`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE param_subst (
  subst_module_param varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  subst_module_num int(2) unsigned NOT NULL DEFAULT '0',
  subst_type_param varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  subst_sstype_param varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  subst_valeur_param mediumtext COLLATE utf8_unicode_ci NOT NULL,
  subst_comment_param longtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (subst_module_param,subst_module_num,subst_type_param,subst_sstype_param)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `param_subst`
--

LOCK TABLES param_subst WRITE;
/*!40000 ALTER TABLE param_subst DISABLE KEYS */;
/*!40000 ALTER TABLE param_subst ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `parametres`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE parametres (
  id_param int(6) unsigned NOT NULL AUTO_INCREMENT,
  type_param varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
  sstype_param varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  valeur_param mediumtext COLLATE utf8_unicode_ci,
  comment_param longtext COLLATE utf8_unicode_ci,
  section_param varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  gestion int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_param),
  UNIQUE KEY typ_sstyp (type_param,sstype_param)
) ENGINE=MyISAM AUTO_INCREMENT=927 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `parametres`
--

LOCK TABLES parametres WRITE;
/*!40000 ALTER TABLE parametres DISABLE KEYS */;
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (1,'pmb','bdd_version','v5.19','Version de noyau de la base de données, à ne changer qu\'en version inférieure si un paramètre était mal passé et relancer la mise à jour. En général, contactez plutôt la mailing liste pmb.user@sigb.net','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (2,'z3950','accessible','1','Z3950 accessible ?\r\n 0 : non, menu inaccessible\r\n 1 : Oui, la librairie PHP_YAZ est activée, la recherche z3950 est possible','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (3,'pmb','nb_lastautorities','50','Nombre de dernières autoritées affichées en gestion d\'autorités','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (4,'pdflettreretard','1before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le courrier de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (5,'pdflettreretard','1after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le courrier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (6,'pdflettreretard','1fdp','L\'équipe de la bibliothèque','Signataire de la lettre.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (7,'pdflettreretard','1madame_monsieur','Madame, Monsieur,','Entête de la lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (8,'pdflettreretard','1nb_par_page','7','Nombre d\'ouvrages en retard imprimé sur les pages suivantes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (9,'pdflettreretard','1nb_1ere_page','4','Nombre d\'ouvrages en retard imprimé sur la première page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (10,'pdflettreretard','1taille_bloc_expl','16','Taille d\'un bloc (2 lignes) d\'ouvrage en retard. Le début de chaque ouvrage en retard sera espacé de cette valeur sur la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (11,'pdflettreretard','1debut_expl_1er_page','160','Début de la liste des exemplaires sur la première page, en mm depuis le bord supérieur de la page. Doit être règlé en fonction du texte qui précède la liste des ouvrages, lequel peut être plus ou moins long.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (12,'pdflettreretard','1debut_expl_page','15','Début de la liste des exemplaires sur les pages suivantes, en mm depuis le bord supérieur de la page.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (13,'pdflettreretard','1limite_after_list','270','Position limite en bas de page. Si un élément imprimé tente de dépasser cette limite, il sera imprimé sur la page suivante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (14,'pdflettreretard','1marge_page_gauche','10','Marge de gauche en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (15,'pdflettreretard','1marge_page_droite','10','Marge de droite en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (16,'pdflettreretard','1largeur_page','210','Largeur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (17,'pdflettreretard','1hauteur_page','297','Hauteur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (18,'pdflettreretard','1format_page','P','Format de la page : \r\n P : Portrait\r\n L : Landscape = paysage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (19,'pdfcartelecteur','pos_h','20','Position horizontale en mm à partir du bord gauche de la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (20,'pdfcartelecteur','pos_v','20','Position verticale en mm à partir du bord supérieur de la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (21,'pdfcartelecteur','biblio_name','$biblio_name','Nom de la bibliothèque ou du centre de ressources imprimé sur la carte de lecteur. Mettre $biblio_name pour reprendre le nom spécifié en localisation d\'exemplaire ou bien mettre autre chose.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (22,'pdfcartelecteur','largeur_nom','80','Largeur accordée à l\'impression du nom du lecteur en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (23,'pdfcartelecteur','valabledu','Valable du','\'Valable du\' dans \"VALABLE DU ##/##/#### au ##/##/####\"','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (24,'pdfcartelecteur','valableau','au','\'au\' dans \"valable du ##/##/#### AU ##/##/####\"','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (25,'pdfcartelecteur','carteno','Carte N° :','Mention précédant le numéro de la carte','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (26,'sauvegarde','cle_crypt1','9b4a840d790eadc71b9064c9a843719b','','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (27,'sauvegarde','cle_crypt2','51580d4fd5f1ad2d981c91ddb04095ec','','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (28,'pmb','resa_dispo','1','Réservation de documents disponibles possible ?\r\n 0 : Non\r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (29,'mailretard','1objet','$biblio_name : documents en retard','Objet du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (30,'mailretard','1before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (31,'mailretard','1after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (32,'mailretard','1madame_monsieur','Bonjour,','Entête du mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (33,'mailretard','1fdp','L\'équipe de la bibliothèque','Signataire du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (34,'pmb','serial_link_article','0','Préremplissage du lien des dépouillements avec le lien de la notice mère en catalogage des périodiques ?\r\n 0 : Non\r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (35,'pmb','num_carte_auto','1','Numéro de carte de lecteur automatique ?\n 0: Non (si utilisation de cartes pré-imprimées)\n 1: Oui, entièrement numérique\n 2,a,b,c: Oui, avec préfixe: a=longueur du préfixe, b=nombre de chiffres de la partie numérique, c=préfixe fixé (facultatif)\n 3,fonction: fonction de génération spécifique dans fichier nommé de la même façon, à placer dans pmb/circ/empr','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (36,'opac','modules_search_title','2','Recherche simple dans les titres :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (37,'opac','modules_search_author','2','Recherche simple dans les auteurs :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (38,'opac','modules_search_publisher','1','Recherche simple dans les éditeurs :\n 0 : interdite\n 1 : autorisée\n 2 : autorisée et validée par défaut\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (39,'opac','modules_search_collection','0','Recherche simple dans les collections :\n 0 : interdite\n 1 : autorisée\n 2 : autorisée et validée par défaut\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (40,'opac','modules_search_subcollection','0','Recherche simple dans les sous-collections :\n 0 : interdite\n 1 : autorisée\n 2 : autorisée et validée par défaut\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (41,'opac','modules_search_category','2','Recherche simple dans les catégories :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (42,'opac','modules_search_keywords','0','Recherche simple dans les indexations libres (mots-clés) :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (43,'opac','modules_search_abstract','0','Recherche simple dans le champ résumé :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (44,'opac','modules_search_content','0','Recherche simple dans les notes de contenu:\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\nINUTILISE POUR L\'INSTANT','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (45,'opac','categories_categ_path_sep','>','Séparateur pour les catégories','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (46,'opac','categories_columns','3','Nombre de colonnes du sommaire général des catégories','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (47,'opac','categories_categ_rec_per_page','6','Nombre de notices à afficher par page dans l\'exploration des catégories','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (48,'opac','categories_categ_sort_records','index_serie, tnvol, index_sew','Explorateur de catégories : mode de tri des notices :\r\n index_serie, tnvol, index_sew > par titre de série, numéro dans la série et index des titres\r\n rand() : aléatoire','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (49,'opac','search_results_first_level','4','Nombre de résultats affichés sur la première page','z_unused',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (50,'opac','search_results_per_page','15','Nombre de résultats affichés sur les pages suivantes','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (833,'demandes','init_workflow','1','Initialisation du workflow de la demande.\n 0 : Validation avant tout\n 1 : Validation avant tout et attribution au validateur\n 2 : Attribution avant tout','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (52,'opac','categories_sub_display','6','Nombre de sous-categories sur la première page','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (53,'opac','categories_sub_mode','libelle_categorie','Mode affichage des sous-categories : \r\n rand() > aléatoire\r\n libelle_categorie > ordre alpha','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (55,'opac','default_lang','fr_FR','Langue de l\'opac : fr_FR ou en_US ou es_ES ou ar','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (56,'opac','show_categ_browser','1','Affichage des catégories en page d\'accueil OPAC:\n0: Non\n1: Oui\n1 3,1: Oui, avec thésaurus id 3 puis 1 (préciser les thésaurus à afficher et l\'ordre)','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (57,'opac','show_book_pics','1','Afficher les vignettes de livres dans les fiches ouvrages :\r\n 0 : Non\r\n 1 : Oui','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (58,'opac','resa','1','Réservations possibles par l\'OPAC 1: oui  ou 0: non','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (59,'opac','resa_dispo','1','Réservations possibles de documents disponibles par l\'OPAC \r\n 1: oui \r\n 0: non','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (60,'opac','show_meteo','0','Affichage de la météo dans l\'OPAC 1: oui  ou 0: non','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (61,'opac','duration_session_auth','1200','Durée de la session lecteur dans l\'OPAC en secondes','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (62,'pmb','relance_adhesion','31','Nombre de jours avant expiration adhésion pour relance','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (63,'pmb','pret_adhesion_depassee','1','Prêts si adhésion dépassée : 0 INTERDIT incontournable, 1 POSSIBLE','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (64,'pdflettreadhesion','fdp','L\'équipe de la bibliothèque','Formule de politesse en bas de page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (65,'pdflettreadhesion','madame_monsieur','Bonjour,','Civilité du destinataire','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (66,'pdflettreadhesion','texte','Votre abonnement arrive à échéance le !!date_fin_adhesion!!. Nous vous remercions de penser à le renouveler lors de votre prochaine visite.\r\n\r\nNous vous prions de recevoir, Madame, Monsieur, l\'expression de nos meilleures salutations.\r\n\r\n\r\n','Phrase d\'introduction de l\'échéance de l\'abonnement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (67,'pdflettreadhesion','marge_page_gauche','10','Marge gauche de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (68,'pdflettreadhesion','marge_page_droite','10','Marge droite de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (69,'pdflettreadhesion','largeur_page','210','Largeur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (70,'pdflettreadhesion','hauteur_page','297','Hauteur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (71,'pdflettreadhesion','format_page','P','P pour Portrait, L pour paysage (Landscape)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (72,'mailrelanceadhesion','objet','$biblio_name : votre abonnement','Objet du courrier de relance d\'adhésion. Utilisez biblio_name pour reprendre le nom précisé dans la localisation des exemplaires.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (73,'mailrelanceadhesion','texte','Votre abonnement arrive à échéance le !!date_fin_adhesion!!. Nous vous remercions de penser à le renouveler lors de votre prochaine visite.\r\n\r\nCordialement,\r\n\r\n','Texte de la relance, !!date_fin_adhesion!! sera remplacé à l\'édition par la date de fin d\'adhésion du lecteur','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (74,'mailrelanceadhesion','madame_monsieur','Madame, Monsieur,','Entête du courrier de relance d\'adhésion','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (75,'mailrelanceadhesion','fdp','L\'équipe de la bibliothèque','Formule de politesse en bas de page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (76,'opac','show_marguerite_browser','0','0 ou 1 : marguerite des catégories','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (77,'opac','show_100cases_browser','0','0 ou 1 : affichage de 100 catégories','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (78,'pmb','indexint_decimal','1','0 ou 1 : l\'indexation interne est-elle une cotation décimale type Dewey','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (79,'opac','modules_search_indexint','0','Recherche simple dans les indexations décimales :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (80,'empr','birthdate_optional','1','Année de naissance facultative : \r\n 0 > non:elle est obligatoire \r\n 1 Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (81,'thesaurus','categories_show_empty_categ','1','Affichage des catégories ne contenant aucune notice :\r\n0=non, 1=oui','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (82,'thesaurus','categories_term_search_n_per_page','50','Nombre de termes affichés par page lors d\'une recherche par terme dans les catégories','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (83,'opac','show_loginform','1','Affichage du login lecteur dans l\'OPAC \r\n 0 > non\r\n 1 Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (84,'opac','default_style','pmb4','Style graphique de l\'OPAC, 1 style par défaut, nomargin : sans affichage du bandeau de gauche','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (85,'opac','show_exemplaires','1','Afficher les exemplaires dans l\'OPAC\n 1 Oui,\n 0 : Non','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (86,'pmb','import_modele','func_bdp.inc.php','Quel script de fonctions d\'import utiliser pour personnaliser l\'import ?','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (87,'pmb','quotas_avances','1','Quotas de prêts avancés ? \r\n 0 : Non\r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (88,'opac','logo','logo_default.jpg','Nom du fichier de l\'image logo','z_unused',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (89,'opac','logosmall','images/site/livre.png','Nom du fichier de l\'image petit logo','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (90,'opac','show_bandeaugauche','1','Affichage du bandeau de gauche ? \n 0 : Non\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (91,'opac','show_liensbas','1','Affichage des liens(pmb, google, bibli) en bas de page ? \n 0 : Non\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (92,'opac','show_homeontop','0','Affichage du lien HOME (retour accueil) sous le nom de la bibliothèque ou du centre de ressources (nécessaire si masquage bandeau gauche) ? \r\n 0 : Non\r\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (93,'pmb','resa_quota_pret_depasse','1','Réservation possible même si quota de prêt dépassé ? \n 0 : Non\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (94,'pmb','import_limit_read_file','100','Limite de taille de lecture du fichier en import, en général 100 ou 200 doit fonctionner, si problème de time out : fixer plus bas, 50 par exemple.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (95,'pmb','import_limit_record_load','100','Limite de taille de traitement de notices en import, en général 100 ou 200 doit fonctionner, si problème de time out : fixer plus bas, 50 par exemple.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (96,'opac','biblio_preamble_p1','<a href=\"./index.php\">\r\n<img src=\"./styles/pmb4/images/logo.jpg\" alt=\"logo\" />\r\n</a>','Paragraphe 1 d\'informations (par exemple, description du fonds)','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (97,'opac','biblio_preamble_p2','<div id=\"titre_bienvenue\">Bienvenue sur le Portail de la Bibliothèque</div>\r\n\r\n<!--<ul id=\"menuDeroulant\">\r\n\r\n<li>\r\n<a href=\'./index.php\'>Accueil</a>\r\n</li>\r\n\r\n<li>\r\n<a href=\'http://\'>Infopage 1</a>\r\n<ul class=\"sousMenu\">\r\n<li>\r\n<a href=\'http://\'>Infopage 11</a>\r\n</li>\r\n<li>\r\n<a href=\'http://\'>Infopage 12</a>\r\n</li>\r\n<li>\r\n<a href=\'http://\'>Infopage 13</a>\r\n</li>\r\n</ul>\r\n</li>\r\n\r\n<li>\r\n<a href=\'http://\'>Infopage 2</a>\r\n</li>\r\n\r\n<li>\r\n<a href=\'http://\'>Infopage 3</a>\r\n</li>\r\n\r\n</ul>-->','Paragraphe 2 d\'informations : accueil du public.','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (98,'opac','biblio_quicksummary_p1','','Paragraphe 1 de résumé, est masqué par défaut dans la feuille de style, voir id quickSummary.p1','z_unused',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (99,'opac','biblio_quicksummary_p2','','Paragraphe 2 de résumé, est masqué par défaut dans la feuille de style, voir id quickSummary.p2','z_unused',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (100,'opac','show_dernieresnotices','0','Affichage des dernières notices créées en bas de page ? \r\n 0 : Non\r\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (101,'opac','show_etageresaccueil','1','Affichage des étagères dans la page d\'accueil en bas de page ? \n 0 : Non\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (102,'opac','biblio_important_p1','','Infos importantes 1, dans la feuille de style, voir id important.p1\r\n\r\n','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (775,'opac','allow_simili_search','1','Activer les recherches similaires sur une notice :\n0 : Non\n1 : Activer la recherche \"Dans le même rayon\" et \"Peut-être aimerez-vous\"\n2 : Activer seulement la recherche \"Dans le même rayon\"\n3 : Activer seulement la recherche \"Peut-être aimerez-vous\"','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (103,'opac','biblio_important_p2','','Infos importantes, dans la feuille de style, voir id important.p2','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (104,'opac','biblio_name','Bib\'Doc','Nom de la bibliothèque ou du centre de ressources dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (105,'opac','biblio_website','','Site web de la bibliothèque ou du centre de ressources dans l\'opac\r\n\r\nhttp://www.sigb.net','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (106,'opac','biblio_adr1','ZI de Mont/Loir\r\nBP 10023','Adresse 1 de la bibliothèque ou du centre de ressources dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (107,'opac','biblio_town','CHATEAU DU LOIR','Ville dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (108,'opac','biblio_cp','72500','Code postal dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (109,'opac','biblio_country','France','Pays dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (110,'opac','biblio_phone','02 43 440 660','Téléphone dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (111,'opac','biblio_dep','72','Département dans l\'opac pour la météo','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (112,'opac','biblio_email','pmb@sigb.net','Email de contact dans l\'opac','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (113,'opac','etagere_notices_order','index_serie, tnvol, index_sew','Ordre d\'affichage des notices dans les étagères dans l\'opac \n  index_serie, tit1 : tri par titre de série et titre \n rand()  : aléatoire','j_etagere',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (114,'opac','etagere_notices_format','2','Format d\'affichage des notices dans les étagères de l\'écran d\'accueil \r\n 1 : ISBD seul \r\n 2 : Public seul \r\n 4 : ISBD et Public \r\n 8 : Réduit (titre+auteurs) seul','j_etagere',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (115,'opac','etagere_notices_depliables','1','Affichage dépliable des notices dans les étagères de l\'écran d\'accueil \r\n 0 : Non \r\n 1 : Oui','j_etagere',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (116,'opac','etagere_nbnotices_accueil','5','Nombre de notices affichées dans les étagères de l\'écran d\'accueil \r\n 0 : Toutes \r\n -1 : Aucune \r\n x : x notices affichées au maximum','j_etagere',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (117,'opac','nb_aut_rec_per_page','15','Nombre de notices affichées pour une autorité donnée','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (118,'opac','notices_format','2','Format d\'affichage des notices en résultat de recherche\n 0 : Utiliser le paramètre notices_format_onglets\n 1 : ISBD seul\n 2 : Public seul \n4 : ISBD et Public\n 5 : ISBD et Public avec ISBD en premier \n8 : Réduit (titre+auteurs) seul\n 9 : Templates django (Spécifier le nom du répertoire dans le paramètre notices_format_django_directory)','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (119,'opac','notices_depliable','1','Affichage dépliable des notices en résultat de recherche:\n0: Non dépliable\n1: Dépliable en cliquant que sur l\'icone\n2: Déplibable en cliquant sur toute la ligne du titre','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (120,'opac','term_search_n_per_page','50','Nombre de termes affichés par page en recherche par terme','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (121,'opac','show_empty_categ','1','En recherche par terme, affichage des catégories ne contenant aucun ouvrage :\r\n 0 : Non \r\n 1 : Oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (122,'opac','allow_extended_search','1','Autorisation ou non de la recherche avancée dans l\'OPAC \n 0 : Non \n 1 : Oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (123,'opac','allow_term_search','0','Autorisation ou non de la recherche par termes dans l\'OPAC \r\n 0 : Non \r\n 1 : Oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (124,'opac','term_search_height','350','Hauteur en pixels de la frame de recherche par termes (si pas précisé ou zéro : par défaut 200 pixels)','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (125,'opac','categories_nb_col_subcat','3','Nombre de colonnes de sous-catégories en navigation dans les catégories \n 3 par défaut','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (126,'opac','max_resa','5','Nombre maximum de réservation sur un document \r\n 5 par défaut \r\n 0 pour illimité','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (127,'pmb','show_help','1','Affichage de l\'aide contextuelle dans PMB en partie gestion \r\n 1 Oui \r\n 0 Non','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (128,'opac','show_help','1','Affichage de l\'aide en ligne dans l\'OPAC de PMB  \n 1 Oui \n 0 Non','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (129,'opac','cart_allow','1','Paniers possibles dans l\'OPAC de PMB  \n 1 Oui \n 0 Non','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (130,'opac','max_cart_items','200','Nombre maximum de notices dans un panier utilisateur.','h_cart',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (131,'opac','show_section_browser','1','Afficher le butineur de localisation et de sections ?\n 0 : Non\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (132,'opac','nb_localisations_per_line','5','Nombre de localisations affichées par ligne en page d\'accueil (si show_section_browser=1)','k_section',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (133,'opac','nb_sections_per_line','5','Nombre de sections affichées par ligne en visualisation de localisation (si show_section_browser=1)','k_section',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (134,'opac','cart_only_for_subscriber','0','Paniers de notices réservés aux adhérents de la bibliothèque ou du centre de ressources ?\r\n 1: Oui\r\n 0: Non, autorisé pour tout internaute','h_cart',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (135,'opac','notice_reduit_format','1','Format d\'affichage des réduits de notices :\r\n 0 = titre+auteur principal\r\n 1 = titre+auteur principal+date édition\r\n 2 = titre+auteur principal+date édition + ISBN\r\n 3 = titre seul\r\n P 1,2,3 = tit+aut+champs persos id 1 2 3\r\n E 1,2,3 = tit+aut+édit+champs persos id 1 2 3\r\n T = tit1+tit4\r\n 4 = titre+titre parallèle+auteur principal\r\n H 1 = id d\'un template de notice','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (136,'pdflettreresa','before_list','Suite à votre demande de réservation, nous vous informons que le ou les ouvrages ci-dessous sont à votre disposition à la bibliothèque.','Texte apparaissant avant la liste des ouvrages en résa dans le courrier de confirmation de résa','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (137,'pdflettreresa','after_list','Passé le délai de réservation, ces ouvrages seront remis en circulation, vous priant de les retirer dans les meilleurs délais.','Texte apparaissant après la liste des ouvrages','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (138,'pdflettreresa','fdp','L\'équipe de la bibliothèque','Signataire de la lettre, utiliser $biblio_name pour reprendre le paramètre \"biblio name\" ou bien mettre autre chose.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (139,'pdflettreresa','madame_monsieur','Bonjour,','Entête de la lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (140,'pdflettreresa','nb_par_page','7','Nombre d\'ouvrages réservés imprimé sur les pages suivantes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (141,'pdflettreresa','nb_1ere_page','4','Nombre d\'ouvrages réservés imprimé sur la première page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (142,'pdflettreresa','taille_bloc_expl','20','Taille d\'un bloc (2 lignes) d\'ouvrage en réservation. Le début de chaque ouvrage en résa sera espacé de cette valeur sur la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (143,'pdflettreresa','debut_expl_1er_page','160','Début de la liste des ouvrages sur la première page, en mm depuis le bord supérieur de la page. Doit être règlé en fonction du texte qui précède la liste des ouvrages, lequel peut être plus ou moins long.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (144,'pdflettreresa','debut_expl_page','15','Début de la liste des ouvrages sur les pages suivantes, en mm depuis le bord supérieur de la page.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (145,'pdflettreresa','limite_after_list','270','Position limite en bas de page. Si un élément imprimé tente de dépasser cette limite, il sera imprimé sur la page suivante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (146,'pdflettreresa','marge_page_gauche','10','Marge de gauche en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (147,'pdflettreresa','marge_page_droite','10','Marge de droite en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (148,'pdflettreresa','largeur_page','210','Largeur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (149,'pdflettreresa','hauteur_page','297','Hauteur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (150,'pdflettreresa','format_page','P','Format de la page : \r\n P : Portrait\r\n L : Landscape = paysage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (151,'opac','categories_max_display','200','Pour la page d\'accueil, nombre maximum de catégories principales affichées','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (152,'opac','search_other_function','','Fonction complémentaire pour les recherches en page d\'accueil','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (153,'opac','lien_bas_supplementaire','<a href=\"http://www.photo-libre.fr\" target=_\"blank\">Photos Libres</a>','Lien supplémentaire en bas de page d\'accueil, à renseigner complètement : a href= lien /a\r\n\r\n<a href=\'http://www.sigb.net/\' target=_blank>SIGB.NET</a>','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (154,'z3950','import_modele','func_other.inc.php','Quel script de fonctions d\'import utiliser pour personnaliser l\'import en intégration z3950 ?','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (155,'ldap','server','chinon','Serveur LDAP, IP ou host','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (156,'ldap','basedn','','Racine du nom de domaine LDAP','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (157,'ldap','port','389','Port du serveur LDAP','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (158,'ldap','filter','(&(objectclass=person)(gidnumber=GID))','Serveur LDAP, IP ou host','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (159,'ldap','fields','uid,gecos,departmentnumber','Champs du serveur LDAP','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (160,'ldap','lang','fr_FR','Langue du serveur LDAP','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (161,'ldap','groups','','Groupes du serveur LDAP','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (162,'ldap','accessible','0','LDAP accessible ?','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (163,'opac','categories_show_only_last','0','Dans la fiche d\'une notice : \n 0 tout afficher \n 1 : afficher uniquement la dernière feuille de l\'arbre de la catégorie','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (164,'thesaurus','categories_show_only_last','0','Dans la fiche d\'une notice : \n 0 tout afficher \n 1 : afficher uniquement la dernière feuille de l\'arbre de la catégorie','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (165,'pmb','prefill_cote','custom_cote_02.inc.php','Script personnalisé de construction de la cote de l\'exemplaire','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (166,'ldap','proto','3','Version du protocole LDAP : 3 ou 2','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (167,'ldap','binddn','uid=UID,ou=People','Description de la liaison : construction de la chaine binddn pour lier l\'authentification au serveur LDAP dans l\'OPAC','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (168,'empr','corresp_import','','Table de correspondances colonnes/champs en import de lecteurs à partir d\'un fichier ASCII','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (169,'pmb','type_audit','2','Gestion/affichage des dates de création/modification \r\n 0: Rien\r\n 1: Création et dernière modification\r\n 2: Création et toutes les dates de modification','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (170,'pmb','gestion_abonnement','1','Utiliser la gestion des abonnements des lecteurs ? \r\n 0 : Non\r\n 1 : Oui, gestion simple, \r\n 2 : Oui, gestion avancée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (171,'pmb','utiliser_calendrier','1','Utiliser le calendrier des jours d\'ouverture ?\n 0 : non\n 1 : oui, pour le calcul des dates de retour et des retards\n 2 : oui, pour le calcul des dates de retour uniquement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (172,'pmb','gestion_financiere','1','Utiliser le module gestion financière ? \r\n 0 : Non\r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (173,'pmb','gestion_tarif_prets','0','Utiliser la gestion des tarifs de prêts ? \n 0 : Non\n 1 : Oui, gestion simple, \n 2 : Oui, gestion avancée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (174,'pmb','gestion_amende','1','Utiliser la gestion des amendes:\r\n 0 = Non\r\n 1 = Gestion simple\r\n 2 = Gestion avancée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (175,'finance','amende_jour','0','Amende par jour de retard pour tout type de document. Attention, le séparateur décimal est le point, pas la virgule','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (176,'finance','delai_avant_amende','14','Délai avant déclenchement de l\'amende, en jour','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (177,'finance','delai_recouvrement','7','Délai entre 3eme relance et mise en recouvrement officiel de l\'amende, en jour','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (178,'finance','amende_maximum','0','Amende maximum, quel que soit le retard l\'amende est plafonnée à ce montant. 0 pour désactiver ce plafonnement.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (179,'pdflettreresa','priorite_email','1','Priorité des lettres de confirmation de réservation par mail lors de la validation d\'une réservation:\n 0 : Lettre seule \n 1 : Mail, à défaut lettre\n 2 : Mail ET lettre\n 3 : Aucune alerte','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (180,'pdflettreresa','priorite_email_manuel','1','Priorité des lettres de confirmation de réservation par mail lors de l\'impression à partir du bouton :\n 0 : Lettre seule \n 1 : Mail, à défaut lettre\n 2 : Mail ET lettre\n 3 : Aucune alerte','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (181,'finance','blocage_abt','1','Blocage du prêt si le compte abonnement est débiteur\n 0 : pas de blocage \n 1 : blocage avec forçage possible  : blocage incontournable.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (182,'finance','blocage_pret','1','Blocage du prêt si le compte prêt est débiteur\n 0 : pas de blocage \n 1 : blocage avec forçage possible  : blocage incontournable.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (183,'finance','blocage_amende','1','Blocage du prêt si le compte amende est débiteur\n 0 : pas de blocage \n 1 : blocage avec forçage possible  : blocage incontournable.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (184,'pmb','gestion_devise','&euro;','Devise de la gestion financière, ce qui va être affiché en code HTML','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (185,'opac','book_pics_url','http://images-eu.amazon.com/images/P/!!isbn!!.08.MZZZZZZZ.jpg','URL des vignettes des notices, dans le chemin fourni, !!isbn!! sera remplacé par le code ISBN ou EAN de la notice purgé de tous les tirets ou points. \r\n exemple : http://www.monsite/opac/images/vignettes/!!isbn!!.jpg','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (186,'opac','lien_moteur_recherche','','Lien supplémentaire en bas de page d\'accueil, à renseigner complètement : a href= lien /a\r\n\r\n<a href=http://www.google.fr target=_blank>Faire une recherche avec Google</a>','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (187,'pmb','pret_express_statut','2','Statut de notice à utiliser en création d\'exemplaires en prêts express','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (188,'opac','notice_affichage_class','','Nom de la classe d\'affichage pour personnalisation de l\'affichage des notices','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (189,'pmb','confirm_retour','0','En retour de documents, le retour doit-il être confirmé ? \n 0 : Non, on peut passer les codes-barres les uns après les autres \n 1 : Oui, il faut valider le retour après chaque code-barre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (190,'opac','show_meteo_url','<img src=\"http://perso0.free.fr/cgi-bin/meteo.pl?dep=72\" alt=\"\" border=\"0\" hspace=0>','URL de la météo affichée','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (191,'pmb','limitation_dewey','0','Nombre maximum de caractères dans la Dewey (676) en import : \n 0 aucune limitation \n 3 : limitation de 000 à 999 \n 5 (exemple) limitation 000.0 \n -1 : aucune importation','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (192,'finance','delai_1_2','14','Délai entre 1ere et 2eme relance','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (193,'finance','delai_2_3','21','Délai entre 2eme et 3eme relance','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (194,'pmb','lecteurs_localises','1','Lecteurs localisés ? \r\n 0: Non \r\n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (195,'dsi','active','1','D.S.I activée ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (196,'dsi','auto','0','D.S.I automatique activée ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (197,'dsi','insc_categ','0','Inscription automatique dans les bannettes de la catégorie du lecteur en création ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (198,'opac','allow_bannette_priv','1','Possibilité pour les lecteurs de créer ou modifier leurs bannettes privées\r\n 0: Non\r\n 1: Oui\r\n 2: Oui et le bouton de création s\'affiche en permanence en recherche multicritères','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (199,'opac','allow_resiliation','1','Possibilité pour les lecteurs de résilier leur abonnement aux bannettes pro \r\n 0: Non \r\n 1: Oui','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (200,'opac','show_categ_bannette','0','Affichage des bannettes de la catégorie du lecteur et possibilité de s\'y abonner \n 0: Non \n 1: Oui','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (201,'opac','url_base','./','URL de base de l\'opac : typiquement mettre l\'url publique web http://monsite/opac/ ne pas oublier le / final','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (202,'finance','relance_1','0','Frais de la première lettre de relance','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (203,'finance','relance_2','0','Frais de la deuxième lettre de relance','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (204,'finance','relance_3','2','Frais de la troisième lettre de relance','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (205,'finance','statut_perdu','12','Statut (d\'exemplaire) perdu pour des ouvrages non rendus','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (206,'pdflettreretard','2after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le courrier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (207,'pdflettreretard','2before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le courrier de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (208,'pdflettreretard','2debut_expl_1er_page','160','Début de la liste des exemplaires sur la première page, en mm depuis le bord supérieur de la page. Doit être règlé en fonction du texte qui précède la liste des ouvrages, lequel peut être plus ou moins long.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (209,'pdflettreretard','2debut_expl_page','15','Début de la liste des exemplaires sur les pages suivantes, en mm depuis le bord supérieur de la page.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (210,'pdflettreretard','2fdp','L\'équipe de la bibliothèque','Signataire de la lettre.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (211,'pdflettreretard','2format_page','P','Format de la page : \r\n P : Portrait\r\n L : Landscape = paysage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (212,'pdflettreretard','2hauteur_page','297','Hauteur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (213,'pdflettreretard','2largeur_page','210','Largeur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (214,'pdflettreretard','2limite_after_list','270','Position limite en bas de page. Si un élément imprimé tente de dépasser cette limite, il sera imprimé sur la page suivante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (215,'pdflettreretard','2madame_monsieur','Madame, Monsieur,','Entête de la lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (216,'pdflettreretard','2marge_page_droite','10','Marge de droite en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (217,'pdflettreretard','2marge_page_gauche','10','Marge de gauche en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (218,'pdflettreretard','2nb_1ere_page','4','Nombre d\'ouvrages en retard imprimé sur la première page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (219,'pdflettreretard','2nb_par_page','7','Nombre d\'ouvrages en retard imprimé sur les pages suivantes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (220,'pdflettreretard','2taille_bloc_expl','16','Taille d\'un bloc (2 lignes) d\'ouvrage en retard. Le début de chaque ouvrage en retard sera espacé de cette valeur sur la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (221,'pdflettreretard','3after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le courrier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (222,'pdflettreretard','3before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le courrier de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (223,'pdflettreretard','3debut_expl_1er_page','160','Début de la liste des exemplaires sur la première page, en mm depuis le bord supérieur de la page. Doit être règlé en fonction du texte qui précède la liste des ouvrages, lequel peut être plus ou moins long.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (224,'pdflettreretard','3debut_expl_page','15','Début de la liste des exemplaires sur les pages suivantes, en mm depuis le bord supérieur de la page.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (225,'pdflettreretard','3fdp','Le responsable','Signataire de la lettre.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (226,'pdflettreretard','3format_page','P','Format de la page : \r\n P : Portrait\r\n L : Landscape = paysage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (227,'pdflettreretard','3hauteur_page','297','Hauteur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (228,'pdflettreretard','3largeur_page','210','Largeur de la page en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (229,'pdflettreretard','3limite_after_list','270','Position limite en bas de page. Si un élément imprimé tente de dépasser cette limite, il sera imprimé sur la page suivante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (230,'pdflettreretard','3madame_monsieur','Madame, Monsieur,','Entête de la lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (231,'pdflettreretard','3marge_page_droite','10','Marge de droite en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (232,'pdflettreretard','3marge_page_gauche','10','Marge de gauche en mm','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (233,'pdflettreretard','3nb_1ere_page','4','Nombre d\'ouvrages en retard imprimé sur la première page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (234,'pdflettreretard','3nb_par_page','7','Nombre d\'ouvrages en retard imprimé sur les pages suivantes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (235,'pdflettreretard','3taille_bloc_expl','16','Taille d\'un bloc (2 lignes) d\'ouvrage en retard. Le début de chaque ouvrage en retard sera espacé de cette valeur sur la page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (236,'pdflettreretard','3before_recouvrement','Sans nouvelles de votre part dans les sept jours, nous nous verrons contraints de déléguer au trésor public le recouvrement des ouvrages suivants :','Texte avant la liste des ouvrages en recouvrement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (237,'opac','bannette_notices_order',' index_serie, tnvol, index_sew ','Ordre d\'affichage des notices dans les bannettes dans l\'opac \n  index_serie, tnvol, index_sew : tri par titre de série et titre \n rand()  : aléatoire','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (238,'opac','bannette_notices_format','2','Format d\'affichage des notices dans les bannettes \r\n 1 : ISBD seul \r\n 2 : Public seul \r\n 4 : ISBD et Public \r\n 8 : Réduit (titre+auteurs) seul','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (239,'opac','bannette_notices_depliables','1','Affichage dépliable des notices dans les bannettes \n 0 : Non \n 1 : Oui','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (240,'opac','bannette_nb_liste','10','Nbre de notices par bannettes en affichage de la liste des bannettes \r\n 0 Toutes \r\n N : maxi N\r\n -1 : aucune','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (241,'opac','dsi_active','1','DSI, bannettes accessibles par l\'OPAC ? \r\n 0 : Non \r\n 1 : Oui','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (242,'mailretard','2after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (243,'mailretard','2before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (244,'mailretard','2fdp','L\'équipe de la bibliothèque','Signataire du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (245,'mailretard','2madame_monsieur','Madame, Monsieur','Entête du mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (246,'mailretard','2objet','$biblio_name : documents en retard','Objet du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (247,'mailretard','3after_list','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (248,'mailretard','3before_list','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (249,'mailretard','3fdp','Le responsable.','Signataire du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (250,'mailretard','3madame_monsieur','Madame, Monsieur','Entête du mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (251,'mailretard','3objet','$biblio_name : documents en retard','Objet du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (252,'mailretard','3before_recouvrement','Sans nouvelles de votre part dans les sept jours, nous nous verrons contraints de déléguer au trésor public le recouvrement des ouvrages suivants :','Texte avant la liste des ouvrages en recouvrement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (253,'mailretard','priorite_email','1','Priorité des lettres de retard lors des relances :\n 0 : Lettre seule \n 1 : Mail, à défaut lettre\n 2 : Mail ET lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (254,'pmb','import_modele_lecteur','','Modèle d\'import des lecteurs','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (255,'pmb','blocage_retard','0','Bloquer le prêt d\'une durée équivalente au retard ? 0=non, 1=oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (256,'pmb','blocage_delai','7','Délai à partir duquel le retard est pris en compte pour le blocage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (257,'pmb','blocage_max','60','Nombre maximum de jours bloqués (0 = pas de limite)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (258,'pmb','blocage_coef','1','Coefficient de proportionnalité des jours de retard pour le blocage','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (259,'pmb','blocage_retard_force','1','1 = Le prêt peut-être forcé lors d\'un blocage du compte, 2 = Pas de forçage possible','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (260,'opac','etagere_order',' name ','Tri des étagères dans l\'écran d\'accueil, \n name = par nom\n name DESC = par nom décroissant','j_etagere',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (261,'pmb','book_pics_show','1','Affichage des couvertures de livres en gestion\r\n 1: oui  \r\n 0: non','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (262,'pmb','book_pics_url','http://images-eu.amazon.com/images/P/!!isbn!!.08.MZZZZZZZ.jpg','URL des vignettes des notices, dans le chemin fourni, !!isbn!! sera remplacé par le code ISBN ou EAN de la notice purgé de tous les tirets ou points. \r\n\r\nExemple : http://www.monsite/opac/images/vignettes/!!isbn!!.jpg\r\nVignettes Amazon : http://images-eu.amazon.com/images/P/!!isbn!!.08.MZZZZZZZ.jpg','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (263,'pmb','opac_url','./opac_css/','URL de l\'OPAC vu depuis la partie gestion, par défaut ./opac_css/','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (264,'opac','resa_popup','1','Demande de connexion sous forme de popup ? :\n 0 : Non\n 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (265,'pmb','vignette_x','100','Largeur de la vignette créée pour un exemplaire numérique image','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (266,'pmb','vignette_y','100','Hauteur de la vignette créée pour un exemplaire numérique image','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (267,'pmb','vignette_imagemagick','','Chemin de l\'exécutable ImageMagick (/usr/bin/imagemagick par exemple)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (268,'opac','show_rss_browser','0','Affichage des flux RSS du catalogue en page d\'accueil OPAC 1: oui  ou 0: non','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (269,'pmb','mail_methode','php','Méthode d\'envoi des mails : \n php : fonction mail() de php\n smtp,hote:port,auth,user,pass : en smtp, mettre O ou 1 pour l\'authentification...','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (270,'opac','mail_methode','php','Méthode d\'envoi des mails dans l\'opac : \n php : fonction mail() de php\n smtp,hote:port,auth,user,pass : en smtp, mettre O ou 1 pour l\'authentification...','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (271,'opac','search_show_typdoc','1','Affichage de la restriction par type de document pour les recherches en page d\'accueil','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (272,'pmb','verif_on_line','0','Dans le menu Administration > Outils > Maj Base : vérification d\'une version plus récente de PMB en ligne ? \r\n0 : non : si vous n\'êtes pas connecté à internet \r\n 1 : Oui : si vous avez une connexion à internet','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (273,'opac','show_languages','1 fr_FR,en_UK,es_ES,it_IT,de_DE','Afficher la liste déroulante de sélection de la langue ? \r\n 0 : Non \r\n 1 : Oui \r\nFaire suivre d\'un espace et des codes des langues possibles séparées par des virgules : fr_FR,it_IT,en_UK,nl_NL,oc_FR','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (274,'pmb','pdf_font','Helvetica','Police de caractères à chasse variable pour les éditions en pdf - Police Arial','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (275,'pmb','pdf_fontfixed','Courier','Police de caractères à chasse fixe pour les éditions en pdf - Police Courier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (276,'z3950','debug','0','Debugage (export fichier) des notices lues en Z3950 \r\n 0: Non \r\n 1: 0ui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (277,'pmb','nb_lastnotices','30','Nombre de dernières notices affichées en Catalogue - Dernières notices','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (278,'opac','show_dernieresnotices_nb','5','Nombre de dernières notices affichées en Catalogue - Dernières notices','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (279,'pmb','recouvrement_auto','0','Par défaut passage en recouvrement proposé en gestion des relances si niveau=3 et devrait être en 4: \r\n 1: Oui, recouvrement proposé par défaut \r\n 0: Ne rien faire par défaut','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (280,'pmb','keyword_sep',';','Séparateur des mots clés dans la partie indexation libre, espace ou ; ou , ou ...','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (281,'thesaurus','mode_pmb','0','Niveau d\'utilisation des thésaurus.\n 0 : Un seul thésaurus par défaut.\n 1 : Choix du thésaurus possible.','thesaurus',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (282,'thesaurus','defaut','1','Identifiant du thésaurus par défaut.','thesaurus',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (283,'thesaurus','liste_trad','fr_FR','Liste des langues affichées dans les thésaurus.\n(ex : fr_FR,en_UK,...,ar)','thesaurus',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (284,'opac','thesaurus','0','Niveau d\'utilisation des thésaurus.\n 0 : Un seul thésaurus par défaut.\n 1 : Choix du thésaurus possible.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (285,'acquisition','active','0','Module acquisitions activé.\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (286,'acquisition','gestion_tva','0','Gestion de la TVA.\r\n 0 : Non.\r\n 1 : Oui, avec saisie des prix HT.\r\n 2 : Oui, avec saisie des prix TTC.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (287,'acquisition','poids_sugg','U=1.00,E=0.70,V=0.00','Pondération des suggestions par défaut en pourcentage.\n U=Utilisateurs, E=Emprunteurs, V=Visiteurs.\n ex : U=1.00,E=0.70,V=0.00 \n','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (288,'acquisition','format','8,CA,DD,BL,FA','Taille du Numéro et Préfixes des actes d\'achats.\nex : 8,CA,DD,BL,FA \n8 = Préfixe + 8 Chiffres\nCA=Commande Achat, DD=Demande de Devis,BL=Bon de Livraison, FA=Facture Achat \n','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (289,'acquisition','budget','0','Utilisation d\'un budget pour les commandes.\n 0:optionnel\n 1:obligatoire','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (290,'acquisition','pdfcde_format_page','210x297','Largeur x Hauteur de la page en mm','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (291,'acquisition','pdfcde_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (292,'acquisition','pdfcde_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (293,'acquisition','pdfcde_pos_logo','10,10,20,20','Position du logo: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (294,'acquisition','pdfcde_pos_raison','35,10,100,10,16','Position Raison sociale: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (295,'acquisition','pdfcde_pos_date','150,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (296,'acquisition','pdfcde_pos_adr_fac','10,35,60,5,10','Position Adresse de facturation: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (297,'acquisition','pdfcde_pos_adr_liv','10,75,60,5,10','Position Adresse de livraison: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (298,'acquisition','pdfcde_pos_adr_fou','100,55,100,6,14','Position Adresse fournisseur: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (299,'acquisition','pdfcde_pos_num','10,110,0,10,16','Position numéro de commande: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (300,'acquisition','pdfcde_text_size','10','Taille de la police texte','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (301,'acquisition','pdfcde_text_before','','Texte avant le tableau de commande','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (302,'acquisition','pdfcde_text_after','','Texte après le tableau de commande','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (303,'acquisition','pdfcde_tab_cde','5,10','Table de commandes: Hauteur ligne,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (304,'acquisition','pdfcde_pos_tot','10,40,5,10','Position total de commande: Distance par rapport au bord gauche de la page, Largeur, Hauteur ligne,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (305,'acquisition','pdfcde_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (306,'acquisition','pdfcde_pos_sign','10,60,5,10','Position signature: Distance par rapport au bord gauche de la page, Largeur, Hauteur ligne,Taille police','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (307,'acquisition','pdfcde_text_sign','Le responsable de la bibliothèque.','Texte signature','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (308,'acquisition','pdfdev_format_page','210x297','Largeur x Hauteur de la page en mm','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (309,'acquisition','pdfdev_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (310,'acquisition','pdfdev_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (311,'acquisition','pdfdev_pos_logo','10,10,20,20','Position du logo: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (312,'acquisition','pdfdev_pos_raison','35,10,100,10,16','Position Raison sociale: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (313,'acquisition','pdfdev_pos_date','150,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (314,'acquisition','pdfdev_pos_adr_fac','10,35,60,5,10','Position Adresse de facturation: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (315,'acquisition','pdfdev_pos_adr_liv','10,75,60,5,10','Position Adresse de livraison: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (316,'acquisition','pdfdev_pos_adr_fou','100,55,100,6,14','Position Adresse fournisseur: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (317,'acquisition','pdfdev_pos_num','10,110,0,10,16','Position numéro de commande: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (318,'acquisition','pdfdev_text_size','10','Taille de la police texte','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (319,'acquisition','pdfdev_text_before','','Texte avant le tableau de commande','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (321,'acquisition','pdfdev_text_after','','Texte après le tableau de commande','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (322,'acquisition','pdfdev_tab_dev','5,10','Table de commandes: Hauteur ligne,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (323,'acquisition','pdfdev_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (324,'acquisition','pdfdev_pos_sign','10,60,5,10','Position signature: Distance par rapport au bord gauche de la page, Largeur, Hauteur ligne,Taille police','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (325,'acquisition','pdfdev_text_sign','Le responsable de la bibliothèque.','Texte signature','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (326,'opac','export_allow','1','Export de notices à partir de l\'opac : \n 0 : interdit \n 1 : pour tous \n 2 : pour les abonnés uniquement','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (327,'opac','resa_planning','0','Utiliser un planning de réservation ? \n 0: Non \n 1: Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (328,'opac','resa_contact','<a href=\'mailto:pmb@sigb.net\'>pmb@sigb.net</a>','Code HTML d\'information sur la personne à contacter par exemple en cas de problème de réservation.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (329,'opac','default_operator','0','Opérateur par défaut. 0 : OR, 1 : AND.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (330,'opac','modules_search_all','2','Recherche simple dans l\'ensemble des champs :\n 0 : interdite\n 1 : autorisée\n 2 : autorisée et validée par défaut\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (331,'acquisition','pdfliv_format_page','210x297','Largeur x Hauteur de la page en mm','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (332,'acquisition','pdfliv_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (333,'acquisition','pdfliv_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (334,'acquisition','pdfliv_pos_raison','10,10,100,10,16','Position Raison sociale: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (335,'acquisition','pdfliv_pos_adr_liv','10,20,60,5,10','Position Adresse de livraison: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (336,'acquisition','pdfliv_pos_adr_fou','110,20,100,5,10','Position éléments fournisseur: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (337,'acquisition','pdfliv_pos_num','10,60,0,6,14','Position numéro Commande/Livraison: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (338,'acquisition','pdfliv_tab_liv','5,10','Table de livraisons: Hauteur ligne,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (339,'acquisition','pdfliv_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (340,'pmb','default_operator','0','Opérateur par défaut. \n 0 : OR, \n 1 : AND.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (341,'mailretard','priorite_email_3','0','Faire le troisième niveau de relance par mail :\n 0 : Non, lettre \n 1 : Oui, par mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (342,'opac','show_suggest','2','Proposer de faire des suggestions dans l\'OPAC.\r\n 0 : Non.\r\n 1 : Oui, avec authentification.\r\n 2 : Oui, sans authentification.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (343,'acquisition','email_sugg','0','Information par email de l\'évolution des suggestions.\r\n 0 : Non\r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (344,'acquisition','pdfliv_text_size','10','Taille de la police texte','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (345,'acquisition','pdfliv_pos_date','170,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (346,'acquisition','pdffac_text_size','10','Taille de la police texte','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (347,'acquisition','pdffac_format_page','210x297','Largeur x Hauteur de la page en mm','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (348,'acquisition','pdffac_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (349,'acquisition','pdffac_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (350,'acquisition','pdffac_pos_raison','10,10,100,10,16','Position Raison sociale: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (351,'acquisition','pdffac_pos_date','170,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (352,'acquisition','pdffac_pos_adr_fac','10,20,60,5,10','Position Adresse de facturation: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (353,'acquisition','pdffac_pos_adr_fou','110,20,100,5,10','Position éléments fournisseur: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (354,'acquisition','pdffac_pos_num','10,60,0,6,14','Position numéro Commande/Facture: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (355,'acquisition','pdffac_tab_fac','5,10','Table de facturation: Hauteur ligne,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (356,'acquisition','pdffac_pos_tot','10,40,5,10','Position total de commande: Distance par rapport au bord gauche de la page, Largeur, Hauteur ligne,Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (357,'acquisition','pdffac_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (358,'acquisition','pdfsug_text_size','8','Taille de la police texte','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (359,'acquisition','pdfsug_format_page','210x297','Largeur x Hauteur de la page en mm','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (360,'acquisition','pdfsug_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (361,'acquisition','pdfsug_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (362,'acquisition','pdfsug_pos_titre','10,10,100,10,16','Position titre: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (363,'acquisition','pdfsug_pos_date','170,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (364,'acquisition','pdfsug_tab_sug','5,10','Table de suggestions: Hauteur ligne,Taille police','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (365,'acquisition','pdfsug_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (366,'acquisition','mel_rej_obj','Rejet suggestion','Objet du mail de rejet de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (367,'acquisition','mel_rej_cor','Votre suggestion du !!date!! est rejetée.\n\n','Corps du mail de rejet de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (368,'acquisition','mel_con_obj','Confirmation suggestion','Objet du mail de confirmation de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (369,'acquisition','mel_con_cor','Votre suggestion du !!date!! est retenue pour un prochain achat.\n\n','Corps du mail de confirmation de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (370,'acquisition','mel_aba_obj','Abandon suggestion','Objet du mail d\'abandon de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (371,'acquisition','mel_aba_cor','Votre suggestion du !!date!! n\'est pas retenue ou n\'est pas disponible à la vente.\n\n','Corps du mail d\'abandon de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (372,'acquisition','mel_cde_obj','Commande suggestion','Objet du mail de commande de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (373,'acquisition','mel_cde_cor','Votre suggestion du !!date!! est en commande.\n\n','Corps du mail de commande de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (374,'acquisition','mel_rec_obj','Réception suggestion','Objet du mail de réception de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (375,'acquisition','mel_rec_cor','Votre suggestion du !!date!! a été reçue et sera bientôt disponible en réservation.\n\n','Corps du mail de réception de suggestion','mel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (376,'opac','allow_tags_search','0','Recherche par tag (mots clés utilisateurs) \n 1 = oui \n 0 = non','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (377,'opac','allow_add_tag','0','Permettre aux utilisateurs d\'ajouter un tag à une notice.\n 0 : non\n 1 : oui\n 2 : identification obligatoire pour ajouter','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (378,'opac','avis_allow','1','Permet de consulter/ajouter un avis pour les notices \r\n 0 : non \r\n 1 : sans être identifié : consultation possible, ajout impossible \r\n 2 : identification obligatoire pour consulter et ajouter \r\n 3 : consultation et ajout anonymes possibles \r\n 3 : consultation et ajout anonymes possibles','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (379,'opac','avis_nb_max','30','Nombre maximal de commentaires conservés par notice. Les plus vieux sont effacés au profit des plus récents quand ce nombre est atteint.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (380,'pmb','show_rtl','0','Affichage possible de droite a gauche \r\n 0 non \r\n 1 oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (381,'opac','avis_show_writer','0','Afficher le rédacteur de l\'avis \n 0 : non \n 1 : Prénom NOM \n 2 : login OPAC uniquement','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (382,'pmb','form_editables','0','Grilles de notices éditables \n 0 non \n 1 oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (383,'acquisition','sugg_to_cde','0','Transfert des suggestions en commande.\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (384,'thesaurus','categories_categ_in_line','0','Affichage des catégories en ligne.\n 0 : Non.\n 1 : Oui.','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (385,'opac','categories_categ_in_line','0','Affichage des catégories en ligne.\r\n 0 : Non.\r\n 1 : Oui.','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (386,'pmb','label_construct_script','','Script de construction d\'étiquette de cote','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (387,'dsi','func_after_diff','','Script à exécuter après diffusion d\'une bannette','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (388,'opac','notice_groupe_fonction','','Quel fichier/fonction inclure pour la présentation des resultats si toutes les notices d\'une recherche sont parmi les types mentionnés \n exemple : a,b text;c,d music;k photo fera include(text.inc.php) et appel à la fonction text()','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (389,'opac','photo_mean_size_x','','Taille X de la photo format \'moyen\', si vide, pas de redimensionnement','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (390,'opac','photo_mean_size_y','','Taille Y de la photo format \'moyen\', si vide, pas de redimensionnement','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (391,'opac','photo_watermark','','Watermark à ajouter sur les photos, si vide, pas de watermark','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (392,'opac','photo_show_form','','Afficher le formulaire de commande de photo ? \n 0: Non \n 1:Oui','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (393,'opac','photo_email_form','','Emails des destinataires des commandes de photo à séparer par des espaces si multiples.','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (394,'opac','photo_watermark_transparency','50','Transparence du watermark de 0 à 100 en %','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (395,'opac','show_onglet_empr','0','Afficher l\'onglet de compte emprunteur avec les onglets de recherche ? \n 0: Non \n 1: Oui \n 2: n\'afficher l\'onglet empr que lorsque l\'utilisateur est authentifié (et dans ce cas le clic sur l\'onglet mène vers empr.php)','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (396,'pmb','url_base','http://SERVER/DIRECTORY/','URL de base de la gestion : typiquement mettre l\'url http://monserveur/pmb/ ne pas oublier le / final','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (397,'opac','show_empr','0','Afficher l\'emprunteur actuel dans la liste des exemplaires ?\n 0 : non\n 1 : pour les abonnés\n 2 : pour tout le monde','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (398,'opac','show_login_form_next','','Après connexion de l\'emprunteur se diriger vers quel module ? \n Vide = Compte emprunteur \n index.php = Retour en accueil','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (399,'opac','allow_term_troncat_search','0','Troncature automatique à droite \n 1 = oui \n 0 = non','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (400,'opac','show_results_first_page','1','Affichage de résultats sur la première page lors d\'une recherche pour tous les champs \r\n 0=non \r\n 1=oui.','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (401,'opac','nb_results_first_page','15','Nombres de notices à afficher lors d\'une recherche pour le critère Tous les champs.','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (402,'opac','show_infobulles_categ','0','Affichage des infobulles sur les libellés des catégories. \n 0=non \n 1=oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (403,'acquisition','sugg_display','','Nom de la fonction personnalisée d\'affichage des suggestions','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (404,'acquisition','sugg_categ','0','Affectation des suggestions à une catégorie de suggestions.\n 0 : Non\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (405,'acquisition','sugg_categ_default','1','Identifiant de la catégorie de suggestions par défaut.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (406,'opac','sugg_categ','0','Affectation des suggestions à une catégorie de suggestions.\n 0 : Non.\n 1 : Oui.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (407,'opac','sugg_categ_default','1','Identifiant de la catégorie de suggestions par défaut.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (408,'acquisition','pdfsug_print','','Quel script utiliser pour personnaliser l\'impression des listes de suggestions ?','pdfsug',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (409,'acquisition','pdfdev_print','','Quel script utiliser pour personnaliser l\'impression des devis ?','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (410,'acquisition','pdfcde_print','','Quel script utiliser pour personnaliser l\'impression des commandes ?','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (411,'acquisition','pdfliv_print','','Quel script utiliser pour personnaliser l\'impression des bons de livraison ?','pdfliv',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (412,'acquisition','pdffac_print','','Quel script utiliser pour personnaliser l\'impression des factures ?','pdffac',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (413,'pmb','notice_reduit_format','1','Format d\'affichage des réduits de notices :\n 0 = titre+auteur principal\n 1 = titre+auteur principal+date édition\n 2 = titre+auteur principal+date édition + ISBN\n 3 = titre seul\n P 1,2,3 = tit+aut+champs persos id 1 2 3\n E 1,2,3 = tit+aut+édit+champs persos id 1 2 3\n T = tit1+tit4\n 4 = titre+titre parallèle+auteur principal\n H 1 = id d\'un template de notice','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (414,'pmb','resa_planning','0','Utiliser un planning de réservation ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (415,'pmb','antivol','0','Système magnétique antivol à télécommander ? \n 1 Oui \n 0 Non','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (416,'acquisition','custom_calc_numero','','Fonction personnalisée de numérotation des actes d\'achats.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (417,'pmb','numero_exemplaire_auto','1','Autorise la numérotation automatique d\'exemplaire ? \r\n 0 : non\r\n 1 : Oui, pour monographies et bulletins\r\n 2 : Oui, pour monographies seules\r\n 3 : Oui, pour bulletins seuls','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (418,'pmb','numero_exemplaire_auto_script','gen_code/gen_code_exemplaire_ucac.php','Nom du fichier de Script php pour la génération des codes d\'exemplaires en automatique','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (419,'empr','lecteur_controle_doublons','0','Contrôle sur les doublons de lecteurs:\r\n0 : pas de controle sur les doublons, en saisie de fiche de lecteur. \r\n1,empr_nom,empr_prenom,... : recherche doublons sur les champs \'empr\', \r\n2,empr_nom,empr_prenom,... : recherche doublons sur les champs \'empr\', et champ personnalisables.\r\n3,empr_nom, empr_prenom ,... : idem, en rajoutant le test sur le groupe.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (420,'pmb','pret_nombre_prolongation','3','Nombre de prolongations autorisées','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (421,'pmb','pret_restriction_prolongation','2','0 : pas de restriction\r\n1 : prolongation limitée au paramètre pret_nombre_prolongation \r\n2 : prolongation gérée par les quotas ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (422,'opac','pret_prolongation','1','0 : pas de prolongation\r\n1 : prolongation autorisée','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (423,'mailretard','1after_list_group','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger les emprunts de votre groupe ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (424,'mailretard','1before_list_group','Sauf erreur de notre part, les emprunteurs de votre groupe ont toujours en leur possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (425,'mailretard','1fdp_group','L\'équipe de la bibliothèque','Signataire du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (426,'mailretard','1madame_monsieur_group','Bonjour,','Entête du mail','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (427,'mailretard','1objet_group','$biblio_name : documents en retard','Objet du mail de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (428,'pmb','first_week_day_format','0','Format de la semaine: \n 0, la semaine commence le lundi \n 1 la semaine commence le dimanche','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (429,'opac','export_allow_expl','0','Exporter les exemplaires avec les notices : \n 0 : Non \n 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (430,'opac','nb_max_tri','200','Nombre maximum de notices pour lesquelles le tri est autorisé.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (431,'pmb','nb_max_tri','200','Nombre maximum de notices pour lesquelles le tri est autorisé.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (432,'opac','pret_duree_prolongation','15','Nombre de jours de prolongation autorisé','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (433,'opac','surlignage','3','Surligner les mots recherchés :\r\n0 : pas de surlignage\r\n1 : surlignage obligatoire\r\n2 : surlignage activable\r\n3 : surlignage désactivable','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (434,'opac','nb_max_criteres_tri','3','Nombre maximum de critères de tri à afficher.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (435,'empr','show_caddie','1','Afficher le module de paniers de lecteurs: \r\n 0: Non \r\n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (436,'empr','pics_url','','URL des photos des emprunteurs, dans le chemin fourni, !!num_carte!! sera remplacé par le numéro de carte du lecteur. \n exemple : http://www.monsite/photos/lecteurs/!!num_carte!!.jpg','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (437,'empr','pics_max_size','100','Taille maximale des photos des emprunteurs, en largeur ou en hauteur','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (438,'thesaurus','classement_mode_pmb','0','Niveau d\'utilisation des plans de classement des indexations. \n 0 : Un seul plan de classement. \n 1 : Choix du plan de classement possible.','classement',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (439,'thesaurus','classement_defaut','1','Identifiant du plan de classement par défaut.','classement',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (440,'empr','electronic_loan_ticket','0','Envoyer un ticket de prêt électronique ? \n 0: Non, \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (441,'empr','electronic_loan_ticket_obj','!!biblio_name!! : emprunt(s) du !!date!!','Objet du mail de ticket électronique de prêt','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (442,'empr','electronic_loan_ticket_msg','Bonjour, <br />Voici la liste de vos emprunts et/ou réservations en date du !!date!! :<br /><br />!!all_loans!! !!all_reservations!!<br />Retrouvez toutes ces informations sur votre compte à l\'adresse <a href=!!biblio_website!!>!!biblio_website!!</a>.','Corps du mail de ticket électronique de prêt','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (443,'pmb','droits_explr_localises','0','Les droits de gestion des exemplaires sont-ils localisés ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (444,'empr','fiche_depliee','1','La fiche emprunteur sera automatiquement : \n 0 : pliée \n 1 : dépliée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (445,'empr','statut_adhes_depassee','2','id du statut pour lequel les emprunteurs dont la date d\'adhesion est dépassée n\'apparaissent pas en zone d\'alerte','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (446,'opac','authorized_styles','bueil,pmb34,pmb4','Styles de l\'OPAC autorisés, séparés par une virgule','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (447,'empr','relance_adhesion','0','Les relances d\'adhésion sont envoyées : \n 0 : exclusivement par lettre \n 1 : mail, à défaut par lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (448,'empr','show_rows','b,n,c,g,s,1','Colonnes affichées en liste de lecteurs, saisir les colonnes séparées par des virgules. Les colonnes disponibles pour l\'affichage de la liste des emprunteurs sont : \n n: nom+prénom \n a: adresse \n b: code-barre \n c: catégories \n g: groupes \n l: localisation \n s: statut \n cp: code postal \n v: ville \n y: année de naissance \n ab: type d\'abonnement \n #e[n] : [n] = id des champs personnalisés lecteurs \n 1: icône panier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (449,'empr','sort_rows','n,c,l,s','Colonnes qui seront disponibles pour le tri des emprunteurs. Les colonnes possibles sont : \n n: nom+prénom \n b: code-barres \n c: catégories \n g: groupes \n l: localisation \n s: statut \n cp: code postal \n v: ville \n y: année de naissance \n ab: type d\'abonnement \n #e[n] : [n] = id des champs personnalisés lecteurs \n #p[n] : [n] = id des champs personnalisés prêts','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (450,'empr','filter_rows','l,c,cs,s,g','Colonnes disponibles pour filtrer la liste des emprunteurs : \n v: ville\n l: localisation\n c: catégorie\n s: statut\n g: groupe\n y: année de naissance\n cp: code postal\n cs : code statistique\n ab : type d\'abonnement \n #e[n] : [n] = id des champs personnalisés lecteurs \n #p[n] : [n] = id des champs personnalisés prêts','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (451,'empr','header_format','','Champs personnalisés qui seront affichés dans l\'entête de la fiche emprunteur. Saisir les ids séparés par des virgules','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (452,'empr','archivage_prets','0','Archiver les prêts des emprunteurs ? \n 0: Non \n 1: Oui\nATTENTION pour la France: nous attirons votre attention sur l\'obligation de déclarer votre traitement à la CNIL (www.cnil.fr) si vous activez cette fonctionnalité.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (453,'empr','archivage_prets_purge','120','Nombre de jours maximum où doivent être conservées les archives nominatives de prêts : \r\n0: illimité \r\nN: N jours','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (454,'opac','autres_lectures','1','Afficher les emprunts des autres lecteurs du document courant ? \r\n 0: Non \r\n 1: Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (455,'opac','autres_lectures_tri','rand()','Tri des autres lectures proposées : \n rand(): aléatoire \n tit: par Titre','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (456,'opac','autres_lectures_nb_mini_emprunts','1','Nombre minimum d\'emprunts pour être comptabilisés \r\n 1: un seul emprunt suffit pour proposer la notice comme lecture associée \r\n N: N emprunts minimum nécessaires ','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (457,'opac','autres_lectures_nb_maxi','5','Nombre maximum de lectures associées proposées','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (458,'opac','autres_lectures_nb_jours_maxi','0','Délai en jours au delà duquel les emprunts ne sont pas comptabilisés, 0 pour illimité','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (459,'opac','empr_hist_nb_max','0','Nombre maximum de prêts précédents à afficher, 0 pour illimité','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (460,'opac','empr_hist_nb_jour_max','0','Délai en jours au delà duquel les prêts précédents ne sont pas affichés, 0 pour illimité','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (461,'opac','allow_tags_search_min_occ','1','Nombre mini d\'occurence d\'un tag pour être affiché, 1 pour tous','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (462,'pmb','etat_collections_localise','0','L\'état des collections est-il localisé ? \n 0 : non \n 1 : oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (463,'pmb','clean_nb_elements','100','Nombre d\'éléments traités par passe en nettoyage de base','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (464,'pmb','rfid_activate','0','Enregistrements des prêts par platine RFID ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (465,'opac','bull_results_per_page','12','Nombre de bulletins affichés par page dans l\'affichage d\'un périodique','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (466,'pmb','rfid_serveur_url','','URL du serveur de webservices RFID','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (467,'opac','authorized_information_pages','','Pages \"includable\" dans la page de l\'opac ./index.php?lvl=information&askedpage= : \r\n Mettre les noms des fichiers séparés par une virgule','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (468,'pmb','notice_controle_doublons','0','Contrôle sur les doublons en saisie de la notice \n 0: Pas de contrôle sur les doublons, \n 1,tit1,tit2, ... : Recherche par méthode _exacte_ de doublons sur des champs, défini dans le fichier notice.xml  \n 2,tit1,tit2, ... : Recherche par _similitude_ ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (469,'opac','title_ponderation','0.5','Majoration de la pondération des mots du titre \n   mettre 0 (zero) pour interdire la majoration \n ATTENTION utiliser le point décimal ','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (470,'pmb','title_ponderation','0.5','Majoration de la pondération des mots du titre \n   mettre 0 (zero) pour interdire la majoration \n ATTENTION utiliser le point décimal ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (471,'pmb','param_etiq_codes_barres','','Paramètres de sauvegarde des paramètres d\'édition d\'étiquettes codes-barres','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (472,'pmb','javascript_office_editor','','Code HTML à insérer pour remplacer les textarea par un éditeur Office javascript','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (473,'opac','biblio_post_adress','','Bloc d\'information après le bloc adresse, dans la feuille de style, voir id post_adress\r\n\r\n<!--<ul id=\"menuDeroulant\">\r\n<li>\r\n<a href=\"./index.php?search_type_asked=simple_search\"><font size=2>Recherche avancée</font></a>\r\n</li>\r\n</ul>-->','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (474,'opac','allow_external_search','1','Autorisation ou non de la recherche par connecteurs externes dans l\'OPAC \r\n 0 : Non \r\n 1 : Oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (475,'pmb','nb_noti_calc_empty_words','50','Un mot sera considéré comme vide s\'il apparaît dans un nombre de notices minimum. Saisir le pourcentage par rapport au nombre de notices total.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (476,'opac','fonction_affichage_liste_bull','affichage_liste_bulletins_tableau','Fonction d\'affichage de la liste des bulletins d\'un périodique\nValeurs possibles:\naffichage_liste_bulletins_normale (Si paramètre vide)\naffichage_liste_bulletins_tableau\naffichage_liste_bulletins_depliable','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (479,'dsi','bannette_notices_order','index_serie, tnvol, index_sew','Ordre des notices au sein de la bannette: \r\n index_serie, tnvol, index_sew : par titre \r\n create_date desc : par date de saisie décroissante \r\n rand() : aléatoire','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (480,'opac','websubscribe_show','0','Afficher la possibilité de s\'inscrire en ligne ?\n0: Non\n1: Oui\n2: Oui + proposition s\'incription sur les réservations/abonnements','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (481,'opac','websubscribe_empr_status','2,1','Id des statuts des inscrits séparés par une virgule: en attente de validation, validés','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (482,'opac','websubscribe_empr_categ','0','Id de la catégorie des inscrits par le web non adhérents complets','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (483,'opac','websubscribe_empr_stat','0','Id du code statistique des inscrits par le web non adhérents complets','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (484,'opac','websubscribe_valid_limit','24','Durée maximum des inscriptions en attente de validation','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (485,'pmb','mail_html_format','1','Format d\'envoi des mails à partir de l\'opac: \n 0: Texte brut\n 1: HTML \n 2: HTML, images incluses\nAttention, ne fonctionne qu\'en mode d\'envoi smtp !','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (486,'opac','mail_html_format','1','Format d\'envoi des mails à partir de l\'opac: \n 0: Texte brut\n 1: HTML \n 2: HTML, images incluses\nAttention, ne fonctionne qu\'en mode d\'envoi smtp !','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (487,'opac','websubscribe_empr_location','0','Id de la localisation des inscrits par le web non adhérents complets','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (488,'opac','allow_bannette_export','0','Possibilité pour les lecteurs de recevoir les notices de leurs bannettes privées en pièce jointe au mail ?\n 0: Non \n 1: Oui','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (489,'opac','expl_data','expl_cb,expl_cote,tdoc_libelle,location_libelle,section_libelle','Colonne des exemplaires, dans l\'ordre donné, séparé par des virgules : expl_cb,expl_cote,tdoc_libelle,location_libelle,section_libelle','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (490,'opac','expl_order','location_libelle,section_libelle,expl_cote,tdoc_libelle','Ordre d\'affichage des exemplaires, dans l\'ordre donné, séparé par des virgules : location_libelle,section_libelle,expl_cote,tdoc_libelle','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (491,'opac','curl_available','1','La librairie cURL est-elle disponible pour les interrogations RSS notamment ? \n 0: Non \n 1: Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (492,'pmb','curl_available','1','La librairie cURL est-elle disponible pour les interrogations RSS notamment ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (493,'opac','thesaurus_defaut','1','Identifiant du thésaurus par défaut.','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (494,'opac','recherches_pliables','0','Les cases à cocher de la recherche simple sont-elles pliées ? \r\n 0: Non \r\n 1: Oui et pliée par défaut \r\n 2: Oui et dépliée par défaut \r\n 3: invisibles','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (495,'pmb','rfid_ip_port','192.168.0.10,SerialPort=10;','Association ip du poste de prêt et Numéro du port utilisé par le serveur RFID. Ex: 192.168.0.10,SerialPort=10; IpPosteClient,SerialPort=NumPortPlatine; séparé par des points-virgules pour désigner tous les postes','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (496,'pmb','pret_timeout_temp','15','Temps en minutes, après lequel un prêt temporaire est effacé','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (497,'opac','permalink','1','Afficher l\'Id de la notice avec un lien permanent ? \r\n 0: Non \r\n 1: Oui','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (498,'pdflettreretard','3after_recouvrement','Sans nouvelles de votre part dans les sept jours, nous nous verrons contraints de déléguer au Trésor Public le recouvrement des ouvrages ci-dessus.','Texte apparaissant après la liste des ouvrages en recouvrement s\'il n\'y a pas d\'autres ouvrages en niveau 1 et 2','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (499,'pdflettreretard','impression_tri','empr_cp,empr_ville,empr_nom,empr_prenom','Tri pour l\'impression des lettres de relances ? Les champs sont ceux de la table empr séparés par des virgules. Exemple: empr_nom, empr_prenom','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (500,'pmb','pret_date_retour_adhesion_depassee','0','La date de retour peut-elle dépasser la date de fin d\'adhésion ? \n 0: Non: la date de retour sera calculée pour ne pas dépasser la date de fin d\'adhésion. \n 1: Oui, la date de retour du prêt sera indépendante de date de fin d\'adhésion.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (501,'opac','extended_search_auto','1','En recherche multicritères, la sélection d\'un champ ajoute celui-ci automatiquement sans avoir besoin de cliquer sur le bouton Ajouter ? \n 0: Non \n 1: Oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (502,'pmb','extended_search_auto','1','En recherche multicritères, la sélection d\'un champ ajoute celui-ci automatiquement sans avoir besoin de cliquer sur le bouton Ajouter ? \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (503,'thesaurus','categories_affichage_ordre','0','Paramétrage de l\'ordre d\'affichage des catégories d\'une notice.\nPar ordre alphabétique: 0(par défaut)\nPar ordre de saisie: 1','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (504,'opac','categories_affichage_ordre','0','Paramétrage de l\'ordre d\'affichage des catégories d\'une notice.\nPar ordre alphabétique: 0(par défaut)\nPar ordre de saisie: 1','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (505,'pmb','rfid_driver','','Driver du pilote RFID : le nom du répertoire contenant les javascripts propre au matériel en place.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (506,'pmb','allow_external_search','1','Autorisation ou non de la recherche par connecteurs externes (masque également le menu Administration-Connecteurs) \r\n 0 : Non \r\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (507,'pmb','scan_pmbws_client_url','','URL de l\'interface de numérisation (client du webservice)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (508,'pmb','scan_pmbws_url','','URL du webservice de pilotage du scanner','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (509,'opac','biblio_main_header','<link href=\'http://fonts.googleapis.com/css?family=Dosis:400,500\' rel=\'stylesheet\' type=\'text/css\'>','Texte pouvant apparaitre dans le bloc principal, au dessus de tous les autres, nécessaire pour certaines mises en page particulières.','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (510,'opac','sugg_localises','0','Activer la localisation des suggestions des lecteurs ? \n 0: Pas de localisation possible.\n 1: Localisation au choix du lecteur.\n 2: Localisation restreinte à la localisation du lecteur.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (511,'acquisition','sugg_localises','0','Activer la localisation des suggestions ? \n 0: Pas de localisation possible. \n 1: Localisation activée.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (512,'opac','categories_nav_max_display','200','Limiter l\'affichage des catégories en navigation dans les sous-catégories. 0: Pas de limitation. >0: Nombre max de catégories à afficher','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (513,'pmb','pret_aff_limitation','0','Activer la limitation de l\'affichage de la liste des prêts dans la fiche lecteur ? \n 0: Inactif. \n 1: Limitation activée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (514,'pmb','pret_aff_nombre','10','Nombre de prêts à afficher si le paramètre pret_aff_limitation est actif. \n 0: tout voir, illimité. \n ## Nombre de prêts à afficher sur la première page','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (515,'pmb','printer_ticket_url','','Permet d\'utiliser une imprimante de ticket, connectée en local sur le poste de prêt client. Vide : pas d\'imprimante. Url (http://localhost/printer/bixolon_srp350.php ) : imprimante active.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (516,'pmb','transferts_actif','0','Active le systeme de transferts d\'exemplaires entre sites\n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (517,'transferts','statut_validation','0','id du statut dans lequel seront placés les documents dont le transfert est validé','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (518,'transferts','statut_transferts','0','id du statut dans lequel seront placés les documents en cours de transit','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (519,'transferts','validation_actif','1','Active la validation des transferts\n 0: Non \n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (520,'transferts','nb_jours_pret_defaut','30','Nombre de jours de pret par defaut','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (521,'transferts','nb_jours_alerte','7','Nombre de jours avant la fin du pret ou l\'alerte s\'affiche','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (522,'transferts','transfert_transfere_actif','0','Autorise le transfert d\'exemplaire deja transferer','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (523,'transferts','tableau_nb_lignes','10','Nombre de transferts affichés dans les tableaux','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (524,'transferts','envoi_lot','0','traitement par lot possible en envoi','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (525,'transferts','reception_lot','0','traitement par lot possible en reception','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (526,'transferts','retour_lot','0','traitement par lot possible en retour','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (527,'transferts','retour_origine','0','Force le retour de l\'exemplaire dans son lieu d\'origine\n 0: Non \n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (528,'transferts','retour_origine_force','1','Permet de forcer le retour de l\'exemplaire\n 0: Non \n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (529,'transferts','retour_action_defaut','1','Action par defaut lors du retour d\'un emprunt\n 0: change localisation \n 1: genere transfert','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (530,'transferts','retour_action_autorise_autre','1','Autorise une autre action lors du retour de l\'exemplaire\n 0: Non\n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (531,'transferts','retour_change_localisation','1','Sauvegarde de la localisation lors du changement\n 0: Non \n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (532,'transferts','retour_etat_transfert','1','Etat du transfert lors de sa generation auto\n 0: creer \n 1: envoyer','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (533,'transferts','retour_motif_transfert','Transfert suite au retour de l\'exemplaire sur notre site','Motif du transfert lors de sa generation auto','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (534,'transferts','choix_lieu_opac','0','0 pour pas de choix et obligatoirement dans la localisation ou est enregistré l\'utilisateur, 1 pour n\'importe quelle localisation au choix, 2 pour un lieu fixe précisé, 3 pour le lieu de l\'exemplaire','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (535,'transferts','site_fixe','1','id du site pour le retrait des livres si choix_lieu_opac=2','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (536,'transferts','resa_motif_transfert','Transfert suite à une réservation','Motif du transfert lors de sa generation auto pour une réservation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (537,'transferts','resa_etat_transfert','1','Etat du transfert lors de sa generation auto\n 0: creer \n 1: envoyer','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (538,'pmb','recherche_ajax_mode','1','Affichage accéléré des résultats de recherche: \"réduit\" uniquement, la suite est chargée lors du click sur le \"+\". \n 0: Inactif \n 1: Actif','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (539,'pmb','expl_title_display_format','expl_location,expl_section,expl_cote,expl_cb','Format d\'affichage du titre de l\'exemplaire en recherche multi-critères d\'exemplaires. Les libellés des champs correspondent aux champs de la table exemplaires, ou aux id de champs personnalisés. Séparés par une virgule. Les champs disposant d\'un libellé seront remplacés par le libellé correspondant. Exemple: expl_location,expl_section,expl_cote,expl_cb','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (540,'opac','empr_code_info','','Code HTML affiché au dessus des boutons dans la fiche emprunteur.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (541,'opac','term_search_height_bottom','120','Hauteur de la partie supérieure de la frame de recherche par termes (en px)','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (542,'pmb','rfid_library_code','','Code numérique d\'identification de la bibliothèque propriétaire des exemplaires (10 caractères)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (543,'opac','show_infopages_id','','Id des infopages à afficher sous la recherche simple, séparées par des virgules.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (544,'thesaurus','auto_postage_montant','0','Activer la recherche des notices des catégories mères ? \n  0 non, \n 1 oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (545,'thesaurus','auto_postage_descendant','0','Activer la recherche des notices des catégories filles. \n 0 non, \n 1 oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (546,'thesaurus','auto_postage_nb_descendant','0','Nombre de niveaux de recherche de notices dans les catégories filles. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (547,'thesaurus','auto_postage_nb_montant','0','Nombre de niveaux de recherche de notices dans les catégories mères. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (548,'thesaurus','auto_postage_etendre_recherche','0','Proposer la possibilité d\'étendre la recherche dans les catégories mères ou filles. \n 0: non, \n 1: Exclusivement dans les catégories filles, \n 2: Etendre dans les catégories mères et filles, \n 3: Exclusivement dans les catégories mères. ','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (549,'opac','auto_postage_montant','0','Activer la recherche des notices des catégories mères. \n 0 non, \n 1 oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (550,'opac','auto_postage_descendant','0','Activer la recherche des notices des catégories filles. \n 0 non, \n 1 oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (551,'opac','auto_postage_nb_descendant','0','Nombre de niveaux de recherche de notices dans les catégories filles. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (552,'opac','auto_postage_nb_montant','0','Nombre de niveaux de recherche de notices dans les catégories mères. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (553,'opac','auto_postage_etendre_recherche','0','Proposer la possibilité d\'étendre la recherche dans les catégories mères ou filles. \n 0: non, \n 1: Exclusivement dans les catégories filles, \n 2: Etendre dans les catégories mères et filles, \n 3: Exclusivement dans les catégories mères. ','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (554,'gestion_acces','active','0','Module gestion des droits d\'accès activé ?\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (555,'gestion_acces','user_notice','0','Gestion des droits d\'accès des utilisateurs aux notices \r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (556,'pmb','abt_end_delay','30','Délais d\'alerte d\'avertissement des abonnements arrivant à échéance (en jours)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (557,'pmb','set_time_limit','1200','max_execution_time de certaines opérations (export d\'actions personnalisées, envoi DSI, export, etc.) \nAttention, peut être sans effet si l\'hébergement ne l\'autorise pas (free.fr par exemple)\n 0 : illimité (déconseillé) \n ###: ### secondes','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (558,'pmb','expl_list_display_comments','3','Afficher les commentaires des exemplaires en liste d\'exemplaires : \r\n 0 : non \r\n 1 : commentaire bloquant \r\n 2 : commentaire non bloquant \r\n 3 : les deux commentaires','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (559,'pmb','confirm_delete_from_caddie','2','Action à réaliser lors de la suppression d\'une notice située dans un panier. \r\n0 : Interdire \r\n1 : Supprimer sans confirmation \r\n2 : Demander une confirmation de suppression ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (560,'opac','flux_rss_notices_order','index_serie, tnvol, index_sew ','Ordre d\'affichage des notices dans les flux sortants dans l\'opac \r\n  index_serie, tnvol, index_sew : tri par titre de série et titre \r\n rand()  : aléatoire \r\n notice_id desc par ordre décroissant de création de notice','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (561,'opac','modules_search_titre_uniforme','0','Recherche simple dans les titres uniformes :\r\n 0 : interdite\r\n 1 : autorisée\r\n 2 : autorisée et validée par défaut\r\n -1 : également interdite en recherche multi-critères','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (562,'opac','congres_affichage_mode','0','Mode d\'affichage des congrès: \n 0 : Comme pour les auteurs, \n 1 : ajout d\'un navigateur de congrès','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (563,'opac','show_suggest_notice','0','Afficher le lien de proposition de suggestion sur une notice existante.\n 0 : Non.\n 1 : Oui, avec authentification.\n 2 : Oui, sans authentification.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (564,'pmb','explnum_statut','0','Utiliser un statut sur les documents numériques \n 0: non \n 1: oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (565,'opac','show_empty_items_block','1','Afficher le bloc exemplaires même si aucun exemplaire sur la notice ? : \n 0 : Non, \n 1 : Oui','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (566,'pmb','printer_ticket_script','','Script permettant de personaliser l\'impression du ticket de prêt. Le répertoire du script est à paramétrer à partir de la racine de PMB.\nSi vide PMB utilise ./circ/ticket-pret.inc.php','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (567,'opac','curl_proxy','','Paramétrage de proxy de cURL, vide si aucun proxy, sinon\nhost,port,user,password;2nd_host et ainsi de suite','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (568,'pmb','curl_proxy','','Paramétrage de proxy de cURL, vide si aucun proxy, sinon\nhost,port,user,password;2nd_host et ainsi de suite','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (569,'pmb','latest_order','notice_id desc','Tri des dernières notices ? \n notice_id desc : par id de notice décroissant: idéal mais peut être problématique après une migration ou un import \n create_date desc: par la colonne date de création.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (570,'opac','password_forgotten_show','1','Afficher le lien  \"Mot de passe oublié ?\" \n 0: Non \n 1: Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (571,'opac','aff_expl_localises','0','Activer l\'affichage des exemplaires localisés par onglet.\n 0 : désactivé \n 1: premier onglet affiche les exemplaires de la localisation du lecteur, le deuxieme affiche tous les exemplaires','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (572,'gestion_acces','empr_notice','0','Gestion des droits d\'accès des emprunteurs aux notices \r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (573,'opac','show_infopages_id_top','','Id des infopages à afficher SUR la recherche simple, séparées par des virgules.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (574,'opac','show_search_title','0','Afficher le titre du bloc de recherche : \n 0 : Non, \n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (575,'opac','allow_personal_search','0','Activer l\'affichage de l\'onglet des recherches personalisées \n 0 : Non.\n 1 : Oui.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (576,'ldap','opac_only','0','Ne pas utiliser l\'authentification LDAP en gestion: \n 0: Non \n 1 : Oui, en OPAC uniquement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (577,'pmb','multi_search_operator','or','Type d\'opérateur de recherche pour les listes avec plusieurs valeurs: \n or : pour le OU \n and : pour le ET','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (578,'opac','multi_search_operator','or','Type d\'opérateur de recherche pour les listes avec plusieurs valeurs: \n or : pour le OU \n and : pour le ET','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (579,'transferts','pret_statut_transfert','0','Autoriser le prêt lorsque l\'exemplaire est en transfert','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (580,'exportparam','generer_liens','0','Générer les liens entre les notices pour l\'export','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (581,'exportparam','export_mere','0','Exporter les notices liées mères','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (582,'exportparam','export_fille','0','Exporter les notices liées filles','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (583,'exportparam','export_bull_link','1','Exporter les liens vers les bulletins pour les notices d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (584,'exportparam','export_perio_link','1','Exporter les liens vers les périodiques pour les notices d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (585,'exportparam','export_art_link','1','Exporter les liens vers les articles pour les notices de périodique','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (586,'exportparam','export_bulletinage','0','Générer le bulletinage pour les notices de périodiques','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (587,'exportparam','export_notice_perio_link','0','Exporter les notices liées de périodique','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (588,'exportparam','export_notice_art_link','0','Exporter les notices liées d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (589,'exportparam','export_notice_mere_link','0','Exporter les notices mères liées','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (590,'exportparam','export_notice_fille_link','0','Exporter les notices filles liées','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (591,'opac','exp_generer_liens','0','Générer les liens entre les notices pour l\'export','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (592,'opac','exp_export_mere','0','Exporter les notices liées mères','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (593,'opac','exp_export_fille','0','Exporter les notices liées filles','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (594,'opac','exp_export_bull_link','1','Exporter les liens vers les bulletins pour les notices d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (595,'opac','exp_export_perio_link','1','Exporter les liens vers les périodiques pour les notices d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (596,'opac','exp_export_art_link','1','Exporter les liens vers les articles pour les notices de périodique','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (597,'opac','exp_export_bulletinage','0','Générer le bulletinage pour les notices de périodiques','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (598,'opac','exp_export_notice_perio_link','0','Exporter les notices liées de périodique','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (599,'opac','exp_export_notice_art_link','0','Exporter les notices liées d\'article','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (600,'opac','exp_export_notice_mere_link','0','Exporter les notices mères liées','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (601,'opac','exp_export_notice_fille_link','0','Exporter les notices filles liées','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (602,'pmb','perio_vidage_log','1','Périodicité de transfert des données depuis la table temporaire des logs vers la table de stockage  (en jours).','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (603,'pmb','perio_vidage_stat','2,30','Périodicité de vidage de la table de stockage (mode,jour) : \r\n0 : ne rien faire\r\n1,x : vider tous les x jours\r\n2,x : vider tous ce qui à plus de x jours','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (604,'pmb','logs_activate','0','Activer les statistiques pour l\'OPAC: \n 0 : non activé \n 1 : activé','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (605,'opac','shared_lists','1','Activer les listes de lecture partagées \r\n 0 : non activées \r\n 1 : activées','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (606,'pmb','indexation_docnum','1','Activer l\'indexation des documents numériques \r\n 0 : non activée \r\n 1 : activée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (607,'pmb','indexation_docnum_allfields','0','Activer par défaut la recherche dans les documents numériques pour la recherche \"Tous les champs\" \n 0 : non activée \n 1 : activée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (608,'opac','indexation_docnum_allfields','0','Activer par défaut la recherche dans les documents numériques pour la recherche \"Tous les champs\" \n 0 : non activée \n 1 : activée','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (609,'opac','modules_search_docnum','1','Recherche simple dans les documents numériques \r\n 0 : interdite \r\n 1 : autorisée \r\n 2 : autorisée et validée par défault','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (610,'pmb','location_reservation','0','Utiliser la gestion de la réservation localisée?\n 0: Non\n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (611,'pmb','extension_tab','0','Afficher l\'onglet Extension ? \n 0 : Non \n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (612,'pmb','indexation_docnum_default','0','Indexer le document numérique par défaut ? \n 0 : Non \n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (613,'opac','shared_lists_readonly','1','Listes de lecture partagées en lecture seule \r\n 0 : non activées \r\n 1 : activées','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (614,'opac','connexion_phrase','','Phrase permettant l\'encodage de la connexion automatique à partir d\'un mail','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (615,'pmb','afficher_numero_lecteur_lettres','0','Afficher le numéro et le mail du lecteur sous l\'adresse dans les différentes lettres','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (616,'pmb','lettres_bloc_adresse_position_absolue','0 100 40','Place le bloc d\'adresse selon des coordonnées absolues.\nactivé x y\nactivé : activer cette fonction (valeurs: 0/1)\nx : Position horizontale\ny : Position verticale','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (617,'pmb','external_service_search_cache','3600','Durée de vie des recherches dans le cache, pour les services externes, en secondes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (618,'pmb','external_service_session_duration','600','Durée de vie des sessions pour les services externes, en secondes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (619,'opac','allow_multiple_sugg','0','Autoriser les suggestions multiples.\r\n0: non\r\n1: oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (620,'dsi','bannette_notices_template','0','Id du template de notice utilisé par défaut en diffusion de bannettes. Si vide ou à 0, le template classique est utilisé.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (621,'demandes','active','0','Module demandes activé.\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (622,'demandes','statut_notice','0','Id du statut de notice pour la notice de demandes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (623,'opac','demandes_active','0','Activer les demandes pour l\'OPAC.\n 0 : Non.\n 1 : Oui.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (624,'pmb','use_uniform_title','1','Utiliser les titres uniformes ? \r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (625,'opac','print_expl_default','0','En impression de panier, imprimer les exemplaires est coché par défaut \n 0 : Non \n 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (626,'demandes','include_note','0','Inclure automatiquement les notes dans le rapport documentaire.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (627,'opac','ie_reload_on_resize','0','Recharger la page si l\'utilisateur redimensionne son navigateur (pb de CSS avec IE) ? \n 0: Non \n 1: Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (628,'pmb','expl_show_dates','1','Afficher les dates des exemplaires ? \r\n 0 : Aucune date.\r\n 1 : Date de création et modification.\r\n 2 : Date de dépôt et retour (BDP).\r\n 3 : Date de création, modification, dépôt et retour.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (629,'gestion_acces','user_notice_def','0','Valeur par défaut en modification de notice pour les droits d\'accès utilisateurs - notices \n 0 : Recalculer.\n 1 : Choisir.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (630,'gestion_acces','empr_notice_def','0','Valeur par défaut en modification de notice pour les droits d\'accès emprunteurs - notices \n 0 : Recalculer.\n 1 : Choisir.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (631,'opac','show_exemplaires_analysis','1','Afficher les exemplaires du bulletin sous l\'article affiché ? \r\n 0: Non \r\n 1: Oui','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (632,'pmb','show_notice_id','1','Afficher l\'identifiant de la notice dans le descriptif ? \r\n 0 : Non.\r\n 1 : Oui. \r\n 1,X : Oui avec préfixe X','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (633,'opac','section_notices_order',' index_serie, tnvol, index_sew ','Ordre d\'affichage des notices dans les sections dans l\'opac \n  index_serie, tnvol, index_sew : tri par titre de série et titre ','k_section',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (634,'opac','show_onglet_help','0','Afficher l\'onglet HELP avec les onglets de recherche affichant l\'infopage et un lien vers l\'infopage dans la barre de navigation \n 0 : Non.\n ## : id de l\'infopage. \n','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (635,'opac','navig_empr','0','Afficher l\'onglet \"Votre compte\" dans la barre de navigation de l\'Opac ? \n 0 : Non \n 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (637,'pmb','prefill_cote_ajax','','Script personnalisé de construction de la cote de l\'exemplaire en ajax','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (638,'pmb','hide_biblioinfo_letter','0','Masquer les informations de localisation dans l\'entête des lettres (pour les bibliothèques possédant du papier à entête)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (639,'pmb','lettres_code_mail_position_absolue','0 100 6','Placer le code lecteur et le mail selon des coordonnées absolues.\n activé x y \n activé : activer cette fonction (valeurs: 0/1) \n x : Position horizontale \n y : Position verticale','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (640,'opac','adhesion_expired_status','0','Id du statut permettant de restreindre les droits des emprunteurs dont l\'abonnement est dépassé. \n\rPMB fera un AND logique avec les droits d\'origine.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (641,'pmb','resa_retour_action_defaut','0','Définit l\'action par défaut à effectuer lors d\'un retour si le document est réservé.\n0, A traiter plus tard.\n1, Valider la réservation.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (642,'pmb','notice_fille_format','0','Affichage des notices filles \n 0: avec leurs détails (notice dépliable avec un plus) \n 1: Juste l\'entête','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (643,'pmb','hide_retdoc_loc_error','0','Gestion du retour de prêt d\'un document issu d\'une autre localisation:\n 0 : Rendu, sans message d\'erreur\n 1 : Non rendu, avec message d\'erreur\n 2 : Rendu, avec message d\'erreur','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (644,'pmb','selfservice_allow','0','Activer de la gestion de la borne de prêt?\n0 : Non. \n1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (645,'selfservice','loc_autre_todo','0','Action à effectuer si le document est issu d\'une autre localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (646,'selfservice','loc_autre_todo_msg','','Message si le document est réservé sur une autre localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (647,'selfservice','resa_ici_todo','0','Action à effectuer si le document est réservé sur cette localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (648,'selfservice','resa_ici_todo_msg','','Message si le document est réservé sur cette localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (649,'selfservice','resa_loc_todo','0','Action à effectuer si le document est réservé sur une autre localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (650,'selfservice','resa_loc_todo_msg','','Message si le document est réservé sur une autre localisation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (651,'selfservice','retour_retard_msg','','Message si le document est rendu en retard','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (652,'selfservice','retour_blocage_msg','','Message si le document est rendu en retard avec blocage','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (653,'selfservice','retour_amende_msg','','Message si le document est rendu en retard avec amende','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (654,'selfservice','pret_carte_invalide_msg','Votre carte n\'est pas valide !','Message borne de prêt: Votre carte n\'est pas valide !','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (655,'selfservice','pret_pret_interdit_msg','Vous n\'êtes pas autorisé à emprunter !','Message borne de prêt: Vous n\'êtes pas autorisé à emprunter !','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (656,'selfservice','pret_deja_prete_msg','Document déjà prêté ! allez le signaler !','Message borne de prêt: Document déjà prêté ! allez le signaler !','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (657,'selfservice','pret_deja_reserve_msg','Vous ne pouvez pas emprunter ce document','Message borne de prêt: Vous ne pouvez pas emprunter ce document','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (658,'selfservice','pret_quota_bloc_msg','Vous ne pouvez pas emprunter ce document','Message borne de prêt: Vous ne pouvez pas emprunter ce document','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (659,'selfservice','pret_non_pretable_msg','Ce document n\'est pas prêtable','Message borne de prêt: Ce document n\'est pas prêtable','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (660,'selfservice','pret_expl_inconnu_msg','Ce document est inconnu','Message borne de prêt: Ce document est inconnu','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (661,'selfservice','pret_prolonge_non_msg','Le prêt ne peut être prolongé','Message borne de prêt: Le prêt ne peut être prolongé','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (663,'opac','photo_filtre_mimetype','\'application/pdf\',\'image/png\',\'image/x-png\',\'image/jpg\',\'image/jpeg\',\'application/msword\',\'application/vnd.ms-excel\',\'application/ms-excel\',\'application/x-msexcel\',\'application/vnd.ms-powerpoint\',\'application/ms-powerpoint\',\'application/mspowerpoint\',\'application/openoffice\',\'URL\',\'application/epub+zip\'','Liste des mimetypes utilisés pour l\'affichage des résultats en mode photothèque séparés par une virgule et entre cotes (ex:\'application/pdf\',\'image/png\')','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (664,'empr','sms_activation','0,0,0,0','Activation de l\'envoi de sms. : relance 1,relance 2,relance 3,resa\n\n 0: Inactif\n 1: Actif','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (665,'empr','sms_config','','Paramétrage de l\'envoi de sms. \nUsage:\n class_name=nom_de_la_classe;param_connection;\nExemple:\n class_name=smstrend;login=xxxx@sigb.net;password=xxxx;tpoa=xxxx;','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (666,'empr','sms_msg_resa_dispo','Bonjour,\nUn document réservé est disponible.\nConsultez votre compte!','Texte du sms envoyé lors de la validation d\'une réservation','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (667,'empr','sms_msg_resa_suppr','Bonjour,\nUne réservation est supprimée.\nConsultez votre compte!','Texte du sms envoyé lors de la suppression d\'une réservation','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (668,'empr','sms_msg_retard','Bonjour,\nVous avez un ou plusieurs document(s) en retard.\nConsultez votre compte!','Texte du sms envoyé lors d\'un retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (669,'pmb','procedure_server_address','','Adresse du serveur de procédures distantes.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (670,'pmb','procedure_server_credentials','','Authentification sur le serveur de procédures distantes.\n1ère ligne: email\n2ème ligne: mot de passe.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (671,'pmb','rfid_pret_mode','0','Mode de fonctionnement du prêt:\n 0: Un document retiré de la platine est retiré du prêt.\n 1: Un document retiré de la platine est conservé pour faciliter le prêt de nombreux documents. ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (672,'internal','emptylogstatopac','0','Paramètre interne, ne pas modifier\r\n =1 si vidage des logs en cours','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (673,'fiches','active','0','Module \'fiches\' activé.\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (674,'opac','visionneuse_allow','1','Visionneuse activée.\r\n 0 : Non.\r\n 1 : Oui.','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (675,'opac','visionneuse_params','a:16:{s:15:&quot;application/pdf&quot;;s:7:&quot;flexpdf&quot;;s:18:&quot;application/msword&quot;;s:7:&quot;flexpdf&quot;;s:24:&quot;application/vnd.ms-excel&quot;;s:7:&quot;flexpdf&quot;;s:20:&quot;application/ms-excel&quot;;s:7:&quot;flexpdf&quot;;s:21:&quot;application/x-msexcel&quot;;s:7:&quot;flexpdf&quot;;s:29:&quot;application/vnd.ms-powerpoint&quot;;s:7:&quot;flexpdf&quot;;s:25:&quot;application/ms-powerpoint&quot;;s:7:&quot;flexpdf&quot;;s:24:&quot;application/mspowerpoint&quot;;s:7:&quot;flexpdf&quot;;s:22:&quot;application/openoffice&quot;;s:7:&quot;flexpdf&quot;;s:20:&quot;application/epub+zip&quot;;s:4:&quot;epub&quot;;s:9:&quot;image/png&quot;;s:6:&quot;images&quot;;s:11:&quot;image/x-png&quot;;s:6:&quot;images&quot;;s:9:&quot;image/jpg&quot;;s:6:&quot;images&quot;;s:10:&quot;image/jpeg&quot;;s:6:&quot;images&quot;;s:9:&quot;image/gif&quot;;s:6:&quot;images&quot;;s:10:&quot;audio/mpeg&quot;;s:5:&quot;audio&quot;;}','tableau de correspondance mimetype=>class','m_photo',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (676,'opac','allow_self_checkout','0','Proposer de faire du prêt autonome dans l\'OPAC.\n 0 : Non.\n 1 : Autorise le prêt de document.\n 2 : Autorise le retour de document.\n 3 : Autorise le prêt et le retour de document.\n','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (677,'opac','self_checkout_url_connector','','URL du connecteur en gestion permettant d\'effectuer le prêt autonome.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (678,'finance','recouvrement_lecteur_statut','0','Mémorise le statut que prennent les lecteurs lors du passage en recouvrememnt','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (679,'thesaurus','auto_postage_search','0','Activer l\'indexation des catégories mères et filles pour la recherche de notices. \n 0 non, \n 1 oui','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (680,'thesaurus','auto_postage_search_nb_descendant','0','Nombre de niveaux de recherche de notices dans les catégories filles. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (681,'thesaurus','auto_postage_search_nb_montant','0','Nombre de niveaux de recherche de notices dans les catégories mères. \n *: illimité, \n n: nombre de niveaux','i_categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (682,'opac','show_bulletin_nav','1','Affichage d\'un navigateur dans les bulletins d\'un périodique. \r\n 0 non \r\n 1 oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (683,'pmb','play_pret_sound','1','Jouer l\'alerte sonore si le prêt et le retour se passe sans erreur ? \n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (684,'pmb','catalog_verif_js','','Script de vérification de saisie de notice','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (685,'opac','default_style_addon','','Ajout de styles CSS aux feuilles déjà incluses ?\n Ne mettre que le code CSS, exemple:  body {background-color: #FF0000;}','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (686,'pmb','rfid_gates_server_url','','URL du serveur des portiques RFID','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (687,'pmb','perso_sep','/','Séparateur des valeurs de champ perso, espace ou ; ou , ou ...','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (688,'pmb','search_full_text','0','Utiliser un index MySQL FULLTEXT pour la recherche sur les documents numériques \n 0: Non \n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (689,'opac','parse_html','1','Activer le parse HTML des pages OPAC \r\n 0: Non \r\n 1: Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (690,'opac','notice_enrichment','1','Activer l\'enrichissement des notices\r\n 0: Non \r\n 1: Oui','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (691,'opac','show_social_network','1','Activer les partages sur les réseaux sociaux \r\n 0: Non \r\n 1: Oui','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (692,'pmb','opac_view_activate','0','Activer les vues OPAC :\n 0 : non activé\n 1 : activé avec gestion classique\n 2 : activé avec gestion avancée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (693,'opac','opac_view_activate','0','Activer les vues OPAC:\r\n 0 : non activé \r\n 1 : activé','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (694,'pmb','sur_location_activate','0','Activer les sur-localisations:\n 0 : non activé \n 1 : activé','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (695,'opac','sur_location_activate','0','Activer les sur-localisations:\n 0 : non activé \n 1 : activé','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (696,'pmb','opac_view_class','','Nom de la classe substituant la class opac_view pour la personnalisation de la gestion des vues Opac','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (697,'opac','faviconurl','','URL du favicon, si vide favicon=celui de PMB','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (698,'opac','allow_affiliate_search','1','Activer les recherches affiliées en OPAC:\r\n 0 : non \r\n 1 : oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (699,'acquisition','pdfrel_format_page','210x297','Largeur x Hauteur de la page en mm','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (700,'acquisition','pdfrel_orient_page','P','Orientation de la page: P=Portrait, L=Paysage','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (701,'acquisition','pdfrel_marges_page','10,20,10,10','Marges de page en mm : Haut,Bas,Droite,Gauche','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (702,'acquisition','pdfrel_pos_logo','10,10,20,20','Position du logo: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (703,'acquisition','pdfrel_pos_raison','35,10,100,10,16','Position Raison sociale: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (704,'acquisition','pdfrel_pos_date','170,10,0,6,8','Position Date: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (705,'acquisition','pdfrel_pos_adr_rel','10,35,60,5,10','Position Adresse de relance: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (706,'acquisition','pdfrel_pos_adr_fou','100,55,100,6,14','Position Adresse fournisseur: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (707,'acquisition','pdfrel_pos_num_cli','10,80,0,10,16','Position numéro de client: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (708,'acquisition','pdfrel_pos_num','10,0,10,16','Position numéro de commande/devis: Distance par rapport au bord gauche de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (709,'acquisition','pdfrel_text_size','10','Taille de la police texte','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (710,'acquisition','pdfrel_pos_titre','10,90,100,10,16','Position titre: Distance par rapport au bord gauche de la page,Distance par rapport au haut de la page,Largeur,Hauteur,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (711,'acquisition','pdfrel_text_before','','Texte avant le tableau de relances','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (712,'acquisition','pdfrel_text_after','','Texte après le tableau de relances','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (713,'acquisition','pdfrel_tab_rel','5,10','Tableau de relances: Hauteur ligne,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (714,'acquisition','pdfrel_pos_footer','15,8','Position bas de page: Distance par rapport au bas de page, Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (715,'acquisition','pdfrel_pos_sign','10,60,5,10','Position signature: Distance par rapport au bord gauche de la page, Largeur, Hauteur ligne,Taille police','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (716,'acquisition','pdfrel_text_sign','Le responsable de la bibliothèque.','Texte signature','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (717,'acquisition','pdfrel_by_mail','0','Effectuer les relances par mail :\r\n 0 : non \r\n 1 : oui','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (718,'acquisition','pdfrel_text_mail','Bonjour, \r\n\r\nVous trouverez ci-joint un état des commandes en cours.\r\n\r\nMerci de nous préciser par retour vos délais d\'envoi.\r\n\r\nCordialement,\r\n\r\nLe responsable de la bibliothèque.','Texte du mail','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (719,'opac','show_perio_browser','0','Affichage du navigateur de périodiques en page d\'accueil OPAC.\r\n 0 : Non.\r\n 1 : Oui.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (720,'acquisition','pdfrel_pdfrtf','0','Envoi des relances en :\n 0 : pdf\n 1 : rtf','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (721,'opac','show_onglet_perio_a2z','1','Activer l\'onglet du navigateur de périodiques en OPAC.\r\n 0 : Non.\r\n 1 : Oui.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (722,'opac','avis_note_display_mode','1','Mode d\'affichage de la note pour les avis de notices.\r\n 0 : Note non visible.\r\n 1 : Affichage de la note sous la forme d\'étoiles.\r\n 2 : Affichage de la note sous la forme textuelle.\r\n 3 : Affichage de la note sous la forme textuelle et d\'étoiles.\n 4 : Affichage de la note sous la forme d\'étoiles, choix de la note sous la forme d\'étoiles.\n 5 : Affichage de la note sous la forme textuelle et d\'étoiles, choix de la note sous la forme d\'étoiles.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (723,'opac','avis_display_mode','1','Mode d\'affichage des avis de notices.\r\n 0 : Visible en lien à coté de l\'onglet Public/ISBD de la notice.\r\n 1 : Visible dans la notice.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (724,'pmb','planificateur_allow','0','Planificateur activé.\n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (725,'acquisition','pdfrel_obj_mail','Etat des en-cours','Objet du mail','pdfrel',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (726,'acquisition','pdfcde_by_mail','0','Effectuer les envois de commandes par mail :\r\n 0 : non \r\n 1 : oui','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (727,'acquisition','pdfcde_obj_mail','Commande','Objet du mail','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (728,'acquisition','pdfcde_text_mail','Bonjour, \r\n\r\nVous trouverez ci-joint une commande à traiter.\r\n\r\nMerci de nous confirmer par retour vos délais d\'envoi.\r\n\r\nCordialement,\r\n\r\nLe responsable de la bibliothèque.','Texte du mail','pdfcde',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (729,'acquisition','pdfdev_by_mail','0','Effectuer les envois de demandes de devis par mail :\r\n 0 : non \r\n 1 : oui','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (730,'acquisition','pdfdev_obj_mail','Demande de devis','Objet du mail','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (731,'acquisition','pdfdev_text_mail','Bonjour, \r\n\r\nVous trouverez ci-joint une demande de devis.\r\n\r\nCordialement,\r\n\r\nLe responsable de la bibliothèque.','Texte du mail','pdfdev',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (732,'pmb','docnum_in_database_allow','1','Autoriser le stockage de document numérique en base ? \n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (733,'opac','recherche_ajax_mode','1','Affichage accéléré des résultats de recherche: header uniquement, la suite est chargée lors du click sur le \"+\".\r\n 0: Inactif\r\n 1: Actif (par lot)\r\n 2: Actif (par notice)','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (734,'pmb','avis_note_display_mode','1','Mode d\'affichage de la note pour les avis de notices.\n 0 : Note non visible.\n 1 : Affichage de la note sous la forme d\'étoiles.\n 2 : Affichage de la note sous la forme textuelle.\n 3 : Affichage de la note sous la forme textuelle et d\'étoiles.\n 4 : Affichage de la note sous la forme d\'étoiles, choix de la note sous la forme d\'étoiles.\n 5 : Affichage de la note sous la forme textuelle et d\'étoiles, choix de la note sous la forme d\'étoiles.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (735,'cms','active','1','Module \'Portail\' activé.\r\n 0 : Non.\r\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (736,'pmb','indexation_lang','','Choix de la langue d\'indexation par défaut. (ex : fr_FR,en_UK,...,ar), si vide c\'est la langue de l\'interface du catalogueur qui est utilisée.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (737,'opac','websubscribe_show_location','0','Afficher la possibilité pour le lecteur de choisir sa localisation lors de son inscription en ligne.\n 0: Non\n 1: Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (738,'opac','collstate_order','archempla_libelle,collstate_cote','Ordre d\'affichage des états des collections, dans l\'ordre donné, séparé par des virgules : archempla_libelle,collstate_cote','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (739,'opac','default_sort','d_num_6,c_text_1','Tri par défaut des recherches OPAC.\nDe la forme, c_num_6 (c pour croissant, d pour décroissant, puis num ou text pour numérique ou texte et enfin l\'identifiant du champ (voir fichier xml sort.xml))','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (740,'pmb','fine_precision','2','Nombre de décimales pour l\'affichage des amendes','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (741,'opac','search_cache_duration','600','Durée de validité (en secondes) du cache des recherches OPAC','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (742,'pmb','path_php','','Chemin absolu de l\'interpréteur PHP, local ou distant','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (743,'opac','explnum_order','explnum_mimetype, explnum_nom, explnum_id','Ordre d\'affichage des documents numériques, dans l\'ordre donné, séparé par des virgules : explnum_mimetype, explnum_nom, explnum_id','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (744,'pmb','amende_comptabilisation','0','Date à laquelle le début de l\'amende sera comptabilisée \r\n 0 : à partir de la date de retour \r\n 1 : à partir du délai de grâce','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (745,'pmb','pret_calcul_retard_date_debut_incluse','0','Compter le jour de retour ou de relance comme un jour de retard pour le calcul de l\'amende ? \r\n 0 : Non \r\n  1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (746,'opac','exclude_fields','','Identifiants des champs à exclure de la recherche tous les champs (liste dispo dans le fichier includes/indexation/champ_base.xml)','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (747,'opac','serialcirc_active','0','Activer la circulation des pédioques dans l\'OPAC \r\n 0: Non \r\n 1: Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (748,'pmb','bdd_subversion','25','Sous-version de la base de données','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (749,'pmb','import_modele_authorities','authority_import','Quelle classe d\'import utiliser pour les notices d\'autorités ?','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (750,'pmb','location_resa_planning','0','Utiliser la gestion de la prévision localisée?\n 0: Non\n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (751,'demandes','email_demandes','1','Information par email de l\'évolution des demandes.\n 0 : Non\n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (752,'pmb','short_loan_management','0','Gestion des prêts courts\n 0: Non\n 1: Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (753,'pmb','loan_trust_management','0','Gestion de monopole de prêt\n 0: Non\n x: nombre de jours entre 2 prêts d\'un exemplaire d\'une même notice (ou bulletin)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (754,'opac','perio_a2z_abc_search','1','Recherche abécédaire dans le navigateur de périodiques en OPAC.\r\n0 : Non.\r\n1 : Oui.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (755,'opac','perio_a2z_max_per_onglet','15','Recherche dans le navigateur de périodiques en OPAC : nombre maximum de notices par onglet.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (756,'pmb','indexation_docnum_ext','','Paramètres de gestion d\'accès aux programmes externes pour l\'indexation des documents numériques :\n\n Chaque paramètre est défini par un  couple : \"nom=valeur\"\n Les paramètres sont séparés par un \"point-virgule\".\n\n\n Exemples d\'utilisation de \"pyodconverter\", \"jodconverter\" et \"pdftotext\" :\n\npyodconverter_cmd=/opt/openoffice.org3/program/python /opt/ooo_converter/DocumentConverter.py %1s %2s;\njodconverter_cmd=/usr/bin/java -jar /opt/ooo_converter/jodconverter-2.2.2/lib/jodconverter-cli-2.2.2.jar %1s %2s;\njodconverter_url=http://localhost:8080/converter/converted/%1s;\npdftotext_cmd=/usr/bin/pdftotext -enc UTF-8 %1s -;','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (757,'opac','notices_format_onglets','','Liste des id de template de notice pour ajouter des onglets personnalisés en affichage de notice\nExemple: 1,3,ISBD,PUBLIC\nLe paramètre notices_format doit être à 0 pour placer ISBD et PUBLIC','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (758,'opac','visionneuse_alert','','Message d\'alerte à l\'ouverture des documents numériques.','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (759,'opac','cms','1','id du CMS utilisé en OPAC','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (760,'pmb','expl_data','expl_cb,expl_cote,location_libelle,section_libelle,statut_libelle,tdoc_libelle','Colonne des exemplaires, dans l\'ordre donné, séparé par des virgules : expl_cb,expl_cote,location_libelle,section_libelle,statut_libelle,tdoc_libelle #n : id des champs personnalisés \r\n expl_cb est obligatoire et sera ajouté si absent','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (761,'pmb','expl_display_location_without_expl','0','Affichage de la liste des localisations sans exemplaire\n 0: Non\n 1: oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (762,'opac','show_group_checkout','1','Le responsable du groupe de lecteur voit les prêts de son groupe\r\n 0: Non\r\n 1: oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (763,'opac','facette_in_bandeau_2','0','La navigation par facettes apparait dans le bandeau ou dans le bandeau 2\n0 : dans le bandeau\n1 : Dans le bandeau 2','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (764,'opac','autolevel2','1','0 : mode normal de recherche.\n1 : Affiche le résultat de la recherche tous les champs après calcul du niveau 1 de recherche.\n2 : Affiche directement le résultat de la recherche tous les champs sans passer par le calcul du niveau 1 de recherche.','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (765,'opac','first_page_params','{\r\n\"lvl\":\"cmspage\",\r\n\"pageid\":\"3\"\r\n}','Structure Json récapitulant les paramètres à initialiser pour la page d\'accueil :\r\nExemple : \r\n{\r\n\"lvl\":\"cmspage\",\r\n\"pageid\":2\r\n}','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (766,'opac','show_links_invisible_docnums','1','Afficher les liens vers les documents numériques non visible en mode non connecté. (Ne fonctionne pas avec les droits d\'accès).\r\n 0 : Non.\r\n1 : Oui.','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (767,'pmb','img_folder','','Répertoire de stockage des images','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (768,'pmb','img_url','','URL d\'accès du répertoire des images (pmb_img_folder)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (769,'pmb','book_pics_msg','','Message sur le survol des vignettes des notices correspondant au chemin fourni par le paramètre book_pics_url','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (770,'opac','book_pics_msg','','Message sur le survol des vignettes des notices correspondant au chemin fourni par le paramètre book_pics_url','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (771,'opac','visionneuse_alert_doctype','','Liste des types de documents pour lesquels une alerte est générée (séparés par une virgule).','m_photo',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (772,'pmb','archive_warehouse','0','Identifiant de l\'entrepôt d\'archivage à la suppression des notices.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (773,'pmb','printer_name','','Nom de l\'imprimante de ticket de prêt, utilisant l\'applet jzebra. Le nom de l\'imprimante doit correspondre à la class développée spécifiquement pour la piloter.\nExemple: Nommer l\'imprimante \'metapace\' pour utiliser le driver classes/printer/metapace.class.php','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (774,'empr','groupes_localises','0','Groupes de lecteurs localisés par rapport au responsable \n0: Non \n1: oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (776,'opac','notices_depliable_plus','plus.gif','Image à utiliser devant un titre de notice pliée','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (777,'opac','notices_depliable_moins','minus.gif','Image à utiliser devant un titre de notice dépliée','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (778,'pmb','pret_groupement','0','Activer le prêt d\'exemplaires regroupés en un seul lot. La gestion des groupes se gére en Circulation / Groupe d\'exemplaires :\n 0 : non \n 1 : oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (779,'transferts','regroupement_depart','0','Active le regroupement des départs\n 0: Non \n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (780,'pmb','rfid_afi_security_codes','','Gestion de l\'antivol par le registre AFI.\nLa première valeur est celle de l\'antivol actif, la deuxième est celle de lantivol inactif.\nExemple: 07,C2  ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (787,'pdflettreretard','1before_list_group','Sauf erreur de notre part, vous avez toujours en votre possession le ou les ouvrage(s) suivant(s) dont la durée de prêt est aujourd\'hui dépassée :','Texte apparaissant avant la liste des ouvrages en retard dans le courrier de relance de retard','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (782,'opac','simple_search_suggestions','0','Activer la suggestion de mots en recherche simple via la complétion\n0 : Désactiver\n1 : Activer\n\nNB : Cette fonction nécessite l\'installation de l\'extention levenshtein dans MySQL','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (783,'opac','stemming_active','0','Activer le stemming dans la recherche\n0 : Désactiver\n1 : Activer\n','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (786,'cms','url_base_cms_build','','url de construction du CMS de l\'OPAC','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (788,'pdflettreretard','1after_list_group','Nous vous remercions de prendre rapidement contact par téléphone au $biblio_phone ou par mail à $biblio_email pour étudier la possibilité de prolonger ces prêts ou de rapporter les ouvrages concernés.','Texte apparaissant après la liste des ouvrages en retard dans le courrier','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (789,'pdflettreretard','1fdp_group','L\'équipe de la bibliothèque','Signataire de la lettre.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (790,'pdflettreretard','1madame_monsieur_group','Madame, Monsieur,','Entête de la lettre','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (791,'opac','show_bandeau_2','1','Affichage du bandeau_2 ? \n 0 : Non\n 1 : Oui','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (792,'opac','param_social_network','{\n			\"token\":\"ra-4d9b1e202c30dea1\",\n			\"version\":\"300\",\n			\"buttons\":[\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_facebook_like\",\n			\"fb:like:layout\":\"button_count\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_tweet\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_counter addthis_button_compact\"\n			}\n			}\n			],\n			\"toolBoxParams\":{\n			\"class\":\"addthis_toolbox addthis_default_style\"\n			},\n			\"addthis_share\":{\n			\n			},\n			\"addthis_config\":{\n			\"data_track_clickback\":\"true\",\n			\"ui_click\":\"true\"\n			}\n			}\n			','Tableau de paramètrage de l\'API de gestion des interconnexions aux réseaux sociaux.\n			Au format JSON.\n			Exemple :\n			{\n			\"token\":\"ra-4d9b1e202c30dea1\",\n			\"version\":\"300\",\n			\"buttons\":[\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_preferred_1\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_preferred_2\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_preferred_3\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_preferred_4\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_button_compact\"\n			}\n			},\n			{\n			\"attributes\":{\n			\"class\":\"addthis_counter addthis_bubble_style\"\n			}\n			}\n			],\n			\"toolBoxParams\":{\n			\"class\":\"addthis_toolbox addthis_default_style addthis_32x32_style\"\n			},\n			\"addthis_share\":{\n			\n			},\n			\"addthis_config\":{\n			\"data_track_addressbar\":true\n			}\n			}','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (817,'opac','default_sort_list','0 d_num_6,c_text_28;d_text_7','Afficher la liste déroulante de sélection d\'un tri ? \n 0 : Non \n 1 : Oui \nFaire suivre d\'un espace pour l\'ajout de plusieurs tris sous la forme : c_num_6|Libelle;d_text_7|Libelle 2;c_num_5|Libelle 3\n\nc pour croissant, d pour décroissant\nnum ou text pour numérique ou texte\nidentifiant du champ (voir fichier xml sort.xml)\nlibellé du tri (optionnel)','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (793,'transferts','pret_demande_statut','0','Appliquer ce statut avant la validation','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (794,'opac','perio_a2z_show_bulletin_notice','0','Affichage de la notice de bulletin dans le navigateur de périodiques','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (795,'pmb','procs_force_execution','0','Permettre le forçage de l\'exécution des procédures','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (796,'opac','draggable','1','Permet d\'activer le glisser déposer dans le panier pour l\'affichage des notices à l\'OPAC','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (803,'cms','cache_ttl','1800','durée de vie du cache des cadres du portail (en secondes)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (797,'opac','meta_description','','Contenu du meta tag description pour les moteurs de recherche','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (798,'opac','meta_keywords','','Contenu du meta tag keywords pour les moteurs de recherche','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (799,'opac','meta_author','','Contenu du meta tag author pour les moteurs de recherche','b_aff_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (800,'pmb','html_allow_expl_cote','0','Autoriser le code HTML dans les cotes exemplaires ? \n 0 : non \n 1','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (801,'pmb','default_style_addon','','Ajout de styles CSS aux feuilles déjà incluses ?\n Ne mettre que le code CSS, exemple:  body {background-color: #FF0000;}','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (802,'pmb','serialcirc_subst','','Nom du fichier permettant de personnaliser l\'impression de la liste de circulation des périodiques','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (804,'pmb','serial_thumbnail_url_article','0','Préremplissage de l\'url de la vignette des dépouillements avec l\'url de la vignette de la notice mère en catalogage des périodiques ? \n 0 : Non \n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (805,'pmb','mail_delay','0','Temps d\'attente en millisecondes entre chaque mail envoyé lors d\'un envoi groupé. \n 0 : Pas d\'attente','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (806,'pmb','curl_timeout','5','Timeout cURL (en secondes) pour la vérification des liens','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (807,'empr','allow_prolong_members_group','0','Autoriser la prolongation groupée des adhésions des membres d\'un groupe ? \n 0 : Non \n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (808,'thesaurus','auto_index_notice_fields','','Liste des champs de notice à utiliser pour l\'indexation automatique.\n\nSyntaxe: nom_champ=poids_indexation;\n\nLes noms des champs sont ceux précisés dans le fichier XML \"pmb/includes/notice/notice.xml\"\nLe poids de l\'indexation est une valeur de 0.00 à 1. (Si rien n\'est précisé, le poids est de 1)\n\nExemple :\n\ntit1=1.00;n_resume=0.5;','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (809,'thesaurus','auto_index_search_param','','Surchage des paramètres de recherche de l\'indexation automatique.\nSyntaxe: param=valeur;\n\nListes des parametres:\n\nmax_relevant_words = 20 (nombre maximum de mots et de lemmes de la notice à prendre en compte pour le calcul)\n\nautoindex_deep_ratio = 0.05 (ratio sur la profondeur du terme dans le thésaurus)\nautoindex_stem_ratio = 0.80 (ratio de pondération des lemmes / aux mots)\n\nautoindex_max_up_distance = 2 (distance maximum de recherche dans les termes génériques du thésaurus)\nautoindex_max_up_ratio = 0.01 (pondération sur les termes génériques)\n\nautoindex_max_down_distance = 2 (distance maximum de recherche dans les termes spécifiques du thésaurus)\nautoindex_max_down_ratio = 0.01 (pondération sur les termes spécifiques)\n\nautoindex_see_also_ratio = 0.01 (surpondération sur les termes voir aussi du thésaurus)\n\nautoindex_distance_type = 1 (calcul de distance de 1 à 4)\nautoindex_distance_ratio = 0.50 (ratio de pondération sur la distance entre les mots trouvés et les termes d\'une expression du thésaurus)\n\nmax_relevant_terms = 10 (nombre maximum de termes retournés)','categories',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (810,'empr','abonnement_default_debit','0','Choix par défaut pour la prolongation des lecteurs. \n 0 : Ne pas débiter l\'abonnement \n 1 : Débiter l\'abonnement sans la caution \n 2 : Débiter l\'abonnement et la caution','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (834,'demandes','notice_auto','0','Création automatique de la notice de demande :\n0 : Non\n1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (835,'demandes','default_action','1','Création par défaut d\'une action lors de la validation de la demande :\n0 : Non\n1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (836,'pmb','synchro_rdf','0','Activer la synchronisation rdf\n 0 : non \n 1 : oui (l\'activation de ce paramètre nécessite une ré-indexation)','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (812,'opac','print_template_default','0','En impression de panier, identifiant du template de notice utilisé par défaut. Si vide ou à 0, le template classique est utilisé','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (813,'pmb','show_permalink','0','Afficher le lien permanent de l\'OPAC en gestion ? \n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (814,'pmb','expl_show_lastempr','1','Afficher l\'emprunteur précédent sur la fiche exemplaire ? \n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (815,'pmb','gestion_financiere_caisses','0','Activer la gestion de caisses en gestion financière? \n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (816,'pmb','diarization_docnum','0','Activer la segmentation des documents numériques vidéo ou audio 0 : non activée 1 : activée','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (818,'opac','default_sort_display','0','Afficher le libellé du tri appliqué par défaut en résultat de recherche ? \n 0 : Non \n 1 : Oui','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (819,'opac','show_bannettes','0','Affichage des bannettes en page d\'accueil OPAC.\n 0 : Non.\n 1 : Oui.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (820,'opac','facettes_ajax','1','Charger les facettes en ajax\n0 : non\n1 : oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (821,'opac','search_all_keep_empty_words','1','Conserver les mots vides pour les autorités dans la recherche tous les champs\n0 : non\n1 : oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (822,'pmb','pret_already_loaned','0','Activer le piège en prêt si le document a déjà été emprunté par le lecteur. Nécessite l\'activation de l\'archivage des prêts\n0 : non\n1 : oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (824,'opac','nb_notices_similaires','6','Nombre de notices similaires affichées lors du dépliage d\'une notice.\nValeur max = 6.','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (825,'opac','notice_reduit_format_similaire','1','Format d\'affichage des réduits de notices similaires :\n 0 = titre+auteur principal\n 1 = titre+auteur principal+date édition\n 2 = titre+auteur principal+date édition + ISBN\n 3 = titre seul\n P 1,2,3 = tit+aut+champs persos id 1 2 3\n E 1,2,3 = tit+aut+édit+champs persos id 1 2 3\n T = tit1+tit4\n 4 = titre+titre parallèle+auteur principal\n H 1 = id d\'un template de notice','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (826,'opac','search_noise_limit_type','0','Ecrêter les résulats de recherche en fonction de la pertinence. \n0 : Non \n1 : Retirer du résultat tout ce qui est en dessous de la moyenne - l\'écart-type\n2,ratio : Retirer du résultat tout ce qui est en dessous de la moyenne - un ratio de l\'écart-type (ex: 2,1.96)\n3,ratio : Retirer du résultat tout ce qui est dessous d\'un ratio de la pertinence max (ex: 3,0.25 élimine tout ce qui est inférieur à 25% de la plus forte pertinence)','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (827,'opac','search_relevant_with_frequency','0','Utiliser la fréquence d\'apparition des mots dans les notices pour le calcul de la pertinence.\n0 : Non \n1 : Oui','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (828,'empr','prolong_calc_date_adhes_depassee','0','Si la date d\'adhésion est dépassée, le calcul de la prolongation se fait à partir de :\n 0 : la date de fin d\'adhésion\n 1 : la date du jour','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (829,'opac','bannette_priv_periodicite','15','Périodicité d\'envoi par défaut en création de bannette privée (en jours)','l_dsi',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (830,'opac','show_subscribed_bannettes','0','Affichage des bannettes auxquelles le lecteur est abonné en page d\'accueil OPAC :\n0 : Non.\n1 : Oui.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (831,'opac','show_public_bannettes','0','Affichage des bannettes sélectionnées en page d\'accueil OPAC :\n0 : Non.\n1 : Oui.','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (837,'faq','active','0','Module \'FAQ\' activé.\n 0 : Non.\n 1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (838,'opac','websubscribe_num_carte_auto','','Numéro de carte de lecteur automatique ?\n 2,a,b,c: Oui avec préfixe: a=longueur du préfixe, b=nombre de chiffres de la partie numérique, c=préfixe fixé (facultatif)\n 3,fonction: fonction de génération spécifique dans fichier nommé de la même façon, à placer dans pmb/opac_css/circ/empr','f_modules',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (839,'pdfcartelecteur','printer_card_handler','','Gestionnaire d\'impression :\n\n 1 = script \"print_cb.php\"\n 2 = applet jzebra\n 3 = requête ajax','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (840,'pdfcartelecteur','printer_card_name','','Nom de l\'imprimante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (841,'pdfcartelecteur','printer_card_url','','Adresse de l\'imprimante.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (842,'pmb','notice_img_folder_id','0','Identifiant du répertoire d\'upload des vignettes de notices','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (843,'pmb','compare_notice_template','0','Choix du template d\'affichage des notices en mode comparaison.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (844,'pmb','compare_notice_nb','5','Nombre de notices à afficher et à raffraichir en mode comparaison.','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (845,'opac','compare_notice_active','1','Activer le comparateur de notices','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (846,'pmb','autorites_verif_js','','Script de vérification de saisie des autorités','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (847,'opac','resa_cart','1','Paramètre pour masquer/afficher la reservation par panier\n0 : Non \n1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (848,'pmb','search_stemming_active','0','Activer le stemming dans la recherche\n0 : Désactiver\n1 : Activer','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (849,'pmb','search_exclude_fields','','Identifiants des champs à exclure de la recherche tous les champs (liste dispo dans le fichier includes/indexation/champ_base.xml)','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (850,'pmb','search_noise_limit_type','0','Ecrêter les résulats de recherche en fonction de la pertinence. \n0 : Non \n1 : Retirer du résultat tout ce qui est en dessous de la moyenne - l\'écart-type\n2,ratio : Retirer du résultat tout ce qui est en dessous de la moyenne - un ratio de l\'écart-type (ex: 2,1.96)\n3,ratio : Retirer du résultat tout ce qui est dessous d\'un ratio de la pertinence max (ex: 3,0.25 élimine tout ce qui est inférieur à 25% de la plus forte pertinence)','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (851,'pmb','search_relevant_with_frequency','0','Utiliser la fréquence d\'apparition des mots dans les notices pour le calcul de la pertinence.\n0 : Non \n1 : Oui','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (852,'pmb','allow_term_troncat_search','0','Troncature à droite automatique :\n0 : Non \n1 : Oui','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (853,'pmb','search_cache_duration','0','Durée de validité (en secondes) du cache des recherches','search',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (854,'pmb','print_expl_default','0','En impression de panier, imprimer les exemplaires est coché par défaut \n 0 : Non \n 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (855,'thesaurus','concepts_active','0','Active ou non l\'utilisation des concepts:\n0 : Non\n1 : Oui','concepts',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (856,'thesaurus','concepts_affichage_ordre','0','Paramétrage de l\'ordre d\'affichage des concepts d\'une notice.\nPar ordre alphabétique: 0(par défaut)\nPar ordre de saisie: 1','concepts',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (857,'thesaurus','concepts_concept_in_line','0','Affichage des concepts en ligne.\n 0 : Non.\n 1 : Oui.','concepts',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (858,'opac','collstate_data','','Colonne des états des collections, dans l\'ordre donné, séparé par des virgules : location_libelle,emplacement_libelle,cote,type_libelle,statut_opac_libelle,origine,state_collections,archive,lacune,surloc_libelle,note\nLes valeurs possibles sont les propriétés de la classe PHP \"pmb/opac_css/classes/collstate.class.php\".','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (859,'thesaurus','ontology_filemtime','0','Paramètre caché pour conservation de la date de dernière modification de l\'ontologie','ontologie',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (860,'gestion_acces','empr_docnum','0','Gestion des droits d\'accès des emprunteurs aux documents numériques\n0 : Non.\n1 : Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (861,'gestion_acces','empr_docnum_def','0','Valeur par défaut en modification de document numérique pour les droits d\'accès emprunteurs - documents numériques\n0 : Recalculer.\n1 : Choisir.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (862,'transferts','retour_action_resa','1','Génére un transfert pour répondre à une réservation lors du retour de l\'exemplaire\n 0: Non\n 1: Oui','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (863,'pmb','logs_exclude_robots','1','Exclure les robots dans les logs OPAC ?\n 0: Non\n 1: Oui. \nFaire suivre d\'une virgule pour éventuellement exclure les logs OPAC provenant de certaines adresses IP, elles-mêmes séparées par des virgules (ex : 1,127.0.0.1,192.168.0.1).','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (864,'pmb','map_activate','0','Activation du géoréférencement','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (865,'pmb','map_max_holds','250,0','Dans l\'ordre donné séparé par une virgule: Nombre limite d\'emprises affichées, mode de clustering \nValeurs possibles pour le mode :\n\n0 => Clustering standard avec augmentation dynamique des seuils jusqu\'a atteindre le nombre maximum d\'emprises affichées\n\n1 => Clusterisation de toutes les emprises','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (879,'opac','map_holds_record_color','#D6A40F','Couleur des emprises associées à des notices','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (866,'pmb','map_holds_record_color','#D6A40F','Couleur des emprises associées à des notices','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (867,'pmb','map_holds_authority_color','#D60F0F','Couleur des emprises associées à des autorités','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (868,'pmb','map_base_layer_type','OSM','Fonds de carte à utiliser.\nValeurs possibles :\nOSM           => Open Street Map\nWMS           => The Web Map Server base layer type selector.\nGOOGLE        => Google\nARCGIS        =>The ESRI ARCGis base layer selector.\n','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (869,'pmb','map_base_layer_params','','Structure JSON à passer au fond de carte\nexemple :\n{\n \"name\": \"Nom du fond de carte\",\n \"url\": \"url du fond de carte\",\n \"options\":{\n  \"layers\": \"MONDE_MOD1\"\n }\n}','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (870,'pmb','map_size_search_edition','800*480','Taille de la carte en saisie de recherche','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (871,'pmb','map_size_search_result','800*480','Taille de la carte en résultat de recherche','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (872,'pmb','map_size_notice_view','800*480','Taille de la carte en visualisation de notice','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (873,'pmb','map_size_notice_edition','800*480','Taille de la carte en édition de notice','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (874,'pmb','notice_img_pics_max_size','150','Taille maximale des vignettes uploadées dans les notices, en largeur ou en hauteur','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (875,'opac','map_activate','0','Activation du géoréférencement','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (876,'pmb','psexec_cmd','psexec -d','Paramètres de lancement de psexec (planificateur sous windows)\r\n\nAjouter l\'option -accepteula sur les versions les plus récentes. ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (877,'pmb','editorial_dojo_editor','1','Activation de l\'éditeur DoJo dans le contenu éditorial:\n 0 : non \n 1 : oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (878,'opac','map_max_holds','250,0','Dans l\'ordre donné séparé par une virgule: Nombre limite d\'emprises affichées, mode de clustering \nValeurs possibles pour le mode :\n\n0 => Clustering standard avec augmentation dynamique des seuils jusqu\'a atteindre le nombre maximum d\'emprises affichées\n\n1 => Clusterisation de toutes les emprises','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (880,'opac','map_holds_authority_color','#D60F0F','Couleur des emprises associées à des autorités','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (881,'opac','map_size_search_edition','800*480','Taille de la carte en saisie de recherche','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (882,'opac','map_size_search_result','800*480','Taille de la carte en résultat de recherche','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (883,'opac','map_size_notice_view','800*480','Taille de la carte en visualisation de notice','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (884,'opac','map_base_layer_type','OSM','Fonds de carte à utiliser.\nValeurs possibles :\nOSM           => Open Street Map\nWMS           => The Web Map Server base layer type selector.\nGOOGLE        => Google\nARCGIS        =>The ESRI ARCGis base layer selector.\n','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (885,'opac','map_base_layer_params','','Structure JSON à passer au fond de carte\nexemple :\n{\n \"name\": \"Nom du fond de carte\",\n \"url\": \"url du fond de carte\",\n \"options\":{\n  \"layers\": \"MONDE_MOD1\"\n }\n}','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (886,'acquisition','budget_show_all','0','Sélection d\'une rubrique budgétaire en commande : toutes les afficher ?\n 0: Non (par pagination)\n 1: Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (887,'pmb','abt_label_perio','0','Création d\'un abonnement : reprendre le nom du périodique ?\n 0: Non \n 1: Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (888,'acquisition','show_abt_in_cmde','0','Afficher l\'abonnement dans les lignes de la commande ?\n 0: Non \n 1: Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (889,'pmb','nomenclature_record_children_link','','Type de relation entre une notice de nomenclature et ses notices filles.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (890,'pmb','nomenclature_activate','0','Activation des nomenclatures:\n 0 : non \n 1 : oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (891,'demandes','email_generic','','Information par un email générique de l\'évolution des demandes.\n 1,adrmail@mail.fr : Envoi une copie uniquement pour toutes les nouvelles demandes\n 2,adrmail@mail.fr : Envoi une copie uniquement des mails envoyés aux personnes affectées\n 3,adrmail@mail.fr : Envoi une copie dans les 2 cas précédents\n ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (892,'opac','demandes_affichage_simplifie','0','Active le format simplifié des demandes en Opac:\n 0 : non \n 1 : oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (893,'opac','demandes_no_action','0','Interdire l\'ajout d\'une action en Opac:\n 0 : non \n 1 : oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (894,'pmb','map_hold_ratio_min','4','Ratio minimum d\'occupation en pourcentage d\'une emprise pour s\'afficher','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (895,'pmb','map_hold_ratio_max','75','Ratio maximum d\'occupation en pourcentage d\'une emprise pour s\'afficher','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (896,'pmb','map_hold_distance','10','Rapport de distance entre deux points pour les agréger','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (897,'opac','modules_search_concept','0','Recherche dans les concepts : \n 0 : interdite, \n 1 : autorisée, \n 2 : autorisée et validée par défaut','c_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (898,'opac','map_hold_ratio_min','4','Ratio minimum d\'occupation en pourcentage d\'une emprise pour s\'afficher','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (899,'opac','map_hold_ratio_max','75','Ratio maximum d\'occupation en pourcentage d\'une emprise pour s\'afficher','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (900,'opac','map_hold_distance','10','Rapport de distance entre deux points pour les agréger','map',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (901,'ldap','encoding_utf8','0','Les informations du LDAP sont en utf-8 ?\n 0: Non \n 1: Oui.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (902,'opac','script_analytics','','Code Javascript d\'analyse d\'audience (Par exemple pour Google Analytics, XiTi,..).','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (903,'opac','accessibility','1','Accessibilité activée.\n 0 : Non.\n 1 : Oui.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (904,'pmb','newrecord_timeshift','0','Nombre de jours de conservation des notices en tant que nouveauté.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (905,'opac','notices_format_django_directory','','Nom du répertoire de templates django à utiliser en affichage de notice.\nLaisser vide pour utiliser le common.','e_aff_notice',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (906,'opac','allow_download_docnums','1','Autoriser le téléchargement des documents numériques.\n 0 : Non.\n 1 : Individuellement (un par un).\n 2 : Archive ZIP.','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (907,'opac','notices_display_modes','','Nom du fichier xml de paramétrage du choix du mode d\'affichage des notices à l\'OPAC.\nPar défaut : display_modes_exemple.xml dans /opac_css/includes/records/','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (908,'opac','url_more_about_cookies','','Lien pour en savoir plus sur l\'utilisation des cookies et des traceurs','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (909,'opac','authorities_templates_folder','./includes/templates/authorities/common','Repertoire des templates utilisés pour l\'affichage des autorités en OPAC','',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (910,'dsi','private_bannette_notices_template','0','Id du template de notice utilisé par défaut en diffusion de bannettes privées. Si vide ou à 0, le template classique est utilisé.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (911,'cms','active_image_cache','0','Activer la mise en cache des vignettes du contenu éditorial.\n 0: non \n 1:Oui \nAttention, si l\'OPAC ne se trouve pas sur le même serveur que la gestion, la purge du cache ne peut pas se faire automatiquement','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (912,'opac','empr_password_salt','','Phrase pour le hashage des mots de passe emprunteurs','a_general',1);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (913,'pmb','notices_show_dates','0','Afficher les dates des notices ? \n 0 : Aucune date.\n 1 : Date de création et modification.','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (914,'opac','compress_css','0','Activer la compilation et la compression des feuilles de styles.\n0: Non\n1: Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (915,'pmb','resa_planning_toresa','10','Délai d\'alerte pour le transfert des prévisions en réservations (en jours). ','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (916,'pmb','serialcirc_simple_print_script','','Script de construction d\'étiquette de circulation simplifiée de périodique','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (917,'opac','max_results_on_a_page','500','Nombre maximum de notices à afficher sur une page, utile notamment quand la navigation est désactivée','d_aff_recherche',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (918,'pmb','mail_adresse_from','','Adresse d\'expédition des emails. Ce paramètre permet de forcer le From des mails envoyés par PMB. Le reply-to reste inchangé (mail de l\'utilisateur en DSI ou relance, mail de la localisation ou paramètre opac_biblio_mail à défaut).\nFormat : adresse_email;libellé\nExemple : pmb@sigb.net;PMB Services','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (919,'opac','mail_adresse_from','','Adresse d\'expédition des emails. Ce paramètre permet de forcer le From des mails envoyés par PMB. Le reply-to reste inchangé (mail de l\'utilisateur en DSI ou relance, mail de la localisation ou paramètre opac_biblio_mail à défaut).\nFormat : adresse_email;libellé\nExemple : pmb@sigb.net;PMB Services','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (920,'opac','pret_prolongation_blocage','0','Bloquer la prolongation s\'il y a un niveau de relance validé sur le prêt ?\n0 : Non 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (921,'opac','empr_export_loans','0','Afficher sur le compte emprunteur un bouton permettant d\'exporter les prêts dans un tableur ?\n0 : Non 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (922,'opac','cookies_consent','1','Afficher le bandeau d\'acceptation des cookies et des traceurs ? \n0 : Non 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (923,'pmb','collstate_data','','Colonne des états des collections, dans l\'ordre donné, séparé par des virgules : location_libelle,emplacement_libelle,cote,type_libelle,statut_opac_libelle,origine,state_collections,archive,lacune,surloc_libelle,note,#n : id des champs personnalisés\nLes valeurs possibles sont les propriétés de la classe PHP \"pmb/classes/collstate.class.php\".','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (924,'opac','quick_access','1','Activer le sélecteur d\'accès rapide ? \n0 : Non 1 : Oui','a_general',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (925,'pmb','resa_alert_localized','0','Si les lecteurs sont localisés, restreindre les notifications par email des nouvelles réservations aux utilisateurs selon le site de gestion des lecteurs par défaut ? \n0 : Non 1 : Oui','',0);
INSERT INTO parametres (id_param, type_param, sstype_param, valeur_param, comment_param, section_param, gestion) VALUES (926,'pmb','catalog_verif_js_integration','','Script de vérification de saisie de notice en intégration','',0);
/*!40000 ALTER TABLE parametres ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pclassement`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pclassement (
  id_pclass int(10) unsigned NOT NULL AUTO_INCREMENT,
  name_pclass varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  typedoc varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_pclass)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pclassement`
--

LOCK TABLES pclassement WRITE;
/*!40000 ALTER TABLE pclassement DISABLE KEYS */;
INSERT INTO pclassement (id_pclass, name_pclass, typedoc) VALUES (1,'Dewey 100','abcdefgijklmr');
/*!40000 ALTER TABLE pclassement ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `perio_relance`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE perio_relance (
  rel_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  rel_abt_num int(10) unsigned NOT NULL DEFAULT '0',
  rel_date_parution date NOT NULL DEFAULT '0000-00-00',
  rel_libelle_numero varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  rel_comment_gestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  rel_comment_opac mediumtext COLLATE utf8_unicode_ci NOT NULL,
  rel_nb int(10) unsigned NOT NULL DEFAULT '0',
  rel_date date NOT NULL DEFAULT '0000-00-00',
  PRIMARY KEY (rel_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `perio_relance`
--

LOCK TABLES perio_relance WRITE;
/*!40000 ALTER TABLE perio_relance DISABLE KEYS */;
/*!40000 ALTER TABLE perio_relance ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `planificateur`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE planificateur (
  id_planificateur int(11) unsigned NOT NULL AUTO_INCREMENT,
  num_type_tache int(11) NOT NULL,
  libelle_tache varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  desc_tache varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  num_user int(11) NOT NULL,
  param mediumtext COLLATE utf8_unicode_ci,
  statut tinyint(1) unsigned DEFAULT '0',
  rep_upload int(8) DEFAULT NULL,
  path_upload mediumtext COLLATE utf8_unicode_ci,
  perio_heure varchar(28) COLLATE utf8_unicode_ci DEFAULT NULL,
  perio_minute varchar(28) COLLATE utf8_unicode_ci DEFAULT '01',
  perio_jour_mois varchar(128) COLLATE utf8_unicode_ci DEFAULT '*',
  perio_jour varchar(128) COLLATE utf8_unicode_ci DEFAULT NULL,
  perio_mois varchar(128) COLLATE utf8_unicode_ci DEFAULT NULL,
  calc_next_heure_deb varchar(28) COLLATE utf8_unicode_ci DEFAULT NULL,
  calc_next_date_deb date DEFAULT NULL,
  PRIMARY KEY (id_planificateur)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `planificateur`
--

LOCK TABLES planificateur WRITE;
/*!40000 ALTER TABLE planificateur DISABLE KEYS */;
/*!40000 ALTER TABLE planificateur ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pret`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pret (
  pret_idempr int(10) unsigned NOT NULL DEFAULT '0',
  pret_idexpl int(10) unsigned NOT NULL DEFAULT '0',
  pret_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  pret_retour date DEFAULT NULL,
  pret_arc_id int(10) unsigned NOT NULL DEFAULT '0',
  niveau_relance int(1) NOT NULL DEFAULT '0',
  date_relance date DEFAULT '0000-00-00',
  printed int(1) NOT NULL DEFAULT '0',
  retour_initial date DEFAULT '0000-00-00',
  cpt_prolongation int(1) NOT NULL DEFAULT '0',
  pret_temp varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  short_loan_flag int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (pret_idexpl),
  KEY i_pret_idempr (pret_idempr),
  KEY i_pret_arc_id (pret_arc_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pret`
--

LOCK TABLES pret WRITE;
/*!40000 ALTER TABLE pret DISABLE KEYS */;
INSERT INTO pret (pret_idempr, pret_idexpl, pret_date, pret_retour, pret_arc_id, niveau_relance, date_relance, printed, retour_initial, cpt_prolongation, pret_temp, short_loan_flag) VALUES (10,50,'2012-11-20 09:32:13','2013-01-22',2,0,'0000-00-00',0,'2012-12-11',2,'',0);
INSERT INTO pret (pret_idempr, pret_idexpl, pret_date, pret_retour, pret_arc_id, niveau_relance, date_relance, printed, retour_initial, cpt_prolongation, pret_temp, short_loan_flag) VALUES (10,65,'2012-11-20 09:32:31','2013-01-01',3,0,'0000-00-00',0,'2012-12-11',1,'',0);
INSERT INTO pret (pret_idempr, pret_idexpl, pret_date, pret_retour, pret_arc_id, niveau_relance, date_relance, printed, retour_initial, cpt_prolongation, pret_temp, short_loan_flag) VALUES (7,94,'2012-11-20 09:33:31','2013-01-01',4,0,'0000-00-00',0,'2012-12-11',1,'',0);
INSERT INTO pret (pret_idempr, pret_idexpl, pret_date, pret_retour, pret_arc_id, niveau_relance, date_relance, printed, retour_initial, cpt_prolongation, pret_temp, short_loan_flag) VALUES (7,90,'2012-11-20 09:34:17','2012-12-11',5,0,'0000-00-00',0,'2012-12-11',0,'',0);
INSERT INTO pret (pret_idempr, pret_idexpl, pret_date, pret_retour, pret_arc_id, niveau_relance, date_relance, printed, retour_initial, cpt_prolongation, pret_temp, short_loan_flag) VALUES (1,53,'2012-11-20 09:34:36','2012-12-11',6,0,'0000-00-00',0,'2012-12-11',0,'',0);
/*!40000 ALTER TABLE pret ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pret_archive`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pret_archive (
  arc_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  arc_debut datetime DEFAULT '0000-00-00 00:00:00',
  arc_fin datetime DEFAULT NULL,
  arc_id_empr int(10) unsigned NOT NULL DEFAULT '0',
  arc_empr_cp varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  arc_empr_ville varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  arc_empr_prof varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  arc_empr_year int(4) unsigned DEFAULT '0',
  arc_empr_categ smallint(5) unsigned DEFAULT '0',
  arc_empr_codestat smallint(5) unsigned DEFAULT '0',
  arc_empr_sexe tinyint(3) unsigned DEFAULT '0',
  arc_empr_statut int(10) unsigned NOT NULL DEFAULT '1',
  arc_empr_location int(6) unsigned NOT NULL DEFAULT '0',
  arc_type_abt int(6) unsigned NOT NULL DEFAULT '0',
  arc_expl_typdoc int(5) unsigned DEFAULT '0',
  arc_expl_cote varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  arc_expl_statut smallint(5) unsigned DEFAULT '0',
  arc_expl_location smallint(5) unsigned DEFAULT '0',
  arc_expl_location_origine int(10) unsigned NOT NULL DEFAULT '0',
  arc_expl_location_retour int(10) unsigned NOT NULL DEFAULT '0',
  arc_expl_codestat smallint(5) unsigned DEFAULT '0',
  arc_expl_owner mediumint(8) unsigned DEFAULT '0',
  arc_expl_section int(5) unsigned NOT NULL DEFAULT '0',
  arc_expl_id int(10) unsigned NOT NULL DEFAULT '0',
  arc_expl_notice int(10) unsigned NOT NULL DEFAULT '0',
  arc_expl_bulletin int(10) unsigned NOT NULL DEFAULT '0',
  arc_groupe varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  arc_niveau_relance int(1) unsigned DEFAULT '0',
  arc_date_relance date NOT NULL DEFAULT '0000-00-00',
  arc_printed int(1) unsigned DEFAULT '0',
  arc_cpt_prolongation int(1) unsigned DEFAULT '0',
  arc_short_loan_flag int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (arc_id),
  KEY i_pa_expl_id (arc_expl_id),
  KEY i_pa_idempr (arc_id_empr),
  KEY i_pa_expl_notice (arc_expl_notice),
  KEY i_pa_expl_bulletin (arc_expl_bulletin),
  KEY i_pa_arc_fin (arc_fin),
  KEY i_pa_arc_empr_categ (arc_empr_categ),
  KEY i_pa_arc_expl_location (arc_expl_location)
) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pret_archive`
--

LOCK TABLES pret_archive WRITE;
/*!40000 ALTER TABLE pret_archive DISABLE KEYS */;
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (1,'2012-08-05 16:00:57','2012-10-24 10:47:37',0,'','','',0,7,2,0,1,1,0,1,'RK ROB',1,1,0,0,12,2,10,30,53,0,'',0,'0000-00-00',0,1,0);
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (2,'2012-11-20 09:32:13','2012-12-11 00:00:00',0,'72500','CHATEAU DU LOIR','Formatrice',1985,7,3,2,1,1,0,1,'P BUR',1,1,0,0,12,2,10,50,106,0,'',0,'0000-00-00',0,0,0);
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (3,'2012-11-20 09:32:31','2012-12-11 00:00:00',0,'72500','CHATEAU DU LOIR','Formatrice',1985,7,3,2,1,1,0,1,'BD J GUE',1,1,0,0,11,1,20,65,92,0,'',0,'0000-00-00',0,0,0);
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (4,'2012-11-20 09:33:31','2012-12-11 00:00:00',0,'72500','CHATEAU DU LOIR','Développeur PMB',1972,7,3,1,1,1,0,18,'PER GEO',1,1,0,0,12,2,31,94,0,5,'',0,'0000-00-00',0,0,0);
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (5,'2012-11-20 09:34:17','2012-12-11 00:00:00',0,'72500','CHATEAU DU LOIR','Développeur PMB',1972,7,3,1,1,1,0,1,'960 DEP',1,1,0,0,12,1,10,90,71,0,'',0,'0000-00-00',0,0,0);
INSERT INTO pret_archive (arc_id, arc_debut, arc_fin, arc_id_empr, arc_empr_cp, arc_empr_ville, arc_empr_prof, arc_empr_year, arc_empr_categ, arc_empr_codestat, arc_empr_sexe, arc_empr_statut, arc_empr_location, arc_type_abt, arc_expl_typdoc, arc_expl_cote, arc_expl_statut, arc_expl_location, arc_expl_location_origine, arc_expl_location_retour, arc_expl_codestat, arc_expl_owner, arc_expl_section, arc_expl_id, arc_expl_notice, arc_expl_bulletin, arc_groupe, arc_niveau_relance, arc_date_relance, arc_printed, arc_cpt_prolongation, arc_short_loan_flag) VALUES (6,'2012-11-20 09:34:36','2012-12-11 00:00:00',0,'01000','StarwarsTown','Pilote',1900,8,4,1,1,1,0,1,'RX BRA',1,1,0,0,12,2,24,53,103,0,'',0,'0000-00-00',0,0,0);
/*!40000 ALTER TABLE pret_archive ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pret_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pret_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  filters int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pret_custom`
--

LOCK TABLES pret_custom WRITE;
/*!40000 ALTER TABLE pret_custom DISABLE KEYS */;
/*!40000 ALTER TABLE pret_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pret_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pret_custom_lists (
  pret_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  pret_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  pret_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY i_pret_custom_champ (pret_custom_champ),
  KEY i_pret_champ_list_value (pret_custom_champ,pret_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pret_custom_lists`
--

LOCK TABLES pret_custom_lists WRITE;
/*!40000 ALTER TABLE pret_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE pret_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pret_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE pret_custom_values (
  pret_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  pret_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  pret_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  pret_custom_text text COLLATE utf8_unicode_ci,
  pret_custom_integer int(11) DEFAULT NULL,
  pret_custom_date date DEFAULT NULL,
  pret_custom_float float DEFAULT NULL,
  KEY i_pret_custom_champ (pret_custom_champ),
  KEY i_pret_custom_origine (pret_custom_origine)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pret_custom_values`
--

LOCK TABLES pret_custom_values WRITE;
/*!40000 ALTER TABLE pret_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE pret_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `procs`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE procs (
  idproc smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  requete blob NOT NULL,
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  autorisations longtext COLLATE utf8_unicode_ci,
  parameters mediumtext COLLATE utf8_unicode_ci,
  num_classement int(5) unsigned NOT NULL DEFAULT '0',
  proc_notice_tpl int(2) unsigned NOT NULL DEFAULT '0',
  proc_notice_tpl_field varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (idproc),
  KEY idproc (idproc)
) ENGINE=MyISAM AUTO_INCREMENT=29 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `procs`
--

LOCK TABLES procs WRITE;
/*!40000 ALTER TABLE procs DISABLE KEYS */;
/*!40000 ALTER TABLE procs ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `procs_classements`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE procs_classements (
  idproc_classement smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  libproc_classement varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (idproc_classement)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `procs_classements`
--

LOCK TABLES procs_classements WRITE;
/*!40000 ALTER TABLE procs_classements DISABLE KEYS */;
INSERT INTO procs_classements (idproc_classement, libproc_classement) VALUES (1,'Statistiques collections');
INSERT INTO procs_classements (idproc_classement, libproc_classement) VALUES (2,'Statistiques lecteurs');
INSERT INTO procs_classements (idproc_classement, libproc_classement) VALUES (3,'Statistiques prêts');
INSERT INTO procs_classements (idproc_classement, libproc_classement) VALUES (4,'Listes');
/*!40000 ALTER TABLE procs_classements ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `publisher_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE publisher_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `publisher_custom`
--

LOCK TABLES publisher_custom WRITE;
/*!40000 ALTER TABLE publisher_custom DISABLE KEYS */;
/*!40000 ALTER TABLE publisher_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `publisher_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE publisher_custom_lists (
  publisher_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  publisher_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  publisher_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (publisher_custom_champ),
  KEY editorial_champ_list_value (publisher_custom_champ,publisher_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `publisher_custom_lists`
--

LOCK TABLES publisher_custom_lists WRITE;
/*!40000 ALTER TABLE publisher_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE publisher_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `publisher_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE publisher_custom_values (
  publisher_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  publisher_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  publisher_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  publisher_custom_text text COLLATE utf8_unicode_ci,
  publisher_custom_integer int(11) DEFAULT NULL,
  publisher_custom_date date DEFAULT NULL,
  publisher_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (publisher_custom_champ),
  KEY editorial_custom_origine (publisher_custom_origine),
  KEY i_pcv_st (publisher_custom_small_text),
  KEY i_pcv_t (publisher_custom_text(255)),
  KEY i_pcv_i (publisher_custom_integer),
  KEY i_pcv_d (publisher_custom_date),
  KEY i_pcv_f (publisher_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `publisher_custom_values`
--

LOCK TABLES publisher_custom_values WRITE;
/*!40000 ALTER TABLE publisher_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE publisher_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `publishers`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE publishers (
  ed_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  ed_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_adr1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_adr2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_cp varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_ville varchar(96) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_pays varchar(96) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ed_web varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_publisher mediumtext COLLATE utf8_unicode_ci,
  ed_comment mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (ed_id),
  KEY ed_name (ed_name),
  KEY ed_ville (ed_ville)
) ENGINE=MyISAM AUTO_INCREMENT=55 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `publishers`
--

LOCK TABLES publishers WRITE;
/*!40000 ALTER TABLE publishers DISABLE KEYS */;
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (6,'Seuil','','','','Paris','','',' seuil paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (7,'les Éd. du Toucan','','','','[Issy-les-Moulineaux]','','',' les ed du toucan issy les moulineaux ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (8,'Hazan','','','','[Vanves]','','',' hazan vanves ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (9,'Didier jeunesse','','','','Paris','','',' didier jeunesse paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (11,'Pastel','','','','[Bruxelles]','','',' pastel bruxelles ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (12,'l\'école des loisirs','','','','Paris','','',' l ecole des loisirs paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (13,'Gallimard','','','','Paris','','',' gallimard paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (14,'Serpent à plumes','','','','Paris','','',' serpent a plumes paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (15,'Vents d\'ailleurs','','','','La Roque-d\'Anthéron','','',' vents d ailleurs la roque d antheron ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (16,'Kaléidoscope','','','','Paris','','',' kaleidoscope paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (17,'Hachette Jeunesse','','','','','','',' hachette jeunesse ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (18,'Circonflexe','','','','[Paris]','','',' circonflexe paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (19,'l\'Oeil neuf éd.','','','','Paris','','',' l oeil neuf ed paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (20,'Éd. du Cercle de la librairie','','','','[Paris]','','',' ed du cercle de la librairie paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (21,'Presses universitaires de France','','','','Paris','','',' presses universitaires de france paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (22,'Casterman','','','','','','',' casterman ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (23,'Gallimard jeunesse','','','','[Paris]','','',' gallimard jeunesse paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (24,'Denoël','','','','[Paris]','','',' denoel paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (25,'Éd. First','','','','Paris','','',' ed first paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (26,'Milan','','','','Toulouse','','',' milan toulouse ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (27,'Éd. du Rouergue','','','','Rodez','','',' ed du rouergue rodez ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (28,'Gallimard jeunesse - Giboulées','','','','[Paris]','','',' gallimard jeunesse giboulees paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (29,'Nathan','','','','','','',' nathan ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (30,'Éd. Lito','','','','Champigny-sur-Marne','','',' ed lito champigny sur marne ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (31,'Rue du monde','','','','[Voisins-le-Bretonneux]','','',' rue du monde voisins le bretonneux ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (32,'Mila éd.','','','','[Paris]','','',' mila ed paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (33,'l\'École des loisirs-Loulou & Cie','','','','Paris','','',' l ecole des loisirs loulou cie paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (34,'l\'Atalante','','','','Nantes','','',' l atalante nantes ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (35,'10-18','','','','','','',' 10 18 ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (36,'Arola','','','','','','',' arola ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (37,'Cah cinema','','','','','','',' cah cinema ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (38,'Gallimard Jeunesse Musique','','','','','','',' gallimard jeunesse musique ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (39,'Twentieth century Fox','','','','Paris','','',' twentieth century fox paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (40,'Warner home video','','','','Neuilly-sur-Seine','','',' warner home video neuilly sur seine ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (41,'Columbia Tristar home video','','','','Boulogne-Billancourt','','',' columbia tristar home video boulogne billancourt ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (42,'Manteca','','','','','','',' manteca ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (43,'AZ','','','','Paris','','',' az paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (44,'Universal music jazz France','','','','','','',' universal music jazz france ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (45,'Universal Polydor','','','','','','',' universal polydor ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (46,'Because music','','','','Paris','','',' because music paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (47,'Participations éditions presse','','','','Paris','','',' participations editions presse paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (48,'ENSSIB','','','','Villeurbanne','','',' enssib villeurbanne ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (49,'Éd. Grains de sel','','','','Lyon','','',' ed grains de sel lyon ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (50,'Studio magazine','','','','Paris','','',' studio magazine paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (51,'Garnier frères','','','','Paris','','',' garnier freres paris ','');
INSERT INTO publishers (ed_id, ed_name, ed_adr1, ed_adr2, ed_cp, ed_ville, ed_pays, ed_web, index_publisher, ed_comment) VALUES (52,'Poulet-Malassis et De Broise','','','','Paris','','',' poulet malassis et de broise paris ','');
/*!40000 ALTER TABLE publishers ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `quotas`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE quotas (
  quota_type int(10) unsigned NOT NULL DEFAULT '0',
  constraint_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  elements int(10) unsigned NOT NULL DEFAULT '0',
  `value` float DEFAULT NULL,
  PRIMARY KEY (quota_type,constraint_type,elements)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `quotas`
--

LOCK TABLES quotas WRITE;
/*!40000 ALTER TABLE quotas DISABLE KEYS */;
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'MAX',0,10);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'DEFAULT',0,5);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'FORCE_LEND',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'MAX_QUOTA',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'PRIORITY',17,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'PRIORITY',3,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'PRIORITY',1,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (1,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'MAX',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'MAX',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'DEFAULT',0,21);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'PRIORITY',17,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'PRIORITY',3,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'PRIORITY',1,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (2,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'DEFAULT',0,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'FORCE_LEND',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'PRIORITY',17,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'PRIORITY',3,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'PRIORITY',1,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (64,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'MAX',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'DEFAULT',0,21);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'PRIORITY',17,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'PRIORITY',3,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'PRIORITY',1,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (128,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'MAX',0,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'DEFAULT',0,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'FORCE_LEND',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'MAX_QUOTA',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'PRIORITY',20,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'PRIORITY',6,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'PRIORITY',4,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (4,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'MAX',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'DEFAULT',0,7);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'PRIORITY',20,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'PRIORITY',6,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'PRIORITY',4,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (8,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'MAX',0,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'DEFAULT',0,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'FORCE_LEND',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'MAX_QUOTA',0,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'PRIORITY',24,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'PRIORITY',10,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'PRIORITY',8,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (16,'PRIORITY',2,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'MAX',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'MIN',0,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'DEFAULT',0,7);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'CONFLICT',0,4);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'PRIORITY',24,0);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'PRIORITY',16,1);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'PRIORITY',10,2);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'PRIORITY',8,3);
INSERT INTO quotas (quota_type, constraint_type, elements, value) VALUES (32,'PRIORITY',2,4);
/*!40000 ALTER TABLE quotas ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `quotas_finance`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE quotas_finance (
  quota_type int(10) unsigned NOT NULL DEFAULT '0',
  constraint_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  elements int(10) unsigned NOT NULL DEFAULT '0',
  `value` float DEFAULT NULL,
  PRIMARY KEY (quota_type,constraint_type,elements)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `quotas_finance`
--

LOCK TABLES quotas_finance WRITE;
/*!40000 ALTER TABLE quotas_finance DISABLE KEYS */;
/*!40000 ALTER TABLE quotas_finance ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `quotas_opac_views`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE quotas_opac_views (
  quota_type int(10) unsigned NOT NULL DEFAULT '0',
  constraint_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  elements int(10) unsigned NOT NULL DEFAULT '0',
  `value` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (quota_type,constraint_type,elements)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `quotas_opac_views`
--

LOCK TABLES quotas_opac_views WRITE;
/*!40000 ALTER TABLE quotas_opac_views DISABLE KEYS */;
/*!40000 ALTER TABLE quotas_opac_views ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rapport_demandes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rapport_demandes (
  id_item int(10) unsigned NOT NULL AUTO_INCREMENT,
  contenu mediumtext COLLATE utf8_unicode_ci NOT NULL,
  num_note int(10) NOT NULL DEFAULT '0',
  num_demande int(10) NOT NULL DEFAULT '0',
  ordre mediumint(3) NOT NULL DEFAULT '0',
  `type` mediumint(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_item)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rapport_demandes`
--

LOCK TABLES rapport_demandes WRITE;
/*!40000 ALTER TABLE rapport_demandes DISABLE KEYS */;
/*!40000 ALTER TABLE rapport_demandes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rdfstore_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rdfstore_index (
  num_triple int(10) unsigned NOT NULL DEFAULT '0',
  subject_uri text CHARACTER SET utf8 NOT NULL,
  subject_type text COLLATE utf8_unicode_ci NOT NULL,
  predicat_uri text CHARACTER SET utf8 NOT NULL,
  num_object int(10) unsigned NOT NULL DEFAULT '0',
  object_val text CHARACTER SET utf8 NOT NULL,
  object_index text CHARACTER SET utf8 NOT NULL,
  object_lang char(5) CHARACTER SET utf8 NOT NULL DEFAULT '',
  PRIMARY KEY (num_object)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rdfstore_index`
--

LOCK TABLES rdfstore_index WRITE;
/*!40000 ALTER TABLE rdfstore_index DISABLE KEYS */;
/*!40000 ALTER TABLE rdfstore_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `recouvrements`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE recouvrements (
  recouvr_id int(16) unsigned NOT NULL AUTO_INCREMENT,
  empr_id int(10) unsigned NOT NULL DEFAULT '0',
  id_expl int(10) unsigned NOT NULL DEFAULT '0',
  date_rec date NOT NULL DEFAULT '0000-00-00',
  libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  montant decimal(16,2) DEFAULT '0.00',
  recouvr_type int(2) unsigned NOT NULL DEFAULT '0',
  date_pret datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_relance1 datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_relance2 datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_relance3 datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (recouvr_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `recouvrements`
--

LOCK TABLES recouvrements WRITE;
/*!40000 ALTER TABLE recouvrements DISABLE KEYS */;
/*!40000 ALTER TABLE recouvrements ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resa`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE resa (
  id_resa mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  resa_idempr int(10) unsigned NOT NULL DEFAULT '0',
  resa_idnotice mediumint(8) unsigned NOT NULL DEFAULT '0',
  resa_idbulletin int(8) unsigned NOT NULL DEFAULT '0',
  resa_date datetime DEFAULT NULL,
  resa_date_debut date NOT NULL DEFAULT '0000-00-00',
  resa_date_fin date NOT NULL DEFAULT '0000-00-00',
  resa_cb varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resa_confirmee int(1) unsigned NOT NULL DEFAULT '0',
  resa_loc_retrait smallint(5) unsigned NOT NULL DEFAULT '0',
  resa_arc int(10) unsigned NOT NULL DEFAULT '0',
  resa_planning_id_resa int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_resa),
  KEY resa_date_fin (resa_date_fin),
  KEY resa_date (resa_date),
  KEY resa_cb (resa_cb),
  KEY i_idbulletin (resa_idbulletin),
  KEY i_idnotice (resa_idnotice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resa`
--

LOCK TABLES resa WRITE;
/*!40000 ALTER TABLE resa DISABLE KEYS */;
/*!40000 ALTER TABLE resa ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resa_archive`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE resa_archive (
  resarc_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  resarc_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  resarc_debut date NOT NULL DEFAULT '0000-00-00',
  resarc_fin date NOT NULL DEFAULT '0000-00-00',
  resarc_idnotice int(10) unsigned NOT NULL DEFAULT '0',
  resarc_idbulletin int(10) unsigned NOT NULL DEFAULT '0',
  resarc_confirmee int(1) unsigned DEFAULT '0',
  resarc_cb varchar(14) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resarc_loc_retrait smallint(5) unsigned DEFAULT '0',
  resarc_from_opac int(1) unsigned DEFAULT '0',
  resarc_anulee int(1) unsigned DEFAULT '0',
  resarc_pretee int(1) unsigned DEFAULT '0',
  resarc_arcpretid int(10) unsigned NOT NULL DEFAULT '0',
  resarc_id_empr int(10) unsigned NOT NULL DEFAULT '0',
  resarc_empr_cp varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resarc_empr_ville varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resarc_empr_prof varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resarc_empr_year int(4) unsigned DEFAULT '0',
  resarc_empr_categ smallint(5) unsigned DEFAULT '0',
  resarc_empr_codestat smallint(5) unsigned DEFAULT '0',
  resarc_empr_sexe tinyint(3) unsigned DEFAULT '0',
  resarc_empr_location int(6) unsigned NOT NULL DEFAULT '1',
  resarc_expl_nb int(5) unsigned DEFAULT '0',
  resarc_expl_typdoc int(5) unsigned DEFAULT '0',
  resarc_expl_cote varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  resarc_expl_statut smallint(5) unsigned DEFAULT '0',
  resarc_expl_location smallint(5) unsigned DEFAULT '0',
  resarc_expl_codestat smallint(5) unsigned DEFAULT '0',
  resarc_expl_owner mediumint(8) unsigned DEFAULT '0',
  resarc_expl_section int(5) unsigned NOT NULL DEFAULT '0',
  resarc_resa_planning_id_resa int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (resarc_id),
  KEY i_pa_idempr (resarc_id_empr),
  KEY i_pa_notice (resarc_idnotice),
  KEY i_pa_bulletin (resarc_idbulletin),
  KEY i_pa_resarc_date (resarc_date)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resa_archive`
--

LOCK TABLES resa_archive WRITE;
/*!40000 ALTER TABLE resa_archive DISABLE KEYS */;
/*!40000 ALTER TABLE resa_archive ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resa_loc`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE resa_loc (
  resa_loc int(8) unsigned NOT NULL DEFAULT '0',
  resa_emprloc int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (resa_loc,resa_emprloc),
  KEY i_resa_emprloc (resa_emprloc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resa_loc`
--

LOCK TABLES resa_loc WRITE;
/*!40000 ALTER TABLE resa_loc DISABLE KEYS */;
/*!40000 ALTER TABLE resa_loc ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resa_planning`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE resa_planning (
  id_resa mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  resa_idempr mediumint(8) unsigned NOT NULL DEFAULT '0',
  resa_idnotice mediumint(8) unsigned NOT NULL DEFAULT '0',
  resa_idbulletin int(8) unsigned NOT NULL DEFAULT '0',
  resa_date datetime DEFAULT NULL,
  resa_date_debut date NOT NULL DEFAULT '0000-00-00',
  resa_date_fin date NOT NULL DEFAULT '0000-00-00',
  resa_validee int(1) unsigned NOT NULL DEFAULT '0',
  resa_confirmee int(1) unsigned NOT NULL DEFAULT '0',
  resa_loc_retrait int(5) unsigned NOT NULL DEFAULT '0',
  resa_qty int(5) unsigned NOT NULL DEFAULT '1',
  resa_remaining_qty int(5) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_resa),
  KEY resa_date_fin (resa_date_fin),
  KEY resa_date (resa_date)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resa_planning`
--

LOCK TABLES resa_planning WRITE;
/*!40000 ALTER TABLE resa_planning DISABLE KEYS */;
/*!40000 ALTER TABLE resa_planning ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resa_ranger`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE resa_ranger (
  resa_cb varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (resa_cb)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resa_ranger`
--

LOCK TABLES resa_ranger WRITE;
/*!40000 ALTER TABLE resa_ranger DISABLE KEYS */;
/*!40000 ALTER TABLE resa_ranger ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `responsability`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE responsability (
  responsability_author mediumint(8) unsigned NOT NULL DEFAULT '0',
  responsability_notice mediumint(8) unsigned NOT NULL DEFAULT '0',
  responsability_fonction varchar(4) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  responsability_type mediumint(1) unsigned NOT NULL DEFAULT '0',
  responsability_ordre smallint(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (responsability_author,responsability_notice,responsability_fonction),
  KEY responsability_notice (responsability_notice)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `responsability`
--

LOCK TABLES responsability WRITE;
/*!40000 ALTER TABLE responsability DISABLE KEYS */;
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (19,73,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (15,71,'440',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (18,72,'250',2,2);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (17,72,'440',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (16,72,'070',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (13,69,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (12,68,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (14,70,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (11,68,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (20,74,'440',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (22,75,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (21,75,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (22,76,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (21,76,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (23,77,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (26,78,'730',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (25,78,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (24,78,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (27,79,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (29,80,'',1,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (28,80,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (30,81,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (31,82,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (33,83,'651',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (32,83,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (34,84,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (35,85,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (37,86,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (36,86,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (41,87,'730',2,2);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (40,87,'730',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (39,87,'440',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (38,87,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (42,88,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (45,89,'440',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (44,89,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (43,89,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (46,90,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (47,91,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (48,92,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (50,93,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (49,93,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (51,94,'',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (52,95,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (53,96,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (55,97,'440',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (54,97,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (57,98,'651',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (56,98,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (59,99,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (58,99,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (59,100,'070',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (58,100,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (60,101,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (27,102,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (63,103,'730',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (62,103,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (61,103,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (65,104,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (64,104,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (65,105,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (64,105,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,106,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (68,108,'',1,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (69,109,'440',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (71,110,'',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (70,110,'005',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,110,'300',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (72,111,'005',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,111,'300',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (73,112,'0',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,112,'300',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,113,'300',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (70,114,'005',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (66,114,'300',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (74,115,'590',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (75,116,'590',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (76,117,'590',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (77,118,'590',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (78,119,'590',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (79,124,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (80,125,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (81,126,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (82,127,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (83,128,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (84,132,'651',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (88,135,'070',2,2);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (87,135,'440',2,1);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (86,135,'730',2,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (85,135,'070',0,0);
INSERT INTO responsability (responsability_author, responsability_notice, responsability_fonction, responsability_type, responsability_ordre) VALUES (89,136,'070',0,0);
/*!40000 ALTER TABLE responsability ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `responsability_tu`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE responsability_tu (
  responsability_tu_author_num int(10) unsigned NOT NULL DEFAULT '0',
  responsability_tu_num int(10) unsigned NOT NULL DEFAULT '0',
  responsability_tu_fonction char(4) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  responsability_tu_type int(10) unsigned NOT NULL DEFAULT '0',
  responsability_tu_ordre smallint(2) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (responsability_tu_author_num,responsability_tu_num,responsability_tu_fonction),
  KEY responsability_tu_author (responsability_tu_author_num),
  KEY responsability_tu_num (responsability_tu_num)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `responsability_tu`
--

LOCK TABLES responsability_tu WRITE;
/*!40000 ALTER TABLE responsability_tu DISABLE KEYS */;
/*!40000 ALTER TABLE responsability_tu ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rss_content`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rss_content (
  rss_id int(10) unsigned NOT NULL DEFAULT '0',
  rss_content longblob NOT NULL,
  rss_content_parse longblob NOT NULL,
  rss_last timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (rss_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rss_content`
--

LOCK TABLES rss_content WRITE;
/*!40000 ALTER TABLE rss_content DISABLE KEYS */;
INSERT INTO rss_content (rss_id, rss_content, rss_content_parse, rss_last) VALUES (120, , ,'2012-10-25 07:29:11');
/*!40000 ALTER TABLE rss_content ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rss_flux`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rss_flux (
  id_rss_flux int(9) unsigned NOT NULL AUTO_INCREMENT,
  nom_rss_flux varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  link_rss_flux blob NOT NULL,
  descr_rss_flux blob NOT NULL,
  lang_rss_flux varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'fr',
  copy_rss_flux blob NOT NULL,
  editor_rss_flux varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  webmaster_rss_flux varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ttl_rss_flux int(9) unsigned NOT NULL DEFAULT '60',
  img_url_rss_flux blob NOT NULL,
  img_title_rss_flux blob NOT NULL,
  img_link_rss_flux blob NOT NULL,
  format_flux blob NOT NULL,
  rss_flux_content longblob NOT NULL,
  rss_flux_last timestamp NOT NULL DEFAULT '0000-00-00 00:00:00',
  export_court_flux tinyint(1) unsigned NOT NULL DEFAULT '0',
  tpl_rss_flux int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_rss_flux)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rss_flux`
--

LOCK TABLES rss_flux WRITE;
/*!40000 ALTER TABLE rss_flux DISABLE KEYS */;
/*!40000 ALTER TABLE rss_flux ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rss_flux_content`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rss_flux_content (
  num_rss_flux int(9) unsigned NOT NULL DEFAULT '0',
  type_contenant char(3) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'BAN',
  num_contenant int(9) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (num_rss_flux,type_contenant,num_contenant)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rss_flux_content`
--

LOCK TABLES rss_flux_content WRITE;
/*!40000 ALTER TABLE rss_flux_content DISABLE KEYS */;
/*!40000 ALTER TABLE rss_flux_content ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `rubriques`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE rubriques (
  id_rubrique int(8) unsigned NOT NULL AUTO_INCREMENT,
  num_budget int(8) unsigned NOT NULL DEFAULT '0',
  num_parent int(8) unsigned NOT NULL DEFAULT '0',
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  commentaires mediumtext COLLATE utf8_unicode_ci NOT NULL,
  montant float(8,2) unsigned NOT NULL DEFAULT '0.00',
  num_cp_compta varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  autorisations longtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_rubrique)
) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `rubriques`
--

LOCK TABLES rubriques WRITE;
/*!40000 ALTER TABLE rubriques DISABLE KEYS */;
/*!40000 ALTER TABLE rubriques ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sauv_lieux`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sauv_lieux (
  sauv_lieu_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sauv_lieu_nom varchar(50) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_lieu_url varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_lieu_protocol varchar(10) COLLATE utf8_unicode_ci DEFAULT 'file',
  sauv_lieu_host varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_lieu_login varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_lieu_password varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (sauv_lieu_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sauv_lieux`
--

LOCK TABLES sauv_lieux WRITE;
/*!40000 ALTER TABLE sauv_lieux DISABLE KEYS */;
/*!40000 ALTER TABLE sauv_lieux ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sauv_log`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sauv_log (
  sauv_log_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sauv_log_start_date date DEFAULT NULL,
  sauv_log_file varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_log_succeed int(11) DEFAULT '0',
  sauv_log_messages longtext COLLATE utf8_unicode_ci,
  sauv_log_userid int(11) DEFAULT NULL,
  PRIMARY KEY (sauv_log_id)
) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sauv_log`
--

LOCK TABLES sauv_log WRITE;
/*!40000 ALTER TABLE sauv_log DISABLE KEYS */;
/*!40000 ALTER TABLE sauv_log ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sauv_sauvegardes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sauv_sauvegardes (
  sauv_sauvegarde_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sauv_sauvegarde_nom varchar(50) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_sauvegarde_file_prefix varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_sauvegarde_tables longtext COLLATE utf8_unicode_ci,
  sauv_sauvegarde_lieux longtext COLLATE utf8_unicode_ci,
  sauv_sauvegarde_users longtext COLLATE utf8_unicode_ci,
  sauv_sauvegarde_compress int(11) DEFAULT '0',
  sauv_sauvegarde_compress_command longtext COLLATE utf8_unicode_ci,
  sauv_sauvegarde_crypt int(11) DEFAULT '0',
  sauv_sauvegarde_key1 varchar(32) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_sauvegarde_key2 varchar(32) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (sauv_sauvegarde_id)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sauv_sauvegardes`
--

LOCK TABLES sauv_sauvegardes WRITE;
/*!40000 ALTER TABLE sauv_sauvegardes DISABLE KEYS */;
INSERT INTO sauv_sauvegardes (sauv_sauvegarde_id, sauv_sauvegarde_nom, sauv_sauvegarde_file_prefix, sauv_sauvegarde_tables, sauv_sauvegarde_lieux, sauv_sauvegarde_users, sauv_sauvegarde_compress, sauv_sauvegarde_compress_command, sauv_sauvegarde_crypt, sauv_sauvegarde_key1, sauv_sauvegarde_key2) VALUES (1,'tout','full','1','','1',0,'internal::',0,'','');
/*!40000 ALTER TABLE sauv_sauvegardes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sauv_tables`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sauv_tables (
  sauv_table_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sauv_table_nom varchar(50) COLLATE utf8_unicode_ci DEFAULT NULL,
  sauv_table_tables mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (sauv_table_id),
  UNIQUE KEY sauv_table_nom (sauv_table_nom)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sauv_tables`
--

LOCK TABLES sauv_tables WRITE;
/*!40000 ALTER TABLE sauv_tables DISABLE KEYS */;
INSERT INTO sauv_tables (sauv_table_id, sauv_table_nom, sauv_table_tables) VALUES (1,'TOUT','abo_liste_lecture,abts_abts,abts_abts_modeles,abts_grille_abt,abts_grille_modele,abts_modeles,abts_periodicites,acces_profiles,acces_rights,actes,admin_session,analysis,arch_emplacement,arch_statut,arch_type,audit,aut_link,author_custom,author_custom_lists,author_custom_values,authorities_sources,authors,authperso,authperso_authorities,authperso_custom,authperso_custom_lists,authperso_custom_values,avis,bannette_abon,bannette_contenu,bannette_equation,bannette_exports,bannette_facettes,bannette_tpl,bannettes,bannettes_descriptors,budgets,bulletins,cache_amendes,caddie,caddie_content,caddie_procs,cashdesk,cashdesk_locations,cashdesk_sections,categ_custom,categ_custom_lists,categ_custom_values,categories,classements,cms,cms_articles,cms_articles_descriptors,cms_build,cms_cache_cadres,cms_cadre_content,cms_cadres,cms_collections,cms_documents,cms_documents_links,cms_editorial_custom,cms_editorial_custom_lists,cms_editorial_custom_values,cms_editorial_fields_global_index,cms_editorial_publications_states,cms_editorial_types,cms_editorial_words_global_index,cms_hash,cms_managed_modules,cms_modules_extensions_datas,cms_pages,cms_pages_env,cms_sections,cms_sections_descriptors,cms_vars,cms_version,collection_custom,collection_custom_lists,collection_custom_values,collections,collections_state,collstate_custom,collstate_custom_lists,collstate_custom_values,comptes,connectors,connectors_categ,connectors_categ_sources,connectors_out,connectors_out_oai_deleted_records,connectors_out_oai_tokens,connectors_out_setcache_values,connectors_out_setcaches,connectors_out_setcateg_sets,connectors_out_setcategs,connectors_out_sets,connectors_out_sources,connectors_out_sources_esgroups,connectors_sources,coordonnees,demandes,demandes_actions,demandes_custom,demandes_custom_lists,demandes_custom_values,demandes_notes,demandes_theme,demandes_type,demandes_users,docs_codestat,docs_location,docs_section,docs_statut,docs_type,docsloc_section,docwatch_categories,docwatch_datasources,docwatch_items,docwatch_items_descriptors,docwatch_items_tags,docwatch_selectors,docwatch_tags,docwatch_watches,dsi_archive,editions_states,empr,empr_caddie,empr_caddie_content,empr_caddie_procs,empr_categ,empr_codestat,empr_custom,empr_custom_lists,empr_custom_values,empr_grilles,empr_groupe,empr_statut,empty_words_calculs,entites,entrepot_source_1,entrepot_source_2,entrepot_source_3,entrepot_source_4,entrepot_source_5,entrepot_source_6,entrepot_source_7,entrepot_source_8,entrepots_localisations,equations,error_log,es_cache,es_cache_blob,es_cache_int,es_converted_cache,es_esgroup_esusers,es_esgroups,es_esusers,es_methods,es_methods_users,es_searchcache,es_searchsessions,etagere,etagere_caddie,exemplaires,exemplaires_temp,exercices,expl_custom,expl_custom_lists,expl_custom_values,explnum,explnum_doc,explnum_doc_actions,explnum_doc_sugg,explnum_location,explnum_segments,explnum_speakers,explnum_statut,external_count,facettes,faq_questions,faq_questions_categories,faq_questions_fields_global_index,faq_questions_words_global_index,faq_themes,faq_types,fiche,frais,gestfic0_custom,gestfic0_custom_lists,gestfic0_custom_values,grilles,groupe,groupexpl,groupexpl_expl,harvest_field,harvest_profil,harvest_profil_import,harvest_profil_import_field,harvest_search_field,harvest_src,import_marc,index_concept,indexint,indexint_custom,indexint_custom_lists,indexint_custom_values,infopages,lenders,liens_actes,lignes_actes,lignes_actes_relances,lignes_actes_statuts,linked_mots,log_expl_retard,log_retard,logopac,mailtpl,map_echelles,map_emprises,map_hold_areas,map_projections,map_refs,mots,noeuds,nomenclature_children_records,nomenclature_exotic_instruments,nomenclature_exotic_other_instruments,nomenclature_families,nomenclature_formations,nomenclature_instruments,nomenclature_musicstands,nomenclature_notices_nomenclatures,nomenclature_types,nomenclature_voices,nomenclature_workshops,nomenclature_workshops_instruments,notice_onglet,notice_statut,notice_tpl,notice_tplcode,notices,notices_authorities_sources,notices_authperso,notices_categories,notices_custom,notices_custom_lists,notices_custom_values,notices_externes,notices_fields_global_index,notices_global_index,notices_langues,notices_mots_global_index,notices_relations,notices_titres_uniformes,offres_remises,onto_uri,opac_filters,opac_liste_lecture,opac_sessions,opac_view_notices_1,opac_views,opac_views_empr,origin_authorities,origine_notice,ouvertures,paiements,param_subst,parametres,pclassement,perio_relance,planificateur,pret,pret_archive,pret_custom,pret_custom_lists,pret_custom_values,procs,procs_classements,publisher_custom,publisher_custom_lists,publisher_custom_values,publishers,quotas,quotas_finance,quotas_opac_views,rapport_demandes,rdfstore_index,recouvrements,resa,resa_archive,resa_loc,resa_planning,resa_ranger,responsability,responsability_tu,rss_content,rss_flux,rss_flux_content,rubriques,sauv_lieux,sauv_log,sauv_sauvegardes,sauv_tables,search_cache,search_perso,search_persopac,search_persopac_empr_categ,serialcirc,serialcirc_ask,serialcirc_circ,serialcirc_copy,serialcirc_diff,serialcirc_expl,serialcirc_group,serialcirc_tpl,serie_custom,serie_custom_lists,serie_custom_values,series,sessions,shorturls,skos_fields_global_index,skos_words_global_index,source_sync,sources_enrichment,statopac,statopac_request,statopac_vues,statopac_vues_col,storages,sub_collections,subcollection_custom,subcollection_custom_lists,subcollection_custom_values,suggestions,suggestions_categ,suggestions_origine,suggestions_source,sur_location,taches,taches_docnum,taches_type,tags,thesaurus,titres_uniformes,transacash,transactions,transactype,transferts,transferts_demande,transferts_source,translation,tris,tu_custom,tu_custom_lists,tu_custom_values,tu_distrib,tu_ref,tu_subdiv,tva_achats,type_abts,type_comptes,types_produits,upload_repertoire,users,users_groups,vedette,vedette_link,vedette_object,visionneuse_params,voir_aussi,words,z_attr,z_bib,z_notices,z_query');
/*!40000 ALTER TABLE sauv_tables ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_cache`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE search_cache (
  object_id varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  delete_on_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `value` mediumblob NOT NULL,
  PRIMARY KEY (object_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_cache`
--

LOCK TABLES search_cache WRITE;
/*!40000 ALTER TABLE search_cache DISABLE KEYS */;
/*!40000 ALTER TABLE search_cache ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_perso`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE search_perso (
  search_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  num_user int(8) unsigned NOT NULL DEFAULT '0',
  search_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  search_shortname varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  search_query mediumtext COLLATE utf8_unicode_ci NOT NULL,
  search_human mediumtext COLLATE utf8_unicode_ci NOT NULL,
  search_directlink tinyint(1) unsigned NOT NULL DEFAULT '0',
  autorisations mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (search_id)
) ENGINE=MyISAM AUTO_INCREMENT=15 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_perso`
--

LOCK TABLES search_perso WRITE;
/*!40000 ALTER TABLE search_perso DISABLE KEYS */;
INSERT INTO search_perso (search_id, num_user, search_name, search_shortname, search_query, search_human, search_directlink, autorisations) VALUES (12,3,'Champignons','Champi','a:2:{s:6:\"SEARCH\";a:1:{i:0;s:4:\"f_42\";}i:0;a:5:{s:6:\"SEARCH\";s:4:\"f_42\";s:2:\"OP\";s:7:\"BOOLEAN\";s:5:\"FIELD\";a:1:{i:0;s:11:\"champignon*\";}s:5:\"INTER\";N;s:8:\"FIELDVAR\";N;}}',' <i><strong>Tous les champs</strong> Expression bool&eacute;enne (champignon*)</i> ',1,'3');
/*!40000 ALTER TABLE search_perso ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_persopac`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE search_persopac (
  search_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  num_empr int(8) unsigned NOT NULL DEFAULT '0',
  search_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  search_shortname varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  search_query mediumtext COLLATE utf8_unicode_ci NOT NULL,
  search_human mediumtext COLLATE utf8_unicode_ci NOT NULL,
  search_directlink tinyint(1) unsigned NOT NULL DEFAULT '0',
  search_limitsearch tinyint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (search_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_persopac`
--

LOCK TABLES search_persopac WRITE;
/*!40000 ALTER TABLE search_persopac DISABLE KEYS */;
/*!40000 ALTER TABLE search_persopac ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_persopac_empr_categ`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE search_persopac_empr_categ (
  id_categ_empr int(11) NOT NULL DEFAULT '0',
  id_search_persopac int(11) NOT NULL DEFAULT '0',
  KEY i_id_s_persopac (id_search_persopac),
  KEY i_id_categ_empr (id_categ_empr)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_persopac_empr_categ`
--

LOCK TABLES search_persopac_empr_categ WRITE;
/*!40000 ALTER TABLE search_persopac_empr_categ DISABLE KEYS */;
/*!40000 ALTER TABLE search_persopac_empr_categ ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc (
  id_serialcirc int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_abt int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_type int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_virtual int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_duration int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_checked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_retard_mode int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_allow_resa int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_allow_copy int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_allow_send_ask int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_allow_subscription int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_duration_before_send int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_statut_circ int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_statut_circ_after int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_state int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_tpl mediumtext COLLATE utf8_unicode_ci NOT NULL,
  serialcirc_piedpage text COLLATE utf8_unicode_ci NOT NULL,
  serialcirc_no_ret int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_sort_diff text COLLATE utf8_unicode_ci NOT NULL,
  serialcirc_simple int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_serialcirc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc`
--

LOCK TABLES serialcirc WRITE;
/*!40000 ALTER TABLE serialcirc DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_ask`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_ask (
  id_serialcirc_ask int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_ask_perio int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_ask_serialcirc int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_ask_empr int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_ask_type int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_ask_statut int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_ask_date date NOT NULL DEFAULT '0000-00-00',
  serialcirc_ask_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_serialcirc_ask)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_ask`
--

LOCK TABLES serialcirc_ask WRITE;
/*!40000 ALTER TABLE serialcirc_ask DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_ask ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_circ`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_circ (
  id_serialcirc_circ int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_circ_diff int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_circ_expl int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_circ_empr int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_circ_serialcirc int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_order int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_subscription int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_hold_asked int(11) NOT NULL DEFAULT '0',
  serialcirc_circ_ret_asked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_trans_asked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_trans_doc_asked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_circ_expected_date datetime DEFAULT NULL,
  serialcirc_circ_pointed_date datetime DEFAULT NULL,
  PRIMARY KEY (id_serialcirc_circ)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_circ`
--

LOCK TABLES serialcirc_circ WRITE;
/*!40000 ALTER TABLE serialcirc_circ DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_circ ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_copy`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_copy (
  id_serialcirc_copy int(11) NOT NULL AUTO_INCREMENT,
  num_serialcirc_copy_empr int(11) NOT NULL DEFAULT '0',
  num_serialcirc_copy_bulletin int(11) NOT NULL DEFAULT '0',
  serialcirc_copy_analysis mediumtext COLLATE utf8_unicode_ci,
  serialcirc_copy_date date NOT NULL DEFAULT '0000-00-00',
  serialcirc_copy_state int(11) NOT NULL DEFAULT '0',
  serialcirc_copy_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_serialcirc_copy)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_copy`
--

LOCK TABLES serialcirc_copy WRITE;
/*!40000 ALTER TABLE serialcirc_copy DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_copy ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_diff`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_diff (
  id_serialcirc_diff int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_diff_serialcirc int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_diff_empr_type int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_diff_type_diff int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_diff_empr int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_diff_group_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  serialcirc_diff_duration int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_diff_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_serialcirc_diff)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_diff`
--

LOCK TABLES serialcirc_diff WRITE;
/*!40000 ALTER TABLE serialcirc_diff DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_diff ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_expl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_expl (
  id_serialcirc_expl int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_expl_id int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_expl_serialcirc int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_bulletine_date date NOT NULL DEFAULT '0000-00-00',
  serialcirc_expl_state_circ int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_expl_serialcirc_diff int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_ret_asked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_trans_asked int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_trans_doc_asked int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_expl_current_empr int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_expl_start_date date NOT NULL DEFAULT '0000-00-00',
  PRIMARY KEY (id_serialcirc_expl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_expl`
--

LOCK TABLES serialcirc_expl WRITE;
/*!40000 ALTER TABLE serialcirc_expl DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_expl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_group`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_group (
  id_serialcirc_group int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_serialcirc_group_diff int(10) unsigned NOT NULL DEFAULT '0',
  num_serialcirc_group_empr int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_group_responsable int(10) unsigned NOT NULL DEFAULT '0',
  serialcirc_group_order int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_serialcirc_group)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_group`
--

LOCK TABLES serialcirc_group WRITE;
/*!40000 ALTER TABLE serialcirc_group DISABLE KEYS */;
/*!40000 ALTER TABLE serialcirc_group ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serialcirc_tpl`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serialcirc_tpl (
  serialcirctpl_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  serialcirctpl_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  serialcirctpl_comment varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  serialcirctpl_tpl text COLLATE utf8_unicode_ci NOT NULL,
  serialcirctpl_piedpage text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (serialcirctpl_id)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serialcirc_tpl`
--

LOCK TABLES serialcirc_tpl WRITE;
/*!40000 ALTER TABLE serialcirc_tpl DISABLE KEYS */;
INSERT INTO serialcirc_tpl (serialcirctpl_id, serialcirctpl_name, serialcirctpl_comment, serialcirctpl_tpl, serialcirctpl_piedpage) VALUES (1,'Template PMB','','a:3:{i:0;a:3:{s:4:\"type\";s:4:\"name\";s:2:\"id\";s:1:\"0\";s:5:\"label\";N;}i:1;a:3:{s:4:\"type\";s:5:\"ville\";s:2:\"id\";s:1:\"0\";s:5:\"label\";N;}i:2;a:3:{s:4:\"type\";s:5:\"libre\";s:2:\"id\";s:1:\"0\";s:5:\"label\";s:9:\"SIGNATURE\";}}','');
/*!40000 ALTER TABLE serialcirc_tpl ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serie_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serie_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serie_custom`
--

LOCK TABLES serie_custom WRITE;
/*!40000 ALTER TABLE serie_custom DISABLE KEYS */;
/*!40000 ALTER TABLE serie_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serie_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serie_custom_lists (
  serie_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  serie_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  serie_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (serie_custom_champ),
  KEY editorial_champ_list_value (serie_custom_champ,serie_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serie_custom_lists`
--

LOCK TABLES serie_custom_lists WRITE;
/*!40000 ALTER TABLE serie_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE serie_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `serie_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE serie_custom_values (
  serie_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  serie_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  serie_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  serie_custom_text text COLLATE utf8_unicode_ci,
  serie_custom_integer int(11) DEFAULT NULL,
  serie_custom_date date DEFAULT NULL,
  serie_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (serie_custom_champ),
  KEY editorial_custom_origine (serie_custom_origine),
  KEY i_scv_st (serie_custom_small_text),
  KEY i_scv_t (serie_custom_text(255)),
  KEY i_scv_i (serie_custom_integer),
  KEY i_scv_d (serie_custom_date),
  KEY i_scv_f (serie_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `serie_custom_values`
--

LOCK TABLES serie_custom_values WRITE;
/*!40000 ALTER TABLE serie_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE serie_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `series`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE series (
  serie_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  serie_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  serie_index mediumtext COLLATE utf8_unicode_ci,
  PRIMARY KEY (serie_id)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `series`
--

LOCK TABLES series WRITE;
/*!40000 ALTER TABLE series DISABLE KEYS */;
INSERT INTO series (serie_id, serie_name, serie_index) VALUES (1,'Aya de Yopougon',' aya yopougon ');
INSERT INTO series (serie_id, serie_name, serie_index) VALUES (2,'Jojo',' jojo ');
INSERT INTO series (serie_id, serie_name, serie_index) VALUES (3,'Les annales du disque-monde',' annales disque monde ');
/*!40000 ALTER TABLE series ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sessions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sessions (
  SESSID varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  login varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  IP varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  SESSstart varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  LastOn varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  SESSNAME varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notifications text COLLATE utf8_unicode_ci
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sessions`
--

LOCK TABLES sessions WRITE;
/*!40000 ALTER TABLE sessions DISABLE KEYS */;
/*!40000 ALTER TABLE sessions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shorturls`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE shorturls (
  id_shorturl int(10) unsigned NOT NULL AUTO_INCREMENT,
  shorturl_hash varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  shorturl_last_access datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  shorturl_context text COLLATE utf8_unicode_ci NOT NULL,
  shorturl_type varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  shorturl_action varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_shorturl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shorturls`
--

LOCK TABLES shorturls WRITE;
/*!40000 ALTER TABLE shorturls DISABLE KEYS */;
/*!40000 ALTER TABLE shorturls ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `skos_fields_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE skos_fields_global_index (
  id_item int(10) unsigned NOT NULL DEFAULT '0',
  code_champ int(3) unsigned NOT NULL DEFAULT '0',
  code_ss_champ int(3) unsigned NOT NULL DEFAULT '0',
  ordre int(4) unsigned NOT NULL DEFAULT '0',
  `value` text COLLATE utf8_unicode_ci NOT NULL,
  pond int(4) unsigned NOT NULL DEFAULT '100',
  lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  authority_num varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  PRIMARY KEY (id_item,code_champ,code_ss_champ,lang,ordre),
  KEY i_value (`value`(300)),
  KEY i_code_champ_code_ss_champ (code_champ,code_ss_champ)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `skos_fields_global_index`
--

LOCK TABLES skos_fields_global_index WRITE;
/*!40000 ALTER TABLE skos_fields_global_index DISABLE KEYS */;
/*!40000 ALTER TABLE skos_fields_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `skos_words_global_index`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE skos_words_global_index (
  id_item int(10) unsigned NOT NULL DEFAULT '0',
  code_champ int(10) unsigned NOT NULL DEFAULT '0',
  code_ss_champ int(10) unsigned NOT NULL DEFAULT '0',
  num_word int(10) unsigned NOT NULL DEFAULT '0',
  pond int(10) unsigned NOT NULL DEFAULT '100',
  position int(10) unsigned NOT NULL DEFAULT '1',
  field_position int(10) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (id_item,code_champ,num_word,position,code_ss_champ),
  KEY code_champ (code_champ),
  KEY i_id_mot (num_word,id_item),
  KEY i_code_champ_code_ss_champ_num_word (code_champ,code_ss_champ,num_word)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `skos_words_global_index`
--

LOCK TABLES skos_words_global_index WRITE;
/*!40000 ALTER TABLE skos_words_global_index DISABLE KEYS */;
/*!40000 ALTER TABLE skos_words_global_index ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `source_sync`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE source_sync (
  source_id int(10) unsigned NOT NULL DEFAULT '0',
  nrecu varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ntotal varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  message varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_sync datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  percent int(10) unsigned NOT NULL DEFAULT '0',
  env mediumtext COLLATE utf8_unicode_ci NOT NULL,
  cancel int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (source_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `source_sync`
--

LOCK TABLES source_sync WRITE;
/*!40000 ALTER TABLE source_sync DISABLE KEYS */;
INSERT INTO source_sync (source_id, nrecu, ntotal, message, date_sync, percent, env, cancel) VALUES (5,'','','','2012-12-11 18:55:08',0,'',2);
/*!40000 ALTER TABLE source_sync ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sources_enrichment`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sources_enrichment (
  source_enrichment_num int(11) NOT NULL DEFAULT '0',
  source_enrichment_typnotice varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_enrichment_typdoc varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  source_enrichment_params mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (source_enrichment_num,source_enrichment_typnotice,source_enrichment_typdoc),
  KEY i_s_enrichment_typnoti (source_enrichment_typnotice),
  KEY i_s_enrichment_typdoc (source_enrichment_typdoc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sources_enrichment`
--

LOCK TABLES sources_enrichment WRITE;
/*!40000 ALTER TABLE sources_enrichment DISABLE KEYS */;
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (2,'m','','');
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (3,'m','','');
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (3,'m','g','');
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (4,'m','g','');
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (3,'m','j','');
INSERT INTO sources_enrichment (source_enrichment_num, source_enrichment_typnotice, source_enrichment_typdoc, source_enrichment_params) VALUES (4,'m','j','');
/*!40000 ALTER TABLE sources_enrichment ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `statopac`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE statopac (
  id_log int(8) unsigned NOT NULL AUTO_INCREMENT,
  date_log timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  url_demandee varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  url_referente varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  get_log blob NOT NULL,
  post_log blob NOT NULL,
  num_session varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  server_log blob NOT NULL,
  empr_carac blob NOT NULL,
  empr_doc blob NOT NULL,
  empr_expl blob NOT NULL,
  nb_result blob NOT NULL,
  gen_stat blob NOT NULL,
  PRIMARY KEY (id_log),
  KEY sopac_date_log (date_log)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `statopac`
--

LOCK TABLES statopac WRITE;
/*!40000 ALTER TABLE statopac DISABLE KEYS */;
/*!40000 ALTER TABLE statopac ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `statopac_request`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE statopac_request (
  idproc int(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  requete blob NOT NULL,
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  num_vue mediumint(8) NOT NULL DEFAULT '0',
  autorisations longtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (idproc)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `statopac_request`
--

LOCK TABLES statopac_request WRITE;
/*!40000 ALTER TABLE statopac_request DISABLE KEYS */;
/*!40000 ALTER TABLE statopac_request ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `statopac_vues`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE statopac_vues (
  id_vue int(8) unsigned NOT NULL AUTO_INCREMENT,
  date_consolidation datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  nom_vue varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `comment` text COLLATE utf8_unicode_ci NOT NULL,
  date_debut_log datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_fin_log datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (id_vue)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `statopac_vues`
--

LOCK TABLES statopac_vues WRITE;
/*!40000 ALTER TABLE statopac_vues DISABLE KEYS */;
/*!40000 ALTER TABLE statopac_vues ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `statopac_vues_col`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE statopac_vues_col (
  id_col int(8) unsigned NOT NULL AUTO_INCREMENT,
  nom_col varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  expression varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_vue mediumint(8) NOT NULL DEFAULT '0',
  ordre mediumint(8) NOT NULL DEFAULT '0',
  filtre varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  maj_flag int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (id_col)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `statopac_vues_col`
--

LOCK TABLES statopac_vues_col WRITE;
/*!40000 ALTER TABLE statopac_vues_col DISABLE KEYS */;
/*!40000 ALTER TABLE statopac_vues_col ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `storages`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE storages (
  id_storage int(10) unsigned NOT NULL AUTO_INCREMENT,
  storage_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  storage_class varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  storage_params text COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_storage),
  KEY i_storage_class (storage_class)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `storages`
--

LOCK TABLES storages WRITE;
/*!40000 ALTER TABLE storages DISABLE KEYS */;
/*!40000 ALTER TABLE storages ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sub_collections`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sub_collections (
  sub_coll_id mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  sub_coll_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  sub_coll_parent mediumint(9) unsigned NOT NULL DEFAULT '0',
  sub_coll_issn varchar(12) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  index_sub_coll mediumtext COLLATE utf8_unicode_ci,
  subcollection_web mediumtext COLLATE utf8_unicode_ci NOT NULL,
  subcollection_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  authority_import_denied int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (sub_coll_id),
  KEY sub_coll_name (sub_coll_name)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sub_collections`
--

LOCK TABLES sub_collections WRITE;
/*!40000 ALTER TABLE sub_collections DISABLE KEYS */;
INSERT INTO sub_collections (sub_coll_id, sub_coll_name, sub_coll_parent, sub_coll_issn, index_sub_coll, subcollection_web, subcollection_comment, authority_import_denied) VALUES (1,'Science-fiction',21,'',' science fiction ','','',0);
INSERT INTO sub_collections (sub_coll_id, sub_coll_name, sub_coll_parent, sub_coll_issn, index_sub_coll, subcollection_web, subcollection_comment, authority_import_denied) VALUES (2,'Fantastique',28,'',' fantastique ','','',0);
/*!40000 ALTER TABLE sub_collections ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subcollection_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE subcollection_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subcollection_custom`
--

LOCK TABLES subcollection_custom WRITE;
/*!40000 ALTER TABLE subcollection_custom DISABLE KEYS */;
/*!40000 ALTER TABLE subcollection_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subcollection_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE subcollection_custom_lists (
  subcollection_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  subcollection_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  subcollection_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (subcollection_custom_champ),
  KEY editorial_champ_list_value (subcollection_custom_champ,subcollection_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subcollection_custom_lists`
--

LOCK TABLES subcollection_custom_lists WRITE;
/*!40000 ALTER TABLE subcollection_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE subcollection_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subcollection_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE subcollection_custom_values (
  subcollection_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  subcollection_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  subcollection_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  subcollection_custom_text text COLLATE utf8_unicode_ci,
  subcollection_custom_integer int(11) DEFAULT NULL,
  subcollection_custom_date date DEFAULT NULL,
  subcollection_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (subcollection_custom_champ),
  KEY editorial_custom_origine (subcollection_custom_origine),
  KEY i_scv_st (subcollection_custom_small_text),
  KEY i_scv_t (subcollection_custom_text(255)),
  KEY i_scv_i (subcollection_custom_integer),
  KEY i_scv_d (subcollection_custom_date),
  KEY i_scv_f (subcollection_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subcollection_custom_values`
--

LOCK TABLES subcollection_custom_values WRITE;
/*!40000 ALTER TABLE subcollection_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE subcollection_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suggestions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE suggestions (
  id_suggestion int(12) unsigned NOT NULL AUTO_INCREMENT,
  titre text COLLATE utf8_unicode_ci NOT NULL,
  editeur varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  auteur varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `code` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  prix float(8,2) unsigned NOT NULL DEFAULT '0.00',
  commentaires mediumtext COLLATE utf8_unicode_ci,
  commentaires_gestion text COLLATE utf8_unicode_ci,
  statut int(3) unsigned NOT NULL DEFAULT '0',
  num_produit int(8) NOT NULL DEFAULT '0',
  num_entite int(5) NOT NULL DEFAULT '0',
  index_suggestion mediumtext COLLATE utf8_unicode_ci NOT NULL,
  nb int(5) unsigned NOT NULL DEFAULT '1',
  date_creation date NOT NULL DEFAULT '0000-00-00',
  date_decision date NOT NULL DEFAULT '0000-00-00',
  num_rubrique int(8) unsigned NOT NULL DEFAULT '0',
  num_fournisseur int(5) unsigned NOT NULL DEFAULT '0',
  num_notice int(8) unsigned NOT NULL DEFAULT '0',
  url_suggestion varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_categ int(12) NOT NULL DEFAULT '1',
  sugg_location smallint(5) unsigned NOT NULL DEFAULT '0',
  sugg_source int(8) NOT NULL DEFAULT '0',
  date_publication varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  notice_unimarc blob NOT NULL,
  PRIMARY KEY (id_suggestion)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suggestions`
--

LOCK TABLES suggestions WRITE;
/*!40000 ALTER TABLE suggestions DISABLE KEYS */;
/*!40000 ALTER TABLE suggestions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suggestions_categ`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE suggestions_categ (
  id_categ int(12) NOT NULL AUTO_INCREMENT,
  libelle_categ varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_categ)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suggestions_categ`
--

LOCK TABLES suggestions_categ WRITE;
/*!40000 ALTER TABLE suggestions_categ DISABLE KEYS */;
INSERT INTO suggestions_categ (id_categ, libelle_categ) VALUES (1,'catégorie par défaut');
/*!40000 ALTER TABLE suggestions_categ ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suggestions_origine`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE suggestions_origine (
  origine varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_suggestion int(12) unsigned NOT NULL DEFAULT '0',
  type_origine int(3) unsigned NOT NULL DEFAULT '0',
  date_suggestion date NOT NULL DEFAULT '0000-00-00',
  PRIMARY KEY (origine,num_suggestion,type_origine),
  KEY i_origine (origine,type_origine)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suggestions_origine`
--

LOCK TABLES suggestions_origine WRITE;
/*!40000 ALTER TABLE suggestions_origine DISABLE KEYS */;
/*!40000 ALTER TABLE suggestions_origine ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suggestions_source`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE suggestions_source (
  id_source int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle_source varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_source)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suggestions_source`
--

LOCK TABLES suggestions_source WRITE;
/*!40000 ALTER TABLE suggestions_source DISABLE KEYS */;
/*!40000 ALTER TABLE suggestions_source ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sur_location`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE sur_location (
  surloc_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  surloc_libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_pic varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_visible_opac tinyint(1) unsigned NOT NULL DEFAULT '1',
  surloc_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_adr1 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_adr2 varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_cp varchar(15) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_town varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_state varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_country varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_phone varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_email varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_website varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_logo varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  surloc_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  surloc_num_infopage int(6) unsigned NOT NULL DEFAULT '0',
  surloc_css_style varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (surloc_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sur_location`
--

LOCK TABLES sur_location WRITE;
/*!40000 ALTER TABLE sur_location DISABLE KEYS */;
/*!40000 ALTER TABLE sur_location ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taches`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE taches (
  id_tache int(11) unsigned NOT NULL AUTO_INCREMENT,
  num_planificateur int(11) DEFAULT NULL,
  start_at datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  end_at datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `status` varchar(128) COLLATE utf8_unicode_ci DEFAULT NULL,
  msg_statut blob,
  commande int(8) NOT NULL DEFAULT '0',
  next_state int(8) NOT NULL DEFAULT '0',
  msg_commande blob,
  indicat_progress int(3) DEFAULT NULL,
  rapport mediumtext COLLATE utf8_unicode_ci,
  id_process int(8) DEFAULT NULL,
  PRIMARY KEY (id_tache)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taches`
--

LOCK TABLES taches WRITE;
/*!40000 ALTER TABLE taches DISABLE KEYS */;
/*!40000 ALTER TABLE taches ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taches_docnum`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE taches_docnum (
  id_tache_docnum int(11) unsigned NOT NULL AUTO_INCREMENT,
  tache_docnum_nomfichier varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  tache_docnum_mimetype varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  tache_docnum_data mediumblob NOT NULL,
  tache_docnum_extfichier varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
  tache_docnum_repertoire int(8) DEFAULT NULL,
  tache_docnum_path mediumtext COLLATE utf8_unicode_ci NOT NULL,
  num_tache int(11) NOT NULL,
  PRIMARY KEY (id_tache_docnum)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taches_docnum`
--

LOCK TABLES taches_docnum WRITE;
/*!40000 ALTER TABLE taches_docnum DISABLE KEYS */;
/*!40000 ALTER TABLE taches_docnum ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taches_type`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE taches_type (
  id_type_tache int(11) unsigned NOT NULL,
  parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  timeout int(11) NOT NULL DEFAULT '5',
  histo_day int(11) NOT NULL DEFAULT '7',
  histo_number int(11) NOT NULL DEFAULT '3',
  restart_on_failure int(1) unsigned NOT NULL DEFAULT '0',
  alert_mail_on_failure varchar(255) COLLATE utf8_unicode_ci DEFAULT '',
  PRIMARY KEY (id_type_tache)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taches_type`
--

LOCK TABLES taches_type WRITE;
/*!40000 ALTER TABLE taches_type DISABLE KEYS */;
/*!40000 ALTER TABLE taches_type ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tags`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tags (
  id_tag mediumint(8) NOT NULL AUTO_INCREMENT,
  libelle varchar(200) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_notice mediumint(8) NOT NULL DEFAULT '0',
  user_code varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  dateajout timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (id_tag)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tags`
--

LOCK TABLES tags WRITE;
/*!40000 ALTER TABLE tags DISABLE KEYS */;
/*!40000 ALTER TABLE tags ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `thesaurus`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE thesaurus (
  id_thesaurus int(3) unsigned NOT NULL AUTO_INCREMENT,
  libelle_thesaurus varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  langue_defaut varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'fr_FR',
  active char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '1',
  opac_active char(1) COLLATE utf8_unicode_ci NOT NULL DEFAULT '1',
  num_noeud_racine int(9) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_thesaurus),
  UNIQUE KEY libelle_thesaurus (libelle_thesaurus)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `thesaurus`
--

LOCK TABLES thesaurus WRITE;
/*!40000 ALTER TABLE thesaurus DISABLE KEYS */;
INSERT INTO thesaurus (id_thesaurus, libelle_thesaurus, langue_defaut, active, opac_active, num_noeud_racine) VALUES (1,'Agneaux','fr_FR','1','1',1);
/*!40000 ALTER TABLE thesaurus ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `titres_uniformes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE titres_uniformes (
  tu_id int(9) unsigned NOT NULL AUTO_INCREMENT,
  tu_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_tonalite varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_comment mediumtext COLLATE utf8_unicode_ci NOT NULL,
  index_tu mediumtext COLLATE utf8_unicode_ci NOT NULL,
  tu_import_denied int(10) unsigned NOT NULL DEFAULT '0',
  tu_num_author bigint(11) unsigned NOT NULL DEFAULT '0',
  tu_forme varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_date varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_date_date date NOT NULL DEFAULT '0000-00-00',
  tu_sujet text COLLATE utf8_unicode_ci NOT NULL,
  tu_lieu varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_histoire text COLLATE utf8_unicode_ci,
  tu_caracteristique text COLLATE utf8_unicode_ci,
  tu_public varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_contexte text COLLATE utf8_unicode_ci,
  tu_coordonnees varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_equinoxe varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_completude int(2) unsigned NOT NULL DEFAULT '0',
  tu_tonalite_marclist varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tu_forme_marclist varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (tu_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `titres_uniformes`
--

LOCK TABLES titres_uniformes WRITE;
/*!40000 ALTER TABLE titres_uniformes DISABLE KEYS */;
/*!40000 ALTER TABLE titres_uniformes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transacash`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transacash (
  transacash_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  transacash_empr_num int(10) unsigned NOT NULL DEFAULT '0',
  transacash_desk_num int(10) unsigned NOT NULL DEFAULT '0',
  transacash_user_num int(10) unsigned NOT NULL DEFAULT '0',
  transacash_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  transacash_sold float NOT NULL DEFAULT '0',
  transacash_collected float NOT NULL DEFAULT '0',
  transacash_rendering float NOT NULL DEFAULT '0',
  PRIMARY KEY (transacash_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transacash`
--

LOCK TABLES transacash WRITE;
/*!40000 ALTER TABLE transacash DISABLE KEYS */;
/*!40000 ALTER TABLE transacash ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transactions`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transactions (
  id_transaction int(10) unsigned NOT NULL AUTO_INCREMENT,
  compte_id int(8) unsigned NOT NULL DEFAULT '0',
  user_id int(10) unsigned NOT NULL DEFAULT '0',
  user_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  machine varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  date_enrgt datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  date_prevue date DEFAULT NULL,
  date_effective date DEFAULT NULL,
  montant decimal(16,2) NOT NULL DEFAULT '0.00',
  sens int(1) NOT NULL DEFAULT '0',
  realisee int(1) NOT NULL DEFAULT '0',
  commentaire mediumtext COLLATE utf8_unicode_ci,
  encaissement int(1) NOT NULL DEFAULT '0',
  transactype_num int(10) unsigned NOT NULL DEFAULT '0',
  cashdesk_num int(10) unsigned NOT NULL DEFAULT '0',
  transacash_num int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_transaction)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transactions`
--

LOCK TABLES transactions WRITE;
/*!40000 ALTER TABLE transactions DISABLE KEYS */;
INSERT INTO transactions (id_transaction, compte_id, user_id, user_name, machine, date_enrgt, date_prevue, date_effective, montant, sens, realisee, commentaire, encaissement, transactype_num, cashdesk_num, transacash_num) VALUES (1,1,1,'admin','127.0.0.1','2012-10-24 10:47:37','2012-10-24',NULL,2.85,-1,0,'Amende exemplaire 30',0,0,0,0);
/*!40000 ALTER TABLE transactions ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transactype`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transactype (
  transactype_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  transactype_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  transactype_quick_allowed int(10) unsigned NOT NULL DEFAULT '0',
  transactype_unit_price float NOT NULL DEFAULT '0',
  PRIMARY KEY (transactype_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transactype`
--

LOCK TABLES transactype WRITE;
/*!40000 ALTER TABLE transactype DISABLE KEYS */;
/*!40000 ALTER TABLE transactype ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transferts`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transferts (
  id_transfert int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_notice int(10) unsigned NOT NULL DEFAULT '0',
  num_bulletin int(10) unsigned NOT NULL DEFAULT '0',
  date_creation date NOT NULL,
  type_transfert int(5) unsigned NOT NULL DEFAULT '0',
  etat_transfert tinyint(3) unsigned NOT NULL DEFAULT '0',
  origine int(5) unsigned NOT NULL DEFAULT '0',
  origine_comp varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `source` smallint(5) unsigned DEFAULT NULL,
  destinations varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  date_retour date DEFAULT NULL,
  motif varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_transfert),
  KEY etat_transfert (etat_transfert)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transferts`
--

LOCK TABLES transferts WRITE;
/*!40000 ALTER TABLE transferts DISABLE KEYS */;
/*!40000 ALTER TABLE transferts ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transferts_demande`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transferts_demande (
  id_transfert_demande int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_transfert int(10) unsigned NOT NULL DEFAULT '0',
  date_creation date NOT NULL,
  sens_transfert tinyint(3) unsigned NOT NULL DEFAULT '0',
  num_location_source smallint(5) unsigned NOT NULL DEFAULT '0',
  num_location_dest smallint(5) unsigned NOT NULL DEFAULT '0',
  num_expl int(10) unsigned NOT NULL DEFAULT '0',
  etat_demande tinyint(3) unsigned NOT NULL DEFAULT '0',
  date_visualisee date DEFAULT NULL,
  date_envoyee date DEFAULT NULL,
  date_reception date DEFAULT NULL,
  motif_refus varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  statut_origine int(10) unsigned NOT NULL DEFAULT '0',
  section_origine int(10) unsigned NOT NULL DEFAULT '0',
  resa_trans int(8) unsigned NOT NULL DEFAULT '0',
  resa_arc_trans int(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (id_transfert_demande),
  KEY num_transfert (num_transfert),
  KEY num_location_source (num_location_source),
  KEY num_location_dest (num_location_dest),
  KEY num_expl (num_expl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transferts_demande`
--

LOCK TABLES transferts_demande WRITE;
/*!40000 ALTER TABLE transferts_demande DISABLE KEYS */;
/*!40000 ALTER TABLE transferts_demande ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `transferts_source`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE transferts_source (
  trans_source_numexpl int(10) unsigned NOT NULL DEFAULT '0',
  trans_source_numloc int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (trans_source_numexpl)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `transferts_source`
--

LOCK TABLES transferts_source WRITE;
/*!40000 ALTER TABLE transferts_source DISABLE KEYS */;
/*!40000 ALTER TABLE transferts_source ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `translation`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE translation (
  trans_table varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  trans_field varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  trans_lang varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  trans_num int(8) unsigned NOT NULL DEFAULT '0',
  trans_text varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (trans_table,trans_field,trans_lang,trans_num),
  KEY i_lang (trans_lang)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `translation`
--

LOCK TABLES translation WRITE;
/*!40000 ALTER TABLE translation DISABLE KEYS */;
/*!40000 ALTER TABLE translation ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tris`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tris (
  id_tri int(4) NOT NULL AUTO_INCREMENT,
  tri_par varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  nom_tri varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  tri_reference varchar(40) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'notices',
  PRIMARY KEY (id_tri)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tris`
--

LOCK TABLES tris WRITE;
/*!40000 ALTER TABLE tris DISABLE KEYS */;
INSERT INTO tris (id_tri, tri_par, nom_tri, tri_reference) VALUES (1,'d_num_19','Date de publication d&eacute;croissante','notices');
/*!40000 ALTER TABLE tris ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_custom`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_custom (
  idchamp int(10) unsigned NOT NULL AUTO_INCREMENT,
  num_type int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  titre varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `type` varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'text',
  datatype varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `options` text COLLATE utf8_unicode_ci,
  multiple int(11) NOT NULL DEFAULT '0',
  obligatoire int(11) NOT NULL DEFAULT '0',
  ordre int(11) DEFAULT NULL,
  search int(1) unsigned NOT NULL DEFAULT '0',
  export int(1) unsigned NOT NULL DEFAULT '0',
  exclusion_obligatoire int(1) unsigned NOT NULL DEFAULT '0',
  pond int(11) NOT NULL DEFAULT '100',
  opac_sort int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (idchamp)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_custom`
--

LOCK TABLES tu_custom WRITE;
/*!40000 ALTER TABLE tu_custom DISABLE KEYS */;
/*!40000 ALTER TABLE tu_custom ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_custom_lists`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_custom_lists (
  tu_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  tu_custom_list_value varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  tu_custom_list_lib varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  ordre int(11) DEFAULT NULL,
  KEY editorial_custom_champ (tu_custom_champ),
  KEY editorial_champ_list_value (tu_custom_champ,tu_custom_list_value)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_custom_lists`
--

LOCK TABLES tu_custom_lists WRITE;
/*!40000 ALTER TABLE tu_custom_lists DISABLE KEYS */;
/*!40000 ALTER TABLE tu_custom_lists ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_custom_values`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_custom_values (
  tu_custom_champ int(10) unsigned NOT NULL DEFAULT '0',
  tu_custom_origine int(10) unsigned NOT NULL DEFAULT '0',
  tu_custom_small_text varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  tu_custom_text text COLLATE utf8_unicode_ci,
  tu_custom_integer int(11) DEFAULT NULL,
  tu_custom_date date DEFAULT NULL,
  tu_custom_float float DEFAULT NULL,
  KEY editorial_custom_champ (tu_custom_champ),
  KEY editorial_custom_origine (tu_custom_origine),
  KEY i_tcv_st (tu_custom_small_text),
  KEY i_tcv_t (tu_custom_text(255)),
  KEY i_tcv_i (tu_custom_integer),
  KEY i_tcv_d (tu_custom_date),
  KEY i_tcv_f (tu_custom_float)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_custom_values`
--

LOCK TABLES tu_custom_values WRITE;
/*!40000 ALTER TABLE tu_custom_values DISABLE KEYS */;
/*!40000 ALTER TABLE tu_custom_values ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_distrib`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_distrib (
  distrib_num_tu int(9) unsigned NOT NULL DEFAULT '0',
  distrib_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  distrib_ordre smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (distrib_num_tu,distrib_ordre)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_distrib`
--

LOCK TABLES tu_distrib WRITE;
/*!40000 ALTER TABLE tu_distrib DISABLE KEYS */;
/*!40000 ALTER TABLE tu_distrib ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_ref`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_ref (
  ref_num_tu int(9) unsigned NOT NULL DEFAULT '0',
  ref_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  ref_ordre smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (ref_num_tu,ref_ordre)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_ref`
--

LOCK TABLES tu_ref WRITE;
/*!40000 ALTER TABLE tu_ref DISABLE KEYS */;
/*!40000 ALTER TABLE tu_ref ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tu_subdiv`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tu_subdiv (
  subdiv_num_tu int(9) unsigned NOT NULL DEFAULT '0',
  subdiv_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  subdiv_ordre smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (subdiv_num_tu,subdiv_ordre)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tu_subdiv`
--

LOCK TABLES tu_subdiv WRITE;
/*!40000 ALTER TABLE tu_subdiv DISABLE KEYS */;
/*!40000 ALTER TABLE tu_subdiv ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tva_achats`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE tva_achats (
  id_tva int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  taux_tva float(4,2) unsigned NOT NULL DEFAULT '0.00',
  num_cp_compta varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  PRIMARY KEY (id_tva)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tva_achats`
--

LOCK TABLES tva_achats WRITE;
/*!40000 ALTER TABLE tva_achats DISABLE KEYS */;
INSERT INTO tva_achats (id_tva, libelle, taux_tva, num_cp_compta) VALUES (1,'7',7.00,'');
/*!40000 ALTER TABLE tva_achats ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `type_abts`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE type_abts (
  id_type_abt int(5) unsigned NOT NULL AUTO_INCREMENT,
  type_abt_libelle varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  prepay int(1) unsigned NOT NULL DEFAULT '0',
  prepay_deflt_mnt decimal(16,2) NOT NULL DEFAULT '0.00',
  tarif decimal(16,2) NOT NULL DEFAULT '0.00',
  commentaire mediumtext COLLATE utf8_unicode_ci NOT NULL,
  caution decimal(16,2) NOT NULL DEFAULT '0.00',
  localisations varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_type_abt)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `type_abts`
--

LOCK TABLES type_abts WRITE;
/*!40000 ALTER TABLE type_abts DISABLE KEYS */;
/*!40000 ALTER TABLE type_abts ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `type_comptes`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE type_comptes (
  id_type_compte int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  type_acces int(8) unsigned NOT NULL DEFAULT '0',
  acces_id mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (id_type_compte)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `type_comptes`
--

LOCK TABLES type_comptes WRITE;
/*!40000 ALTER TABLE type_comptes DISABLE KEYS */;
/*!40000 ALTER TABLE type_comptes ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `types_produits`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE types_produits (
  id_produit int(8) unsigned NOT NULL AUTO_INCREMENT,
  libelle varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  num_cp_compta varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  num_tva_achat varchar(25) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  PRIMARY KEY (id_produit),
  KEY libelle (libelle)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `types_produits`
--

LOCK TABLES types_produits WRITE;
/*!40000 ALTER TABLE types_produits DISABLE KEYS */;
/*!40000 ALTER TABLE types_produits ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `upload_repertoire`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE upload_repertoire (
  repertoire_id int(8) unsigned NOT NULL AUTO_INCREMENT,
  repertoire_nom varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  repertoire_url mediumtext COLLATE utf8_unicode_ci NOT NULL,
  repertoire_path mediumtext COLLATE utf8_unicode_ci NOT NULL,
  repertoire_navigation int(1) NOT NULL DEFAULT '0',
  repertoire_hachage int(1) NOT NULL DEFAULT '0',
  repertoire_subfolder int(8) NOT NULL DEFAULT '0',
  repertoire_utf8 int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (repertoire_id)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `upload_repertoire`
--

LOCK TABLES upload_repertoire WRITE;
/*!40000 ALTER TABLE upload_repertoire DISABLE KEYS */;
/*!40000 ALTER TABLE upload_repertoire ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE users (
  userid int(5) NOT NULL AUTO_INCREMENT,
  create_dt date NOT NULL DEFAULT '0000-00-00',
  last_updated_dt date NOT NULL DEFAULT '0000-00-00',
  username varchar(100) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  pwd varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  user_digest varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  nom varchar(30) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  prenom varchar(30) COLLATE utf8_unicode_ci DEFAULT NULL,
  rights int(8) unsigned NOT NULL DEFAULT '0',
  user_lang varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'fr_FR',
  nb_per_page_search int(10) unsigned NOT NULL DEFAULT '4',
  nb_per_page_select int(10) unsigned NOT NULL DEFAULT '10',
  nb_per_page_gestion int(10) unsigned NOT NULL DEFAULT '20',
  param_popup_ticket smallint(1) unsigned NOT NULL DEFAULT '0',
  param_sounds smallint(1) unsigned NOT NULL DEFAULT '1',
  param_rfid_activate int(1) NOT NULL DEFAULT '1',
  param_licence int(1) unsigned NOT NULL DEFAULT '0',
  deflt_notice_statut int(6) unsigned NOT NULL DEFAULT '1',
  deflt_integration_notice_statut int(6) NOT NULL DEFAULT '1',
  xmlta_indexation_lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  deflt_docs_type int(6) unsigned NOT NULL DEFAULT '1',
  deflt_lenders int(6) unsigned NOT NULL DEFAULT '0',
  deflt_styles varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'default',
  deflt_docs_statut int(6) unsigned DEFAULT '0',
  deflt_docs_codestat int(6) unsigned DEFAULT '0',
  value_deflt_lang varchar(20) COLLATE utf8_unicode_ci DEFAULT 'fre',
  value_deflt_fonction varchar(20) COLLATE utf8_unicode_ci DEFAULT '070',
  value_deflt_relation varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  value_deflt_relation_serial varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  value_deflt_relation_bulletin varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  value_deflt_relation_analysis varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  deflt_docs_location int(6) unsigned DEFAULT '0',
  deflt_collstate_location int(6) unsigned DEFAULT '0',
  deflt_bulletinage_location int(6) unsigned NOT NULL DEFAULT '0',
  deflt_resas_location int(6) unsigned DEFAULT '0',
  deflt_docs_section int(6) unsigned DEFAULT '0',
  value_deflt_module varchar(30) COLLATE utf8_unicode_ci DEFAULT 'circu',
  user_email varchar(255) COLLATE utf8_unicode_ci DEFAULT '',
  user_alert_resamail int(1) unsigned NOT NULL DEFAULT '0',
  user_alert_demandesmail int(1) unsigned NOT NULL DEFAULT '0',
  user_alert_subscribemail int(1) unsigned NOT NULL DEFAULT '0',
  deflt2docs_location int(6) unsigned NOT NULL DEFAULT '0',
  deflt_empr_statut bigint(20) unsigned NOT NULL DEFAULT '1',
  deflt_thesaurus int(3) unsigned NOT NULL DEFAULT '1',
  deflt_concept_scheme int(3) NOT NULL DEFAULT '-1',
  deflt_import_thesaurus int(11) NOT NULL DEFAULT '1',
  value_prefix_cote tinyblob NOT NULL,
  xmlta_doctype char(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'a',
  xmlta_doctype_serial varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  xmlta_doctype_bulletin varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  xmlta_doctype_analysis varchar(2) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  speci_coordonnees_etab longtext COLLATE utf8_unicode_ci NOT NULL,
  value_email_bcc varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  value_deflt_antivol varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '0',
  explr_invisible mediumtext COLLATE utf8_unicode_ci,
  explr_visible_mod mediumtext COLLATE utf8_unicode_ci,
  explr_visible_unmod mediumtext COLLATE utf8_unicode_ci,
  deflt3bibli int(5) unsigned NOT NULL DEFAULT '0',
  deflt3exercice int(8) unsigned NOT NULL DEFAULT '0',
  deflt3rubrique int(8) unsigned NOT NULL DEFAULT '0',
  deflt3dev_statut int(3) NOT NULL DEFAULT '-1',
  deflt3cde_statut int(3) NOT NULL DEFAULT '-1',
  deflt3liv_statut int(3) NOT NULL DEFAULT '-1',
  deflt3fac_statut int(3) NOT NULL DEFAULT '-1',
  deflt3sug_statut int(3) NOT NULL DEFAULT '-1',
  environnement mediumblob NOT NULL,
  param_allloc int(1) unsigned NOT NULL DEFAULT '0',
  grp_num int(10) unsigned DEFAULT '0',
  deflt_arch_statut int(6) unsigned NOT NULL DEFAULT '0',
  deflt_arch_emplacement int(6) unsigned NOT NULL DEFAULT '0',
  deflt_arch_type int(6) unsigned NOT NULL DEFAULT '0',
  deflt_upload_repertoire int(8) NOT NULL DEFAULT '0',
  deflt3lgstatdev int(3) NOT NULL DEFAULT '1',
  deflt3lgstatcde int(3) NOT NULL DEFAULT '1',
  deflt3receptsugstat int(3) NOT NULL DEFAULT '32',
  deflt_short_loan_activate int(1) unsigned NOT NULL DEFAULT '0',
  deflt_cashdesk int(11) NOT NULL DEFAULT '0',
  deflt_explnum_statut int(6) unsigned NOT NULL DEFAULT '1',
  user_alert_suggmail int(1) unsigned NOT NULL DEFAULT '0',
  deflt_notice_replace_keep_categories int(1) NOT NULL DEFAULT '0',
  deflt_notice_is_new int(1) unsigned NOT NULL DEFAULT '0',
  deflt_agnostic_warehouse int(6) unsigned NOT NULL DEFAULT '0',
  deflt_cms_article_statut int(6) unsigned NOT NULL DEFAULT '0',
  deflt_cms_article_type int(6) unsigned NOT NULL DEFAULT '0',
  deflt_cms_section_type int(6) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (userid)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users`
--

LOCK TABLES users WRITE;
/*!40000 ALTER TABLE users DISABLE KEYS */;
INSERT INTO users (userid, create_dt, last_updated_dt, username, pwd, user_digest, nom, prenom, rights, user_lang, nb_per_page_search, nb_per_page_select, nb_per_page_gestion, param_popup_ticket, param_sounds, param_rfid_activate, param_licence, deflt_notice_statut, deflt_integration_notice_statut, xmlta_indexation_lang, deflt_docs_type, deflt_lenders, deflt_styles, deflt_docs_statut, deflt_docs_codestat, value_deflt_lang, value_deflt_fonction, value_deflt_relation, value_deflt_relation_serial, value_deflt_relation_bulletin, value_deflt_relation_analysis, deflt_docs_location, deflt_collstate_location, deflt_bulletinage_location, deflt_resas_location, deflt_docs_section, value_deflt_module, user_email, user_alert_resamail, user_alert_demandesmail, user_alert_subscribemail, deflt2docs_location, deflt_empr_statut, deflt_thesaurus, deflt_concept_scheme, deflt_import_thesaurus, value_prefix_cote, xmlta_doctype, xmlta_doctype_serial, xmlta_doctype_bulletin, xmlta_doctype_analysis, speci_coordonnees_etab, value_email_bcc, value_deflt_antivol, explr_invisible, explr_visible_mod, explr_visible_unmod, deflt3bibli, deflt3exercice, deflt3rubrique, deflt3dev_statut, deflt3cde_statut, deflt3liv_statut, deflt3fac_statut, deflt3sug_statut, environnement, param_allloc, grp_num, deflt_arch_statut, deflt_arch_emplacement, deflt_arch_type, deflt_upload_repertoire, deflt3lgstatdev, deflt3lgstatcde, deflt3receptsugstat, deflt_short_loan_activate, deflt_cashdesk, deflt_explnum_statut, user_alert_suggmail, deflt_notice_replace_keep_categories, deflt_notice_is_new, deflt_agnostic_warehouse, deflt_cms_article_statut, deflt_cms_article_type, deflt_cms_section_type) VALUES (1,'2002-07-28','2012-12-14','admin','*4ACFE3202A5FF5CF467898FC58AAB1D615029441','028262ca7d82187e983fa4a9937891e2','Super User','',198911,'fr_FR',20,20,50,0,0,0,0,1,1,'',1,2,'enjoy',1,12,'fre','070','a-up','a-up','a-up','a-up',1,0,1,0,10,'admin','pmb@sigb.net',0,0,0,1,1,1,0,1,'','a','a','a','a','','','0','0','0','0',0,0,0,-1,-1,-1,-1,-1,'',1,0,1,1,1,0,1,1,64,0,0,1,0,0,0,0,0,0,0);
/*!40000 ALTER TABLE users ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_groups`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE users_groups (
  grp_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  grp_name varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (grp_id),
  KEY i_users_groups_grp_name (grp_name)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_groups`
--

LOCK TABLES users_groups WRITE;
/*!40000 ALTER TABLE users_groups DISABLE KEYS */;
/*!40000 ALTER TABLE users_groups ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `vedette`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE vedette (
  id_vedette int(11) unsigned NOT NULL AUTO_INCREMENT,
  label varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  grammar varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'rameau',
  PRIMARY KEY (id_vedette)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `vedette`
--

LOCK TABLES vedette WRITE;
/*!40000 ALTER TABLE vedette DISABLE KEYS */;
/*!40000 ALTER TABLE vedette ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `vedette_link`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE vedette_link (
  num_vedette int(10) unsigned NOT NULL,
  num_object int(10) unsigned NOT NULL,
  type_object int(10) unsigned NOT NULL,
  PRIMARY KEY (num_vedette,num_object,type_object)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `vedette_link`
--

LOCK TABLES vedette_link WRITE;
/*!40000 ALTER TABLE vedette_link DISABLE KEYS */;
/*!40000 ALTER TABLE vedette_link ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `vedette_object`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE vedette_object (
  object_type int(3) unsigned NOT NULL DEFAULT '0',
  object_id int(11) unsigned NOT NULL DEFAULT '0',
  num_vedette int(11) unsigned NOT NULL DEFAULT '0',
  subdivision varchar(50) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  position int(3) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (object_type,object_id,num_vedette,subdivision,position),
  KEY i_vedette_object_object (object_type,object_id),
  KEY i_vedette_object_vedette (num_vedette)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `vedette_object`
--

LOCK TABLES vedette_object WRITE;
/*!40000 ALTER TABLE vedette_object DISABLE KEYS */;
/*!40000 ALTER TABLE vedette_object ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `visionneuse_params`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE visionneuse_params (
  visionneuse_params_id int(11) NOT NULL AUTO_INCREMENT,
  visionneuse_params_class varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  visionneuse_params_parameters mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (visionneuse_params_id),
  UNIQUE KEY visionneuse_params_class (visionneuse_params_class)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `visionneuse_params`
--

LOCK TABLES visionneuse_params WRITE;
/*!40000 ALTER TABLE visionneuse_params DISABLE KEYS */;
INSERT INTO visionneuse_params (visionneuse_params_id, visionneuse_params_class, visionneuse_params_parameters) VALUES (1,'epub','a:2:{s:6:&quot;size_x&quot;;s:2:&quot;95&quot;;s:6:&quot;size_y&quot;;s:2:&quot;95&quot;;}');
/*!40000 ALTER TABLE visionneuse_params ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `voir_aussi`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE voir_aussi (
  num_noeud_orig int(9) unsigned NOT NULL DEFAULT '0',
  num_noeud_dest int(9) unsigned NOT NULL DEFAULT '0',
  langue varchar(5) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  comment_voir_aussi mediumtext COLLATE utf8_unicode_ci NOT NULL,
  PRIMARY KEY (num_noeud_orig,num_noeud_dest,langue),
  KEY num_noeud_dest (num_noeud_dest)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `voir_aussi`
--

LOCK TABLES voir_aussi WRITE;
/*!40000 ALTER TABLE voir_aussi DISABLE KEYS */;
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1390,1602,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1391,1599,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1392,1600,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1394,2166,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1395,1596,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1398,1597,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1399,1592,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1400,1601,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1401,1592,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1411,2105,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1413,2106,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1414,2104,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1415,2103,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1416,2102,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1417,2101,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1431,2058,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1435,2060,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1545,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1553,1612,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1563,2493,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1592,1399,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1592,1401,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1595,2479,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1596,1395,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1597,1398,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1598,2200,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1599,1391,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1600,1392,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1601,1400,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1602,1390,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1607,2407,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1612,1553,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1623,1795,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1623,1796,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1628,1737,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1670,2494,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1672,2494,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1726,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1729,2496,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1737,1628,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1760,2280,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1795,1623,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (1796,1623,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2057,2112,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2058,1431,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2060,1435,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2101,1417,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2102,1416,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2103,1415,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2104,1414,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2105,1411,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2106,1413,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2112,2057,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2166,1394,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2184,2485,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2184,2486,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2200,1598,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2280,1760,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2407,1607,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2467,2510,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2479,1595,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2485,2184,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2486,2184,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2490,2495,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2491,1545,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2491,1726,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2491,2496,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2491,2499,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2491,2500,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2492,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2493,2490,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2493,2495,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2494,1670,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2494,1672,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2494,2490,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2495,2493,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2496,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2496,2497,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2497,2496,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2499,2496,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2499,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2499,1689,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2500,2492,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2500,2491,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2500,1689,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2502,2492,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2504,2503,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2507,2509,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2508,1764,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2509,2507,'fr_FR','');
INSERT INTO voir_aussi (num_noeud_orig, num_noeud_dest, langue, comment_voir_aussi) VALUES (2510,1672,'fr_FR','');
/*!40000 ALTER TABLE voir_aussi ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `words`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE words (
  id_word int(10) unsigned NOT NULL AUTO_INCREMENT,
  word varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  double_metaphone varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  stem varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (id_word),
  UNIQUE KEY i_word_lang (word,lang),
  KEY i_stem_lang (stem,lang)
) ENGINE=MyISAM AUTO_INCREMENT=3934 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `words`
--

LOCK TABLES words WRITE;
/*!40000 ALTER TABLE words DISABLE KEYS */;
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1,'039125','','','039125');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2,'07','','','07');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3,'1','','','1');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (4,'125','','','125');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (5,'126','','','126');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (6,'140','','','140');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (7,'18','','','18');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (8,'1820','','','1820');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (9,'1865','','','1865');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (10,'1867','','','1867');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (11,'1897','','','1897');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (12,'1985','','','1985');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (13,'1996','','','1996');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (14,'1997','','','1997');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (15,'1998','','','1998');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (16,'1999','','','1999');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (17,'2','','','2');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (18,'2004','','','2004');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (19,'2062','','','2062');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (20,'20sf','','SF SF','20sf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (21,'3','','','3');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (22,'330','','','330');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (23,'33700003470461','','','33700003470461');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (24,'33700003868672','','','33700003868672');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (25,'33700004243164','','','33700004243164');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (26,'3370000451296','','','3370000451296');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (27,'3370000451300','','','3370000451300');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (28,'3370000451301','','','3370000451301');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (29,'38','','','38');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (30,'4','','','4');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (31,'47','','','47');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (32,'48','','','48');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (33,'547','','','547');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (34,'551','','','551');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (35,'58','','','58');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (36,'590','','','590');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (37,'62','','','62');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (38,'7','','','7');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (39,'70','','','70');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (40,'7234','','','7234');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (41,'760','','','760');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (42,'780','','','780');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (43,'840','','','840');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (44,'86274','','','86274');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (45,'86967','','','86967');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (46,'910','','','910');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (47,'978','','','978');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (48,'aborigenes','','APRJ APRK','aborigen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (49,'actant','','AKTN AKTN','actant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (50,'acteur','','AKTR AKTR','acteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (51,'adagio','','ATJ ATK','adagio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (52,'admis','','ATMS ATMS','admis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (53,'adultes','','ATLT ATLT','adult');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (54,'affectueusement','','AFKT AFKT','affectu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (55,'africain','','AFRK AFRK','africain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (56,'afrique','fr_FR','AFRK AFRK','afriqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (57,'aise','','AS AS','ais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (58,'ajouter','','AJTR AHTR','ajout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (59,'albinoni','','ALPN ALPN','albinon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (60,'allie','','AL AL','alli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (61,'ami','','AM AM','ami');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (62,'andante','','ANTN ANTN','andant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (63,'andreae','','ANTR ANTR','andrea');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (64,'animaux','','ANM ANM','animal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (65,'annees','','ANS ANS','anne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (66,'anthropologie','','AN0R ANTR','anthropolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (67,'archeologiques','','ARXL ARKL','archeolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (68,'argentine','','ARJN ARKN','argentin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (69,'argentine','fr_FR','ARJN ARKN','argentin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (70,'arrondissements','','ARNT ARNT','arrond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (71,'artiodactyles','','ARTT ARTT','artiodactyl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (72,'arts','','ARTS ARTS','art');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (73,'associe','','ASS ASX','assoc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (74,'assure','','ASR ASR','assur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (75,'atlantique','','ATLN ATLN','atlant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (76,'aube','','AP AP','aub');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (77,'audio','','AT AT','audio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (78,'audios','','ATS ATS','audios');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (79,'australie','','ASTR ASTR','austral');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (80,'australie','fr_FR','ASTR ASTR','austral');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (81,'authentifier','','A0NT ATNT','authentifi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (82,'autour','','ATR ATR','autour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (83,'autres','','ATRS ATRS','autr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (84,'avant','','AFNT AFNT','avant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (85,'aventure','','AFNT AFNT','aventur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (86,'avoir','','AFR AFR','avoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (87,'ayant','','ANT ANT','ayant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (88,'bach','','PK PK','bach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (89,'balzac','','PLSK PLSK','balzac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (90,'bande','','PNT PNT','band');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (91,'bande','fr_FR','PNT PNT','band');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (92,'baptiste','','PPTS PPTS','baptist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (93,'baroques','','PRKS PRKS','baroqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (94,'bdp','','PTP PTP','bdp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (95,'benard','','PNRT PNRT','benard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (96,'benjamin','','PNJM PNJM','benjamin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (97,'betises','','PTSS PTSS','betis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (98,'bibliobus','','PPLP PPLP','bibliobus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (99,'bibliotheque','','PPL0 PPLT','bibliothequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (100,'bien','','PN PN','bien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (101,'boccherini','','PXRN PXRN','boccherin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (102,'bon','','PN PN','bon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (103,'bonne','','PN PN','bon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (104,'boos','','PS PS','boos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (105,'bouts','','PTS PTS','bout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (106,'bri','','PR PR','bri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (107,'brillant','','PRLN PRLN','brill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (108,'bruit','','PRT PRT','bruit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (109,'bruitage','','PRTJ PRTK','bruitag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (110,'bruitages','','PRTJ PRTK','bruitag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (111,'camille','','KML KML','camill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (112,'canon','','KNN KNN','canon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (113,'cantilene','','KNTL KNTL','cantilen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (114,'carte','','KRT KRT','cart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (115,'cartonne','','KRTN KRTN','carton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (116,'casimir','','KSMR KSMR','casim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (117,'cd','','KT KT','cd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (118,'ce','','S S','ce');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (119,'celebre','','SLPR SLPR','celebr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (120,'central','','SNTR SNTR','central');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (121,'ces','','SS SS','ce');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (122,'cet','','ST ST','cet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (123,'cette','','ST ST','cet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (124,'chainon','','XNN XNN','chainon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (125,'chainons','','XNNS XNNS','chainon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (126,'chateaux','','XT XT','chateau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (127,'cherche','','XRX XRK','cherch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (128,'chirurgien','','XRRJ XRRK','chirurgien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (129,'christian','','KRSX KRSX','christian');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (130,'chrysalide','','KRSL KRSL','chrysalid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (131,'ciel','','SL XL','ciel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (132,'cinema','','SNM SNM','cinem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (133,'clowns','','KLNS KLNS','clown');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (134,'coc','','KK KK','coc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (135,'cochette','','KXT KKT','cochet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (136,'cochon','','KXN KKN','cochon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (137,'cochons','','KXNS KKNS','cochon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (138,'comme','','KM KM','comm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (139,'compagnon','','KMPN KMPK','compagnon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (140,'compositeur','','KMPS KMPS','compositeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (141,'concerto','','KNSR KNSR','concerto');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (142,'confirme','','KNFR KNFR','confirm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (143,'conjugent','','KNJJ KNJK','conjugent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (144,'connait','','KNT KNT','con');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (145,'conscience','','KNSN KNSN','conscienc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (146,'consommation','','KNSM KNSM','consomm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (147,'consultation','','KNSL KNSL','consult');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (148,'conte','','KNT KNT','cont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (149,'contemporain','','KNTM KNTM','contemporain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (150,'convaincu','','KNFN KNFN','convaincu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (151,'cordes','','KRTS KRTS','cord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (152,'coul','','KL KL','coul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (153,'couleurs','','KLRS KLRS','couleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (154,'courts','','KRTS KRTS','court');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (155,'couv','','KF KF','couv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (156,'crane','','KRN KRN','cran');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (157,'crimee','','KRM KRM','crime');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (158,'crise','','KRS KRS','cris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (159,'cruels','','KRLS KRLS','cruel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (160,'dangereusement','','TNJR TNKR','danger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (161,'dans','','TNS TNS','dan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (162,'debout','','TPT TPT','debout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (163,'decide','','TST TST','decid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (164,'decor','','TKR TKR','decor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (165,'decouvert','','TKFR TKFR','decouvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (166,'decouverte','','TKFR TKFR','decouvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (167,'delires','','TLRS TLRS','delir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (168,'demeure','','TMR TMR','demeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (169,'deroule','','TRL TRL','deroul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (170,'desert','','TSRT TSRT','desert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (171,'dessin','fr_FR','TSN TSN','dessin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (172,'dessinee','','TSN TSN','dessine');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (173,'deux','','TKS TKS','deux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (174,'devenu','','TFN TFN','devenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (175,'diapree','','TPR TPR','diapre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (176,'dieu','','T T','dieu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (177,'document','','TKMN TKMN','docu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (178,'documentaires','','TKMN TKMN','documentair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (179,'doit','','TT TT','doit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (180,'dont','','TNT TNT','dont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (181,'drame','','TRM TRM','dram');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (182,'economie','','AKNM AKNM','econom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (183,'economie','fr_FR','AKNM AKNM','econom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (184,'efficace','','AFKS AFKS','efficac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (185,'enfants','','ANFN ANFN','enfant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (186,'enfin','','ANFN ANFN','enfin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (187,'engluer','','ANKL ANKL','englu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (188,'enregistrement','','ANRJ ANRK','enregistr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (189,'enterrement','','ANTR ANTR','enterr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (190,'entre','','ANTR ANTR','entre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (191,'eploree','','APLR APLR','eplore');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (192,'espoirs','','ASPR ASPR','espoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (193,'est','','AST AST','est');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (194,'etait','','ATT ATT','etait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (195,'etat','','ATT ATT','etat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (196,'etrangers','','ATRN ATRN','etranger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (197,'etudes','','ATTS ATTS','etud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (198,'exactement','','AKSK AKSK','exact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (199,'exotique','','AKST AKST','exot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (200,'extrait','','AKST AKST','extrait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (201,'faire','','FR FR','fair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (202,'fait','','FT FT','fait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (203,'fameux','','FMKS FMKS','fameux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (204,'femme','','FM FM','femm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (205,'ferrero','','FRR FRR','ferrero');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (206,'fete','','FT FT','fet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (207,'fichier','','FX FKR','fichi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (208,'fiction','','FKXN FKXN','fiction');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (209,'film','','FLM FLM','film');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (210,'finances','','FNNS FNNS','financ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (211,'fins','','FNS FNS','fin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (212,'fond','','FNT FNT','fond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (213,'fonds','','FNTS FNTS','fond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (214,'foraine','','FRN FRN','forain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (215,'fossiles','','FSLS FSLS','fossil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (216,'fr','','FR FR','fr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (217,'fran','','FRN FRN','fran');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (218,'fuite','','FT FT','fuit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (219,'funeste','','FNST FNST','funest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (220,'g','','K K','g');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (221,'gal','','KL KL','gal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (222,'gallie','','KL KL','gall');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (223,'garnison','','KRNS KRNS','garnison');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (224,'geo','','J K','geo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (225,'goret','','KRT KRT','goret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (226,'grand','','KRNT KRNT','grand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (227,'graphiques','','KRFK KRFK','graphiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (228,'graphisme','','KRFS KRFS','graphism');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (229,'grave','','KRF KRF','grav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (230,'groin','','KRN KRN','groin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (231,'guenon','','KNN KNN','guenon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (232,'habilement','','HPLM HPLM','habil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (233,'haut','','HT HT','haut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (234,'heure','','HR HR','heur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (235,'histoire','','HSTR HSTR','histoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (236,'historique','','HSTR HSTR','histor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (237,'hollandais','','HLNT HLNT','holland');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (238,'hollywood','','HLT HLT','hollywood');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (239,'homme','','HM HM','homm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (240,'http','','TP TP','http');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (241,'hugo','','HK HK','hugo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (242,'il','','AL AL','il');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (243,'ile','','AL AL','ile');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (244,'ill','','AL AL','ill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (245,'indetermine','','ANTT ANTT','indetermin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (246,'inferieure','','ANFR ANFR','inferieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (247,'interet','','ANTR ANTR','interet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (248,'intrigue','','ANTR ANTR','intrigu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (249,'investit','','ANFS ANFS','invest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (250,'ironie','','ARN ARN','iron');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (251,'j','','J A','j');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (252,'jacob','','JKP AKP','jacob');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (253,'java','','JF AF','jav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (254,'jbd','','JPT APT','jbd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (255,'jean','','JN AN','jean');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (256,'jesus','','JSS ASS','jesus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (257,'jeunes','','JNS ANS','jeun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (258,'jexiste','','JKSS AKSS','jexist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (259,'joie','','J A','joi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (260,'jour','','JR AR','jour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (261,'journaliste','','JRNL ARNL','journal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (262,'jr','','JR AR','jr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (263,'laisse','','LS LS','laiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (264,'lam','','LM LM','lam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (265,'lamartine','','LMRT LMRT','lamartin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (266,'lamquet','','LMKT LMKT','lamquet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (267,'lecteur','','LKTR LKTR','lecteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (268,'les','','LS LS','le');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (269,'leur','','LR LR','leur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (270,'leurs','','LRS LRS','leur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (271,'litt','','LT LT','litt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (272,'livre','','LFR LFR','livr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (273,'livre','fr_FR','LFR LFR','livr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (274,'livret','','LFRT LFRT','livret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (275,'loire','','LR LR','loir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (276,'loire','fr_FR','LR LR','loir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (277,'longue','','LNK LNK','longu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (278,'louables','','LPLS LPLS','louabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (279,'lucy','','LS LS','lucy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (280,'lui','','L L','lui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (281,'ma','','M M','ma');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (282,'machoire','','MKR MKR','machoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (283,'magie','','MJ MK','mag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (284,'mais','','M MS','mais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (285,'maitres','','MTRS MTRS','maitr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (286,'majeur','','MJR MJR','majeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (287,'mal','','ML ML','mal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (288,'malheurs','','MLRS MLRS','malheur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (289,'malicieux','','MLSK MLXK','malici');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (290,'mammif','fr_FR','MMF MMF','mammif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (291,'mandoline','','MNTL MNTL','mandolin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (292,'mangecoeur','','MNJK MNKK','mangecoeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (293,'manquant','','MNKN MNKN','manqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (294,'mariages','','MRJS MRKS','mariag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (295,'marigot','','MRKT MRKT','marigot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (296,'maternite','','MTRN MTRN','maternit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (297,'mathieu','','M0 MT','mathieu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (298,'melange','','MLNJ MLNK','melang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (299,'meme','','MM MM','mem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (300,'menuet','','MNT MNT','menuet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (301,'merveilleux','','MRFL MRFL','merveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (302,'meurt','','MRT MRT','meurt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (303,'millions','','MLNS MLNS','million');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (304,'mis','','MS MS','mis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (305,'monde','','MNT MNT','mond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (306,'mondialisation','fr_FR','MNTL MNTL','mondialis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (307,'morceau','','MRS MRS','morceau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (308,'mozart','','MSRT MSRT','mozart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (309,'mp3','','MP MP','mp3');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (310,'multimedia','','MLTM MLTM','multimedi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (311,'musique','','MSK MSK','musiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (312,'musset','','MST MST','musset');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (313,'nantes','','NNTS NNTS','nant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (314,'ne','','N N','ne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (315,'nomment','','NMNT NMNT','nomment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (316,'notoriete','','NTRT NTRT','notoriet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (317,'nouvelle','','NFL NFL','nouvel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (318,'nouvelles','','NFLS NFLS','nouvel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (319,'nouvelles','fr_FR','NFLS NFLS','nouvel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (320,'occultisme','','AKLT AKLT','occult');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (321,'ocean','','ASN ASN','ocean');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (322,'ographie','','AKRF AKRF','ograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (323,'on','','AN AN','on');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (324,'ou','','A A','ou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (325,'p','','P P','p');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (326,'pachelbel','','PXLP PKLP','pachelbel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (327,'pages','','PJS PKS','pag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (328,'paimboeuf','','PMPF PMPF','paimboeuf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (329,'pantagas','','PNTK PNTK','pantag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (330,'papillon','','PPLN PPLN','papillon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (331,'par','','PR PR','par');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (332,'parce','','PRS PRS','parc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (333,'parcourant','','PRKR PRKR','parcour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (334,'passions','','PSNS PSNS','passion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (335,'pays','fr_FR','PS PS','pay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (336,'perdu','','PRT PRT','perdu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (337,'pere','','PR PR','per');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (338,'personnage','','PRSN PRSN','personnag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (339,'personnages','','PRSN PRSN','personnag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (340,'pete','','PT PT','pet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (341,'petit','','PTT PTT','pet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (342,'peu','','P P','peu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (343,'peuple','','PPL PPL','peupl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (344,'pistes','','PSTS PSTS','pist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (345,'pl','','PL PL','pl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (346,'place','','PLS PLS','plac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (347,'plaintive','','PLNT PLNT','plaintiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (348,'plus','','PLS PLS','plus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (349,'pmb','','PMP PMP','pmb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (350,'poisse','','PS PS','poiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (351,'porc','','PRK PRK','porc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (352,'porcelet','','PRSL PRSL','porcelet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (353,'porterait','','PRTR PRTR','port');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (354,'pour','','PR PR','pour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (355,'poursuivi','','PRSF PRSF','poursuiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (356,'pourtant','','PRTN PRTN','pourt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (357,'precieuses','','PRSS PRXS','precieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (358,'premier','','PRM PRMR','premi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (359,'principale','','PRNS PRNS','principal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (360,'production','','PRTK PRTK','product');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (361,'propre','','PRPR PRPR','propr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (362,'prouver','','PRFR PRFR','prouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (363,'puis','','PS PS','puis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (364,'qu','','K K','qu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (365,'qualite','','KLT KLT','qualit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (366,'quatorze','','KTRS KTRS','quatorz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (367,'quatre','','KTR KTR','quatr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (368,'que','','K K','que');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (369,'quelques','','KLKS KLKS','quelqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (370,'qui','','K K','qui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (371,'r','','R R','r');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (372,'ramener','','RMNR RMNR','ramen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (373,'rature','','RTR RTR','ratur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (374,'re','','R R','re');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (375,'realite','','RLT RLT','realit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (376,'rebondissements','','RPNT RPNT','rebond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (377,'recit','','RST RST','rec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (378,'recueil','','RKL RKL','recueil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (379,'region','','RJN RKN','region');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (380,'regional','','RJNL RKNL','regional');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (381,'regnent','','RNNT RKNN','regnent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (382,'reliques','','RLKS RLKS','reliqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (383,'remuer','','RMR RMR','remu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (384,'rencontre','','RNKN RNKN','rencontr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (385,'renon','','RNN RNN','renon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (386,'res','fr_FR','RS RS','re');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (387,'reserve','','RSRF RSRF','reserv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (388,'reve','','RF RF','rev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (389,'riche','','RX RK','rich');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (390,'rififi','','RFF RFF','rifif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (391,'roman','','RMN RMN','roman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (392,'romans','','RMNS RMNS','roman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (393,'s','','S S','s');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (394,'sa','','S S','sa');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (395,'sauver','','SFR SFR','sauv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (396,'savane','','SFN SFN','savan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (397,'savants','','SFNT SFNT','sav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (398,'scenario','','SNR SNR','scenario');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (399,'se','','S S','se');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (400,'semarang','','SMRN SMRN','semarang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (401,'serie','','SR SR','ser');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (402,'servi','','SRF SRF','serv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (403,'services','','SRFS SRFS','servic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (404,'ses','','SS SS','se');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (405,'seul','','SL SL','seul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (406,'seule','','SL SL','seul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (407,'seuls','','SLS SLS','seul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (408,'si','','S S','si');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (409,'singe','','SNJ SNK','sing');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (410,'sommeille','','SML SML','sommeil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (411,'son','','SN SN','son');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (412,'sont','','SNT SNT','sont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (413,'soundfishing','','SNTF SNTF','soundfishing');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (414,'spiritisme','','SPRT SPRT','spirit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (415,'studio','','STT STT','studio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (416,'succedent','','SXTN SXTN','succedent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (417,'suides','','STS STS','suid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (418,'sur','','SR SR','sur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (419,'surnomme','','SRNM SRNM','surnomm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (420,'talent','','TLNT TLNT','talent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (421,'tatars','','TTRS TTRS','tatar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (422,'terre','','TR TR','terr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (423,'theosophie','','0SF TSF','theosoph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (424,'thomas','','TMS TMS','thom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (425,'tome','','TM TM','tom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (426,'tous','','TS TS','tous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (427,'trait','','TRT TRT','trait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (428,'truie','','TR TR','trui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (429,'uns','','ANS ANS','un');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (430,'utilisant','','ATLS ATLS','utilis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (431,'utilisent','','ATLS ATLS','utilisent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (432,'utopies','','ATPS ATPS','utop');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (433,'uvre','','AFR AFR','uvre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (434,'valise','','FLS FLS','valis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (435,'venitien','','FNTN FNTN','venitien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (436,'verrat','','FRT FRT','verrat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (437,'vertebres','','FRTP FRTP','vertebr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (438,'veuve','','FF FF','veuv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (439,'vigny','','FN FKN','vigny');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (440,'vivaldi','','FFLT FFLT','vivald');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (441,'voici','','FS FS','voic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (442,'vont','','FNT FNT','vont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (443,'voyage','fr_FR','FJ FK','voyag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (444,'voyages','','FJS FKS','voyag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (445,'vraiment','','FRMN FRMN','vrai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (446,'vue','','F F','vu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (447,'y','','A A','y');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (448,'zele','','SL SL','zel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (449,'zim','','SM SM','zim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (450,'zoologie','','SLJ SLK','zoolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (451,'test','','TST TST','test');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (452,'lgt','','LKT LKT','lgt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (453,'editeur','','ATTR ATTR','editeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (454,'collection','','KLKX KLKX','collect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (455,'pyongyan','','PNKN PNJN','pyongyan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (456,'delisle','','TLL TLL','delisl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (457,'guy','','K K','guy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (458,'278','','','278');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (459,'voyage','','FJ FK','voyag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (460,'inde','','ANT ANT','inde');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (461,'bac','','PK PK','bac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (462,'poche','','PX PK','poch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (463,'7e','','','7e');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (464,'ed','','AT AT','ed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (465,'166','','','166');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (466,'devenue','','TFN TFN','devenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (467,'plate','','PLT PLT','plat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (468,'imaginait','','AMJN AMKN','imagin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (469,'moyen','','MN MN','moyen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (470,'age','','AJ AK','age');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (471,'faut','','FT FT','faut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (472,'pas','','PS PS','pas');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (473,'trop','','TRP TRP','trop');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (474,'approcher','','APRX APRK','approch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (475,'bord','','PRT PRT','bord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (476,'c','','K K','c');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (477,'evidemment','','AFTM AFTM','evident');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (478,'journee','','JRN ARN','journe');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (479,'magnifique','','MNFK MKNF','magnif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (480,'catalogue','','KTLK KTLK','catalogu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (481,'compagnie','','KMPN KMPK','compagn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (482,'moment','','MMNT MMNT','moment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (483,'bureau','','PR PR','bureau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (484,'kin','','KN KN','kin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (485,'donnait','','TNT TNT','don');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (486,'lagon','','LKN LKN','lagon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (487,'frange','','FRNJ FRNK','frang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (488,'palmiers','','PLMR PLMR','palmi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (489,'rouleaux','','RL RL','rouleau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (490,'brisaient','','PRSN PRSN','bris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (491,'contre','','KNTR KNTR','contr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (492,'recifs','','RSFS RSFS','recif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (493,'211','','','211');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (494,'04459','','','04459');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (495,'roman','fr_FR','RMN RMN','roman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (496,'aventure','fr_FR','AFNT AFNT','aventur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (497,'33700004388761','','','33700004388761');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (498,'sou','','S S','sou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (499,'pyongyang','','PNKN PNJN','pyongyang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (500,'germinal','','KRMN JRMN','germinal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (501,'1995','','','1995');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (502,'nouveau','','NF NF','nouveau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (503,'g','fr_FR','K K','g');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (504,'ographie','fr_FR','AKRF AKRF','ograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (505,'3370000451293','','','3370000451293');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (506,'3370000451294','','','3370000451294');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (507,'pmb0006','','PMP PMP','pmb0006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (508,'mag','','MK MK','mag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (509,'periodique','','PRTK PRTK','period');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (510,'chateau','','XT XT','chateau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (511,'du','','T T','du');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (512,'loir','','LR LR','loir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (513,'guide','','KT KT','guid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (514,'elections','','ALKX ALKX','elect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (515,'americaines','','AMRK AMRK','americain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (516,'impr','','AMPR AMPR','impr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (517,'2012','','','2012');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (518,'vol','','FL FL','vol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (519,'250','','','250');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (520,'porte','','PRT PRT','port');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (521,'duel','','TL TL','duel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (522,'obama','','APM APM','obam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (523,'romney','','RMN RMN','romney');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (524,'presidents','','PRST PRST','president');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (525,'election','','ALKX ALKX','elect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (526,'etats','','ATTS ATTS','etat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (527,'unis','','ANS ANS','unis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (528,'262','','','262');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (529,'04066','','','04066');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (530,'6','','','6');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (531,'perrin','','PRN PRN','perrin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (532,'paris','','PRS PRS','paris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (533,'324','','','324');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (534,'973','','','973');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (535,'0093','','','0093');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (536,'tempus','','TMPS TMPS','tempus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (537,'bacharan','','PKRN PKRN','bacharan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (538,'nicole','','NKL NKL','nicol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (539,'simonnet','','SMNT SMNT','simonnet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (540,'dominique','','TMNK TMNK','domin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (541,'1951','','','1951');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (542,'traite','','TRT TRT','trait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (543,'abandon','','APNT APNT','abandon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (544,'pensees','','PNSS PNSS','pense');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (545,'160','','','160');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (546,'alexandre','','ALKS ALKS','alexandr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (547,'jollien','','JLN ALN','jollien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (548,'poursuit','','PRST PRST','poursuit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (549,'quete','','KT KT','quet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (550,'philosophique','','FLSF FLSF','philosoph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (551,'dune','','TN TN','dun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (552,'sagesse','','SJS SKS','sagess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (553,'nous','','NS NS','nous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (554,'apporte','','APRT APRT','apport');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (555,'paix','','PKS PKS','paix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (556,'interieure','','ANTR ANTR','interieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (557,'but','','PT PT','but');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (558,'voie','','F F','voi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (559,'royale','','RL RL','royal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (560,'vivre','','FFR FFR','vivr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (561,'theme','','0M TM','them');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (562,'directeur','','TRKT TRKT','directeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (563,'labandon','','LPNT LPNT','labandon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (564,'termes','','TRMS TRMS','term');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (565,'bouddhistes','','PTST PTST','bouddhist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (566,'non','','NN NN','non');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (567,'fixation','','FKSX FKSX','fixat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (568,'fixer','','FKSR FKSR','fix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (569,'cest','','SST SST','cest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (570,'debarrasser','','TPRS TPRS','debarrass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (571,'representations','','RPRS RPRS','represent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (572,'etiquettes','','ATKT ATKT','etiquet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (573,'figent','','FJNT FKNT','figent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (574,'identites','','ATNT ATNT','identit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (575,'immuables','','AMPL AMPL','immuabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (576,'laisser','','LSR LSR','laiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (577,'vie','','F F','vi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (578,'etre','','ATR ATR','etre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (579,'quelle','','KL KL','quel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (580,'rien','','RN RN','rien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (581,'vouloir','','FLR FLR','vouloir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (582,'changer','','XNKR XNJR','chang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (583,'sobstiner','','SPST SPST','sobstin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (584,'ouvert','','AFRT AFRT','ouvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (585,'changement','','XNJM XNKM','chang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (586,'cela','','SL SL','cel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (587,'rend','','RNT RNT','rend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (588,'perte','','PRT PRT','pert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (589,'vivable','','FFPL FFPL','vivabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (590,'lautre','','LTR LTR','lautr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (591,'aussi','','AS AS','auss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (592,'chemin','','KMN KMN','chemin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (593,'determinant','','TTRM TTRM','determin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (594,'saccepter','','SXPT SXPT','saccept');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (595,'soi','','S S','soi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (596,'tel','','TL TL','tel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (597,'lon','','LN LN','lon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (598,'handicape','','HNTK HNTK','handicap');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (599,'travail','','TRFL TRFL','travail');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (600,'permanent','','PRMN PRMN','permanent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (601,'dalexandre','','TLKS TLKS','dalexandr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (602,'source','','SRS SRS','sourc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (603,'livres','','LFRS LFRS','livr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (604,'chacune','','XKN XKN','chacun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (605,'20','','','20');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (606,'reunies','','RNS RNS','reun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (607,'celui','','SL SL','celui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (608,'ci','','S S','ci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (609,'fois','','F FS','fois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (610,'remede','','RMT RMT','remed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (611,'meditation','','MTTX MTTX','medit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (612,'vivante','','FFNT FFNT','viv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (613,'obstacles','','APST APST','obstacl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (614,'ecartent','','AKRT AKRT','ecartent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (615,'chemins','','KMNS KMNS','chemin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (616,'conduisent','','KNTS KNTS','conduisent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (617,'lamitie','','LMT LMT','lamit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (618,'determination','','TTRM TTRM','determin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (619,'fragilite','','FRJL FRKL','fragilit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (620,'gratuite','','KRTT KRTT','gratuit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (621,'etc','','ATK ATK','etc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (622,'autant','','ATNT ATNT','aut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (623,'voies','','FS FS','voi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (624,'qualexandre','','KLKS KLKS','qualexandr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (625,'sefforce','','SFRS SFRS','sefforc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (626,'dexperimenter','','TKSP TKSP','dexperiment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (627,'quotidien','','KTTN KTTN','quotidien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (628,'puisant','','PSNT PSNT','puis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (629,'petits','','PTTS PTTS','petit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (630,'evenements','','AFNM AFNM','even');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (631,'heureux','','HRKS HRKS','heureux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (632,'malheureux','','MLRK MLRK','malheur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (633,'ponctuent','','PNKT PNKT','ponctuent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (634,'reflexion','','RFLK RFLK','reflexion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (635,'querelle','','KRL KRL','querel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (636,'impatience','','AMPT AMPT','impatient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (637,'angoisse','','ANKS ANKS','angoiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (638,'ressources','','RSRS RSRS','ressourc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (639,'accueillir','','AKLR AKLR','accueil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (640,'sans','','SNS SNS','san');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (641,'souffrance','','SFRN SFRN','souffranc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (642,'esquisse','','ASKS ASKS','esquiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (643,'ainsi','','ANS ANS','ains');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (644,'art','','ART ART','art');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (645,'depouille','','TPL TPL','depouill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (646,'aide','','AT AT','aid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (647,'trouver','','TRFR TRFR','trouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (648,'laudace','','LTS LTS','laudac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (649,'danser','','TNSR TNSR','dans');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (650,'joyeusement','','JSMN ASMN','joyeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (651,'ronde','','RNT RNT','rond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (652,'lexistence','','LKSS LKSS','lexistent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (653,'passe','','PS PS','pass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (654,'dix','','TKS TKS','dix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (655,'sept','','SPT SPT','sept');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (656,'ans','','ANS ANS','an');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (657,'institution','','ANST ANST','institu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (658,'personnes','','PRSN PRSN','person');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (659,'handicapees','','HNTK HNTK','handicape');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (660,'philosophe','','FLSF FLSF','philosoph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (661,'formation','','FRMX FRMX','format');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (662,'auteur','','ATR ATR','auteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (663,'eloge','','ALJ ALK','elog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (664,'faiblesse','','FPLS FPLS','faibless');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (665,'cerf','','SRF SRF','cerf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (666,'marabout','','MRPT MRPT','marabout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (667,'2011','','','2011');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (668,'ouvrage','','AFRJ AFRK','ouvrag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (669,'couronne','','KRN KRN','couron');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (670,'academie','','AKTM AKTM','academ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (671,'francaise','','FRNK FRNK','francais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (672,'seuil','','SL SL','seuil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (673,'metier','','MT MTR','meti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (674,'2002','','','2002');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (675,'construction','','KNST KNST','construct');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (676,'2006','','','2006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (677,'nu','','N N','nu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (678,'2010','','','2010');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (679,'ont','','ANT ANT','ont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (680,'ete','','AT AT','ete');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (681,'grands','','KRNT KRNT','grand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (682,'succes','','SKSS SKSS','succ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (683,'www','','','www');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (684,'librairiedialogues','','LPRR LPRR','librairiedialogu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (685,'ws','','S S','w');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (686,'book','','PK PK','book');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (687,'9782021079418','','','9782021079418');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (688,'unimarc','','ANMR ANMR','unimarc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (689,'marc','','MRK MRK','marc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (690,'8','','','8');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (691,'religion','','RLJN RLKN','religion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (692,'philosophie','','FLSF FLSF','philosoph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (693,'religions','','RLJN RLKN','relig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (694,'02','','','02');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (695,'107941','','','107941');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (696,'barack','','PRK PRK','barack');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (697,'grande','','KRNT KRNT','grand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (698,'desillusion','','TSLS TSLX','desillu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (699,'222','','','222');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (700,'bibliogr','','PPLK PPLK','bibliogr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (701,'219','','','219');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (702,'220','','','220');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (703,'n','','N N','n');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (704,'realise','','RLS RLS','realis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (705,'programme','','PRKR PRKR','programm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (706,'partiellement','','PRTL PRTL','partiel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (707,'imparfaitement','','AMPR AMPR','imparfait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (708,'terme','','TRM TRM','term');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (709,'economique','','AKNM AKNM','econom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (710,'financiere','','FNNS FNNX','financier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (711,'sociale','','SSL SXL','social');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (712,'toujours','','TJRS THRS','toujour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (713,'retrouve','','RTRF RTRF','retrouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (714,'croissance','','KRSN KRSN','croissanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (715,'plein','','PLN PLN','plein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (716,'emploi','','AMPL AMPL','emploi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (717,'reforme','','RFRM RFRM','reform');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (718,'systeme','','SSTM SSTM','system');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (719,'sante','','SNT SNT','sant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (720,'encore','','ANKR ANKR','encor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (721,'appliquee','','APLK APLK','applique');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (722,'cour','','KR KR','cour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (723,'supreme','','SPRM SPRM','suprem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (724,'validee','','FLT FLT','valide');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (725,'cinq','','SNK SNK','cinq');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (726,'voix','','FKS FKS','voix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (727,'opinion','','APNN APNN','opinion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (728,'publique','','PPLK PPLK','publiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (729,'profondement','','PRFN PRFN','profond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (730,'divisee','','TFS TFS','divise');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (731,'domaine','','TMN TMN','domain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (732,'politique','','PLTK PLTK','polit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (733,'etrangere','','ATRN ATRN','etranger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (734,'spectaculaires','','SPKT SPKT','spectaculair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (735,'execution','','AKSK AKSK','execu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (736,'oussama','','ASM ASM','oussam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (737,'ben','','PN PN','ben');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (738,'laden','','LTN LTN','laden');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (739,'dissimulent','','TSML TSML','dissimulent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (740,'echecs','','AXKS AKKS','echec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (741,'complets','','KMPL KMPL','complet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (742,'partiels','','PRTL PRTL','partiel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (743,'andre','','ANTR ANTR','andre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (744,'kaspi','','KSP KSP','kasp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (745,'explications','','AKSP AKSP','expliqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (746,'manquent','','MNKN MNKN','manquent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (747,'conjoncture','','KNJN KNJN','conjonctur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (748,'diront','','TRNT TRNT','diront');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (749,'defavorable','','TFFR TFFR','defavor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (750,'amerique','','AMRK AMRK','amer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (751,'ajouteront','','AJTR AHTR','ajout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (752,'inexorablement','','ANKS ANKS','inexor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (753,'confrontee','','KNFR KNFR','confronte');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (754,'declin','','TKLN TKLN','declin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (755,'moins','','MNS MNS','moin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (756,'promesses','','PRMS PRMS','promess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (757,'aient','','ANT ANT','aient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (758,'inconsiderees','','ANKN ANKN','inconsidere');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (759,'personnalite','','PRSN PRSN','personnalit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (760,'tout','','TT TT','tout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (761,'compte','','KMPT KMPT','compt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (762,'doute','','TT TT','dout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (763,'exceptionnelle','','AKSP AKSP','exceptionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (764,'cru','','KR KR','cru');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (765,'electeurs','','ALKT ALKT','electeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (766,'americains','','AMRK AMRK','americain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (767,'trancheront','','TRNX TRNK','tranch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (768,'novembre','','NFMP NFMP','novembr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (769,'ils','','ALS ALS','il');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (770,'compareront','','KMPR KMPR','compar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (771,'candidat','','KNTT KNTT','candidat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (772,'republicain','','RPPL RPPL','republicain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (773,'avec','','AFK AFK','avec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (774,'bilan','','PLN PLN','bilan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (775,'president','','PRST PRST','president');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (776,'sortant','','SRTN SRTN','sort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (777,'accorderont','','AKRT AKRT','accord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (778,'second','','SKNT SKNT','second');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (779,'mandat','','MNTT MNTT','mandat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (780,'concession','','KNSS KNSS','concess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (781,'presidence','','PRST PRST','president');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (782,'meilleurs','','MLRS MLRS','meilleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (783,'specialistes','','SPSL SPXL','special');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (784,'francais','','FRNK FRNK','franc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (785,'professeur','','PRFS PRFS','professeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (786,'emerite','','AMRT AMRT','emerit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (787,'sorbonne','','SRPN SRPN','sorbon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (788,'beaucoup','','PKP PKP','beaucoup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (789,'publie','','PPL PPL','publ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (790,'civilisation','','SFLS SFLS','civilis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (791,'parmi','','PRM PRM','parm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (792,'ouvrages','','AFRJ AFRK','ouvrag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (793,'john','','JN AN','john');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (794,'f','','F F','f');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (795,'kennedy','','KNT KNT','kennedy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (796,'famille','','FML FML','famill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (797,'mythe','','M0 MT','myth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (798,'complexe','','KMPL KMPL','complex');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (799,'2007','','','2007');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (800,'juifs','','JFS AFS','juif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (801,'plon','','PLN PLN','plon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (802,'2008','','','2008');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (803,'franklin','','FRNK FRNK','franklin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (804,'roosevelt','','RSFL RSFL','roosevelt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (805,'coll','','KL KL','coll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (806,'helene','','HLN HLN','helen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (807,'harter','','HRTR HRTR','hart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (808,'tallandier','','TLNT TLNT','tallandi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (809,'gouvernement','','KFRN KFRN','gouvern');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (810,'2009','','','2009');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (811,'259','','','259');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (812,'21063','','','21063');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (813,'320','','','320');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (814,'09051','','','09051');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (815,'1937','','','1937');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (816,'qergr','','KRKR KRKR','qergr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (817,'zr','','SR SR','zr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (818,'rgaz','','RKS RKS','rgaz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (819,'8192','','','8192');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (820,'qer','','KR KR','qer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (821,'catfish','','KTFX KTFX','catfish');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (822,'blues','','PLS PLS','blu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (823,'154','','','154');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (824,'discogr','','TSKK TSKK','discogr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (825,'oeuvres','','AFRS AFRS','oeuvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (826,'12','','','12');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (827,'idee','','AT AT','ide');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (828,'tete','','TT TT','tet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (829,'fuir','','FR FR','fuir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (830,'plantation','','PLNT PLNT','plantat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (831,'coton','','KTN KTN','coton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (832,'travaillent','','TRFL TRFL','travaillent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (833,'freres','','FRRS FRRS','frer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (834,'soeurs','','SRS SRS','soeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (835,'suivre','','SFR SFR','suivr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (836,'oncle','','ANKL ANKL','oncle');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (837,'eddie','','AT AT','eddi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (838,'devenir','','TFNR TFNR','deven');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (839,'chanteur','','XNTR XNTR','chanteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (840,'chicago','','XKK XKK','chicago');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (841,'chronique','','KRNK KRNK','chroniqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (842,'noir','','NR NR','noir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (843,'prises','','PRSS PRSS','pris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (844,'escrocs','','ASKK ASKK','escroc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (845,'poil','','PL PL','poil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (846,'compris','','KMPR KMPR','compr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (847,'ku','','K K','ku');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (848,'klux','','KLKS KLKS','klux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (849,'klan','','KLN KLN','klan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (850,'vaut','','FT FT','vaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (851,'vivacite','','FFST FFST','vivacit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (852,'ecriture','','AKRT AKRT','ecritur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (853,'beau','','P P','beau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (854,'portrait','','PRTR PRTR','portr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (855,'epoque','','APK APK','epoqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (856,'laurence','','LRNS LRNS','laurenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (857,'liban','','LPN LPN','liban');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (858,'lire','','LR LR','lir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (859,'racisme','','RSSM RSSM','racism');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (860,'029506','','','029506');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (861,'litt','fr_FR','LT LT','litt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (862,'rature','fr_FR','RTR RTR','ratur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (863,'fran','fr_FR','FRN FRN','fran');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (864,'aise','fr_FR','AS AS','ais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (865,'22020295067','','','22020295067');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (866,'6438646236','','','6438646236');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (867,'her','','HR HR','her');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (868,'trois','','TR TRS','trois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (869,'feles','','FLS FLS','fel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (870,'pendu','','PNT PNT','pendu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (871,'29','','','29');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (872,'lucien','','LSN LXN','lucien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (873,'trouve','','TRF TRF','trouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (874,'tresor','','TRSR TRSR','tresor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (875,'grange','','KRNJ KRNK','grang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (876,'abandonnee','','APNT APNT','abandonne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (877,'lorsqu','','LRSK LRSK','lorsqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (878,'retourne','','RTRN RTRN','retourn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (879,'copains','','KPNS KPNS','copain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (880,'centre','','SNTR SNTR','centr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (881,'batiment','','PTMN PTMN','bat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (882,'subterfuge','','SPTR SPTR','subterfug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (883,'mort','','MRT MRT','mort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (884,'sien','','SN SN','sien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (885,'grace','','KRS KRS','grac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (886,'dede','','TT TT','ded');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (887,'sauve','','SF SF','sauv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (888,'chercher','','XRXR XRKR','cherch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (889,'secours','','SKRS SKRS','secour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (890,'criminel','','KRMN KRMN','criminel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (891,'ecroue','','AKR AKR','ecrou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (892,'84146','','','84146');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (893,'554','','','554');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (894,'800','','','800');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (895,'33700003413727','','','33700003413727');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (896,'er','','AR AR','er');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (897,'opp','','AP AP','opp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (898,'sarah','','SR SR','sarah');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (899,'cordoue','','KRT KRT','cordou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (900,'136','','','136');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (901,'defaut','','TFT TFT','defaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (902,'fils','','FLS FLS','fil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (903,'vieux','','FKS FKS','vieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (904,'savant','','SFNT SFNT','sav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (905,'point','','PNT PNT','point');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (906,'fille','','FL FL','fill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (907,'ainee','','AN AN','aine');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (908,'disciple','','TSPL TSPL','discipl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (909,'interdite','','ANTR ANTR','interdit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (910,'femmes','','FMS FMS','femm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (911,'accomplir','','AKMP AKMP','accompl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (912,'voeux','','FKS FKS','voeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (913,'accepte','','AKSP AKSP','accept');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (914,'travestir','','TRFS TRFS','travest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (915,'samuel','','SML SML','samuel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (916,'elle','','AL AL','elle');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (917,'recoit','','RKT RKT','recoit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (918,'poeme','','PM PM','poem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (919,'galant','','KLNT KLNT','gal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (920,'jeune','','JN AN','jeun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (921,'etudiant','','ATTN ATTN','etudi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (922,'musulman','','MSLM MSLM','musulman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (923,'aime','','AM AM','aim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (924,'belle','','PL PL','bel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (925,'amour','','AMR AMR','amour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (926,'toile','','TL TL','toil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (927,'fresque','','FRSK FRSK','fresqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (928,'12e','','','12e');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (929,'siecle','','SKL SKL','siecl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (930,'452','','','452');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (931,'espagne','fr_FR','ASPN ASPK','espagn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (932,'33700003719453','','','33700003719453');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (933,'cau','','K K','cau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (934,'mille','','ML ML','mill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (935,'pattes','','PTS PTS','patt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (936,'233','','','233');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (937,'titre','','TTR TTR','titr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (938,'crypte','','KRPT KRPT','crypt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (939,'designe','','TSN TSKN','design');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (940,'onze','','ANS ANS','onze');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (941,'joueurs','','JRS ARS','joueur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (942,'equipe','','AKP AKP','equip');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (943,'france','','FRNS FRNS','franc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (944,'football','','FTPL FTPL','football');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (945,'impliques','','AMPL AMPL','impliqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (946,'alternative','','ALTR ALTR','altern');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (947,'rapport','','RPRT RPRT','rapport');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (948,'evenement','','AFNM AFNM','even');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (949,'bleus','','PLS PLS','bleus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (950,'champions','','XMPN XMPN','champion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (951,'ballon','','PLN PLN','ballon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (952,'rond','','RNT RNT','rond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (953,'207','','','207');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (954,'24700','','','24700');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (955,'football','fr_FR','FTPL FTPL','football');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (956,'33700003550072','','','33700003550072');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (957,'rx','','RKS RKS','rx');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (958,'rio','','R R','rio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (959,'policiers','','PLSR PLXR','polici');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (960,'deteriore','','TTRR TTRR','deterior');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (961,'puits','','PTS PTS','puit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (962,'110','','','110');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (963,'secheresse','','SXRS SKRS','secheress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (964,'tari','','TR TR','tar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (965,'sauf','','SF SF','sauf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (966,'logan','','LKN LKN','logan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (967,'fermiers','','FRMR FRMR','fermi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (968,'noirs','','NRS NRS','noir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (969,'aisee','','AS AS','aise');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (970,'partagent','','PRTJ PRTK','partagent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (971,'eau','','A A','eau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (972,'precieuse','','PRSS PRXS','precieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (973,'ur','','AR AR','ur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (974,'1910','','','1910');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (975,'sud','','ST ST','sud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (976,'americain','','AMRK AMRK','americain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (977,'ranc','','RNK RNK','ranc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (978,'urs','','ARS ARS','ur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (979,'tenaces','','TNSS TNSS','tenac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (980,'long','','LNK LNK','long');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (981,'tension','','TNSN TNXN','tension');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (982,'monte','','MNT MNT','mont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (983,'accablante','','AKPL AKPL','accabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (984,'chaleur','','XLR XLR','chaleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (985,'08','','','08');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (986,'164155','','','164155');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (987,'810','','','810');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (988,'am','','AM AM','am');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (989,'ricaine','','RKN RKN','ricain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (990,'am','fr_FR','AM AM','am');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (991,'ricaine','fr_FR','RKN RKN','ricain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (992,'33700004389030','','','33700004389030');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (993,'33700004389026','','','33700004389026');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (994,'jrk','','JRK ARK','jrk');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (995,'tay','','T T','tay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (996,'ghetto','','KT KT','ghetto');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (997,'9','','','9');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (998,'1993','','','1993');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (999,'afrique','','AFRK AFRK','afriqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1000,'futuriste','','FTRS FTRS','futur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1001,'consortium','','KNSR KNSR','consortium');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1002,'exploite','','AKSP AKSP','exploit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1003,'outrance','','ATRN ATRN','outranc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1004,'continent','','KNTN KNTN','continent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1005,'quand','','KNT KNT','quand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1006,'dayak','','TK TK','dayak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1007,'decouvre','','TKFR TKFR','decouvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1008,'dirige','','TRJ TRK','dirig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1009,'empire','','AMPR AMPR','empir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1010,'technologique','','TKNL TKNL','technolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1011,'autre','','ATR ATR','autr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1012,'frere','','FRR FRR','frer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1013,'lutte','','LT LT','lutt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1014,'prend','','PRNT PRNT','prend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1015,'dimension','','TMNS TMNX','dimens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1016,'fascinante','','FSNN FSNN','fascin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1017,'possede','','PST PST','possed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1018,'energie','','ANRJ ANRK','energ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1019,'force','','FRS FRS','forc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1020,'meilleures','','MLRS MLRS','meilleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1021,'sagas','','SKS SKS','sag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1022,'visionnaire','','FSNR FXNR','visionnair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1023,'dessin','','TSN TSN','dessin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1024,'adamov','','ATMF ATMF','adamov');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1025,'signe','','SN SKN','sign');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1026,'1542','','','1542');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1027,'science','fr_FR','SNS SNS','scienc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1028,'fiction','fr_FR','FKXN FKXN','fiction');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1029,'33700003669468','','','33700003669468');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1030,'bd','','PT PT','bd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1031,'ada','','AT AT','ada');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1032,'zaks','','SKS SKS','zak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1033,'ville','','FL FL','vill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1034,'mere','','MR MR','mer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1035,'detruite','','TTRT TTRT','detruit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1036,'implosee','','AMPL AMPL','implose');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1037,'reussi','','RS RS','reuss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1038,'echapper','','AXPR AKPR','echapp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1039,'intercepteurs','','ANTR ANTR','intercepteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1040,'fidele','','FTL FTL','fidel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1041,'tit','','TT TT','tit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1042,'caille','','KL KL','caill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1043,'voila','','FL FL','voil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1044,'coeur','','KR KR','coeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1045,'pret','','PRT PRT','pret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1046,'fondre','','FNTR FNTR','fondr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1047,'univers','','ANFR ANFR','univer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1048,'inhospitalier','','ANSP ANSP','inhospitali');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1049,'suivi','','SF SF','suiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1050,'quelque','','KLK KLK','quelqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1051,'distance','','TSTN TSTN','distanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1052,'simon','','SMN SMN','simon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1053,'jamais','','JM AMS','jam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1054,'rattraper','','RTRP RTRP','rattrap');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1055,'or','','AR AR','or');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1056,'hommes','','HMS HMS','homm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1057,'masques','','MSKS MSKS','masqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1058,'yeux','','AKS AKS','yeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1059,'sanguins','','SNKN SNKN','sanguin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1060,'legende','','LJNT LKNT','legend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1061,'caches','','KXS KKS','cach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1062,'dedale','','TTL TTL','dedal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1063,'galeries','','KLRS KLRS','galer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1064,'souterraines','','STRN STRN','souterrain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1065,'labyrinthiques','','LPRN LPRN','labyrinth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1066,'tardera','','TRTR TRTR','tard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1067,'fixe','','FKS FKS','fix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1068,'bientot','','PNTT PNTT','bientot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1069,'resonneront','','RSNR RSNR','reson');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1070,'tambours','','TMPR TMPR','tambour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1071,'traditions','','TRTX TRTX','tradit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1072,'humaines','','HMNS HMNS','humain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1073,'anciennes','','ANSN ANXN','ancien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1074,'ombres','','AMPR AMPR','ombre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1075,'demesurees','','TMSR TMSR','demesure');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1076,'silhouettes','','SLTS SLTS','silhouet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1077,'primitives','','PRMT PRMT','primit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1078,'viendront','','FNTR FNTR','viendront');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1079,'allonger','','ALNK ALNJ','allong');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1080,'aupres','','APRS APRS','aupr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1081,'intervention','','ANTR ANTR','intervent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1082,'parviendra','','PRFN PRFN','parviendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1083,'triompher','','TRMF TRMF','triomph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1084,'definitivement','','TFNT TFNT','definit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1085,'tant','','TNT TNT','tant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1086,'gens','','JNS KNS','gen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1087,'espece','','ASPS ASPS','espec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1088,'soit','','ST ST','soit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1089,'fin','','FN FN','fin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1090,'alors','','ALRS ALRS','alor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1091,'juste','','JST AST','just');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1092,'expriment','','AKSP AKSP','expriment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1093,'lieux','','LKS LKS','lieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1094,'desertiques','','TSRT TSRT','desert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1095,'certaine','','SRTN SRTN','certain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1096,'facon','','FKN FKN','facon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1097,'finissait','','FNST FNST','fin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1098,'2083','','','2083');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1099,'33700003669484','','','33700003669484');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1100,'chambre','','XMPR XMPR','chambr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1101,'verte','','FRT FRT','vert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1102,'1994','','','1994');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1103,'addis','','ATS ATS','addis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1104,'abeba','','APP APP','abeb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1105,'nee','','N N','ne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1106,'fini','','FN FN','fin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1107,'misere','','MSR MSR','miser');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1108,'crasse','','KRS KRS','crass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1109,'colbius','','KLPS KLPS','colbius');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1110,'leader','','LTR LTR','lead');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1111,'m','','M M','m');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1112,'surgir','','SRJR SRKR','surg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1113,'megalopole','','MKLP MKLP','megalopol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1114,'techniques','','TKNK TKNK','techniqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1115,'sophistiquees','','SFST SFST','sophistique');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1116,'cotoient','','KTNT KTNT','cotoient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1117,'valet','','FLT FLT','valet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1118,'despote','','TSPT TSPT','despot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1119,'cori','','KR KR','cor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1120,'courtisane','','KRTS KRTS','courtisan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1121,'comportement','','KMPR KMPR','comport');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1122,'trouble','','TRPL TRPL','troubl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1123,'peine','','PN PN','pein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1124,'car','','KR KR','car');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1125,'sait','','ST ST','sait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1126,'maintenant','','MNTN MNTN','mainten');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1127,'lointains','','LNTN LNTN','lointain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1128,'souvenirs','','SFNR SFNR','souvenir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1129,'vision','','FSN FXN','vision');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1130,'fugace','','FKS FKS','fugac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1131,'percevaient','','PRSF PRSF','percev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1132,'formidables','','FRMT FRMT','formid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1133,'changements','','XNJM XNKM','chang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1134,'orchestrait','','ARKS ARKS','orchestr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1135,'clone','','KLN KLN','clon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1136,'briser','','PRSR PRSR','bris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1137,'chaines','','XNS XNS','chain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1138,'relient','','RLNT RLNT','relient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1139,'maitre','','MTR MTR','maitr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1140,'empereur','','AMPR AMPR','empereur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1141,'nouvel','','NFL NFL','nouvel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1142,'1727','','','1727');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1143,'33700003669485','','','33700003669485');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1144,'pmb0002','','PMP PMP','pmb0002');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1145,'2ch','','X K','2ch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1146,'albums','','ALPM ALPM','album');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1147,'monsieur','','MNSR MNSR','monsieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1148,'je','','J A','je');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1149,'sais','','S SS','sais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1150,'8001','','','8001');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1151,'2334','','','2334');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1152,'33700004243347','','','33700004243347');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1153,'ebd','','APT APT','ebd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1154,'gee','','J K','ge');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1155,'paroles','','PRLS PRLS','parol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1156,'bonheur','','PNR PNR','bonheur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1157,'pagine','','PJN PKN','pagin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1158,'59','','','59');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1159,'anthologique','','AN0L ANTL','antholog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1160,'textes','','TKST TKST','text');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1161,'temps','','TMPS TMPS','temp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1162,'pays','','PS PS','pay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1163,'donne','','TN TN','don');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1164,'presentation','','PRSN PRSN','present');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1165,'originale','','ARJN ARKN','original');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1166,'ecrits','','AKRT AKRT','ecrit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1167,'enclaves','','ANKL ANKL','enclav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1168,'illustrations','','ALST ALST','illustr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1169,'226','','','226');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1170,'09017','','','09017');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1171,'psychologie','fr_FR','SXLJ SKLK','psycholog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1172,'psychanalyse','fr_FR','SXNL SKNL','psychanalys');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1173,'33700003453202','','','33700003453202');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1174,'808','','','808');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1175,'metamorphose','','MTMR MTMR','metamorphos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1176,'fleurs','','FLRS FLRS','fleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1177,'143','','','143');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1178,'depl','','TPL TPL','depl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1179,'jaquette','','JKT AKT','jaquet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1180,'microcosmos','','MKRK MKRK','microcosmos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1181,'milliers','','MLRS MLRS','milli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1182,'lecteurs','','LKTR LKTR','lecteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1183,'emerveilles','','AMRF AMRF','emerveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1184,'devant','','TFNT TFNT','dev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1185,'prodiges','','PRTJ PRTK','prodig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1186,'insoupconnes','','ANSP ANSP','insoupcon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1187,'carre','','KR KR','carr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1188,'herbes','','HRPS HRPS','herb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1189,'folles','','FLS FLS','foll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1190,'claude','','KLT KLT','claud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1191,'nuridsany','','NRTS NRTS','nuridsany');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1192,'marie','','MR MR','mar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1193,'perennou','','PRN PRN','perennou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1194,'sillonnent','','SLNN SLNN','sillonnent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1195,'prairies','','PRRS PRRS','prair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1196,'jardins','','JRTN ARTN','jardin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1197,'invitent','','ANFT ANFT','invitent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1198,'nos','','NS NS','nos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1199,'inattentifs','','ANTN ANTN','inattent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1200,'poser','','PSR PSR','pos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1201,'bouton','','PTN PTN','bouton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1202,'gorge','','KRJ KRK','gorg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1203,'seve','','SF SF','sev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1204,'petale','','PTL PTL','petal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1205,'entrouvre','','ANTR ANTR','entrouvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1206,'chute','','XT XT','chut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1207,'corolle','','KRL KRL','coroll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1208,'moments','','MMNT MMNT','moment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1209,'phares','','FRS FRS','phar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1210,'flamboyante','','FLMP FLMP','flamboi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1211,'fleur','','FLR FLR','fleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1212,'architecture','','ARKT ARKT','architectur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1213,'construite','','KNST KNST','construit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1214,'defaite','','TFT TFT','defait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1215,'jours','','JRS ARS','jour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1216,'transfigurees','','TRNS TRNS','transfigure');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1217,'macrophotographie','','MKRF MKRF','macrophotograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1218,'vingtaine','','FNKT FNKT','vingtain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1219,'especes','','ASPS ASPS','espec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1220,'florales','','FLRL FLRL','floral');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1221,'naissent','','NSNT NSNT','naissent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1222,'vivent','','FFNT FFNT','vivent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1223,'meurent','','MRNT MRNT','meurent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1224,'sous','','SS SS','sous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1225,'invente','','ANFN ANFN','invent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1226,'notre','','NTR NTR','notr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1227,'plaisir','','PLSR PLSR','plais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1228,'regard','','RKRT RKRT','regard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1229,'nature','','NTR NTR','natur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1230,'mi','','M M','mi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1231,'biologie','','PLJ PLK','biolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1232,'poesie','','PS PS','poes');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1233,'pistil','','PSTL PSTL','pistil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1234,'etamine','','ATMN ATMN','etamin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1235,'7324','','','7324');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1236,'2351','','','2351');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1237,'580','','','580');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1238,'botanique','','PTNK PTNK','botan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1239,'plantes','','PLNT PLNT','plant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1240,'fleurs','fr_FR','FLRS FLRS','fleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1241,'33700004118010','','','33700004118010');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1242,'582','','','582');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1243,'nur','','NR NR','nur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1244,'rwanda','','RNT RNT','rwand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1245,'271','','','271');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1246,'appendice','','APNT APNT','appendic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1247,'choix','','XKS XKS','choix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1248,'documents','','TKMN TKMN','docu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1249,'franchophone','','FRNX FRNK','franchophon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1250,'colonisation','','KLNS KLNS','colonis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1251,'7384','','','7384');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1252,'5292','','','5292');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1253,'960','','','960');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1254,'de','','T T','de');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1255,'l','','L L','l');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1256,'rwanda','fr_FR','RNT RNT','rwand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1257,'33700003286792','','','33700003286792');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1258,'967','','','967');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1259,'ove','','AF AF','ove');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1260,'routiere','','RTR RTR','routier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1261,'ardeche','','ARTX ARTK','ardech');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1262,'haute','','HT HT','haut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1263,'11331','','','11331');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1264,'touristique','','TRST TRST','tourist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1265,'25','','','25');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1266,'x','','S S','x');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1267,'16','','','16');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1268,'generation','','JNRX KNRX','gener');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1269,'cartes','','KRTS KRTS','cart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1270,'routieres','','RTRS RTRS','routier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1271,'michelin','','MXLN MKLN','michelin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1272,'toutes','','TTS TTS','tout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1273,'informations','','ANFR ANFR','inform');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1274,'decouvrir','','TKFR TKFR','decouvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1275,'departements','','TPRT TPRT','depart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1276,'reperer','','RPRR RPRR','reper');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1277,'facilement','','FSLM FSLM','facil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1278,'voiture','','FTR FTR','voitur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1279,'nombreuses','','NMPR NMPR','nombreux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1280,'nouveautes','','NFTS NFTS','nouveaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1281,'integrees','','ANTK ANTK','integre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1282,'local','','LKL LKL','local');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1283,'lisible','','LSPL LSPL','lisibl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1284,'echelle','','AXL AKL','echel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1285,'agrandie','','AKRN AKRN','agrand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1286,'150','','','150');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1287,'000e','','','000e');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1288,'175','','','175');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1289,'index','','ANTK ANTK','index');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1290,'complet','','KMPL KMPL','complet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1291,'localites','','LKLT LKLT','localit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1292,'acceder','','AKST AKST','acced');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1293,'rapidement','','RPTM RPTM','rapid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1294,'information','','ANFR ANFR','inform');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1295,'plans','','PLNS PLNS','plan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1296,'circuler','','SRKL SRKL','circul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1297,'grandes','','KRNT KRNT','grand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1298,'agglomerations','','AKLM AKLM','agglomer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1299,'image','','AMJ AMK','imag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1300,'comprendre','','KMPR KMPR','comprendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1301,'symboles','','SMPL SMPL','symbol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1302,'terroirs','','TRRS TRRS','terroir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1303,'centrees','','SNTR SNTR','centre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1304,'route','','RT RT','rout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1305,'autrement','','ATRM ATRM','autr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1306,'pixel','','PKSL PKSL','pixel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1307,'bas','','PS PS','bas');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1308,'vivarais','','FFR FFRS','vivar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1309,'boutieres','','PTRS PTRS','boutier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1310,'brisadois','','PRST PRST','brisadois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1311,'cevennes','','SFNS SFNS','ceven');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1312,'margeriche','','MRKR MRJR','margerich');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1313,'velay','','FL FL','velay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1314,'06','','','06');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1315,'100392','','','100392');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1316,'3370000451291','','','3370000451291');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1317,'mic','','MK MK','mic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1318,'chili','','XL XL','chil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1319,'glace','','KLS KLS','glac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1320,'feu','','F F','feu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1321,'dl','','TL TL','dl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1322,'dvd','','TFT TFT','dvd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1323,'video','','FT FT','video');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1324,'monoface','','MNFS MNFS','monofac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1325,'zone','','SN SN','zon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1326,'h','','','h');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1327,'21','','','21');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1328,'min','','MN MN','min');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1329,'pal','','PL PL','pal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1330,'brochure','','PRXR PRKR','brochur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1331,'14','','','14');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1332,'cm','','KM KM','cm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1333,'contient','','KNTN KNTN','contient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1334,'making','','MKNK MKNK','making');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1335,'of','','AF AF','of');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1336,'vu','','F F','vu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1337,'sites','','STS STS','sit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1338,'fetes','','FTS FTS','fet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1339,'paques','','PKS PKS','paqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1340,'chili','fr_FR','XL XL','chil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1341,'3370000451290','','','3370000451290');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1342,'tf1','','TF TF','tf1');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1343,'angevine','','ANJF ANKF','angevin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1344,'joachim','','JXM AKM','joachim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1345,'bellay','','PL PL','bellay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1346,'2001','','','2001');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1347,'disque','','TSK TSK','disqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1348,'optique','','APTK APTK','optiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1349,'numerique','','NMRK NMRK','numer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1350,'rom','','RM RM','rom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1351,'glossaire','','KLSR KLSR','glossair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1352,'configuration','','KNFK KNFK','configur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1353,'requise','','RKS RKS','requis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1354,'pc','','PK PK','pc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1355,'mo','','M M','mo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1356,'memoire','','MMR MMR','memoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1357,'vive','','FF FF','viv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1358,'windows','','ANTS FNTS','window');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1359,'95','','','95');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1360,'ulterieur','','ALTR ALTR','ulterieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1361,'octuple','','AKTP AKTP','octupl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1362,'vitesse','','FTS FTS','vitess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1363,'affichage','','AFXJ AFKK','affichag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1364,'65','','','65');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1365,'000','','','000');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1366,'macintosh','','MSNT MSNT','macintosh');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1367,'5','','','5');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1368,'renaissance','','RNSN RNSN','renaiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1369,'anjou','','ANJ ANJ','anjou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1370,'renaissance','fr_FR','RNSN RNSN','renaiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1371,'po','fr_FR','P P','po');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1372,'sie','fr_FR','S S','si');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1373,'3370000451292','','','3370000451292');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1374,'cdrom','','KTRM KTRM','cdrom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1375,'loi','','L L','loi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1376,'cederoms','','STRM STRM','cederom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1377,'bagnes','','PNS PKNS','bagn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1378,'madagascar','','MTKS MTKS','madagascar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1379,'49','','','49');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1380,'madagascar','fr_FR','MTKS MTKS','madagascar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1381,'paysages','','PSJS PSKS','paysag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1382,'afghans','','AFKN AFKN','afghan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1383,'26','','','26');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1384,'afghanistan','fr_FR','AFKN AFKN','afghanistan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1385,'peuples','','PPLS PPLS','peupl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1386,'afghanistan','','AFKN AFKN','afghanistan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1387,'102','','','102');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1388,'tribus','','TRPS TRPS','tribus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1389,'pachtounes','','PKTN PKTN','pachtoun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1390,'72','','','72');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1391,'afghanes','','AFKN AFKN','afghan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1392,'120','','','120');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1393,'64','','','64');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1394,'islam','','ALM ALM','islam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1395,'afghan','','AFKN AFKN','afghan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1396,'118','','','118');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1397,'islam','fr_FR','ALM ALM','islam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1398,'allix','','ALKS ALKS','allix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1399,'chenonceau','','XNNS XNNS','chenonceau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1400,'chambord','','XMPR XMPR','chambord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1401,'cheverny','','XFRN XFRN','cheverny');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1402,'charte','','XRT XRT','chart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1403,'xiiie','','S S','xii');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1404,'laquelle','','LKL LKL','laquel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1405,'guillaume','','KLM KLM','guillaum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1406,'rezay','','RS RS','rezay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1407,'paroisse','','PRS PRS','paroiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1408,'ceaux','','S S','ceau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1409,'maine','','MN MN','main');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1410,'vend','','FNT FNT','vend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1411,'messire','','MSR MSR','messir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1412,'vernee','','FRN FRN','verne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1413,'chevalier','','XFL XFLR','chevali');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1414,'six','','SKS SKS','six');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1415,'deniers','','TNRS TNRS','deni');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1416,'rente','','RNT RNT','rent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1417,'acte','','AKT AKT','acte');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1418,'angers','','ANKR ANJR','anger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1419,'jeudi','','JT AT','jeud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1420,'saint','','SNT SNT','saint');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1421,'urbain','','ARPN ARPN','urbain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1422,'an','','AN AN','an');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1423,'cent','','SNT SNT','cent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1424,'vingt','','FNKT FNKT','vingt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1425,'neuf','','NF NF','neuf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1426,'feuillet','','FLT FLT','feuillet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1427,'manuscript','','MNSK MNSK','manuscript');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1428,'conserve','','KNSR KNSR','conserv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1429,'sceau','','S S','sceau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1430,'excellent','','AKSL AKSL','excellent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1431,'conservation','','KNSR KNSR','conserv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1432,'date','','TT TT','dat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1433,'style','','STL STL','styl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1434,'v','','F F','v');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1435,'st','','ST ST','st');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1436,'pouget','','PKT PKT','pouget');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1437,'archiviste','','ARXF ARKF','archiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1438,'paleographe','','PLKR PLKR','paleograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1439,'indre','','ANTR ANTR','indre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1440,'voulu','','FL FL','voulu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1441,'attirer','','ATRR ATRR','attir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1442,'mon','','MN MN','mon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1443,'attention','','ATNX ATNX','attent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1444,'datee','','TT TT','date');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1445,'joedi','','JT AT','joed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1446,'alban','','ALPN ALPN','alban');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1447,'aubin','','APN APN','aubin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1448,'1er','','R R','1er');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1449,'mars','','MRS MRS','mar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1450,'tombant','','TMPN TMPN','tomb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1451,'1299','','','1299');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1452,'19','','','19');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1453,'avril','','AFRL AFRL','avril');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1454,'effectivement','','AFKT AFKT','effect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1455,'lieu','','L L','lieu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1456,'considerer','','KNST KNST','consider');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1457,'fevrier','','FFR FFRR','fevri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1458,'1300','','','1300');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1459,'archive','','ARXF ARKF','archiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1460,'cens','','SNS SNS','cen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1461,'940','','','940');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1462,'europe','','ARP ARP','europ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1463,'3370000451295','','','3370000451295');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1464,'locale','','LKL LKL','local');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1465,'oeuvre','','AFR AFR','oeuvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1466,'couverture','','KFRT KFRT','couvertur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1467,'magazine','','MKSN MKSN','magazin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1468,'rustica','','RSTK RSTK','rustic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1469,'parfait','','PRFT PRFT','parf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1470,'1953','','','1953');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1471,'page','','PJ PK','pag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1472,'fac','','FK FK','fac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1473,'simile','','SML SML','simil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1474,'mentionne','','MNXN MNXN','mention');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1475,'3370000451298','','','3370000451298');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1476,'rus','','RS RS','rus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1477,'canne','','KN KN','cann');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1478,'pommeau','','PM PM','pommeau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1479,'forme','','FRM FRM','form');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1480,'bois','','P PS','bois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1481,'precieux','','PRSK PRXK','precieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1482,'bichromie','','PXRM PKRM','bichrom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1483,'sculpte','','SKLP SKLP','sculpt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1484,'peint','','PNT PNT','peint');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1485,'pied','','PT PT','pied');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1486,'argent','','ARJN ARKN','argent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1487,'sculpture','','SKLP SKLP','sculptur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1488,'680','','','680');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1489,'articles','','ARTK ARTK','articl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1490,'manufactur','','MNFK MNFK','manufactur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1491,'sculpture','fr_FR','SKLP SKLP','sculptur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1492,'3370000451299','','','3370000451299');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1493,'fav','','FF FF','fav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1494,'tours','','TRS TRS','tour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1495,'flle','','FL FL','flle');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1496,'78','','','78');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1497,'1765','','','1765');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1498,'couleur','','KLR KLR','couleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1499,'cassini','','KSN KSN','cassin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1500,'cote','','KT KT','cot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1501,'ge','','J K','ge');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1502,'ff','','F F','ff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1503,'18595','','','18595');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1504,'bnf','','PNF PNF','bnf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1505,'richelieu','','RXL RKL','richelieu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1506,'reprod','','RPRT RPRT','reprod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1507,'sc','','SK SK','sc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1508,'96','','','96');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1509,'614','','','614');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1510,'levee','','LF LF','leve');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1511,'1760','','','1760');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1512,'1762','','','1762');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1513,'bottin','','PTN PTN','bottin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1514,'langelay','','LNJL LNKL','langelay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1515,'verifiee','','FRF FRF','verifie');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1516,'1763','','','1763');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1517,'1764','','','1764');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1518,'briffe','','PRF PRF','briff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1519,'ponsan','','PNSN PNSN','ponsan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1520,'lettre','','LTR LTR','lettr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1521,'chambon','','XMPN XMPN','chambon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1522,'78e','','','78e');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1523,'feuille','','FL FL','feuill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1524,'publiee','','PPL PPL','publie');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1525,'gallica','','KLK KLK','gallic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1526,'scripts','','SKPT SKPT','script');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1527,'consultationtout','','KNSL KNSL','consultationtout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1528,'exe','','AKS AKS','exe');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1529,'o','','A A','o');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1530,'07711576','','','07711576');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1531,'images','','AMJS AMKS','imag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1532,'numerisees','','NMRS NMRS','numerise');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1533,'centre','fr_FR','SNTR SNTR','centr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1534,'produits','','PRTT PRTT','produit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1535,'charcuterie','','XRKT XRKT','charcuter');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1536,'hygiene','','HJN HKN','hygien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1537,'inspection','','ANSP ANSP','inspect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1538,'reglementation','','RKLM RKLM','reglement');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1539,'th','','0 T','th');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1540,'bourrier','','PR PRR','bourri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1541,'1887','','','1887');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1542,'in','','AN AN','in');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1543,'xii','','S S','xii');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1544,'585','','','585');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1545,'exemples','','AKSM AKSM','exempl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1546,'illustres','','ALST ALST','illustr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1547,'gravures','','KRFR KRFR','gravur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1548,'representant','','RPRS RPRS','represent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1549,'ferme','','FRM FRM','ferm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1550,'elevage','','ALFJ ALFK','elevag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1551,'cochelle','','KXL KKL','cochel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1552,'640','','','640');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1553,'nagers','','NKRS NJRS','nager');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1554,'cuisine','','KSN KSN','cuisin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1555,'cout','','KT KT','cout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1556,'soins','','SNS SNS','soin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1557,'beaut','','PT PT','beaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1558,'aliments','fr_FR','ALMN ALMN','aliment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1559,'3370000451302','','','3370000451302');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1560,'bou','','P P','bou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1561,'nimitz','','NMTS NMTS','nimitz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1562,'443','','','443');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1563,'09568','','','09568');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1564,'nouvelle','fr_FR','NFL NFL','nouvel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1565,'33700004500167','','','33700004500167');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1566,'rk','','RK RK','rk');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1567,'rob','','RP RP','rob');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1568,'joli','','JL AL','jol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1569,'moche','','MX MK','moch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1570,'perles','','PRLS PRLS','perl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1571,'contes','','KNTS KNTS','cont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1572,'symbole','','SMPL SMPL','symbol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1573,'mysterieux','','MSTR MSTR','mysteri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1574,'collier','','KL KLR','colli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1575,'perle','','PRL PRL','perl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1576,'crue','','KR KR','cru');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1577,'vient','','FNT FNT','vient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1578,'aneantir','','ANNT ANNT','aneant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1579,'offerts','','AFRT AFRT','offert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1580,'aristocrate','','ARST ARST','aristocrat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1581,'insouciante','','ANSS ANSX','insouci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1582,'port','','PRT PRT','port');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1583,'anvers','','ANFR ANFR','anver');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1584,'ecrivain','','AKRF AKRF','ecrivain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1585,'fuit','','FT FT','fuit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1586,'tels','','TLS TLS','tel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1587,'themes','','0MS TMS','them');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1588,'travers','','TRFR TRFR','traver');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1589,'eux','','AKS AKS','eux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1590,'karen','','KRN KRN','karen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1591,'blixen','','PLKS PLKS','blixen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1592,'demontre','','TMNT TMNT','demontr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1593,'instrument','','ANST ANST','instrument');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1594,'privilegie','','PRFL PRFL','privileg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1595,'exploration','','AKSP AKSP','explor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1596,'mysteres','','MSTR MSTR','myster');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1597,'doux','','T T','doux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1598,'velours','','FLRS FLRS','velour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1599,'timbre','','TMPR TMPR','timbr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1600,'anne','','AN AN','anne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1601,'brochet','','PRXT PRKT','brochet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1602,'transporte','','TRNS TRNS','transport');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1603,'lecture','','LKTR LKTR','lectur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1604,'posee','','PS PS','pose');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1605,'met','','MT MT','met');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1606,'mouvement','','MFMN MFMN','mouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1607,'imagination','','AMJN AMKN','imagin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1608,'auditeur','','ATTR ATTR','auditeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1609,'ecoute','','AKT AKT','ecout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1610,'classe','','KLS KLS','class');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1611,'autorisee','','ATRS ATRS','autorise');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1612,'9782070136001','','','9782070136001');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1613,'lus','','LS LS','lus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1614,'format','','FRMT FRMT','format');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1615,'013600','','','013600');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1616,'gallimard','','KLMR KLMR','gallimard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1617,'ecoutez','','AKTS AKTS','ecout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1618,'1885','','','1885');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1619,'1962','','','1962');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1620,'metzger','','MTSK MTSJ','metzg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1621,'marthe','','MR0 MRT','marth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1622,'sages','','SJS SKS','sag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1623,'179','','','179');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1624,'068730','','','068730');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1625,'dirigee','','TRJ TRK','dirige');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1626,'henri','','HNR HNR','henr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1627,'gougaud','','KKT KKT','gougaud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1628,'ba','','P P','ba');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1629,'amadou','','AMT AMT','amadou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1630,'hampate','','HMPT HMPT','hampat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1631,'1901','','','1901');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1632,'1991','','','1991');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1633,'diverses','','TFRS TFRS','divers');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1634,'poemes','','PMS PMS','poem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1635,'proverbes','','PRFR PRFR','proverb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1636,'differents','','TFRN TFRN','different');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1637,'auteurs','','ATRS ATRS','auteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1638,'photographies','','FTKR FTKR','photograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1639,'8100','','','8100');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1640,'0117','','','0117');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1641,'toucan','','TKN TKN','toucan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1642,'issy','','AS AS','issy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1643,'moulineaux','','MLN MLN','moulineau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1644,'916','','','916');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1645,'002','','','002');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1646,'22','','','22');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1647,'zaid','','ST ST','zaid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1648,'nassera','','NSR NSR','nass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1649,'afriques','','AFRK AFRK','afriqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1650,'395','','','395');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1651,'depuis','','TPS TPS','depuis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1652,'raymond','','RMNT RMNT','raymond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1653,'depardon','','TPRT TPRT','depardon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1654,'parcouru','','PRKR PRKR','parcouru');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1655,'auquel','','AKL AKL','auquel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1656,'consacre','','KNSK KNSK','consacr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1657,'plusieurs','','PLSR PLSR','plusieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1658,'films','','FLMS FLMS','film');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1659,'quantite','','KNTT KNTT','quantit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1660,'350','','','350');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1661,'inedites','','ANTT ANTT','inedit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1662,'presentees','','PRSN PRSN','presente');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1663,'couvrent','','KFRN KFRN','couvrent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1664,'toute','','TT TT','tout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1665,'associations','','ASSX ASXX','associ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1666,'originales','','ARJN ARKN','original');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1667,'privilegient','','PRFL PRFL','privilegient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1668,'rythme','','R0M RTM','rythm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1669,'soutenu','','STN STN','soutenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1670,'arret','','ART ART','arret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1671,'enchainements','','ANXN ANKN','enchain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1672,'montrent','','MNTR MNTR','montrent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1673,'sujets','','SJTS SJTS','sujet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1674,'tres','','TRS TRS','tre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1675,'varies','','FRS FRS','var');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1676,'portraits','','PRTR PRTR','portrait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1677,'villes','','FLS FLS','vill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1678,'activites','','AKTF AKTF','activit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1679,'sociales','','SSLS SXLS','social');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1680,'metiers','','MTRS MTRS','meti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1681,'conflits','','KNFL KNFL','conflit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1682,'exemptes','','AKSM AKSM','exempt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1683,'volonte','','FLNT FLNT','volont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1684,'esthetiser','','AS0T ASTT','esthetis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1685,'propos','','PRPS PRPS','propos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1686,'aucun','','AKN AKN','aucun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1687,'jugement','','JJMN AKMN','jug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1688,'aucune','','AKN AKN','aucun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1689,'these','','0S TS','thes');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1690,'relie','','RL RL','rel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1691,'elles','','ALS ALS','elle');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1692,'impulsion','','AMPL AMPL','impuls');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1693,'simplement','','SMPL SMPL','simpl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1694,'photographe','','FTKR FTKR','photograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1695,'voyageur','','FJR FKR','voyageur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1696,'peuplent','','PPLN PPLN','peuplent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1697,'pourquoi','','PRK PRK','pourquoi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1698,'1960','','','1960');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1699,'annee','','AN AN','anne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1700,'premiere','','PRMR PRMR','premier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1701,'huit','','HT HT','huit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1702,'jusqu','','JSK ASK','jusqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1703,'dernier','','TRN TRNR','derni');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1704,'hiver','','HFR HFR','hiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1705,'horar','','HRR HRR','horar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1706,'ai','','A A','ai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1707,'cesse','','SS SS','cess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1708,'photographier','','FTKR FTKR','photographi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1709,'entiere','','ANTR ANTR','entier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1710,'suffirait','','SFRT SFRT','suff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1711,'pretendre','','PRTN PRTN','pretendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1712,'connaitre','','KNTR KNTR','connaitr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1713,'aujourd','','AJRT AHRT','aujourd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1714,'hui','','H H','hui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1715,'pretextes','','PRTK PRTK','pretext');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1716,'raisons','','RSNS RSNS','raison');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1717,'oublies','','APLS APLS','oubl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1718,'avais','','AF AFS','avais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1719,'envie','','ANF ANF','envi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1720,'rendre','','RNTR RNTR','rendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1721,'liberte','','LPRT LPRT','libert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1722,'reunir','','RNR RNR','reun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1723,'celles','','SLS SLS','cel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1724,'sourires','','SRRS SRRS','sourir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1725,'famines','','FMNS FMNS','famin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1726,'guerres','','KRS KRS','guerr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1727,'civiles','','SFLS SFLS','civil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1728,'voulais','','FL FLS','voul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1729,'oser','','ASR ASR','oser');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1730,'cents','','SNTS SNTS','cent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1731,'respiration','','RSPR RSPR','respir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1732,'etouffer','','ATFR ATFR','etouff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1733,'immense','','AMNS AMNS','immens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1734,'me','','M M','me');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1735,'serions','','SRNS SRNS','serion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1736,'panne','','PN PN','pann');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1737,'envahis','','ANFH ANFH','envah');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1738,'rester','','RSTR RSTR','rest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1739,'silencieux','','SLNS SLNX','silenci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1740,'ecouter','','AKTR AKTR','ecout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1741,'souviens','','SFNS SFNS','souvien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1742,'chaque','','XK XK','chaqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1743,'ose','','AS AS','ose');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1744,'desordre','','TSRT TSRT','desordr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1745,'reunis','','RNS RNS','reun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1746,'pendant','','PNTN PNTN','pend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1747,'quarante','','KRNT KRNT','quar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1748,'7541','','','7541');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1749,'0611','','','0611');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1750,'hazan','','HSN HSN','hazan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1751,'vanves','','FNFS FNFS','vanv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1752,'779','','','779');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1753,'366','','','366');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1754,'1942','','','1942');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1755,'comptines','','KMPT KMPT','comptin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1756,'berceuses','','PRSS PRSS','berceux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1757,'baobab','','PPP PPP','baobab');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1758,'noire','','NR NR','noir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1759,'30','','','30');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1760,'57','','','57');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1761,'compact','','KMPK KMPK','compact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1762,'36','','','36');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1763,'differentes','','TFRN TFRN','different');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1764,'langues','','LNKS LNKS','langu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1765,'congo','','KNK KNK','congo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1766,'mingala','','MNKL MNKL','mingal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1767,'mali','','ML ML','mal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1768,'bambara','','PMPR PMPR','bambar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1769,'cameroun','','KMRN KMRN','cameroun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1770,'bamena','','PMN PMN','bamen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1771,'ivoire','','AFR AFR','ivoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1772,'mauritanie','','MRTN MRTN','mauritan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1773,'peul','','PL PL','peul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1774,'togo','','TK TK','togo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1775,'mina','','MN MN','min');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1776,'senegal','','SNKL SNKL','senegal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1777,'wolof','','ALF FLF','wolof');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1778,'kinyarwanda','','KNRN KNRN','kinyarwand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1779,'guinee','','KN KN','guine');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1780,'susu','','SS SS','susu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1781,'soninke','','SNNK SNNK','sonink');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1782,'centrafrique','','SNTR SNTR','centrafr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1783,'sango','','SNK SNK','sango');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1784,'conakry','','KNKR KNKR','conakry');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1785,'kikongo','','KKNK KKNK','kikongo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1786,'selection','','SLKX SLKX','select');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1787,'representatives','','RPRS RPRS','represent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1788,'diversite','','TFRS TFRS','diversit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1789,'lingala','','LNKL LNKL','lingal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1790,'comptine','','KMPT KMPT','comptin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1791,'transcrite','','TRNS TRNS','transcrit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1792,'langue','','LNK LNK','langu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1793,'origine','','ARJN ARKN','origin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1794,'traduite','','TRTT TRTT','traduit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1795,'commentaires','','KMNT KMNT','commentair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1796,'culturels','','KLTR KLTR','culturel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1797,'regroupes','','RKRP RKRP','regroup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1798,'centrale','','SNTR SNTR','central');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1799,'05277','','','05277');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1800,'didier','','TT TTR','didi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1801,'jeunesse','','JNS ANS','jeuness');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1802,'un','','AN AN','un');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1803,'mindy','','MNT MNT','mindy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1804,'nouhen','','NHN NHN','nouhen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1805,'grosleziat','','KRSL KRSL','grosleziat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1806,'paul','','PL PL','paul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1807,'elodie','','ALT ALT','elod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1808,'chantal','','XNTL XNTL','chantal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1809,'1952','','','1952');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1810,'1970','','','1970');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1811,'yakouba','','AKP AKP','yakoub');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1812,'9782020964876','','','9782020964876');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1813,'herbe','','HRP HRP','herb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1814,'096487','','','096487');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1815,'804','','','804');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1816,'crea','','KR KR','cre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1817,'jeuness','','JNS ANS','jeuness');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1818,'dedieu','','TT TT','dedieu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1819,'thierry','','0R TR','thierry');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1820,'rafara','','RFR RFR','rafar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1821,'populaire','','PPLR PPLR','populair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1822,'2000','','','2000');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1823,'40','','','40');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1824,'05694','','','05694');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1825,'pastel','','PSTL PSTL','pastel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1826,'ecole','','AKL AKL','ecol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1827,'des','','TS TS','de');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1828,'loisirs','','LSRS LSRS','loisir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1829,'bruxelles','','PRKS PRKS','bruxel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1830,'boel','','PL PL','boel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1831,'catherine','','K0RN KTRN','catherin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1832,'1975','','','1975');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1833,'aya','','A A','aya');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1834,'yopougon','','APKN APKN','yopougon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1835,'106','','','106');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1836,'lexique','','LKSK LKSK','lexiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1837,'ivoirien','','AFRN AFRN','ivoirien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1838,'recettes','','RSTS RSTS','recet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1839,'culinaires','','KLNR KLNR','culinair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1840,'conseils','','KNSL KNSL','conseil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1841,'pratique','','PRTK PRTK','pratiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1842,'057588','','','057588');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1843,'741','','','741');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1844,'508','','','508');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1845,'bayou','','P P','bayou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1846,'abouet','','APT APT','abouet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1847,'marguerite','','MRKR MRKR','marguerit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1848,'1971','','','1971');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1849,'oubrerie','','APRR APRR','oubrer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1850,'clement','','KLMN KLMN','clement');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1851,'1966','','','1966');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1852,'2005','','','2005');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1853,'057311','','','057311');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1854,'african','','AFRK AFRK','african');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1855,'psycho','','SX SK','psycho');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1856,'2003','','','2003');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1857,'190','','','190');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1858,'84261','','','84261');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1859,'438','','','438');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1860,'serpent','','SRPN SRPN','serpent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1861,'a','','A A','a');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1862,'plumes','','PLMS PLMS','plum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1863,'843','','','843');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1864,'92','','','92');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1865,'mabanckou','','MPNK MPNK','mabanckou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1866,'alain','','ALN ALN','alain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1867,'soleil','','SLL SLL','soleil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1868,'172','','','172');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1869,'364','','','364');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1870,'13008','','','13008');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1871,'vents','','FNTS FNTS','vent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1872,'d','','T T','d');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1873,'ailleurs','','ALRS ALRS','ailleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1874,'la','','L L','la');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1875,'roque','','RK RK','roqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1876,'antheron','','AN0R ANTR','antheron');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1877,'fragments','','FRKM FRKM','fragment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1878,'marechera','','MRXR MRKR','marech');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1879,'dambudzo','','TMPT TMPT','dambudzo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1880,'1987','','','1987');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1881,'garnier','','KRN KRNR','garni');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1882,'evette','','AFT AFT','evet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1883,'xavier','','SF SFR','xavi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1884,'1964','','','1964');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1885,'loups','','LPS LPS','loup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1886,'31','','','31');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1887,'87767','','','87767');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1888,'470','','','470');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1889,'kaleidoscope','','KLTS KLTS','kaleidoscop');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1890,'gravett','','KRFT KRFT','gravet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1891,'emily','','AML AML','emily');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1892,'bibliothecaire','','PPL0 PPLT','bibliothecair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1893,'192','','','192');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1894,'vielle','','FL FL','viel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1895,'dame','','TM TM','dam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1896,'habite','','HPT HPT','habit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1897,'face','','FS FS','fac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1898,'chez','','XS XS','chez');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1899,'ecrit','','AKRT AKRT','ecrit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1900,'tard','','TRT TRT','tard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1901,'nuit','','NT NT','nuit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1902,'sort','','SRT SRT','sort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1903,'tombee','','TMP TMP','tombe');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1904,'resoudre','','RSTR RSTR','resoudr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1905,'lance','','LNS LNS','lanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1906,'fantastique','','FNTS FNTS','fantast');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1907,'9782013224062','','','9782013224062');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1908,'litterature','','LTRT LTRT','litteratur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1909,'01','','','01');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1910,'322406','','','322406');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1911,'hachette','','HXT HKT','hachet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1912,'gudule','','KTL KTL','gudul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1913,'durual','','TRL TRL','durual');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1914,'christophe','','KRST KRST','christoph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1915,'jojo','','JJ AH','jojo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1916,'secret','','SKRT SKRT','secret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1917,'confie','','KNF KNF','conf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1918,'terrible','','TRPL TRPL','terribl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1919,'pleine','','PLN PLN','plein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1920,'humour','','HMR HMR','humour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1921,'apprentissage','','APRN APRN','apprentissag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1922,'cp','','KP KP','cp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1923,'87833','','','87833');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1924,'390','','','390');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1925,'circonflexe','','SRKN SRKN','circonflex');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1926,'heitz','','HTS HTS','heitz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1927,'bruno','','PRN PRN','bruno');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1928,'1957','','','1957');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1929,'109','','','109');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1930,'notes','','NTS NTS','not');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1931,'bibliothecaires','','PPL0 PPLT','bibliothecair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1932,'deontologie','','TNTL TNTL','deontolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1933,'915543','','','915543');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1934,'03','','','03');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1935,'oeil','','AL AL','oeil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1936,'020','','','020');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1937,'23','','','23');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1938,'melot','','MLT MLT','melot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1939,'michel','','MXL MKL','michel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1940,'1943','','','1943');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1941,'565','','','565');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1942,'533','','','533');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1943,'540','','','540');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1944,'webliogr','','APLK FPLK','webliogr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1945,'541','','','541');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1946,'544','','','544');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1947,'bibliotheconomie','','PPL0 PPLT','bibliotheconom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1948,'7654','','','7654');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1949,'0977','','','0977');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1950,'cercle','','SRKL SRKL','cercl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1951,'librairie','','LPRR LPRR','librair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1952,'944','','','944');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1953,'le','','L L','le');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1954,'association','','ASSX ASXX','associ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1955,'alix','','ALKS ALKS','alix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1956,'yves','','AFS AFS','yve');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1957,'bibliotheques','','PPL0 PPLT','bibliothequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1958,'mise','','MS MS','mis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1959,'127','','','127');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1960,'recherches','','RXRX RKRK','recherch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1961,'contemporaines','','KNTM KNTM','contemporain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1962,'patrimoine','','PTRM PTRM','patrimoin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1963,'role','','RL RL','rol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1964,'charniere','','XRNR XRNR','charnier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1965,'present','','PRSN PRSN','present');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1966,'mission','','MSN MSN','mission');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1967,'identique','','ATNT ATNT','ident');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1968,'moyens','','MNS MNS','moyen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1969,'disposition','','TSPS TSPS','disposit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1970,'modes','','MTS MTS','mod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1971,'usage','','ASJ ASK','usag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1972,'mutation','','MTXN MTXN','mutat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1973,'assigne','','ASN ASKN','assign');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1974,'donc','','TNK TNK','donc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1975,'double','','TPL TPL','doubl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1976,'tache','','TX TK','tach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1977,'presenter','','PRSN PRSN','present');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1978,'occidental','','AXTN AXTN','occidental');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1979,'afin','','AFN AFN','afin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1980,'ampleur','','AMPL AMPL','ampleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1981,'connaissent','','KNSN KNSN','connaissent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1982,'nouveaux','','NF NF','nouveau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1983,'enjeux','','ANJK ANJK','enjeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1984,'economiques','','AKNM AKNM','econom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1985,'engendres','','ANJN ANKN','engendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1986,'telles','','TLS TLS','tel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1987,'evolutions','','AFLX AFLX','evolu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1988,'docteur','','TKTR TKTR','docteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1989,'denis','','TNS TNS','den');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1990,'pallier','','PL PLR','palli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1991,'inspecteur','','ANSP ANSP','inspecteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1992,'general','','JNRL KNRL','general');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1993,'honoraire','','HNRR HNRR','honorair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1994,'13','','','13');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1995,'057064','','','057064');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1996,'presses','','PRSS PRSS','press');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1997,'universitaires','','ANFR ANFR','universitair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1998,'027','','','027');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (1999,'1944','','','1944');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2000,'9782203129375','','','9782203129375');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2001,'mangas','','MNKS MNKS','mang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2002,'203','','','203');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2003,'12937','','','12937');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2004,'casterman','','KSTR KSTR','casterman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2005,'cadet','','KTT KTT','cadet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2006,'for','','FR FR','for');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2007,'brisou','','PRS PRS','brisou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2008,'pellen','','PLN PLN','pellen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2009,'evelyn','','AFLN AFLN','evelyn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2010,'450','','','450');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2011,'travaillant','','TRFL TRFL','travaill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2012,'universite','','ANFR ANFR','universit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2013,'huppee','','HP HP','huppe');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2014,'washington','','AXNK FXNK','washington');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2015,'david','','TFT TFT','david');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2016,'golberg','','KLPR KLPR','golberg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2017,'devient','','TFNT TFNT','devient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2018,'hasards','','HSRT HSRT','hasard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2019,'prive','','PRF PRF','priv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2020,'alan','','ALN ALN','alan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2021,'stowe','','ST ST','stow');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2022,'vieil','','FL FL','vieil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2023,'acariatre','','AKRT AKRT','acariatr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2024,'multimillionnaire','','MLTM MLTM','multimillionnair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2025,'industriel','','ANTS ANTS','industriel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2026,'cynique','','SNK SNK','cyniqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2027,'scrupules','','SKPL SKPL','scrupul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2028,'surtout','','SRTT SRTT','surtout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2029,'bailleur','','PLR PLR','bailleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2030,'parti','','PRT PRT','part');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2031,'sommes','','SMS SMS','somm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2032,'justement','','JSTM ASTM','just');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2033,'presidentielle','','PRST PRST','presidentiel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2034,'gosse','','KS KS','goss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2035,'va','','F F','va');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2036,'guerre','','KR KR','guerr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2037,'ancien','','ANSN ANXN','ancien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2038,'alcoolique','','ALKL ALKL','alcool');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2039,'reconverti','','RKNF RKNF','reconvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2040,'fou','','F F','fou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2041,'voit','','FT FT','voit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2042,'mauvais','','MF MFS','mauv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2043,'arrivee','','ARF ARF','arrive');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2044,'inconnu','','ANKN ANKN','inconnu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2045,'influent','','ANFL ANFL','influent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2046,'commencer','','KMNS KMNS','commenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2047,'classement','','KLSM KLSM','class');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2048,'papiers','','PPRS PPRS','papi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2049,'affaires','','AFRS AFRS','affair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2050,'pris','','PRS PRS','pris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2051,'chasse','','XS XS','chass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2052,'barbouzes','','PRPS PRPS','barbouz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2053,'securite','','SKRT SKRT','securit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2054,'tandis','','TNTS TNTS','tand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2055,'candidate','','KNTT KNTT','candidat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2056,'democrate','','TMKR TMKR','democrat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2057,'grignote','','KRNT KRKN','grignot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2058,'retard','','RTRT RTRT','retard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2059,'vote','','FT FT','vot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2060,'rapproche','','RPRX RPRK','rapproch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2061,'amis','','AMS AMS','amis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2062,'contraint','','KNTR KNTR','contraint');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2063,'veut','','FT FT','veut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2064,'tuer','','TR TR','tu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2065,'apres','','APRS APRS','apre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2066,'reality','','RLT RLT','reality');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2067,'show','','X XF','show');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2068,'adapte','','ATPT ATPT','adapt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2069,'influence','','ANFL ANFL','influenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2070,'dustin','','TSTN TSTN','dustin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2071,'hoffman','','HFMN HFMN','hoffman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2072,'robert','','RPRT RPRT','robert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2073,'niro','','NR NR','niro');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2074,'larry','','LR LR','larry');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2075,'beinhart','','PNRT PNRT','beinhart');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2076,'retour','','RTR RTR','retour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2077,'fracassant','','FRKS FRKS','fracass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2078,'scene','','SN SN','scen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2079,'litteraire','','LTRR LTRR','litterair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2080,'demontant','','TMNT TMNT','demont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2081,'piece','','PS PS','piec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2082,'administration','','ATMN ATMN','administr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2083,'bush','','PX PX','bush');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2084,'maniere','','MNR MNR','manier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2085,'manipuler','','MNPL MNPL','manipul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2086,'public','','PPLK PPLK','public');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2087,'mondiale','','MNTL MNTL','mondial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2088,'jouant','','JNT ANT','jou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2089,'peurs','','PRS PRS','peur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2090,'fantasmes','','FNTS FNTS','fantasm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2091,'archaiques','','ARXK ARKK','archaiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2092,'quoi','','K K','quoi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2093,'critiques','','KRTK KRTK','critiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2094,'virulentes','','FRLN FRLN','virulent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2095,'viennent','','FNNT FNNT','viennent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2096,'vieille','','FL FL','vieil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2097,'077327','','','077327');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2098,'1947','','','1947');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2099,'carrer','','KRR KRR','carr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2100,'patrice','','PTRS PTRS','patric');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2101,'enlevement','','ANLF ANLF','enlev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2102,'56','','','56');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2103,'kidnappant','','KTNP KTNP','kidnapp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2104,'mlle','','ML ML','mlle');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2105,'labourdette','','LPRT LPRT','labourdet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2106,'ravissante','','RFSN RFSN','rav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2107,'chef','','XF XF','chef');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2108,'brigands','','PRKN PRKN','brigand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2109,'complices','','KMPL KMPL','complic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2110,'croient','','KRNT KRNT','croient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2111,'pouvoir','','PFR PFR','pouvoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2112,'obtenir','','APTN APTN','obten');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2113,'municipalite','','MNSP MNSP','municipalit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2114,'rancon','','RNKN RNKN','rancon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2115,'rondelette','','RNTL RNTL','rondelet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2116,'compter','','KMPT KMPT','compt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2117,'courage','','KRJ KRK','courag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2118,'talents','','TLNT TLNT','talent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2119,'053882','','','053882');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2120,'folio','','FL FL','folio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2121,'mahy','','MH MH','mahy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2122,'margaret','','MRKR MRKR','margaret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2123,'1936','','','1936');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2124,'blake','','PLK PLK','blak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2125,'dizier','','TS TSR','dizi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2126,'farre','','FR FR','farr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2127,'quentin','','KNTN KNTN','quentin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2128,'1932','','','1932');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2129,'1941','','','1941');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2130,'pleines','','PLNS PLNS','plein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2131,'fantomes','','FNTM FNTM','fantom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2132,'138','','','138');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2133,'avez','','AFS AFS','avez');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2134,'vous','','FS FS','vous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2135,'peur','','PR PR','peur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2136,'mourir','','MRR MRR','mour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2137,'votre','','FTR FTR','votr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2138,'sommeil','','SML SML','sommeil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2139,'enseveli','','ANSF ANSF','ensevel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2140,'ecroulement','','AKRL AKRL','ecroul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2141,'accumulation','','AKML AKML','accumul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2142,'danger','','TNJR TNKR','dang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2143,'existence','','AKSS AKSS','existent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2144,'classez','','KLSS KLSS','class');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2145,'volumes','','FLMS FLMS','volum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2146,'parution','','PRXN PRXN','parut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2147,'selon','','SLN SLN','selon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2148,'critere','','KRTR KRTR','criter');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2149,'connu','','KN KN','connu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2150,'peut','','PT PT','peut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2151,'voisiner','','FSNR FSNR','voisin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2152,'etagere','','ATKR ATJR','etager');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2153,'irremediablement','','ARMT ARMT','irremedi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2154,'brouilles','','PRLS PRLS','brouill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2155,'graves','','KRFS KRFS','grav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2156,'questions','','KSXN KSXN','question');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2157,'posant','','PSNT PSNT','pos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2158,'disparition','','TSPR TSPR','disparit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2159,'bibliomanes','','PPLM PPLM','biblioman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2160,'outre','','ATR ATR','outr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2161,'passion','','PSN PSN','passion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2162,'posseder','','PSTR PSTR','possed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2163,'celle','','SL SL','cel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2164,'etres','','ATRS ATRS','etre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2165,'vivants','','FFNT FFNT','viv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2166,'complexite','','KMPL KMPL','complexit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2167,'finissent','','FNSN FNSN','fin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2168,'composer','','KMPS KMPS','compos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2169,'labyrinthe','','LPRN LPRN','labyrinth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2170,'dangereux','','TNJR TNKR','danger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2171,'pouvons','','PFNS PFNS','pouvon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2172,'sortir','','SRTR SRTR','sort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2173,'apparaissent','','APRS APRS','apparaissent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2174,'nombre','','NMPR NMPR','nombr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2175,'pessoa','','PS PS','pesso');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2176,'tentant','','TNTN TNTN','tent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2177,'matisse','','MTS MTS','mat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2178,'postulant','','PSTL PSTL','postul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2179,'poste','','PST PST','post');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2180,'controleur','','KNTR KNTR','controleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2181,'droit','','TRT TRT','droit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2182,'pauvres','','PFRS PFRS','pauvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2183,'capitaine','','KPTN KPTN','capitain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2184,'achab','','AXP AKP','achab');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2185,'mystere','','MSTR MSTR','myster');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2186,'jambe','','JMP AMP','jamb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2187,'moby','','MP MP','moby');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2188,'dick','','TK TK','dick');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2189,'occupent','','AKPN AKPN','occupent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2190,'etageres','','ATKR ATJR','etager');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2191,'peuplees','','PPLS PPLS','peuple');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2192,'rencontres','','RNKN RNKN','rencontr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2193,'quittent','','KTNT KTNT','quittent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2194,'26054','','','26054');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2195,'denoel','','TNL TNL','denoel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2196,'844','','','844');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2197,'914','','','914');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2198,'bonnet','','PNT PNT','bonnet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2199,'jacques','','JKS AKS','jacqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2200,'1949','','','1949');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2201,'actuelle','','AKTL AKTL','actuel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2202,'60','','','60');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2203,'faciles','','FSLS FSLS','facil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2204,'realiser','','RLSR RLSR','realis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2205,'215','','','215');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2206,'213','','','213');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2207,'africaine','','AFRK AFRK','africain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2208,'87691','','','87691');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2209,'819','','','819');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2210,'first','','FRST FRST','first');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2211,'641','','','641');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2212,'596','','','596');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2213,'bella','','PL PL','bel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2214,'ola','','AL AL','ola');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2215,'cuvilliez','','KFLS KFLS','cuvill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2216,'joelle','','JL AL','joel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2217,'tabuteau','','TPT TPT','tabuteau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2218,'luc','','LK LK','luc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2219,'251','','','251');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2220,'geographie','','JKRF KKRF','geograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2221,'7459','','','7459');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2222,'5517','','','5517');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2223,'milan','','MLN MLN','milan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2224,'toulouse','','TLS TLS','toulous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2225,'700','','','700');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2226,'83','','','83');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2227,'encyclopes','','ANSK ANSK','encyclop');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2228,'nantet','','NNTT NNTT','nantet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2229,'bernard','','PRNR PRNR','bernard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2230,'1938','','','1938');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2231,'grosse','','KRS KRS','gross');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2232,'legume','','LKM LKM','legum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2233,'84156','','','84156');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2234,'884','','','884');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2235,'rouergue','','RRK RRK','rouergu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2236,'rodez','','RTS RTS','rod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2237,'gourounas','','KRNS KRNS','gouroun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2238,'1965','','','1965');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2239,'enquetes','','ANKT ANKT','enquet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2240,'potager','','PTKR PTJR','potag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2241,'lapou','','LP LP','lapou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2242,'reunit','','RNT RNT','reun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2243,'carotte','','KRT KRT','carott');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2244,'pissenlit','','PSNL PSNL','pissenl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2245,'ecrase','','AKRS AKRS','ecras');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2246,'poireau','','PR PR','poireau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2247,'agression','','AKRS AKRS','agress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2248,'champignon','','XMPN XMPK','champignon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2249,'tomate','','TMT TMT','tomat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2250,'poseur','','PSR PSR','poseur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2251,'lapins','','LPNS LPNS','lapin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2252,'voleur','','FLR FLR','voleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2253,'courgettes','','KRKT KRKT','courget');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2254,'cerisier','','SRS SRSR','cerisi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2255,'devalise','','TFLS TFLS','devalis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2256,'radis','','RTS RTS','rad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2257,'citron','','STRN STRN','citron');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2258,'presse','','PRS PRS','press');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2259,'061220','','','061220');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2260,'giboulees','','KPLS JPLS','giboule');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2261,'guettier','','KT KTR','guetti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2262,'benedicte','','PNTK PNTK','benedict');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2263,'quel','','KL KL','quel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2264,'dis','','TS TS','dis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2265,'06156','','','06156');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2266,'petons','','PTNS PTNS','peton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2267,'gay','','K K','gay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2268,'para','','PR PR','par');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2269,'praline','','PRLN PRLN','pralin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2270,'1956','','','1956');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2271,'prigent','','PRJN PRKN','prigent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2272,'andree','','ANTR ANTR','andre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2273,'1963','','','1963');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2274,'jardin','','JRTN ARTN','jardin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2275,'32','','','32');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2276,'9782092530016','','','9782092530016');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2277,'jardinage','','JRTN ARTN','jardinag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2278,'eveil','','AFL AFL','eveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2279,'petite','','PTT PTT','petit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2280,'enfance','','ANFN ANFN','enfanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2281,'colorier','','KLR KLRR','colori');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2282,'09','','','09');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2283,'253001','','','253001');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2284,'nathan','','N0N NTN','nathan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2285,'805','','','805');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2286,'kididoc','','KTTK KTTK','kididoc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2287,'guidoux','','KT KT','guidoux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2288,'valerie','','FLR FLR','valer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2289,'zigomar','','SKMR SKMR','zigomar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2290,'legumes','','LKMS LKMS','legum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2291,'1992','','','1992');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2292,'28','','','28');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2293,'suite','','ST ST','suit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2294,'raison','','RSN RSN','raison');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2295,'04841','','','04841');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2296,'corentin','','KRNT KRNT','corentin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2297,'philippe','','FLP FLP','philipp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2298,'fruits','','FRTS FRTS','fruit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2299,'marche','','MRX MRK','march');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2300,'printemps','','PRNT PRNT','printemp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2301,'automne','','ATMN ATMN','automn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2302,'244','','','244');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2303,'46006','','','46006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2304,'lito','','LT LT','lito');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2305,'champigny','','XMPN XMPK','champigny');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2306,'marne','','MRN MRN','marn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2307,'512','','','512');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2308,'loubier','','LP LPR','loubi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2309,'virginie','','FRJN FRKN','virgin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2310,'68','','','68');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2311,'notice','','NTS NTS','notic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2312,'red','','RT RT','red');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2313,'915569','','','915569');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2314,'rue','','R R','ru');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2315,'voisins','','FSNS FSNS','voisin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2316,'bretonneux','','PRTN PRTN','breton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2317,'serres','','SRS SRS','serr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2318,'jarrie','','JR AR','jarr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2319,'martin','','MRTN MRTN','martin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2320,'84006','','','84006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2321,'581','','','581');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2322,'mila','','ML ML','mil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2323,'teyras','','TRS TRS','teyr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2324,'emmanuelle','','AMNL AMNL','emmanuel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2325,'christine','','KRST KRST','christin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2326,'rouge','','RJ RK','roug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2327,'emotions','','AMXN AMXN','emot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2328,'naturelles','','NTRL NTRL','naturel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2329,'501','','','501');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2330,'freymann','','FRMN FRMN','freymann');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2331,'saxton','','SKST SKST','saxton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2332,'elffers','','ALFR ALFR','elffer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2333,'joost','','JST AST','joost');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2334,'bebes','','PPS PPS','beb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2335,'croquer','','KRKR KRKR','croqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2336,'24','','','24');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2337,'artisanat','','ARTS ARTS','artisanat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2338,'745','','','745');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2339,'584','','','584');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2340,'50','','','50');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2341,'20487','','','20487');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2342,'loulou','','LL LL','loulou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2343,'cie','','S X','ci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2344,'bravi','','PRF PRF','brav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2345,'soledad','','SLTT SLTT','soledad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2346,'orange','','ARNJ ARNK','orang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2347,'pomme','','PM PM','pomm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2348,'poire','','PR PR','poir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2349,'fahrenheit','','FRNT FRNT','fahrenheit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2350,'451','','','451');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2351,'degres','','TKRS TKRS','degr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2352,'representent','','RPRS RPRS','representent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2353,'temperature','','TMPR TMPR','temperatur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2354,'enflamme','','ANFL ANFL','enflamm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2355,'consume','','KNSM KNSM','consum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2356,'societe','','SST SXT','societ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2357,'future','','FTR FTR','futur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2358,'questionnement','','KSXN KSXN','question');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2359,'consideree','','KNST KNST','considere');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2360,'antisocial','','ANTS ANTS','antisocial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2361,'corps','','KRPS KRPS','corp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2362,'special','','SPSL SPXL','special');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2363,'pompiers','','PMPR PMPR','pompi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2364,'charge','','XRJ XRK','charg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2365,'bruler','','PRLR PRLR','brul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2366,'detention','','TTNX TTNX','detent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2367,'collectif','','KLKT KLKT','collect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2368,'montag','','MNTK MNTK','montag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2369,'pompier','','PMP PMPR','pompi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2370,'pyromane','','PRMN PRMN','pyroman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2371,'rever','','RFR RFR','rev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2372,'different','','TFRN TFRN','different');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2373,'bannirait','','PNRT PNRT','bann');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2374,'imaginaire','','AMJN AMKN','imaginair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2375,'profit','','PRFT PRFT','prof');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2376,'immediatement','','AMTT AMTT','immediat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2377,'consommable','','KNSM KNSM','consomm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2378,'lors','','LRS LRS','lor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2379,'impitoyablement','','AMPT AMPT','impitoi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2380,'desavoue','','TSF TSF','desavou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2381,'041573','','','041573');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2382,'813','','','813');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2383,'54','','','54');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2384,'science','','SNS SNS','scienc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2385,'bradbury','','PRTP PRTP','bradbury');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2386,'ray','','R R','ray');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2387,'1920','','','1920');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2388,'robillot','','RPLT RPLT','robillot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2389,'huitieme','','HTM HTM','huitiem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2390,'279','','','279');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2391,'84172','','','84172');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2392,'039','','','039');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2393,'atalante','','ATLN ATLN','atal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2394,'annales','','ANLS ANLS','annal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2395,'pratchett','','PRXT PRXT','pratchet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2396,'terry','','TR TR','terry');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2397,'1948','','','1948');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2398,'couton','','KTN KTN','couton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2399,'patrick','','PTRK PTRK','patrick');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2400,'sortilege','','SRTL SRTL','sortileg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2401,'270','','','270');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2402,'traduit','','TRTT TRTT','traduit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2403,'anglais','','ANKL ANKL','anglais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2404,'905158','','','905158');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2405,'75','','','75');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2406,'triste','','TRST TRST','trist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2407,'enfant','','ANFN ANFN','enfant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2408,'huitre','','HTR HTR','huitr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2409,'histoires','','HSTR HSTR','histoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2410,'edition','','ATXN ATXN','edit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2411,'speciale','','SPSL SPXL','special');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2412,'128','','','128');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2413,'inventivite','','ANFN ANFN','inventivit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2414,'particuliere','','PRTK PRTK','particulier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2415,'melant','','MLNT MLNT','mel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2416,'craute','','KRT KRT','craut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2417,'tendresse','','TNTR TNTR','tendress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2418,'macabre','','MKPR MKPR','macabr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2419,'tim','','TM TM','tim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2420,'burton','','PRTN PRTN','burton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2421,'etonnante','','ATNN ATNN','eton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2422,'solitaires','','SLTR SLTR','solitair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2423,'etranges','','ATRN ATRN','etrang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2424,'tarderont','','TRTR TRTR','tard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2425,'horrifier','','HRF HRFR','horrifi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2426,'emouvoir','','AMFR AMFR','emouvoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2427,'rire','','RR RR','rir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2428,'9782264048738','','','9782264048738');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2429,'contemporains','','KNTM KNTM','contemporain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2430,'264','','','264');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2431,'04873','','','04873');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2432,'10','','','10');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2433,'850','','','850');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2434,'italienne','','ATLN ATLN','italien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2435,'revue','','RF RF','revu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2436,'dada','','TT TT','dad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2437,'n171','','N N','n171');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2438,'9782358800327','','','9782358800327');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2439,'358','','','358');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2440,'80032','','','80032');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2441,'arola','','ARL ARL','arol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2442,'224','','','224');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2443,'9782866425975','','','9782866425975');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2444,'spectacles','','SPKT SPKT','spectacl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2445,'86642','','','86642');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2446,'597','','','597');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2447,'cah','','K K','cah');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2448,'album','','ALPM ALPM','album');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2449,'baecque','','PK PK','baecqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2450,'anto','','ANT ANT','anto');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2451,'timbelele','','TMPL TMPL','timbelel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2452,'reine','','RN RN','rein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2453,'lune','','LN LN','lun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2454,'laissez','','LSS LSS','laiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2455,'envo','','ANF ANF','envo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2456,'uter','','ATR ATR','uter');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2457,'kora','','KR KR','kor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2458,'balafon','','PLFN PLFN','balafon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2459,'kholle','','KL KL','kholl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2460,'djembes','','TJMP TJMP','djemb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2461,'tama','','TM TM','tam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2462,'accent','','AKSN AKSN','accent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2463,'narrateur','','NRTR NRTR','narrateur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2464,'incomparables','','ANKM ANKM','incompar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2465,'toure','','TR TR','tour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2466,'partez','','PRTS PRTS','part');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2467,'musiques','','MSKS MSKS','musiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2468,'9782070621149','','','9782070621149');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2469,'instruments','','ANST ANST','instrument');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2470,'062114','','','062114');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2471,'mes','','MS MS','me');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2472,'premieres','','PRMR PRMR','premier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2473,'decouvertes','','TKFR TKFR','decouvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2474,'silloray','','SLR SLR','silloray');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2475,'florent','','FLRN FLRN','florent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2476,'edward','','ATRT ATRT','edward');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2477,'mains','','MNS MNS','main');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2478,'45','','','45');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2479,'surround','','SRNT SRNT','surround');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2480,'dolby','','TLP TLP','dolby');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2481,'twentieth','','TNT0 TNTT','twentieth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2482,'century','','SNTR SNTR','century');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2483,'fox','','FKS FKS','fox');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2484,'et','','AT AT','et');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2485,'cinema','fr_FR','SNM SNM','cinem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2486,'depp','','TP TP','depp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2487,'ryder','','RTR RTR','ryd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2488,'johnny','','JN AN','johnny');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2489,'winona','','ANN FNN','winon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2490,'beetlejuice','','PTLJ PTLJ','beetlejuic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2491,'warner','','ARNR FRNR','warn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2492,'home','','HM HM','hom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2493,'neuilly','','NL NL','neuilly');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2494,'seine','','SN SN','sein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2495,'keaton','','KTN KTN','keaton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2496,'mickael','','MKL MKL','mickael');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2497,'000001','','','000001');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2498,'edw','','AT AT','edw');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2499,'videotheque','','FT0K FTTK','videothequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2500,'empruntable','','AMPR AMPR','emprunt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2501,'big','','PK PK','big');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2502,'fish','','FX FX','fish');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2503,'51','','','51');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2504,'sonore','','SNR SNR','sonor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2505,'columbia','','KLMP KLMP','columbi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2506,'tristar','','TRST TRST','tristar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2507,'boulogne','','PLN PLKN','boulogn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2508,'billancourt','','PLNK PLNK','billancourt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2509,'mcgregor','','MKRK MKRK','mcgregor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2510,'ewan','','AN AN','ewan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2511,'noces','','NSS NSS','noc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2512,'funebres','','FNPR FNPR','funebr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2513,'17','','','17');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2514,'charlie','','XRL XRL','charl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2515,'chocolaterie','','XKLT XKLT','chocolater');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2516,'miriam','','MRM MRM','miriam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2517,'makeba','','MKP MKP','makeb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2518,'essential','','ASNX ASNX','essential');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2519,'recordings','','RKRT RKRT','recording');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2520,'the','','0 T','the');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2521,'empress','','AMPR AMPR','empress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2522,'song','','SNK SNK','song');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2523,'disques','','TSKS TSKS','disqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2524,'compacts','','KMPK KMPK','compact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2525,'manteca','','MNTK MNTK','mantec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2526,'musique','fr_FR','MSK MSK','musiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2527,'jammu','','JM AM','jammu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2528,'africa','','AFRK AFRK','afric');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2529,'az','','AS AS','az');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2530,'lo','','L L','lo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2531,'ismael','','ASML ASML','ismael');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2532,'tchamantche','','XMNX XMNX','tchamantch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2533,'universal','','ANFR ANFR','universal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2534,'music','','MSK MSK','music');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2535,'jazz','','JS AS','jazz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2536,'traore','','TRR TRR','traor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2537,'rokia','','RK RK','roki');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2538,'1974','','','1974');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2539,'bemba','','PMP PMP','bemb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2540,'polydor','','PLTR PLTR','polydor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2541,'keita','','KT KT','keit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2542,'salif','','SLF SLF','salif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2543,'000009','','','000009');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2544,'kei','','K K','kei');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2545,'discotheque','','TSK0 TSKT','discothequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2546,'folila','','FLL FLL','folil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2547,'46','','','46');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2548,'41','','','41');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2549,'because','','PKS PKS','becaus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2550,'mariam','','MRM MRM','mariam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2551,'000010','','','000010');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2552,'ama','','AM AM','ama');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2553,'000008','','','000008');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2554,'tra','','TR TR','tra');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2555,'000007','','','000007');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2556,'000006','','','000006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2557,'mak','','MK MK','mak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2558,'000005','','','000005');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2559,'dvdj','','TFTJ TFT','dvdj');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2560,'char','','XR XR','char');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2561,'000004','','','000004');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2562,'noc','','NK NK','noc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2563,'000002','','','000002');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2564,'000003','','','000003');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2565,'bee','','P P','be');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2566,'envouter','','ANFT ANFT','envout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2567,'television','fr_FR','TLFS TLFX','televis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2568,'americaine','','AMRK AMRK','americain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2569,'poesie','fr_FR','PS PS','poes');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2570,'fantastique','fr_FR','FNTS FNTS','fantast');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2571,'merveilleux','fr_FR','MRFL MRFL','merveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2572,'legumes','fr_FR','LKMS LKMS','legum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2573,'arts','fr_FR','ARTS ARTS','art');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2574,'plastiques','fr_FR','PLST PLST','plastiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2575,'740','','','740');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2576,'decoratifs','','TKRT TKRT','decor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2577,'000020','','','000020');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2578,'fre','','FR FR','fre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2579,'cuisine','fr_FR','KSN KSN','cuisin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2580,'menagers','','MNKR MNJR','menager');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2581,'couture','','KTR KTR','coutur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2582,'beaute','','PT PT','beaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2583,'jardinage','fr_FR','JRTN ARTN','jardinag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2584,'jardin','fr_FR','JRTN ARTN','jardin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2585,'bibliotheconomie','fr_FR','PPL0 PPLT','bibliotheconom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2586,'documentation','','TKMN TKMN','document');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2587,'000040','','','000040');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2588,'litterature','fr_FR','LTRT LTRT','litteratur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2589,'noire','fr_FR','NR NR','noir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2590,'ethnologie','fr_FR','A0NL ATNL','ethnolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2591,'000059','','','000059');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2592,'baa','','P P','ba');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2593,'000011','','','000011');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2594,'sil','','SL SL','sil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2595,'000060','','','000060');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2596,'ra','','R R','ra');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2597,'bli','','PL PL','bli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2598,'1979','','','1979');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2599,'0220','','','0220');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2600,'8245','','','8245');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2601,'participations','','PRTS PRTS','particip');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2602,'editions','','ATXN ATXN','edit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2603,'geographie','fr_FR','JKRF KKRF','geograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2604,'403','','','403');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2605,'septembre','','SPTM SPTM','septembr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2606,'numero','','NMR NMR','numero');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2607,'reveil','','RFL RFL','reveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2608,'change','','XNJ XNK','chang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2609,'mortalite','','MRTL MRTL','mortalit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2610,'infantile','','ANFN ANFN','infantil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2611,'amorce','','AMRS AMRS','amorc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2612,'heros','','HRS HRS','heros');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2613,'ibrahim','','APRH APRH','ibrahim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2614,'cinquante','','SNKN SNKN','cinqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2615,'collimateur','','KLMT KLMT','collim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2616,'gout','','KT KT','gout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2617,'yassa','','AS AS','yass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2618,'poulet','','PLT PLT','poulet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2619,'hospitalite','','HSPT HSPT','hospitalit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2620,'senegalaise','','SNKL SNKL','senegalais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2621,'evasion','','AFSN AFXN','evas');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2622,'namibie','','NMP NMP','namib');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2623,'arche','','ARX ARK','arche');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2624,'noe','','N N','no');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2625,'espaces','','ASPS ASPS','espac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2626,'geres','','KRS JRS','ger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2627,'habitants','','HPTN HPTN','habit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2628,'faune','','FN FN','faun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2629,'sauvage','','SFJ SFK','sauvag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2630,'multipliee','','MLTP MLTP','multiplie');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2631,'touristes','','TRST TRST','tourist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2632,'affluent','','AFLN AFLN','affluent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2633,'populations','','PPLX PPLX','popul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2634,'tirent','','TRNT TRNT','tirent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2635,'revenu','','RFN RFN','revenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2636,'valley','','FL FL','valley');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2637,'naitre','','NTR NTR','naitr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2638,'technologies','','TKNL TKNL','technolog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2639,'boostent','','PSTN PSTN','boostent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2640,'campus','','KMPS KMPS','campus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2641,'ebullition','','APLX APLX','ebullit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2642,'demographie','','TMKR TMKR','demograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2643,'oblige','','APLJ APLK','oblig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2644,'etudiants','','ATTN ATTN','etudi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2645,'pressent','','PRSN PRSN','pressent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2646,'universites','','ANFR ANFR','universit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2647,'subsaharienne','','SPSH SPSH','subsaharien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2648,'environnement','','ANFR ANFR','environ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2649,'chantiers','','XNTR XNTR','chanti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2650,'dov','','TF TF','dov');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2651,'zerah','','SR SR','zerah');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2652,'defis','','TFS TFS','def');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2653,'relever','','RLFR RLFR','relev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2654,'geopolitique','','JPLT KPLT','geopolit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2655,'lacs','','LKS LKS','lac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2656,'poudriere','','PTRR PTRR','poudrier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2657,'territoire','','TRTR TRTR','territoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2658,'marque','','MRK MRK','marqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2659,'decennies','','TSNS TSNS','decen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2660,'developpement','','TFLP TFLP','developp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2661,'font','','FNT FNT','font');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2662,'detachable','','TTKP TTKP','detach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2663,'plan','','PLN PLN','plan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2664,'cap','','KP KP','cap');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2665,'capetoniens','','KPTN KPTN','capetonien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2666,'eldorado','','ALTR ALTR','eldorado');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2667,'latine','','LTN LTN','latin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2668,'angola','','ANKL ANKL','angol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2669,'vit','','FT FT','vit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2670,'boom','','PM PM','boom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2671,'exceptionnel','','AKSP AKSP','exceptionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2672,'portugais','','PRTK PRTK','portug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2673,'bresiliens','','PRSL PRSL','bresilien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2674,'chinois','','XN XNS','chinois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2675,'tenter','','TNTR TNTR','tent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2676,'chance','','XNS XNS','chanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2677,'villages','','FLJS FLKS','villag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2678,'bourgogne','','PRKN PRKK','bourgogn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2679,'panorama','','PNRM PNRM','panoram');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2680,'mensuel','','MNSL MNSL','mensuel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2681,'pepites','','PPTS PPTS','pepit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2682,'terroir','','TRR TRR','terroir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2683,'393','','','393');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2684,'ultime','','ALTM ALTM','ultim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2685,'voyageurs','','FJRS FKRS','voyageur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2686,'derniere','','TRNR TRNR','dernier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2687,'frontiere','','FRNT FRNT','frontier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2688,'pacifique','','PSFK PSFK','pacif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2689,'kilometres','','KLMT KLMT','kilometr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2690,'emergee','','AMRJ AMRK','emerge');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2691,'statues','','STTS STTS','statu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2692,'geantes','','JNTS KNTS','ge');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2693,'fascinent','','FSNN FSNN','fascinent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2694,'ressemblera','','RSMP RSMP','ressembl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2695,'metro','','MTR MTR','metro');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2696,'200','','','200');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2697,'gigantesque','','JKNT KKNT','gigantesqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2698,'acheres','','AXRS AKRS','acher');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2699,'silicon','','SLKN SLKN','silicon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2700,'saclay','','SKL SKL','saclay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2701,'megapole','','MKPL MKPL','megapol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2702,'commence','','KMNS KMNS','commenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2703,'devoiler','','TFLR TFLR','devoil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2704,'visage','','FSJ FSK','visag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2705,'iphone','','AFN AFN','iphon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2706,'ecolo','','AKL AKL','ecolo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2707,'etape','','ATP ATP','etap');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2708,'analyse','','ANLS ANLS','analys');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2709,'impact','','AMPK AMPK','impact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2710,'environnemental','','ANFR ANFR','environnemental');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2711,'bijou','','PJ PH','bijou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2712,'apple','','APL APL','apple');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2713,'cracovie','','KRKF KRKF','cracov');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2714,'cite','','ST ST','cit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2715,'polonaise','','PLNS PLNS','polonais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2716,'touristiques','','TRST TRST','tourist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2717,'bloc','','PLK PLK','bloc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2718,'richesse','','RXS RKS','richess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2719,'culturelle','','KLTR KLTR','culturel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2720,'cree','','KR KR','cre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2721,'ambiance','','AMPN AMPN','ambianc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2722,'movida','','MFT MFT','movid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2723,'partir','','PRTR PRTR','part');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2724,'malgre','','MLKR MLKR','malgr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2725,'institutionnelle','','ANST ANST','institutionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2726,'paralyse','','PRLS PRLS','paralys');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2727,'capitale','','KPTL KPTL','capital');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2728,'belge','','PLJ PLK','belg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2729,'creativite','','KRTF KRTF','creativit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2730,'tables','','TPLS TPLS','tabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2731,'hotels','','HTLS HTLS','hotel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2732,'shopping','','XPNK XPNK','shopping');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2733,'tour','','TR TR','tour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2734,'horizon','','HRSN HRSN','horizon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2735,'adresses','','ATRS ATRS','adress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2736,'comment','','KMNT KMNT','comment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2737,'chine','','XN XN','chin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2738,'redessine','','RTSN RTSN','redessin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2739,'grece','','KRS KRS','grec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2740,'birmanie','','PRMN PRMN','birman');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2741,'zambie','','SMP SMP','zamb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2742,'partout','','PRTT PRTT','partout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2743,'financent','','FNNS FNNS','financent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2744,'batissent','','PTSN PTSN','bat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2745,'ports','','PRTS PRTS','port');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2746,'routes','','RTS RTS','rout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2747,'hopitaux','','HPT HPT','hopital');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2748,'phase','','FS FS','phas');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2749,'zouchuqu','','SXK SKK','zouchuqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2750,'strategie','','STRT STRT','strateg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2751,'conquete','','KNKT KNKT','conquet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2752,'azimuts','','ASMT ASMT','azimut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2753,'kapisa','','KPS KPS','kapis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2754,'cyclone','','SKLN SKLN','cyclon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2755,'proche','','PRX PRK','proch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2756,'kaboul','','KPL KPL','kaboul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2757,'province','','PRFN PRFN','provinc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2758,'dangers','','TNJR TNKR','danger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2759,'militaires','','MLTR MLTR','militair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2760,'littoral','','LTRL LTRL','littoral');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2761,'normandie','','NRMN NRMN','normand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2762,'coup','','KP KP','coup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2763,'hauts','','HTS HTS','haut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2764,'normande','','NRMN NRMN','normand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2765,'tourisme','','TRSM TRSM','tourism');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2766,'ile','fr_FR','AL AL','ile');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2767,'paques','fr_FR','PKS PKS','paqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2768,'402','','','402');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2769,'aout','','AT AT','aout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2770,'compostelle','','KMPS KMPS','compostel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2771,'shikoku','','XKK XKK','shikoku');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2772,'lalibela','','LLPL LLPL','lalibel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2773,'syrie','','SR SR','syr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2774,'menace','','MNS MNS','menac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2775,'indien','','ANTN ANTN','indien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2776,'dim','','TM TM','dim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2777,'sum','','SM SM','sum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2778,'microfestin','','MKRF MKRF','microfestin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2779,'chinoise','','XNS XNS','chinois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2780,'sillage','','SLJ SLK','sillag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2781,'ulysse','','ALS ALS','ulyss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2782,'homere','','HMR HMR','homer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2783,'mediterranee','','MTTR MTTR','mediterrane');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2784,'escale','','ASKL ASKL','escal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2785,'vite','','FT FT','vit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2786,'lu','','L L','lu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2787,'mer','','MR MR','mer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2788,'reportage','','RPRT RPRT','reportag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2789,'marins','','MRNS MRNS','marin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2790,'pecheurs','','PXRS PKRS','pecheur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2791,'ecument','','AKMN AKMN','ecument');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2792,'oceans','','ASNS ASNS','ocean');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2793,'glaces','','KLSS KLSS','glac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2794,'bravent','','PRFN PRFN','bravent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2795,'tempetes','','TMPT TMPT','tempet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2796,'preparer','','PRPR PRPR','prepar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2797,'secheresses','','SXRS SKRS','secheress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2798,'sec','','SK SK','sec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2799,'chaud','','XT XT','chaud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2800,'resultat','','RSLT RSLT','resultat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2801,'soif','','SF SF','soif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2802,'agriculteurs','','AKRK AKRK','agriculteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2803,'trinquent','','TRNK TRNK','trinquent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2804,'renouveau','','RNF RNF','renouveau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2805,'sacres','','SKRS SKRS','sacr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2806,'marcheurs','','MRXR MRKR','marcheur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2807,'vers','','FRS FRS','ver');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2808,'spirituelles','','SPRT SPRT','spirituel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2809,'recherche','','RXRX RKRK','recherch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2810,'interieur','','ANTR ANTR','interieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2811,'bilbao','','PLP PLP','bilbao');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2812,'bilbotars','','PLPT PLPT','bilbotar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2813,'terres','','TRS TRS','terr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2814,'fertiles','','FRTL FRTL','fertil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2815,'louer','','LR LR','lou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2816,'puissants','','PSNT PSNT','puiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2817,'investisseurs','','ANFS ANFS','investisseur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2818,'trustent','','TRST TRST','trustent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2819,'champs','','XMPS XMPS','champ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2820,'neocolonialisme','','NKLN NKLN','neocolonial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2821,'agricole','','AKRK AKRK','agricol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2822,'iles','','ALS ALS','ile');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2823,'disputees','','TSPT TSPT','dispute');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2824,'perigord','','PRKR PRKR','perigord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2825,'quercy','','KRS KRS','quercy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2826,'religion','fr_FR','RLJN RLKN','religion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2827,'bulletin','','PLTN PLTN','bulletin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2828,'bbf','','PF PF','bbf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2829,'enssib','','ANSP ANSP','enssib');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2830,'1292','','','1292');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2831,'8399','','','8399');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2832,'villeurbanne','','FLRP FLRP','villeurbann');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2833,'publiques','','PPLK PPLK','publiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2834,'souvent','','SFNT SFNT','souvent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2835,'collections','','KLKX KLKX','collect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2836,'privees','','PRFS PRFS','prive');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2837,'frequentation','','FRKN FRKN','frequent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2838,'empeche','','AMPX AMPK','empech');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2839,'accompagne','','AKMP AKMP','accompagn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2840,'constituer','','KNST KNST','constitu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2841,'privee','','PRF PRF','prive');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2842,'reconstitution','','RKNS RKNS','reconstitu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2843,'sorte','','SRT SRT','sort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2844,'gestion','','KSXN JSXN','gestion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2845,'heurte','','HRT HRT','heurt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2846,'memes','','MMS MMS','mem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2847,'problemes','','PRPL PRPL','problem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2848,'institutionnelles','','ANST ANST','institutionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2849,'rangement','','RNJM RNKM','rang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2850,'acquisition','','AKSX AKSX','acquisit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2851,'caractere','','KRKT KRKT','caracter');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2852,'autorise','','ATRS ATRS','autoris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2853,'licences','','LSNS LSNS','licenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2854,'proprietaire','','PRPR PRPR','proprietair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2855,'obligation','','APLK APLK','oblig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2856,'entretien','','ANTR ANTR','entretien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2857,'evidente','','AFTN AFTN','evident');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2858,'desherbage','','TXRP TXRP','desherbag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2859,'desormais','','TSRM TSRM','desorm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2860,'largement','','LRJM LRKM','larg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2861,'catalogage','','KTLK KTLK','catalogag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2862,'fortiori','','FRTR FRTR','fortior');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2863,'bm','','PM PM','bm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2864,'trajectoire','','TRJK TRJK','trajectoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2865,'usager','','ASKR ASJR','usag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2866,'autodidacte','','ATTT ATTT','autodidact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2867,'frequente','','FRKN FRKN','frequent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2868,'assidument','','ASTM ASTM','assidu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2869,'municipale','','MNSP MNSP','municipal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2870,'montreuil','','MNTR MNTR','montreuil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2871,'coproprietaire','','KPRP KPRP','coproprietair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2872,'unique','','ANK ANK','uniqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2873,'commune','','KMN KMN','commun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2874,'patrie','','PTR PTR','patr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2875,'fut','','FT FT','fut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2876,'contact','','KNTK KNTK','contact');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2877,'passage','','PSJ PSK','passag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2878,'difficile','','TFSL TFSL','difficil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2879,'adolescence','','ATLS ATLS','adolescent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2880,'boulot','','PLT PLT','boulot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2881,'ressemble','','RSMP RSMP','ressembl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2882,'gosses','','KSS KSS','goss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2883,'cause','','KS KS','caus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2884,'empruntes','','AMPR AMPR','emprunt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2885,'semaine','','SMN SMN','semain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2886,'quitte','','KT KT','quitt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2887,'rechange','','RXNJ RKNK','rechang');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2888,'akkouche','','AKX AKK','akkouch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2889,'mouloud','','MLT MLT','mouloud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2890,'abeille','','APL APL','abeil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2891,'ethique','','A0K ATK','ethiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2892,'libre','','LPR LPR','libr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2893,'rurale','','RRL RRL','rural');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2894,'aioutz','','ATS ATS','aioutz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2895,'renaud','','RNT RNT','renaud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2896,'poisson','','PSN PSN','poisson');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2897,'poissonrouge','','PSNR PSNR','poissonroug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2898,'com','','KM KM','com');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2899,'jeux','fr_FR','JKS AKS','jeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2900,'jouets','fr_FR','JTS ATS','jouet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2901,'interactica','','ANTR ANTR','interactic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2902,'georges','','JRJS KRKS','georg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2903,'concept','','KNSP KNSP','concept');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2904,'bienvenue','','PNFN PNFN','bienvenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2905,'trimestrielle','','TRMS TRMS','trimestriel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2906,'creee','','KR KR','cree');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2907,'grains','','KRNS KRNS','grain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2908,'sel','','SL SL','sel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2909,'ni','','N N','ni');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2910,'interessent','','ANTR ANTR','interessent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2911,'illustration','','ALST ALST','illustr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2912,'decale','','TKL TKL','decal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2913,'exigeant','','AKSJ AKSK','exig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2914,'stimule','','STML STML','stimul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2915,'curiosite','','KRST KRST','curiosit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2916,'revisite','','RFST RFST','revisit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2917,'traitements','','TRTM TRTM','trait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2918,'traditionnels','','TRTX TRTX','traditionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2919,'magazines','','MKSN MKSN','magazin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2920,'quels','','KLS KLS','quel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2921,'atouts','','ATTS ATTS','atout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2922,'epure','','APR APR','epur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2923,'original','','ARJN ARKN','original');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2924,'papier','','PP PPR','papi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2925,'offset','','AFST AFST','offset');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2926,'recycle','','RSKL RSKL','recycl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2927,'illustrateurs','','ALST ALST','illustr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2928,'sensibles','','SNSP SNSP','sensibl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2929,'degre','','TKR TKR','degr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2930,'seduit','','STT STT','seduit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2931,'parents','','PRNT PRNT','parent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2932,'presente','','PRSN PRSN','present');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2933,'partie','','PRT PRT','part');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2934,'vraies','','FRS FRS','vrai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2935,'courtes','','KRTS KRTS','court');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2936,'longues','','LNKS LNKS','longu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2937,'envers','','ANFR ANFR','enver');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2938,'jeux','','JKS AKS','jeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2939,'calculer','','KLKL KLKL','calcul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2940,'dechiffrer','','TXFR TKFR','dechiffr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2941,'rubriques','','RPRK RPRK','rubriqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2942,'brac','','PRK PRK','brac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2943,'etrangeres','','ATRN ATRN','etranger');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2944,'scenes','','SNS SNS','scen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2945,'experiences','','AKSP AKSP','experient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2946,'scientifiques','','SNTF SNTF','scientif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2947,'farfelue','','FRFL FRFL','farfelu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2948,'8201','','','8201');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2949,'prix','','PRKS PRKS','prix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2950,'mesdames','','MSTM MSTM','mesdam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2951,'messieurs','','MSRS MSRS','messieur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2952,'magazinegeorges','','MKSN MKSN','magazinegeorg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2953,'2110','','','2110');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2954,'8749','','','8749');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2955,'lyon','','LN LN','lyon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2956,'moustache','','MSTX MSTK','moustach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2957,'nuemro','','NMR NMR','nuemro');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2958,'propose','','PRPS PRPS','propos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2959,'geoges','','JJS KKS','geog');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2960,'souhaite','','SHT SHT','souhait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2961,'agreable','','AKRP AKRP','agreabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2962,'numeros','','NMRS NMRS','numeros');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2963,'cupcake','','KPKK KPKK','cupcak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2964,'cine','','SN SN','cin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2965,'live','','LF LF','liv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2966,'fusion','','FSN FXN','fusion');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2967,'issn','','ASN ASN','issn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2968,'0982','','','0982');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2969,'8354','','','8354');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2970,'1253','','','1253');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2971,'4250','','','4250');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2972,'lexpress','','LKSP LKSP','lexpress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2973,'culture','','KLTR KLTR','cultur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2974,'1969','','','1969');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2975,'9441','','','9441');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2976,'boulnois','','PLN PLNS','boulnois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2977,'p000004','','P P','p000004');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2978,'p000005','','P P','p000005');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2979,'per','','PR PR','per');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2980,'revues','','RFS RFS','revu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2981,'dark','','TRK TRK','dark');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2982,'shadows','','XTS XTS','shadow');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2983,'dossier','','TS TSR','dossi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2984,'mortelle','','MRTL MRTL','mortel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2985,'eva','','AF AF','eva');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2986,'green','','KRN KRN','green');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2987,'journal','','JRNL ARNL','journal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2988,'tournage','','TRNJ TRNK','tournag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2989,'frankenweenie','','FRNK FRNK','frankenween');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2990,'plateau','','PLT PLT','plateau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2991,'rss','','RS RS','rss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2992,'feed','','FT FT','feed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2993,'inforeportagesgeo','','ANFR ANFR','inforeportagesgeo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2994,'xml','','SML SML','xml');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2995,'p000002','','P P','p000002');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2996,'p000003','','P P','p000003');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2997,'actualites','','AKTL AKTL','actualit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2998,'br','','PR PR','br');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (2999,'moz','','MS MS','moz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3000,'editor','','ATTR ATTR','editor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3001,'bogus','','PKS PKS','bogus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3002,'node','','NT NT','nod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3003,'true','','TR TR','tru');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3004,'0000','','','0000');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3005,'00','','','00');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3006,'rubrique','','RPRK RPRK','rubriqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3007,'selections','','SLKX SLKX','select');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3008,'infos','','ANFS ANFS','infos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3009,'pratiques','','PRTK PRTK','pratiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3010,'agenda','','AJNT AKNT','agend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3011,'mois','','M MS','mois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3012,'animations','','ANMX ANMX','anim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3013,'coups','','KPS KPS','coup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3014,'horaires','','HRRS HRRS','horair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3015,'reglement','','RKLM RKLM','regl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3016,'cultures','','KLTR KLTR','cultur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3017,'contemporaine','','KNTM KNTM','contemporain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3018,'vos','','FS FS','vos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3019,'cliches','','KLXS KLKS','clich');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3020,'venez','','FNS FNS','ven');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3021,'auourd','','ART ART','auourd');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3022,'contenu','','KNTN KNTN','contenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3023,'article','','ARTK ARTK','articl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3024,'articlecontenu','','ARTK ARTK','articlecontenu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3025,'lisez','','LSS LSS','lis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3026,'assiette','','AST AST','assiet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3027,'blockquote','','PLKK PLKK','blockquot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3028,'courgette','','KRKT KRKT','courget');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3029,'ennuyant','','ANNT ANNT','ennui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3030,'amusant','','AMSN AMSN','amus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3031,'potagere','','PTKR PTJR','potager');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3032,'ateliers','','ATLR ATLR','ateli');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3033,'creation','','KRXN KRXN','creation');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3034,'legues','','LKS LKS','legu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3035,'11','','','11');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3036,'nouvautes','','NFTS NFTS','nouvaut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3037,'afficher','','AFXR AFKR','affich');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3038,'fantasy','','FNTS FNTS','fantasy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3039,'sf','','SF SF','sf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3040,'classiques','','KLSK KLSK','classiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3041,'passent','','PSNT PSNT','passent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3042,'jouer','','JR AR','jou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3043,'star','','STR STR','star');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3044,'wars','','ARS FRS','war');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3045,'douchettes','','TXTS TKTS','douchet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3046,'laser','','LSR LSR','las');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3047,'articlev','','ARTK ARTK','articlev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3048,'lt','','LT LT','lt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3049,'iframe','','AFRM AFRM','ifram');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3050,'width','','AT FT','width');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3051,'quot','','KT KT','quot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3052,'425','','','425');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3053,'height','','HT HT','height');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3054,'frameborder','','FRMP FRMP','framebord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3055,'scrolling','','SKLN SKLN','scrolling');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3056,'no','','N N','no');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3057,'marginheight','','MRJN MRKN','marginheight');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3058,'marginwidth','','MRJN MRKN','marginwidth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3059,'src','','SRK SRK','src');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3060,'maps','','MPS MPS','map');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3061,'google','','KKL KKL','googl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3062,'q','','K K','q');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3063,'amp','','AMP AMP','amp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3064,'hl','','L L','hl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3065,'geocode','','JKT KKT','geocod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3066,'ch','','K K','ch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3067,'c3','','K K','c3');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3068,'a2teau','','AT AT','a2teau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3069,'aq','','AK AK','aq');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3070,'oq','','AK AK','oq');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3071,'sll','','SL XL','sll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3072,'22475','','','22475');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3073,'0517','','','0517');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3074,'sspn','','SPN SPN','sspn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3075,'816925','','','816925');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3076,'67','','','67');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3077,'631836','','','631836');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3078,'ie','','A A','ie');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3079,'utf8','','ATF ATF','utf8');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3080,'hq','','K K','hq');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3081,'hnear','','NR NR','hnear');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3082,'radius','','RTS RTS','radius');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3083,'15000','','','15000');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3084,'ll','','L L','ll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3085,'684112','','','684112');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3086,'428123','','','428123');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3087,'spn','','SPN SPN','spn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3088,'080896','','','080896');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3089,'145912','','','145912');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3090,'z','','S S','z');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3091,'output','','ATPT ATPT','output');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3092,'embed','','AMPT AMPT','embed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3093,'gt','','KT KT','gt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3094,'small','','SML XML','small');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3095,'href','','RF RF','href');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3096,'color','','KLR KLR','color');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3097,'0000ff','','F F','0000ff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3098,'text','','TKST TKST','text');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3099,'align','','ALN ALKN','align');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3100,'left','','LFT LFT','left');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3101,'agrandir','','AKRN AKRN','agrand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3102,'ouverte','','AFRT AFRT','ouvert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3103,'tableau','','TPL TPL','tableau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3104,'inscription','','ANSK ANSK','inscript');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3105,'inscrire','','ANSK ANSK','inscrir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3106,'projections','','PRJK PRJK','project');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3107,'midi','','MT MT','mid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3108,'soir','','SR SR','soir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3109,'meilleur','','MLR MLR','meilleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3110,'site','','ST ST','sit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3111,'ligne','','LN LKN','lign');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3112,'decouvrez','','TKFR TKFR','decouvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3113,'rayon','','RN RN','rayon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3114,'ul','','AL AL','ul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3115,'li','','L L','li');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3116,'bandes','','PNTS PNTS','band');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3117,'dessinees','','TSNS TSNS','dessine');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3118,'plat','','PLT PLT','plat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3119,'elephants','','ALFN ALFN','eleph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3120,'dos','','TS TS','dos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3121,'tortue','','TRT TRT','tortu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3122,'naviguant','','NFKN NFKN','navigu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3123,'cosmos','','KSMS KSMS','cosmos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3124,'quoiqu','','KK KK','quoiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3125,'disent','','TSNT TSNT','disent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3126,'certaines','','SRTN SRTN','certain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3127,'sectes','','SKTS SKTS','sect');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3128,'verite','','FRT FRT','verit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3129,'cas','','KS KS','cas');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3130,'vrai','','FR FR','vrai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3131,'delirant','','TLRN TLRN','delir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3132,'regles','','RKLS RKLS','regl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3133,'faites','','FTS FTS','fait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3134,'transgressees','','TRNS TRNS','transgresse');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3135,'atypiques','','ATPK ATPK','atyp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3136,'rincevent','','RNSF RNSF','rincevent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3137,'magicien','','MJSN MKXN','magicien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3138,'malchanceux','','MLXN MLKN','malchanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3139,'froussard','','FRSR FRSR','froussard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3140,'rate','','RT RT','rat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3141,'lancer','','LNSR LNSR','lanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3142,'pourrait','','PRT PRT','pourr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3143,'detruire','','TTRR TTRR','detruir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3144,'ciredutemps','','SRTT SRTT','ciredutemp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3145,'sorciere','','SRSR SRXR','sorcier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3146,'certain','','SRTN SRTN','certain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3147,'diriger','','TRJR TRKR','dirig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3148,'ceux','','SKS SKS','ceux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3149,'entourent','','ANTR ANTR','entourent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3150,'rarement','','RRMN RRMN','rar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3151,'obeit','','APT APT','obeit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3152,'faucheuse','','FXS FKS','faucheux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3153,'suaire','','SR SR','suair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3154,'faux','','F F','faux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3155,'aiguisee','','AKS AKS','aiguise');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3156,'humaniste','','HMNS HMNS','human');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3157,'incomprise','','ANKM ANKM','incompris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3158,'chacun','','XKN XKN','chacun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3159,'arrive','','ARF ARF','arriv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3160,'rencontrent','','RNKN RNKN','rencontrent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3161,'possible','','PSPL PSPL','possibl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3162,'totalement','','TTLM TTLM','total');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3163,'menu','','MN MN','menu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3164,'breves','','PRFS PRFS','brev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3165,'fermeture','','FRMT FRMT','fermetur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3166,'noel','','NL NL','noel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3167,'emprunter','','AMPR AMPR','emprunt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3168,'prets','','PRTS PRTS','pret');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3169,'maximum','','MKSM MKSM','maximum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3170,'duree','','TR TR','dure');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3171,'semaines','','SMNS SMNS','semain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3172,'exemple','','AKSM AKSM','exempl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3173,'breve','','PRF PRF','brev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3174,'ceci','','SS SS','cec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3175,'flash','','FLX FLX','flash');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3176,'info','','ANF ANF','info');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3177,'reference','','RFRN RFRN','referent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3178,'yaelle','','AL AL','yael');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3179,'une','','AN AN','une');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3180,'precise','','PRSS PRSS','precis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3181,'resume','','RSM RSM','resum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3182,'periode','','PRT PRT','period');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3183,'periodiques','','PRTK PRTK','period');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3184,'principal','','PRNS PRNS','principal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3185,'archives','','ARXF ARKF','archiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3186,'decembre','','TSMP TSMP','decembr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3187,'000058','','','000058');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3188,'zai','','S S','zai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3189,'000057','','','000057');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3190,'dep','','TP TP','dep');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3191,'000056','','','000056');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3192,'gro','','KR KR','gro');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3193,'000054','','','000054');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3194,'ded','','TT TT','ded');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3195,'000052','','','000052');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3196,'000053','','','000053');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3197,'deb','','TP TP','deb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3198,'000051','','','000051');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3199,'abo','','AP AP','abo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3200,'000050','','','000050');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3201,'000049','','','000049');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3202,'mab','','MP MP','mab');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3203,'000048','','','000048');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3204,'mar','','MR MR','mar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3205,'000047','','','000047');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3206,'gra','','KR KR','gra');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3207,'000046','','','000046');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3208,'rj','','RJ R','rj');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3209,'gud','','KT KT','gud');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3210,'000045','','','000045');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3211,'rjp','','RJP RJP','rjp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3212,'hei','','H H','hei');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3213,'000044','','','000044');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3214,'mel','','ML ML','mel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3215,'000041','','','000041');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3216,'000042','','','000042');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3217,'ass','','AS AS','ass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3218,'000039','','','000039');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3219,'000038','','','000038');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3220,'rp','','RP RP','rp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3221,'bei','','P P','bei');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3222,'000037','','','000037');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3223,'mah','','M M','mah');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3224,'000036','','','000036');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3225,'000034','','','000034');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3226,'bel','','PL PL','bel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3227,'000033','','','000033');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3228,'nan','','NN NN','nan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3229,'000030','','','000030');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3230,'gou','','K K','gou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3231,'000029','','','000029');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3232,'gue','','K K','gu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3233,'000028','','','000028');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3234,'000027','','','000027');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3235,'000026','','','000026');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3236,'gui','','K K','gui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3237,'000032','','','000032');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3238,'000031','','','000031');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3239,'000025','','','000025');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3240,'cor','','KR KR','cor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3241,'000024','','','000024');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3242,'lou','','L L','lou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3243,'000023','','','000023');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3244,'ser','','SR SR','ser');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3245,'000022','','','000022');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3246,'tey','','T T','tey');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3247,'000021','','','000021');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3248,'000019','','','000019');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3249,'bra','','PR PR','bra');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3250,'000018','','','000018');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3251,'000017','','','000017');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3252,'000016','','','000016');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3253,'pra','','PR PR','pra');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3254,'000015','','','000015');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3255,'000014','','','000014');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3256,'bur','','PR PR','bur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3257,'000013','','','000013');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3258,'000012','','','000012');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3259,'p000006','','P P','p000006');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3260,'stu','','ST ST','stu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3261,'fusce','','FS FS','fusc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3262,'egestas','','AJST AKST','egest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3263,'vestibulum','','FSTP FSTP','vestibulum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3264,'neque','','NK NK','nequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3265,'faucibus','','FSPS FSPS','faucibus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3266,'integer','','ANTJ ANTK','integ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3267,'commodo','','KMT KMT','commodo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3268,'pretium','','PRTM PRTM','pretium');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3269,'porttitor','','PRTT PRTT','porttitor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3270,'phasellus','','FSLS FSLS','phasellus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3271,'varius','','FRS FRS','varius');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3272,'dui','','T T','dui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3273,'at','','AT AT','at');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3274,'dignissim','','TNSM TKNS','dignissim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3275,'fermentum','','FRMN FRMN','fermentum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3276,'magna','','MN MKN','magn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3277,'luctus','','LKTS LKTS','luctus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3278,'nulla','','NL NL','null');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3279,'facilisi','','FSLS FSLS','facilis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3280,'cras','','KRS KRS','cras');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3281,'erat','','ART ART','erat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3282,'ullamcorper','','ALMK ALMK','ullamcorp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3283,'tincidunt','','TNST TNST','tincidunt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3284,'eget','','AKT AKT','eget');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3285,'nec','','NK NK','nec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3286,'nisl','','NL NL','nisl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3287,'nam','','NM NM','nam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3288,'ut','','AT AT','ut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3289,'nunc','','NNK NNK','nunc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3290,'etiam','','AXM AXM','etiam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3291,'enim','','ANM ANM','enim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3292,'sapien','','SPN SPN','sapien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3293,'accumsan','','AKMS AKMS','accumsan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3294,'donec','','TNK TNK','donec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3295,'semper','','SMPR SMPR','semp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3296,'tellus','','TLS TLS','tellus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3297,'ultricies','','ALTR ALTR','ultric');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3298,'lorem','','LRM LRM','lorem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3299,'ac','','AK AK','ac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3300,'felis','','FLS FLS','fel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3301,'odio','','AT AT','odio');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3302,'eu','','A A','eu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3303,'urna','','ARN ARN','urna');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3304,'sed','','ST ST','sed');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3305,'quis','','KS KS','quis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3306,'praesent','','PRSN PRSN','praesent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3307,'viverra','','FFR FFR','viverr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3308,'facilisis','','FSLS FSLS','facilis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3309,'elit','','ALT ALT','elit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3310,'volutpat','','FLTP FLTP','volutpat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3311,'arcu','','ARK ARK','arcu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3312,'venenatis','','FNNT FNNT','venenat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3313,'malesuada','','MLST MLST','malesuad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3314,'justo','','JST AST','justo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3315,'velit','','FLT FLT','vel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3316,'ante','','ANT ANT','ante');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3317,'ipsum','','APSM APSM','ipsum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3318,'primis','','PRMS PRMS','prim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3319,'orci','','ARS ARS','orci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3320,'ultrices','','ALTR ALTR','ultric');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3321,'posuere','','PSR PSR','posuer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3322,'cubilia','','KPL KPL','cubili');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3323,'curae','','KR KR','cura');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3324,'congue','','KNK KNK','congu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3325,'dolor','','TLR TLR','dolor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3326,'gravida','','KRFT KRFT','gravid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3327,'diam','','TM TM','diam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3328,'cursus','','KRSS KRSS','cursus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3329,'nisi','','NS NS','nis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3330,'dictum','','TKTM TKTM','dictum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3331,'mauris','','MRS MRS','maur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3332,'leo','','L L','leo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3333,'pellentesque','','PLNT PLNT','pellentesqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3334,'massa','','MS MS','mass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3335,'laoreet','','LRT LRT','laoreet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3336,'sem','','SM SM','sem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3337,'vulputate','','FLPT FLPT','vulputat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3338,'vel','','FL FL','vel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3339,'suspendisse','','SSPN SSPN','suspend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3340,'blandit','','PLNT PLNT','bland');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3341,'mollis','','MLS MLS','moll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3342,'vitae','','FT FT','vita');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3343,'sit','','ST ST','sit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3344,'amet','','AMT AMT','amet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3345,'consectetur','','KNSK KNSK','consectetur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3346,'adipiscing','','ATPS ATPS','adipiscing');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3347,'mattis','','MTS MTS','matt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3348,'eleifend','','ALFN ALFN','eleifend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3349,'tristique','','TRST TRST','tristiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3350,'don','','TN TN','don');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3351,'quichotte','','KXT KKT','quichott');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3352,'100','','','100');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3353,'vignettes','','FNTS FKNT','vignet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3354,'gravees','','KRFS KRFS','grave');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3355,'cervantes','','SRFN SRFN','cerv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3356,'saavedra','','SFTR SFTR','saavedr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3357,'miguel','','MKL MKL','miguel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3358,'1547','','','1547');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3359,'1616','','','1616');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3360,'florian','','FLRN FLRN','florian');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3361,'staal','','STL STL','staal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3362,'pierre','','PR PR','pierr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3363,'claris','','KLRS KLRS','clar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3364,'gustave','','KSTF KSTF','gustav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3365,'jules','','JLS ALS','jul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3366,'1755','','','1755');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3367,'1794','','','1794');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3368,'1817','','','1817');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3369,'1882','','','1882');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3370,'1808','','','1808');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3371,'1892','','','1892');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3372,'1857','','','1857');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3373,'248','','','248');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3374,'malassis','','MLSS MLSS','malass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3375,'broise','','PRS PRS','brois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3376,'baudelaire','','PTLR PTLR','baudelair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3377,'charles','','XRLS XRLS','charl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3378,'1821','','','1821');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3379,'mysterieuse','','MSTR MSTR','mysteri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3380,'1875','','','1875');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3381,'parties','','PRTS PRTS','part');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3382,'616','','','616');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3383,'fig','','FK FK','fig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3384,'hetzel','','HTSL HTSL','hetzel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3385,'verne','','FRN FRN','vern');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3386,'1828','','','1828');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3387,'1905','','','1905');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3388,'ferat','','FRT FRT','ferat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3389,'barbant','','PRPN PRPN','barb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3390,'1819','','','1819');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3391,'1922','','','1922');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3392,'initier','','ANT ANTR','initi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3393,'programmation','','PRKR PRKR','programm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3394,'php','','FP FP','php');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3395,'xxi','','SKS SKS','xxi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3396,'346','','','346');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3397,'212','','','212');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3398,'11990','','','11990');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3399,'eyrolles','','ARLS ARLS','eyroll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3400,'communication','','KMNK KMNK','commun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3401,'programmation','fr_FR','PRKR PRKR','programm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3402,'delannoy','','TLN TLN','delannoy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3403,'1946','','','1946');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3404,'mariant','','MRNT MRNT','mari');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3405,'evolution','','AFLX AFLX','evolu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3406,'territoires','','TRTR TRTR','territoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3407,'ruraux','','RR RR','rural');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3408,'incitation','','ANST ANST','incit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3409,'commun','','KMN KMN','commun');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3410,'theorie','','0R TR','theor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3411,'professionnelle','','PRFS PRFS','professionnel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3412,'partagee','','PRTJ PRTK','partage');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3413,'connaissance','','KNSN KNSN','connaiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3414,'risom','','RSM RSM','risom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3415,'reseau','','RS RS','reseau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3416,'intercommunal','','ANTR ANTR','intercommunal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3417,'solidaire','','SLTR SLTR','solidair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3418,'mediatheques','','MT0K MTTK','mediathequ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3419,'tence','','TNS TNS','tenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3420,'jeures','','JRS ARS','jeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3421,'mazet','','MST MST','mazet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3422,'voy','','F F','voy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3423,'partage','','PRTJ PRTK','partag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3424,'projets','','PRJT PRJT','projet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3425,'animation','','ANMX ANMX','anim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3426,'outils','','ATLS ATLS','outil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3427,'usages','','ASJS ASKS','usag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3428,'appui','','AP AP','appui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3429,'choses','','XSS XSS','chos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3430,'soient','','SNT SNT','soient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3431,'claires','','KLRS KLRS','clair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3432,'angoualima','','ANKL ANKL','angoualim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3433,'greffer','','KRFR KRFR','greff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3434,'doigts','','TKTS TKTS','doigt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3435,'veux','','FKS FKS','veux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3436,'apprecie','','APRS APRX','apprec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3437,'fonction','','FNKX FNKX','fonction');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3438,'geste','','KST JST','gest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3439,'pouvant','','PFNT PFNT','pouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3440,'egaler','','AKLR AKLR','egal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3441,'prouesses','','PRSS PRSS','prouess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3442,'aimerais','','AMR AMRS','aim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3443,'considere','','KNST KNST','consider');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3444,'spirituel','','SPRT SPRT','spirituel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3445,'suis','','SS SS','suis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3446,'conscient','','KNSN KNSN','conscient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3447,'dois','','T TS','dois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3448,'travailler','','TRFL TRFL','travaill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3449,'germaine','','KRMN JRMN','germain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3450,'dire','','TR TR','dir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3451,'couronnement','','KRNM KRNM','couron');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3452,'gregoire','','KRKR KRKR','gregoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3453,'nakobomayo','','NKPM NKPM','nakobomayo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3454,'orphelin','','ARFL ARFL','orphelin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3455,'grandi','','KRNT KRNT','grand');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3456,'industrielle','','ANTS ANTS','industriel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3457,'post','','PST PST','post');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3458,'coloniale','','KLNL KLNL','colonial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3459,'accueilli','','AKL AKL','accueil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3460,'couple','','KPL KPL','coupl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3461,'instruit','','ANST ANST','instruit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3462,'education','','ATKX ATKX','educ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3463,'bourgeoise','','PRJS PRKS','bourgeois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3464,'plante','','PLNT PLNT','plant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3465,'crayon','','KRN KRN','crayon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3466,'violer','','FLR FLR','viol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3467,'refugie','','RFJ RFK','refug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3468,'quartier','','KRT KRTR','quarti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3469,'delabre','','TLPR TLPR','delabr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3470,'modele','','MTL MTL','model');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3471,'serial','','SRL SRL','serial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3472,'killer','','KLR KLR','kill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3473,'defie','','TF TF','def');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3474,'juges','','JJS AKS','jug');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3475,'flics','','FLKS FLKS','flic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3476,'journalistes','','JRNL ARNL','journal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3477,'deboires','','TPRS TPRS','deboir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3478,'psychopathe','','SXP0 SKPT','psychopath');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3479,'velleitaire','','FLTR FLTR','velleitair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3480,'perversite','','PRFR PRFR','perversit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3481,'sens','','SNS SNS','sen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3482,'caneton','','KNTN KNTN','caneton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3483,'mouton','','MTN MTN','mouton');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3484,'pingouin','','PNKN PNKN','pingouin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3485,'chien','','XN XN','chien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3486,'allez','','ALS ALS','allez');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3487,'delicieux','','TLSK TLXK','delici');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3488,'quatrieme','','KTRM KTRM','quatriem');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3489,'synopsis','','SNPS SNPS','synops');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3490,'barbara','','PRPR PRPR','barbar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3491,'adam','','ATM ATM','adam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3492,'forment','','FRMN FRMN','forment');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3493,'adorable','','ATRP ATRP','ador');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3494,'helas','','HLS HLS','hel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3495,'survient','','SRFN SRFN','survient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3496,'stupide','','STPT STPT','stupid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3497,'accident','','AKST AKST','accident');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3498,'devenus','','TFNS TFNS','devenus');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3499,'obliges','','APLJ APLK','oblig');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3500,'hanter','','HNTR HNTR','hant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3501,'murs','','MRS MRS','mur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3502,'deception','','TSPX TSPX','decept');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3503,'voient','','FNT FNT','voient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3504,'livree','','LFR LFR','livre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3505,'excentrique','','AKSN AKSN','excentr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3506,'membres','','MMPR MMPR','membr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3507,'evoluent','','AFLN AFLN','evoluent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3508,'hysterie','','HSTR HSTR','hyster');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3509,'stupidite','','STPT STPT','stupidit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3510,'tentent','','TNTN TNTN','tentent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3511,'chasser','','XSR XSR','chass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3512,'vain','','FN FN','vain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3513,'solution','','SLXN SLXN','solut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3514,'appel','','APL APL','appel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3515,'fantome','','FNTM FNTM','fantom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3516,'exorciseur','','AKSR AKSR','exorciseur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3517,'apprenant','','APRN APRN','appren');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3518,'will','','AL FL','will');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3519,'rapprocher','','RPRX RPRK','rapproch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3520,'berce','','PRS PRS','berc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3521,'fantastiques','','FNTS FNTS','fantast');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3522,'lesquels','','LSKL LSKL','lesquel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3523,'mettait','','MTT MTT','met');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3524,'cotes','','KTS KTS','cot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3525,'extravagants','','AKST AKST','extravag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3526,'extraordinaires','','AKST AKST','extraordinair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3527,'quelles','','KLS KLS','quel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3528,'merveilles','','MRFL MRFL','merveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3529,'attendent','','ATNT ATNT','attendent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3530,'usine','','ASN ASN','usin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3531,'willy','','AL FL','willy');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3532,'wonka','','ANK FNK','wonk');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3533,'pars','','PRS PRS','par');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3534,'vastes','','FSTS FSTS','vast');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3535,'etendues','','ATNT ATNT','etendu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3536,'sucree','','SKR SKR','sucre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3537,'menthe','','MN0 MNT','menth');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3538,'salle','','SL S','sall');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3539,'chocolat','','XKLT XKLT','chocolat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3540,'navigue','','NFK NFK','navigu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3541,'riviere','','RFR RFR','rivier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3542,'bateau','','PT PT','bateau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3543,'sucre','','SKR SKR','sucr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3544,'rose','','RS RS','ros');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3545,'essaye','','AS AS','essay');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3546,'gobestoppeur','','KPST KPST','gobestoppeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3547,'inventions','','ANFN ANFN','invent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3548,'observe','','APSR APSR','observ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3549,'talentueux','','TLNT TLNT','talentu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3550,'ecureuils','','AKRL AKRL','ecureuil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3551,'tri','','TR TR','tri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3552,'noix','','NKS NKS','noix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3553,'ascenseur','','ASNS ASNS','ascenseur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3554,'verre','','FR FR','verr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3555,'television','','TLFS TLFX','televis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3556,'tu','','T T','tu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3557,'trouveras','','TRFR TRFR','trouv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3558,'montagne','','MNTN MNTK','montagn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3559,'saupoudree','','SPTR SPTR','saupoudre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3560,'savoureuse','','SFRS SFRS','savour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3561,'tablette','','TPLT TPLT','tablet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3562,'delice','','TLS TLS','delic');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3563,'fondant','','FNTN FNTN','fond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3564,'guimauve','','KMF KMF','guimauv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3565,'caramel','','KRML KRML','caramel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3566,'plongee','','PLNJ PLNK','plonge');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3567,'humanite','','HMNT HMNT','humanit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3568,'phare','','FR FR','phar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3569,'iiie','','A A','iii');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3570,'millenaire','','MLNR MLNR','millenair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3571,'visions','','FSNS FXNS','vision');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3572,'dechiree','','TXR TKR','dechire');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3573,'eclairages','','AKLR AKLR','eclairag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3574,'desertification','','TSRT TSRT','desertif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3575,'deforestation','','TFRS TFRS','deforest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3576,'exode','','AKST AKST','exod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3577,'rural','','RRL RRL','rural');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3578,'explosion','','AKSP AKSP','explos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3579,'demographique','','TMKR TMKR','demograph');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3580,'profondeur','','PRFN PRFN','profondeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3581,'donnee','','TN TN','donne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3582,'decisive','','TSSF TSSF','decis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3583,'adaptes','','ATPT ATPT','adapt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3584,'remplie','','RMPL RMPL','rempl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3585,'episodes','','APST APST','episod');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3586,'epiques','','APKS APKS','epiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3587,'insoupconnee','','ANSP ANSP','insoupconne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3588,'assombrie','','ASMP ASMP','assombr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3589,'parla','','PRL PRL','parl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3590,'esclavage','','ASKF ASKF','esclavag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3591,'lecon','','LKN LKN','lecon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3592,'solidarite','','SLTR SLTR','solidarit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3593,'inepuisables','','ANPS ANPS','inepuis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3594,'logo','','LK LK','logo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3595,'nigeria','','NJR NKR','nigeri');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3596,'gabon','','KPN KPN','gabon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3597,'offre','','AFR AFR','offre');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3598,'palais','','PL PLS','pal');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3599,'amateurs','','AMTR AMTR','amateur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3600,'chere','','XR XR','cher');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3601,'plats','','PLTS PLTS','plat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3602,'savoureux','','SFRK SFRK','savour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3603,'delicats','','TLKT TLKT','delicat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3604,'contrairement','','KNTR KNTR','contrair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3605,'idees','','ATS ATS','ide');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3606,'recues','','RKS RKS','recu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3607,'peuvent','','PFNT PFNT','peuvent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3608,'simples','','SMPL SMPL','simpl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3609,'dispose','','TSPS TSPS','dispos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3610,'connaissances','','KNSN KNSN','connaiss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3611,'savoir','','SFR SFR','savoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3612,'indispensables','','ANTS ANTS','indispens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3613,'large','','LRJ LRK','larg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3614,'compose','','KMPS KMPS','compos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3615,'tiep','','TP TP','tiep');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3616,'mafe','','MF MF','maf');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3617,'saka','','SK SK','sak');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3618,'mbongo','','MPNK MPNK','mbongo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3619,'accompagnent','','AKMP AKMP','accompagnent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3620,'ingredients','','ANKR ANKR','ingredient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3621,'specifiques','','SPSF SPSF','specif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3622,'preparation','','PRPR PRPR','prepar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3623,'arachide','','ARXT ARKT','arachid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3624,'manioc','','MNK MNK','manioc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3625,'graines','','KRNS KRNS','grain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3626,'courge','','KRJ KRK','courg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3627,'legendes','','LJNT LKNT','legend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3628,'trucs','','TRKS TRKS','truc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3629,'astuces','','ASTS ASTS','astuc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3630,'photos','','FTS FTS','photos');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3631,'portee','','PRT PRT','porte');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3632,'fous','','FS FS','fous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3633,'gouter','','KTR KTR','gout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3634,'apprecier','','APRS APRX','appreci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3635,'saveurs','','SFRS SFRS','saveur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3636,'bouche','','PX PK','bouch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3637,'joigne','','JN AKN','joign');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3638,'esprit','','ASPR ASPR','esprit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3639,'agrementer','','AKRM AKRM','agrement');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3640,'extraordinaire','','AKST AKST','extraordinair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3641,'differemment','','TFRM TFRM','different');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3642,'entier','','ANT ANTR','enti');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3643,'celebrent','','SLPR SLPR','celebrent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3644,'peintures','','PNTR PNTR','peintur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3645,'chair','','XR XR','chair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3646,'saveur','','SFR SFR','saveur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3647,'genial','','JNL KNL','genial');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3648,'vrais','','FR FRS','vrais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3649,'lames','','LMS LMS','lam');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3650,'tranchantes','','TRNX TRNK','tranch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3651,'veritables','','FRTP FRTP','verit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3652,'provoquer','','PRFK PRFK','provoqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3653,'enthousiasme','','AN0S ANTX','enthousiasm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3654,'capable','','KPPL KPPL','capabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3655,'blesser','','PLSR PLSR','bless');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3656,'controle','','KNTR KNTR','control');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3657,'oh','','A A','oh');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3658,'etaient','','ATNT ATNT','etaient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3659,'beaux','','P P','beau');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3660,'encyclopedie','','ANSK ANSK','encycloped');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3661,'devoreraient','','TFRR TFRR','devor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3662,'ca','','K K','ca');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3663,'poussiere','','PSR PSR','poussier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3664,'pense','','PNS PNS','pens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3665,'fulbert','','FLPR FLPR','fulbert');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3666,'assoiffee','','ASF ASF','assoiffe');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3667,'ebloui','','APL APL','eblou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3668,'desempare','','TSMP TSMP','desempar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3669,'falloir','','FLR FLR','falloir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3670,'germer','','KRMR JRMR','germ');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3671,'outil','','ATL ATL','outil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3672,'jardinier','','JRTN ARTN','jardini');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3673,'pousse','','PS PS','pouss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3674,'bout','','PT PT','bout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3675,'lapin','','LPN LPN','lapin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3676,'emprunte','','AMPR AMPR','emprunt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3677,'incroyable','','ANKR ANKR','incroi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3678,'certains','','SRTN SRTN','certain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3679,'parfois','','PRF PRFS','parfois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3680,'xixe','','SKS SKS','xix');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3681,'village','','FLJ FLK','villag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3682,'victor','','FKTR FKTR','victor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3683,'morts','','MRTS MRTS','mort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3684,'epouse','','APS APS','epous');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3685,'cadavre','','KTFR KTFR','cadavr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3686,'mariee','','MR MR','marie');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3687,'promise','','PRMS PRMS','promis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3688,'victoria','','FKTR FKTR','victori');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3689,'attend','','ATNT ATNT','attend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3690,'desesperement','','TSSP TSSP','desesper');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3691,'royaume','','RM RM','royaum');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3692,'avere','','AFR AFR','aver');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3693,'animee','','ANM ANM','anime');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3694,'joyeuse','','JS AS','joyeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3695,'veritable','','FRTP FRTP','verit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3696,'apprend','','APRN APRN','apprend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3697,'pourra','','PR PR','pourr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3698,'ours','','ARS ARS','our');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3699,'aurait','','ART ART','aur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3700,'imagine','','AMJN AMKN','imagin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3701,'mots','','MTS MTS','mot');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3702,'puissent','','PSNT PSNT','puissent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3703,'conjugues','','KNJK KNJK','conjugu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3704,'facons','','FKNS FKNS','facon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3705,'fais','','F FS','fais');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3706,'lorsque','','LRSK LRSK','lorsqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3707,'es','','AS AS','e');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3708,'fatigue','','FTK FTK','fatigu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3709,'fache','','FX FK','fach');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3710,'gronder','','KRNT KRNT','grond');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3711,'moues','','MS MS','mou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3712,'expressions','','AKSP AKSP','express');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3713,'enfantines','','ANFN ANFN','enfantin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3714,'droles','','TRLS TRLS','drol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3715,'tendres','','TNTR TNTR','tendr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3716,'hilarants','','HLRN HLRN','hilar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3717,'devoile','','TFL TFL','devoil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3718,'fil','','FL FL','fil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3719,'magnifiques','','MNFK MKNF','magnif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3720,'accompagnees','','AKMP AKMP','accompagne');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3721,'emplis','','AMPL AMPL','emplis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3722,'invite','','ANFT ANFT','invit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3723,'mediation','','MTXN MTXN','mediat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3724,'emerveillement','','AMRF AMRF','emerveil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3725,'nombreux','','NMPR NMPR','nombreux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3726,'ecrivains','','AKRF AKRF','ecrivain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3727,'engages','','ANKJ ANKK','engag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3728,'espace','','ASPS ASPS','espac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3729,'fascinant','','FSNN FSNN','fascin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3730,'marin','','MRN MRN','marin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3731,'necessairement','','NSSR NSSR','necessair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3732,'nageur','','NJR NKR','nageur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3733,'naviguer','','NFKR NFKR','navigu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3734,'grise','','KRS KRS','gris');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3735,'modeste','','MTST MTST','modest');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3736,'indispensable','','ANTS ANTS','indispens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3737,'decante','','TKNT TKNT','dec');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3738,'regardez','','RKRT RKRT','regard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3739,'furieux','','FRKS FRKS','furieux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3740,'calme','','KLM KLM','calm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3741,'ouvrir','','AFRR AFRR','ouvr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3742,'transperce','','TRNS TRNS','transperc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3743,'couvertures','','KFRT KFRT','couvertur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3744,'visite','','FST FST','visit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3745,'editeurs','','ATTR ATTR','editeur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3746,'directement','','TRKT TRKT','direct');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3747,'colophon','','KLFN KLFN','colophon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3748,'releve','','RLF RLF','relev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3749,'attarde','','ATRT ATRT','attard');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3750,'table','','TPL TPL','tabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3751,'matieres','','MTRS MTRS','matier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3752,'verifie','','FRF FRF','verif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3753,'evalue','','AFL AFL','evalu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3754,'robustesse','','RPST RPST','robustess');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3755,'impression','','AMPR AMPR','impress');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3756,'dit','','TT TT','dit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3757,'savaient','','SFNT SFNT','sav');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3758,'feraient','','FRNT FRNT','fer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3759,'uniquement','','ANKM ANKM','uniqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3760,'eut','','AT AT','eut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3761,'anarchiste','','ANRX ANRK','anarch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3762,'veine','','FN FN','vein');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3763,'chant','','XNT XNT','chant');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3764,'joyce','','JS AS','joyc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3765,'structure','','STRK STRK','structur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3766,'vole','','FL FL','vol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3767,'eclat','','AKLT AKLT','eclat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3768,'importe','','AMPR AMPR','import');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3769,'nom','','NM NM','nom');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3770,'pieds','','PTS PTS','pied');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3771,'origines','','ARJN ARKN','origin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3772,'tiraille','','TRL TRL','tiraill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3773,'faim','','FM FM','faim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3774,'blanche','','PLNX PLNK','blanch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3775,'goodfather','','KTF0 KTFT','goodfath');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3776,'train','','TRN TRN','train');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3777,'baigner','','PNR PKNR','baign');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3778,'nue','','N N','nu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3779,'chutes','','XTS XTS','chut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3780,'rocher','','RXR RKR','roch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3781,'aveugle','','AFKL AFKL','aveugl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3782,'lucide','','LST LST','lucid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3783,'piege','','PJ PK','pieg');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3784,'violence','','FLNS FLNS','violenc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3785,'absurdite','','APSR APSR','absurdit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3786,'apartheid','','APR0 APRT','apartheid');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3787,'emeute','','AMT AMT','emeut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3788,'langage','','LNKJ LNKK','langag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3789,'pensee','','PNS PNS','pense');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3790,'1980','','','1980');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3791,'eclate','','AKLT AKLT','eclat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3792,'balaie','','PL PL','balai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3793,'revers','','RFRS RFRS','rever');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3794,'main','','MN MN','main');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3795,'reel','','RL RL','reel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3796,'irreel','','ARL ARL','irreel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3797,'temoignage','','TMNJ TMKN','temoignag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3798,'propulsant','','PRPL PRPL','propuls');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3799,'litteralement','','LTRL LTRL','litteral');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3800,'dereglement','','TRKL TRKL','deregl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3801,'apprehender','','APRH APRH','apprehend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3802,'revolte','','RFLT RFLT','revolt');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3803,'mythique','','M0K MTK','mythiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3804,'frequents','','FRKN FRKN','frequent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3805,'sejours','','SJRS SHRS','sejour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3806,'prison','','PRSN PRSN','prison');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3807,'garcon','','KRKN KRKN','garcon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3808,'aimait','','AMT AMT','aim');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3809,'inventer','','ANFN ANFN','invent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3810,'deguise','','TKS TKS','deguis');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3811,'chauve','','XF XF','chauv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3812,'souris','','SRS SRS','sour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3813,'ferait','','FRT FRT','fer');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3814,'mechants','','MXNT MKNT','mech');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3815,'miroir','','MRR MRR','miroir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3816,'chat','','XT XT','chat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3817,'joue','','J A','jou');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3818,'citrouille','','STRL STRL','citrouill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3819,'remplacera','','RMPL RMPL','remplac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3820,'essayer','','ASR ASR','essai');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3821,'passerait','','PSRT PSRT','pass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3822,'attaquaient','','ATKN ATKN','attaqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3823,'rassembler','','RSMP RSMP','rassembl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3824,'musees','','MSS MSS','muse');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3825,'jeu','','J A','jeu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3826,'musee','','MS MS','muse');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3827,'pekin','','PKN PKN','pekin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3828,'as','','AS AS','as');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3829,'goutes','','KTS KTS','gout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3830,'gratins','','KRTN KRTN','gratin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3831,'pizzas','','PSS PTSS','pizz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3832,'gaufres','','KFRS KFRS','gaufr');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3833,'tes','','TS TS','te');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3834,'papilles','','PPLS PPLS','papill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3835,'adoreront','','ATRR ATRR','ador');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3836,'concoctes','','KNKK KNKK','concoct');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3837,'specialement','','SPSL SPXL','special');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3838,'comprend','','KMPR KMPR','comprend');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3839,'lointaine','','LNTN LNTN','lointain');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3840,'passablement','','PSPL PSPL','passabl');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3841,'balade','','PLT PLT','balad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3842,'juches','','JXS AKS','juch');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3843,'carapace','','KRPS KRPS','carapac');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3844,'oui','','A A','oui');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3845,'ankh','','ANK ANK','ankh');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3846,'morpork','','MRPR MRPR','morpork');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3847,'croyaient','','KRNT KRNT','croi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3848,'deuxfleurs','','TKSF TKSF','deuxfleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3849,'avait','','AFT AFT','avait');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3850,'air','','AR AR','air');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3851,'tellement','','TLMN TLMN','tel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3852,'inoffensif','','ANFN ANFN','inoffens');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3853,'bonhomme','','PNM PNM','bonhomm');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3854,'chetif','','XTF XTF','chetif');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3855,'fidelement','','FTLM FTLM','fidel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3856,'escorte','','ASKR ASKR','escort');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3857,'bagage','','PKJ PKK','bagag');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3858,'magique','','MJK MKK','magiqu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3859,'deambulant','','TMPL TMPL','deambul');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3860,'myriade','','MRT MRT','myriad');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3861,'petites','','PTTS PTTS','petit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3862,'jambes','','JMPS AMPS','jamb');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3863,'patricien','','PTRS PTRX','patricien');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3864,'calamiteux','','KLMT KLMT','calamit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3865,'sorcier','','SRS SRXR','sorci');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3866,'quadrillee','','KTRL KTRL','quadrille');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3867,'guilde','','KLT KLT','guild');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3868,'voleurs','','FLRS FLRS','voleur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3869,'assassins','','ASSN ASSN','assassin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3870,'perilleuse','','PRLS PRLS','perill');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3871,'devait','','TFT TFT','dev');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3872,'conduire','','KNTR KNTR','conduir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3873,'loin','','LN LN','loin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3874,'caverne','','KFRN KFRN','cavern');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3875,'dragons','','TRKN TRKN','dragon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3876,'rebord','','RPRT RPRT','rebord');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3877,'redoutable','','RTTP RTTP','redout');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3878,'touriste','','TRST TRST','tourist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3879,'lumiere','','LMR LMR','lumier');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3880,'octarine','','AKTR AKTR','octarin');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3881,'cocasse','','KKS KKS','coc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3882,'octogenaire','','AKTJ AKTK','octogenair');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3883,'borgne','','PRN PRKN','borgn');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3884,'edente','','ATNT ATNT','edent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3885,'cohen','','KHN KHN','cohen');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3886,'barbare','','PRPR PRPR','barbar');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3887,'reussira','','RSR RSR','reuss');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3888,'tirer','','TRR TRR','tir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3889,'griffes','','KRFS KRFS','griff');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3890,'poursuivants','','PRSF PRSF','poursuiv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3891,'question','','KSXN KSXN','question');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3892,'tissu','','TS TS','tissu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3893,'passer','','PSR PSR','pass');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3894,'essoreuse','','ASRS ASRS','essor');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3895,'etoile','','ATL ATL','etoil');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3896,'percuter','','PRKT PRKT','percut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3897,'survie','','SRF SRF','surv');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3898,'brumeux','','PRMK PRMK','brumeux');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3899,'tapit','','TPT TPT','tapit');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3900,'effet','','AFT AFT','effet');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3901,'epopee','','APP APP','epope');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3902,'demente','','TMNT TMNT','dement');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3903,'seconds','','SKNT SKNT','second');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3904,'roles','','RLS RLS','rol');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3905,'distribution','','TSTR TSTR','distribu');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3906,'prestigieuse','','PRST PRST','prestigi');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3907,'octavo','','AKTF AKTF','octavo');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3908,'herrena','','HRN HRN','herren');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3909,'harpie','','HRP HRP','harp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3910,'kwartz','','KRTS KRTS','kwartz');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3911,'troll','','TRL TRL','troll');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3912,'trymon','','TRMN TRMN','trymon');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3913,'enchanteur','','ANXN ANKN','enchanteur');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3914,'malefique','','MLFK MLFK','malef');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3915,'naturellement','','NTRL NTRL','naturel');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3916,'1978','','','1978');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3917,'abidjan','','APTJ APTJ','abidjan');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3918,'sent','','SNT SNT','sent');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3919,'debut','','TPT TPT','debut');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3920,'vacances','','FKNS FKNS','vacanc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3921,'gater','','KTR KTR','gat');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3922,'douce','','TS TS','douc');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3923,'equipes','','AKPS AKPS','equip');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3924,'obligatoire','','APLK APLK','obligatoir');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3925,'avaient','','AFNT AFNT','avaient');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3926,'choisir','','XSR XSR','chois');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3927,'camp','','KMP KMP','camp');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3928,'preoccupaient','','PRKP PRKP','preoccup');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3929,'courante','','KRNT KRNT','cour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3930,'amours','','AMRS AMRS','amour');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3931,'raconter','','RKNT RKNT','racont');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3932,'subsiste','','SPSS SPSS','subsist');
INSERT INTO words (id_word, word, lang, double_metaphone, stem) VALUES (3933,'continue','','KNTN KNTN','continu');
/*!40000 ALTER TABLE words ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `z_attr`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE z_attr (
  attr_bib_id int(6) unsigned NOT NULL DEFAULT '0',
  attr_libelle varchar(250) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  attr_attr varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  PRIMARY KEY (attr_bib_id,attr_libelle)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `z_attr`
--

LOCK TABLES z_attr WRITE;
/*!40000 ALTER TABLE z_attr DISABLE KEYS */;
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (2,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (2,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (2,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (2,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (3,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (3,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (3,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (3,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (5,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (5,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (5,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (5,'auteur','1004');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (7,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (7,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (7,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (7,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (8,'mots','1016');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (8,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (8,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (8,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (8,'auteur','1');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (10,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (10,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (10,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (10,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (11,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (11,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (11,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (11,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (12,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (12,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (12,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (12,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (15,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (15,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (15,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (15,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (17,'titre','4');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (17,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (17,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (17,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (21,'sujet','21');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (21,'auteur','1003');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (21,'isbn','7');
INSERT INTO z_attr (attr_bib_id, attr_libelle, attr_attr) VALUES (21,'titre','4');
/*!40000 ALTER TABLE z_attr ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `z_bib`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE z_bib (
  bib_id int(6) unsigned NOT NULL AUTO_INCREMENT,
  bib_nom varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  search_type varchar(20) COLLATE utf8_unicode_ci DEFAULT NULL,
  url varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  `port` varchar(6) COLLATE utf8_unicode_ci DEFAULT NULL,
  base varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  format varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  auth_user varchar(250) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  auth_pass varchar(250) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  sutrs_lang varchar(10) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  fichier_func varchar(255) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (bib_id)
) ENGINE=MyISAM AUTO_INCREMENT=22 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `z_bib`
--

LOCK TABLES z_bib WRITE;
/*!40000 ALTER TABLE z_bib DISABLE KEYS */;
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (2,'ENS Cachan','CATALOG','138.231.48.2','21210','ADVANCE','unimarc','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (3,'BN France','CATALOG','z3950.bnf.fr','2211','TOUT-UTF8','UNIMARC','Z3950','Z3950_BNF','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (5,'Univ Lyon 2 SCD','CATALOG','scdinf.univ-lyon2.fr','21210','ouvrages','unimarc','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (7,'Univ Oxford','CATALOG','library.ox.ac.uk','210','ADVANCE','usmarc','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (8,'Univ Valenciennes','CATALOG','195.221.187.151','210','INNOPAC','UNIMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (10,'Univ Laval (QC)','CATALOG','ariane2.ulaval.ca','2200','UNICORN','USMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (11,'Univ Lib Edinburgh','CATALOG','catalogue.lib.ed.ac.uk','7090','voyager','USMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (12,'Library Of Congress','CATALOG','z3950.loc.gov','7090','Voyager','USMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (15,'ENS Paris','CATALOG','halley.ens.fr','210','INNOPAC','UNIMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (17,'Polytechnique Montréal','CATALOG','advance.biblio.polymtl.ca','210','ADVANCE','USMARC','','','','');
INSERT INTO z_bib (bib_id, bib_nom, search_type, url, port, base, format, auth_user, auth_pass, sutrs_lang, fichier_func) VALUES (21,'SUDOC','CATALOG','carmin.sudoc.abes.fr','210','ABES-Z39-PUBLIC','UNIMARC','','','','');
/*!40000 ALTER TABLE z_bib ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `z_notices`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE z_notices (
  znotices_id int(11) unsigned NOT NULL AUTO_INCREMENT,
  znotices_query_id int(11) DEFAULT NULL,
  znotices_bib_id int(6) unsigned DEFAULT '0',
  isbd mediumtext COLLATE utf8_unicode_ci,
  isbn varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  titre varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  auteur varchar(250) COLLATE utf8_unicode_ci DEFAULT NULL,
  z_marc longblob NOT NULL,
  PRIMARY KEY (znotices_id),
  KEY idx_z_notices_idq (znotices_query_id),
  KEY idx_z_notices_isbn (isbn),
  KEY idx_z_notices_titre (titre),
  KEY idx_z_notices_auteur (auteur)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `z_notices`
--

LOCK TABLES z_notices WRITE;
/*!40000 ALTER TABLE z_notices DISABLE KEYS */;
/*!40000 ALTER TABLE z_notices ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `z_query`
--

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE z_query (
  zquery_id int(11) unsigned NOT NULL AUTO_INCREMENT,
  search_attr varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  zquery_date timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (zquery_id),
  KEY zquery_date (zquery_date)
) ENGINE=MyISAM AUTO_INCREMENT=23 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `z_query`
--

LOCK TABLES z_query WRITE;
/*!40000 ALTER TABLE z_query DISABLE KEYS */;
INSERT INTO z_query (zquery_id, search_attr, zquery_date) VALUES (22,'crit1=isbn&val1=978-2-212-11990-9&bool1=ET&crit2=auteur&val2=','2012-11-20 12:26:06');
INSERT INTO z_query (zquery_id, search_attr, zquery_date) VALUES (21,'crit1=isbn&val1=ISBN 978-2-212-11990-9&bool1=ET&crit2=auteur&val2=','2012-11-20 12:25:29');
INSERT INTO z_query (zquery_id, search_attr, zquery_date) VALUES (20,'crit1=titre&val1=\\&bool1=&crit2=&val2=','2012-11-20 11:29:39');
INSERT INTO z_query (zquery_id, search_attr, zquery_date) VALUES (19,'crit1=titre&val1=don quichotte&bool1=ET&crit2=auteur&val2=cervantes','2012-11-20 11:28:55');
/*!40000 ALTER TABLE z_query ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2016-03-29 17:10:36
